(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1005779,      22717]*)
(*NotebookOutlinePosition[   1022989,      23203]*)
(*  CellTagsIndexPosition[   1022835,      23194]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Time\[Hyphen]Domain Response", "Section",
  CellTags->"4.0"],

Cell[TextData[{
  StyleBox["Control System Professional", "TI"],
  " provides the means to analyze linear systems in both time and frequency \
domains. This chapter deals with the time dependencies of the state and \
output vectors. Refer to Chapter\[NonBreakingSpace]5 for the description of \
frequency\[Hyphen]domain analysis tools. Two approaches, ",
  StyleBox["symbolic", "TI"],
  " and ",
  StyleBox["simulation", "TI"],
  "\[Hyphen]based, are implemented and will be introduced in the following \
sections. The functions ",
  StyleBox["StateResponse", "MR"],
  " and ",
  StyleBox["OutputResponse", "MR"],
  ", which compute the state and output responses, are capable of performing \
both operations and choose their mode depending on the supplied input. ",
  StyleBox["SimulationPlot", "MR"],
  ", on the other hand, always uses the simulation approach.   "
}], "Text",
  CellTags->"4.0"],

Cell[CellGroupData[{

Cell["4.1 Symbolic Approach", "Subsection",
  CellTags->"4.1"],

Cell["For the continuous\[Hyphen]time system ", "Text",
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        OverscriptBox[
          StyleBox["\<\"x\"\>",
            "TB"], "."], \((t)\), "=", 
        StyleBox["\<\"A\"\>",
          "TB"], 
        StyleBox["\<\"x\"\>",
          "TB"], \((t)\), "+", 
        StyleBox["\<\"B\"\>",
          "TB"], 
        StyleBox["\<\"u\"\>",
          "TB"], \((t)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->"4.1"],

Cell[TextData[{
  StyleBox["StateResponse", "MR"],
  ", when supplied with the symbolic input ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"u\"\>",
            "TB"], \((t)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", attempts to find the solution "
}], "Text",
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"x\"\>",
          "TB"], \((t)\), "=", 
        SuperscriptBox["e", 
          RowBox[{\((t - t\_0)\), 
            StyleBox["\<\"A\"\>",
              "TB"]}]], 
        StyleBox["\<\"x\"\>",
          "TB"], \((t\_0)\), "+", \(\[Integral]\_t\_0\%t\), 
        SuperscriptBox["e", 
          RowBox[{\((t - \[Tau])\), 
            StyleBox["\<\"A\"\>",
              "TB"]}]], 
        StyleBox["\<\"B\"\>",
          "TB"], \((\[Tau])\), 
        StyleBox["\<\"u\"\>",
          "TB"], \((\[Tau])\), "\[DifferentialD]", "\[Tau]"}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->"4.1"],

Cell[TextData[{
  "The first term in this equation represents the ",
  StyleBox["zero\[Hyphen]input", "TI"],
  " response (also called the free, natural, unforced, or homogeneous \
response) and the second is the ",
  StyleBox["zero\[Hyphen]state", "TI"],
  " (or particular, forced) response. Once the state response ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"x\"\>",
            "TB"], \((t)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " is found, the output response ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"y\"\>",
            "TB"], \((t)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " can computed directly from the equation "
}], "Text",
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"y\"\>",
          "TB"], \((t)\), "=", 
        StyleBox["\<\"C\"\>",
          "TB"], \((t)\), 
        StyleBox["\<\"x\"\>",
          "TB"], \((t)\), "+", 
        StyleBox["\<\"D\"\>",
          "TB"], \((t)\), 
        StyleBox["\<\"u\"\>",
          "TB"], \((t)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->"4.1"],

Cell[TextData[{
  StyleBox["OutputResponse", "MR"],
  ", therefore, calls ",
  StyleBox["StateResponse", "MR"],
  " first and then proceeds according to the above equation. The preceding \
solution is valid for constant\[Hyphen]coefficient matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", whereas matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " may be time dependent.  \nThe state response for the \
discrete\[Hyphen]time system "
}], "Text",
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"x\"\>",
          "TB"], \((k + 1)\), "=", 
        StyleBox["\<\"A\"\>",
          "TB"], 
        StyleBox["\<\"x\"\>",
          "TB"], \((k)\), "+", 
        StyleBox["\<\"B\"\>",
          "TB"], 
        StyleBox["\<\"u\"\>",
          "TB"], \((k)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->"4.1"],

Cell["is computed according to ", "Text",
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"x\"\>",
          "TB"], \((k)\), "=", 
        SuperscriptBox[
          StyleBox["\<\"A\"\>",
            "TB"], "k"], 
        StyleBox["\<\"x\"\>",
          "TB"], \((0)\), "+", \(\[Sum]\_\(j = 1\)\%k\), 
        SuperscriptBox[
          StyleBox["\<\"A\"\>",
            "TB"], \(k - j\)], 
        StyleBox["\<\"B\"\>",
          "TB"], \((j - 1)\), 
        StyleBox["\<\"u\"\>",
          "TB"], \((j - 1)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->"4.1"],

Cell["and the output response is found by ", "Text",
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"y\"\>",
          "TB"], \((k)\), "=", 
        StyleBox["\<\"C\"\>",
          "TB"], 
        StyleBox["\<\"x\"\>",
          "TB"], \((k)\), "+", 
        StyleBox["\<\"D\"\>",
          "TB"], 
        StyleBox["\<\"u\"\>",
          "TB"], \((k)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->"4.1"],

Cell[TextData[{
  "Again, matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " may be time dependent, but matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " may not. "
}], "Text",
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["StateResponse",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["u",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["var",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["compute",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["state",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["response",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["input",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["signals",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["u",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["given",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["as",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["functions",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["time",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["variable",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["var",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["OutputResponse",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["u",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["var",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["compute",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["output",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["response",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["input",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["signals",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["u",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["given",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["as",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["functions",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["time",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["variable",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["var",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["OutputResponse",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["c",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["d",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["x",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["u",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              RowBox[{
                StyleBox["compute",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["the",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["output",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["response",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["given",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["the",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["system",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["matrices",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["c",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["and",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["d",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}], 
              StyleBox[",",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["state",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["response",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["x",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}], 
              StyleBox[",",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["and",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["input",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["u",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["OutputResponse",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["c",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["x",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["compute",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["output",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["response",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["assuming",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["d",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["is",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["zero",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"4.1"],

Cell["State and output responses to an input function. ", "Caption",
  CellTags->"4.1"],

Cell[TextData[{
  "For both functions, the input system can be supplied in either state\
\[Hyphen]space or transfer function form; however, the computation is always \
carried out in the state\[Hyphen]space form and the transfer functions are \
converted to state\[Hyphen]space form first. Because matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " are not needed to compute the state response, their presence in the input \
system for ",
  StyleBox["StateResponse", "MR"],
  " is optional. "
}], "Text",
  CellTags->"4.1"],

Cell["Load the application. ", "MathCaption",
  CellTags->"4.1"],

Cell["<<ControlSystems`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"4.1"],

Cell["Consider a transfer function with a simple pole. ", "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["TransferFunction[s, 1/(s+1)]", "Input",
  CellLabel->"In[2]:=",
  CellTags->"4.1"],

Cell[BoxData[
    \(TransferFunction[s, {{1\/\(1 + s\)}}]\)], "Output",
  CellLabel->"Out[2]=",
  CellTags->"4.1"]
}, Open  ]],

Cell[TextData[{
  "This finds the output response to the sinusoidal input function ",
  Cell[BoxData[
      \(TraditionalForm\`sin(10  t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ". We can see that the first exponential term (the natural response) will \
vanish, leaving only the harmonic (forced) signal in the output. "
}], "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["OutputResponse[%, Sin[10 t], t]", "Input",
  CellLabel->"In[3]:=",
  CellTags->"4.1"],

Cell[BoxData[
    \({\(10\ E\^\(-t\)\)\/101 + 
        1\/101\ \((\(-10\)\ Cos[10\ t] + Sin[10\ t])\)}\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->"4.1"]
}, Open  ]],

Cell[TextData[{
  "The built\[Hyphen]in ",
  StyleBox["Mathematica", "TI"],
  " function ",
  StyleBox["Plot", "MR"],
  " plots the result on some time interval. "
}], "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["Plot[%, {t, 0, 10}]", "Input",
  CellLabel->"In[4]:=",
  CellTags->"4.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.229731 2.16194 [
[.21429 .21723 -3 -9 ]
[.21429 .21723 3 0 ]
[.40476 .21723 -3 -9 ]
[.40476 .21723 3 0 ]
[.59524 .21723 -3 -9 ]
[.59524 .21723 3 0 ]
[.78571 .21723 -3 -9 ]
[.78571 .21723 3 0 ]
[.97619 .21723 -6 -9 ]
[.97619 .21723 6 0 ]
[.01131 .01354 -24 -4.5 ]
[.01131 .01354 0 4.5 ]
[.01131 .12163 -30 -4.5 ]
[.01131 .12163 0 4.5 ]
[.01131 .33783 -24 -4.5 ]
[.01131 .33783 0 4.5 ]
[.01131 .44593 -18 -4.5 ]
[.01131 .44593 0 4.5 ]
[.01131 .55402 -24 -4.5 ]
[.01131 .55402 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .22973 m
.21429 .23598 L
s
[(2)] .21429 .21723 0 1 Mshowa
.40476 .22973 m
.40476 .23598 L
s
[(4)] .40476 .21723 0 1 Mshowa
.59524 .22973 m
.59524 .23598 L
s
[(6)] .59524 .21723 0 1 Mshowa
.78571 .22973 m
.78571 .23598 L
s
[(8)] .78571 .21723 0 1 Mshowa
.97619 .22973 m
.97619 .23598 L
s
[(10)] .97619 .21723 0 1 Mshowa
.125 Mabswid
.07143 .22973 m
.07143 .23348 L
s
.11905 .22973 m
.11905 .23348 L
s
.16667 .22973 m
.16667 .23348 L
s
.2619 .22973 m
.2619 .23348 L
s
.30952 .22973 m
.30952 .23348 L
s
.35714 .22973 m
.35714 .23348 L
s
.45238 .22973 m
.45238 .23348 L
s
.5 .22973 m
.5 .23348 L
s
.54762 .22973 m
.54762 .23348 L
s
.64286 .22973 m
.64286 .23348 L
s
.69048 .22973 m
.69048 .23348 L
s
.7381 .22973 m
.7381 .23348 L
s
.83333 .22973 m
.83333 .23348 L
s
.88095 .22973 m
.88095 .23348 L
s
.92857 .22973 m
.92857 .23348 L
s
.25 Mabswid
0 .22973 m
1 .22973 L
s
.02381 .01354 m
.03006 .01354 L
s
[(-0.1)] .01131 .01354 1 0 Mshowa
.02381 .12163 m
.03006 .12163 L
s
[(-0.05)] .01131 .12163 1 0 Mshowa
.02381 .33783 m
.03006 .33783 L
s
[(0.05)] .01131 .33783 1 0 Mshowa
.02381 .44593 m
.03006 .44593 L
s
[(0.1)] .01131 .44593 1 0 Mshowa
.02381 .55402 m
.03006 .55402 L
s
[(0.15)] .01131 .55402 1 0 Mshowa
.125 Mabswid
.02381 .03516 m
.02756 .03516 L
s
.02381 .05678 m
.02756 .05678 L
s
.02381 .07839 m
.02756 .07839 L
s
.02381 .10001 m
.02756 .10001 L
s
.02381 .14325 m
.02756 .14325 L
s
.02381 .16487 m
.02756 .16487 L
s
.02381 .18649 m
.02756 .18649 L
s
.02381 .20811 m
.02756 .20811 L
s
.02381 .25135 m
.02756 .25135 L
s
.02381 .27297 m
.02756 .27297 L
s
.02381 .29459 m
.02756 .29459 L
s
.02381 .31621 m
.02756 .31621 L
s
.02381 .35945 m
.02756 .35945 L
s
.02381 .38107 m
.02756 .38107 L
s
.02381 .40269 m
.02756 .40269 L
s
.02381 .42431 m
.02756 .42431 L
s
.02381 .46754 m
.02756 .46754 L
s
.02381 .48916 m
.02756 .48916 L
s
.02381 .51078 m
.02756 .51078 L
s
.02381 .5324 m
.02756 .5324 L
s
.02381 .57564 m
.02756 .57564 L
s
.02381 .59726 m
.02756 .59726 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .22973 m
.02499 .23137 L
.02605 .23566 L
.02729 .24383 L
.02846 .25455 L
.03053 .28018 L
.03279 .31603 L
.04262 .50926 L
.0452 .55124 L
.04762 .58076 L
.04884 .59127 L
.05015 .59902 L
.05089 .60171 L
.0516 .60308 L
.05223 .60332 L
.05293 .6025 L
.05418 .59814 L
.05532 .59104 L
.05663 .5792 L
.05786 .56465 L
.06006 .53124 L
.06244 .48595 L
.07312 .2422 L
.07571 .19413 L
.07714 .17255 L
.07849 .15584 L
.07925 .14812 L
.08009 .14121 L
.08084 .1363 L
.08154 .13295 L
.0822 .13086 L
.08292 .12974 L
.08368 .1299 L
.08439 .1313 L
.08557 .13621 L
.08686 .1452 L
.08821 .15842 L
.08946 .17397 L
.09411 .25362 L
.09956 .36889 L
.10458 .4643 L
.10703 .49821 L
.10827 .51097 L
.10897 .51676 L
.10963 .52126 L
.11034 .52501 L
.11099 .52741 L
.11169 .5289 L
.11246 .52921 L
.11312 .52836 L
Mistroke
.11383 .5263 L
.1151 .51966 L
.11639 .50915 L
.11779 .49373 L
.12032 .45606 L
.12504 .36044 L
.12968 .25305 L
.13224 .19722 L
.13466 .15104 L
.13691 .11644 L
.13818 .10121 L
.13935 .09019 L
.14034 .08331 L
.14142 .07834 L
.14256 .07613 L
.14363 .07684 L
.14479 .08069 L
.14602 .08814 L
.14707 .09715 L
.14821 .10965 L
.15078 .14659 L
.15316 .19001 L
.15863 .30722 L
.1636 .40766 L
.16612 .447 L
.16754 .46414 L
.16885 .47627 L
.17 .48382 L
.17126 .48865 L
.17257 .48973 L
.1738 .48704 L
.17447 .48406 L
.17521 .47962 L
.17654 .46842 L
.17785 .45384 L
.17905 .43733 L
.18468 .33029 L
.18905 .23092 L
.19365 .13486 L
.19606 .0954 L
.19733 .07876 L
.19869 .06466 L
.19995 .05526 L
.20109 .04986 L
.20224 .04751 L
.20332 .04816 L
.20461 .05254 L
.20526 .0562 L
.20597 .06133 L
.20723 .07313 L
Mistroke
.20841 .08717 L
.21108 .1282 L
.21394 .18361 L
.21877 .28952 L
.22391 .3929 L
.22533 .4156 L
.22667 .43375 L
.22797 .44806 L
.22916 .45805 L
.2303 .46461 L
.2315 .46827 L
.23271 .46853 L
.23339 .46715 L
.23403 .46486 L
.23472 .46135 L
.23546 .45631 L
.23682 .44398 L
.23814 .42826 L
.23936 .41072 L
.24506 .29985 L
.25009 .18658 L
.25481 .09543 L
.25718 .06251 L
.25851 .04893 L
.25973 .03989 L
.26099 .03413 L
.26171 .03252 L
.26238 .03212 L
.26308 .03284 L
.26372 .03452 L
.26446 .03764 L
.26516 .04175 L
.274 .17468 L
.27887 .28239 L
.28349 .37608 L
.2861 .4166 L
.28757 .43397 L
.28827 .44068 L
.28893 .44601 L
.2902 .45345 L
.29134 .457 L
.29258 .45736 L
.29327 .45598 L
.29391 .45372 L
.29508 .44711 L
.29617 .43816 L
.29736 .42539 L
.29865 .40852 L
.30365 .3174 L
.30855 .20794 L
Mistroke
.31113 .15188 L
.31387 .09957 L
.31626 .06321 L
.31762 .04735 L
.31889 .03604 L
.32006 .02887 L
.32113 .02507 L
.32236 .02403 L
.32354 .02639 L
.32486 .0329 L
.3256 .03828 L
.32627 .0442 L
.3288 .07503 L
.33176 .1254 L
.33456 .18288 L
.33934 .28931 L
.34187 .34216 L
.34458 .39056 L
.34594 .41028 L
.34722 .42574 L
.34838 .43672 L
.34963 .44533 L
.35082 .45016 L
.35208 .45166 L
.35315 .44996 L
.35434 .44493 L
.35499 .4408 L
.35568 .43542 L
.3569 .42326 L
.35966 .38493 L
.36465 .28687 L
.36963 .17546 L
.37207 .12483 L
.37433 .08448 L
.37638 .05506 L
.37742 .04316 L
.37855 .03296 L
.37967 .02557 L
.38073 .02129 L
.38198 .0196 L
.38312 .0213 L
.38434 .02647 L
.38546 .03429 L
.3867 .04609 L
.38801 .06213 L
.39266 .14239 L
.39791 .25768 L
.40049 .31381 L
.40285 .36037 L
.40506 .39686 L
Mistroke
.40623 .41275 L
.40749 .42677 L
.40875 .4375 L
.40992 .4443 L
.41061 .44681 L
.41127 .44815 L
.41249 .44793 L
.41354 .44491 L
.41466 .43886 L
.41562 .43145 L
.41667 .42098 L
.41902 .38964 L
.42122 .35162 L
.43107 .13904 L
.43346 .09372 L
.43602 .05506 L
.43749 .03844 L
.43883 .02734 L
.43947 .02342 L
.44017 .02024 L
.44143 .01739 L
.44258 .01809 L
.44366 .02159 L
.44485 .02852 L
.44612 .03946 L
.44744 .05457 L
.4487 .0721 L
.45107 .11224 L
.45995 .30384 L
.46215 .34831 L
.46452 .3893 L
.46588 .40851 L
.46713 .42299 L
.46832 .43378 L
.46958 .44172 L
.4708 .44594 L
.47211 .44655 L
.47334 .44341 L
.47447 .43746 L
.47579 .42682 L
.47722 .41105 L
.47982 .37236 L
.48933 .171 L
.49171 .12169 L
.49398 .08112 L
.49601 .05185 L
.49718 .03869 L
.49823 .02924 L
.49937 .02181 L
.50059 .0172 L
Mistroke
.50172 .01605 L
.50278 .01772 L
.504 .02293 L
.50513 .03077 L
.50637 .04258 L
.50767 .05851 L
.51024 .09886 L
.51263 .1452 L
.51807 .26543 L
.52057 .31926 L
.52329 .37084 L
.52453 .39091 L
.52585 .40923 L
.52699 .42231 L
.52822 .43333 L
.52895 .43827 L
.52962 .44174 L
.53093 .44551 L
.53163 .44587 L
.53238 .44495 L
.53318 .44254 L
.53392 .43897 L
.53523 .42955 L
.53643 .4177 L
.5391 .38078 L
.54843 .18646 L
.55089 .13416 L
.55353 .08518 L
.5548 .06525 L
.55602 .04908 L
.55712 .03694 L
.5583 .02686 L
.55957 .0194 L
.56076 .01588 L
.56149 .01537 L
.56217 .01603 L
.56345 .02022 L
.56414 .02407 L
.56487 .0293 L
.56617 .04159 L
.56758 .05876 L
.56912 .08185 L
.57909 .29087 L
.58162 .34276 L
.58435 .39014 L
.58561 .40767 L
.58694 .4229 L
.58808 .43293 L
.58933 .44065 L
.59054 .44465 L
Mistroke
.59165 .44529 L
.59292 .44242 L
.59414 .43616 L
.59526 .42744 L
.59629 .41691 L
.59865 .38506 L
.60382 .28553 L
.60942 .1609 L
.61199 .10909 L
.61471 .06392 L
.61583 .04906 L
.61703 .03589 L
.61835 .025 L
.61958 .01836 L
.62024 .01624 L
.62095 .01513 L
.62221 .01609 L
.62292 .01826 L
.62358 .02134 L
.6243 .02588 L
.62508 .0321 L
.62641 .04567 L
.6278 .06381 L
.6303 .10485 L
.63537 .21083 L
.64008 .31494 L
.64229 .35807 L
.64437 .39256 L
.64553 .40838 L
.64678 .4226 L
.64791 .43264 L
.64896 .43936 L
.65012 .44383 L
.65121 .44515 L
.6524 .44337 L
.65368 .43775 L
.65432 .43352 L
.65502 .42785 L
.6563 .41483 L
.65868 .38172 L
.66883 .17005 L
.67125 .12003 L
.6738 .07494 L
.67598 .04512 L
.67722 .03241 L
.67838 .02356 L
.67906 .01972 L
.67971 .0171 L
.68093 .01486 L
.68224 .01637 L
Mistroke
.68298 .01901 L
.68367 .02259 L
.68498 .03248 L
.68644 .04776 L
.68938 .0912 L
.69453 .19552 L
.69936 .30292 L
.70163 .34872 L
.70406 .39011 L
.70546 .40936 L
.70672 .42352 L
.708 .43429 L
.7092 .44111 L
.71046 .44464 L
.71109 .445 L
.71179 .4443 L
.71302 .44027 L
.71417 .43331 L
.71487 .42765 L
.71553 .4213 L
.71677 .40693 L
.71956 .36413 L
.72928 .15682 L
.73351 .07698 L
.73466 .05974 L
.73589 .0443 L
.73694 .03339 L
.73807 .0244 L
.7393 .01791 L
.74044 .01502 L
.74114 .01477 L
.7418 .0156 L
.74303 .0199 L
.7442 .02718 L
.74527 .03658 L
.7477 .06665 L
.75006 .1061 L
.75267 .15824 L
.75794 .27553 L
.76252 .36755 L
.76383 .38903 L
.76509 .40664 L
.76623 .41999 L
.76744 .43123 L
.7686 .43891 L
.76965 .4432 L
.7707 .44491 L
.7717 .4441 L
.77286 .4402 L
.77393 .43385 L
Mistroke
.7751 .42392 L
.77634 .41022 L
.77889 .37288 L
.7813 .32808 L
.78582 .22978 L
.7911 .1166 L
.79342 .07581 L
.79465 .05771 L
.79598 .04142 L
.79712 .03032 L
.79817 .02267 L
.79918 .0177 L
.80024 .01502 L
.80135 .01506 L
.8024 .01776 L
.80354 .02364 L
.80476 .03318 L
.80599 .04613 L
.80733 .06363 L
.80976 .1035 L
.81431 .19766 L
.81887 .2993 L
.82139 .35001 L
.82377 .3905 L
.82512 .40901 L
.82658 .42513 L
.82723 .43078 L
.82792 .43578 L
.82915 .44207 L
.82981 .44395 L
.83051 .44486 L
.83179 .44348 L
.83304 .43844 L
.83418 .43065 L
.8354 .41917 L
.83671 .40343 L
.83907 .36705 L
.84442 .25762 L
.85004 .13432 L
.8525 .08811 L
.85381 .06724 L
.85523 .04822 L
.85656 .0339 L
.85778 .02414 L
.85895 .01795 L
.86017 .01488 L
.86147 .01551 L
.86268 .01967 L
.86338 .0236 L
.86401 .02812 L
Mistroke
.86542 .04144 L
.86685 .05904 L
.86816 .07864 L
.87113 .1328 L
.8765 .25059 L
.87894 .30417 L
.88156 .35616 L
.88399 .39595 L
.88518 .41173 L
.88629 .4238 L
.88752 .43417 L
.88817 .43827 L
.88886 .44156 L
.88998 .44451 L
.89122 .44433 L
.89192 .44262 L
.89256 .44005 L
.89327 .43611 L
.89401 .43074 L
.89526 .41895 L
.89663 .4023 L
.89916 .36253 L
.90191 .30897 L
.90689 .19844 L
.91133 .10612 L
.91385 .06432 L
.91507 .04821 L
.91622 .03561 L
.91685 .02985 L
.91755 .02459 L
.91876 .01802 L
.91945 .01583 L
.92019 .01472 L
.9215 .01592 L
.92223 .01835 L
.92302 .02235 L
.92376 .02743 L
.92444 .03319 L
.92711 .06496 L
.92944 .10337 L
.932 .15409 L
.93716 .26882 L
.93958 .32086 L
.94222 .37066 L
.94343 .39009 L
.94471 .4079 L
.94582 .4207 L
.94702 .43159 L
.94816 .43908 L
.94922 .44327 L
Mistroke
.95023 .44484 L
.95129 .44389 L
.95245 .43978 L
.95354 .43313 L
.95473 .42281 L
.956 .40847 L
.95861 .36935 L
.96144 .31529 L
.96658 .20176 L
.97619 .03432 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0025oo`03001o
ogoo0?aoo`008Goo00<007ooOol0o7oo000AOol00`00Oomoo`02Ool00`00Oomoo`050003Ool00`00
Oomoo`3lOol0011oo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo0?aoo`002goo0`000Woo
00<007oo000027oo00<007ooOol00goo0P00NWoo00<007ooOol037oo0P003Woo00<007ooOol03Goo
00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol04goo
000@Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`1JOol00`00Oomoo`0<Ool2000>Ool0
0`00Oomoo`0<Ool2000>Ool00`00Oomoo`0<Ool2000>Ool2000=Ool2000>Ool2000=Ool2000EOol0
011oo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo04Yoo`03001oogoo00eoo`03001oogoo
00aoo`8000eoo`03001oo`0000eoo`8000eoo`03001oo`0000eoo`8000eoo`03001oo`0000eoo`80
00ioo`8000eoo`8001Eoo`004Goo00<007ooOol01Woo0P001Goo00<007ooOol0BWoo0P003Goo0P00
3Woo0P003Goo00<007oo00003Goo0P003Goo00<007oo00003Goo0P003Goo00<007oo00003Goo0P00
3Woo0P003Goo00<007oo000057oo000QOol00`00Oomoo`1:Ool2000=Ool00`00Ool0000=Ool2000=
Ool00`00Ool0000=Ool2000=Ool00`00Ool0000=Ool00`00Ool0000<Ool00`00Ool0000=Ool00`00
Ool0000<Ool00`00Ool0000=Ool00`00Ool0000DOol0025oo`8003]oo`8000eoo`03001oo`0000eo
o`03001oo`0000aoo`04001oogoo000<Ool00`00Ool0000<Ool00`00Ool0000=Ool00`00Ool0000=
Ool00`00Ool0000<Ool00`00Ool0000=Ool00`00Ool0000<Ool00`00Ool0000=Ool00`00Ool0000<
Ool00`00Oomoo`05Ool0025oo`03001oogoo03Yoo`8000eoo`03001oo`0000eoo`03001oo`0000ao
o`04001oogoo000<Ool00`00Ool0000<Ool01000Oomoo`0037oo00<007oo00003Goo00<007oo0000
37oo00<007oo000037oo00@007ooOol000aoo`04001oogoo000<Ool00`00Ool0000<Ool00`00Oomo
o`05Ool0025oo`03001oogoo03Yoo`8000eoo`03001oo`0000eoo`03001oo`0000aoo`04001oogoo
000<Ool00`00Ool0000<Ool01000Oomoo`0037oo00<007oo000037oo00@007ooOol000aoo`03001o
o`0000aoo`04001oogoo000<Ool01000Oomoo`002goo00@007ooOol000aoo`03001oogoo00Eoo`00
8Goo00<007ooOol0>Woo0P003Goo00<007oo00003Goo00<007oo000037oo00@007ooOol000]oo`04
001oogoo000<Ool01000Oomoo`0037oo00<007oo000037oo00@007ooOol000aoo`03001oo`0000ao
o`04001oogoo000<Ool01000Oomoo`002goo00@007ooOol000aoo`03001oogoo00Eoo`008Goo00<0
07ooOol0:goo00<007ooOol037oo0P003Goo00<007oo000037oo00@007ooOol000aoo`04001oogoo
000;Ool01@00Oomoogoo00002goo00@007ooOol000aoo`03001oo`0000aoo`04001oogoo000<Ool0
0`00Ool0000<Ool01000Oomoo`0037oo00@007ooOol000]oo`05001oogooOol0000;Ool00`00Oomo
o`05Ool0025oo`03001oogoo02]oo`8000eoo`8000eoo`03001oo`0000aoo`04001oogoo000<Ool0
1000Oomoo`002goo00D007ooOomoo`0000]oo`04001oogoo000<Ool00`00Ool0000<Ool01000Oomo
o`0037oo00@007ooOol000]oo`04001oogoo000<Ool01000Oomoo`002goo00D007ooOomoo`0000]o
o`03001oogoo00Eoo`008Goo0P00;7oo0P0037oo00<007oo00003Goo00<007oo000037oo00@007oo
Ool000aoo`04001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol000]oo`05001oogooOol0
000;Ool01000Oomoo`0037oo00@007ooOol000]oo`04001oogoo000<Ool01000Oomoo`002goo00D0
07ooOomoo`0000]oo`03001oogoo00Eoo`008Goo00<007ooOol0:Woo00<007oo000037oo00<007oo
00003Goo00@007ooOol000]oo`04001oogoo000<Ool01000Oomoo`002goo00D007ooOomoo`0000]o
o`04001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol000aoo`04001oogoo000;Ool01000
Oomoo`0037oo00@007ooOol000]oo`05001oogooOol0000;Ool00`00Oomoo`05Ool0025oo`03001o
ogoo02Yoo`03001oo`0000aoo`04001oogoo000<Ool01000Oomoo`002goo00@007ooOol000aoo`04
001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol000]oo`05001oogooOol0000;Ool01000
Oomoo`0037oo00@007ooOol000]oo`04001oogoo000<Ool01000Oomoo`002goo00D007ooOomoo`00
00]oo`03001oogoo00Eoo`008Goo00<007ooOol0:Woo00<007oo000037oo00@007ooOol000aoo`04
001oogoo000;Ool01000Oomoo`0037oo00@007ooOol000]oo`05001oogooOol0000;Ool01000Oomo
o`002goo00D007ooOomoo`0000]oo`04001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol0
00aoo`04001oogoo000;Ool01@00Oomoogoo00002goo00<007ooOol01Goo000QOol00`00Oomoo`0Z
Ool00`00Ool0000<Ool01000Oomoo`0037oo00@007ooOol000]oo`04001oogoo000<Ool01000Oomo
o`002goo00D007ooOomoo`0000]oo`04001oogoo000;Ool01@00Oomoogoo00002goo00D007ooOomo
o`0000Yoo`05001oogooOol0000;Ool01000Oomoo`0037oo00@007ooOol000]oo`05001oogooOol0
000;Ool00`00Oomoo`05Ool0025oo`03001oogoo01aoo`03001oogoo00]oo`03001oo`0000aoo`04
001oogoo000<Ool01000Oomoo`002goo00@007ooOol000]oo`05001oogooOol0000;Ool01@00Oomo
ogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D0
07ooOomoo`0000]oo`04001oogoo000<Ool01000Oomoo`002goo00D007ooOomoo`0000Yoo`03001o
ogoo00Ioo`008Goo0P0077oo0P003Goo00@007ooOol000]oo`04001oogoo000<Ool01000Oomoo`00
2goo00@007ooOol000]oo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`00
00]oo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`04001oogoo
000;Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`03001oogoo00Ioo`008Goo00<007oo
Ool06goo00<007oo000037oo00@007ooOol000]oo`04001oogoo000;Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`00
00]oo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogoo
Ool0000:Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`03001oogoo00Ioo`008Goo00<0
07ooOol06goo00<007oo000037oo00@007ooOol000]oo`04001oogoo000;Ool01@00Oomoogoo0000
2goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomo
o`0000]oo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol0
27oo00D007ooOomoo`0000Yoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool0
0`00Oomoo`06Ool0025oo`03001oogoo01]oo`03001oo`0000aoo`04001oogoo000;Ool01000Oomo
o`002goo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08
Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool01@00Oomoogoo
00002Woo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`05001oogooOol0000:
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0025oo`03001oogoo01]oo`03001o
o`0000aoo`04001oogoo000;Ool01000Oomoo`002goo00D007ooOomoo`0000]oo`05001oogooOol0
000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]o
o`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00D0
07ooOomoo`0000Yoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`06Ool0025oo`8001]oo`04001oogoo000<Ool01000Oomoo`002goo00@007ooOol000]oo`05001o
ogooOol0000;Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00D007ooOomo
o`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol0
27oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00D007ooOomo
o`0000Yoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Ioo`008Goo00<007ooOol06Woo
00@007ooOol000aoo`04001oogoo000;Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0
27oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00Qoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol0
27oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00D007ooOomo
o`0000Yoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Ioo`008Goo00<007ooOol06Woo
00@007ooOol000aoo`04001oogoo000;Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol027oo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool00`00Oomoo`02Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0
025oo`03001oogoo01Yoo`04001oogoo000<Ool01000Oomoo`002goo00D007ooOomoo`0000Yoo`03
001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000;Ool01@00Oomoogoo
00002Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol01Woo000<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`0JOol01000Oomoo`002goo00D007ooOomoo`0000]oo`05001oogoo
Ool0000:Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
009oo`03001oogoo00Qoo`03001oogoo00Ioo`002goo00<007oo00001goo00<007oo00000Woo00<0
07oo000017oo00<007ooOol06Woo00@007ooOol000]oo`05001oogooOol0000;Ool01@00Oomoogoo
00002Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool027oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo00Qoo`03001oogoo00Ioo`001Woo0`000Woo00<007oo00001goo00<0
07oo000017oo00<007ooOol00Woo0P006goo00@007ooOol000]oo`05001oogooOol0000;Ool01@00
Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Ioo`002goo00<007oo00001goo00<0
07oo00000Woo0P001Goo00<007ooOol06Woo00@007ooOol000]oo`05001oogooOol0000;Ool01@00
Oomoogoo00002Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Ioo`002goo00<007oo00001goo00<0
07oo00000Woo00<007ooOol017oo00<007ooOol037oo00<007ooOol02goo00D007ooOomoo`0000Yo
o`05001oogooOol0000;Ool01@00Oomoogoo00002Goo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol01goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol01Woo000<Ool00`00Oomoo`07Ool01000Oomoogoo0`0017oo00<007ooOol037oo0P0037oo
00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Goo00<007ooOol00goo
00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo
00<007ooOol01goo00<007ooOol01Woo000QOol00`00Oomoo`0<Ool2000<Ool01@00Oomoogoo0000
2Woo00D007ooOomoo`0000]oo`05001oogooOol00009Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool0025oo`8000aoo`03001oo`0000aoo`05001oogooOol0000:Ool01@00Oomoogoo
00002Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool01Woo000QOol00`00Oomoo`0;Ool00`00Ool0000<Ool01@00Oomoogoo00002Woo00D007ooOomo
o`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00Ioo`008Goo00<007ooOol02goo00<007oo000037oo00D007ooOomoo`0000Yoo`05001oogoo
Ool0000:Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00
Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool0025oo`03001oogoo00]oo`03001oo`0000aoo`05001oogooOol0000:Ool01@00Oomo
ogoo00002Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol01goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01goo00<0
07ooOol01Woo000QOol00`00Oomoo`0;Ool00`00Ool0000<Ool01@00Oomoogoo00002Woo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007oo
Ool01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007oo
Ool01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol017oo00<007oo
Ool01goo00<007ooOol01Woo000QOol00`00Oomoo`0;Ool00`00Ool0000<Ool01@00Oomoogoo0000
2Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0
1Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol01goo000QOol2000<Ool01000Oomoo`002goo00D007ooOomo
o`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001o
ogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`008Goo00<007ooOol02goo00@007ooOol000]o
o`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0025oo`03001oogoo00]oo`04
001oogoo000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
025oo`03001oogoo00]oo`04001oogoo000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomo
o`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool0025oo`03001oogoo00]oo`04001oogoo000:Ool00`00Oomoo`02Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool0
0`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0025oo`03001oogoo00Yoo`05001oogoo
Ool0000:Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00
Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00
Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0025o
o`8000]oo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool3
0008Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`03Ool00`00Ool000020004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool01000Oomoogoo0P000goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol017oo0P001Woo00<007oo
Ool01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo1@000Woo
00<007ooOol00goo000QOol00`00Oomoo`0:Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol00Woo0P002Goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol00goo00@007ooOol000Eoo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`07001oogooOol007oo00000Woo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol00goo00<007oo00001Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo0P000Woo00<007oo000017oo000QOol00`00Oomoo`0:Ool0
1@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0
0goo1@0017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol017oo00L007ooOomoo`00Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00006Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool20002Ool0
0`00Ool00004Ool0025oo`03001oogoo00Yoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00
Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool01000Oomoogoo0P000goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol017oo0P001Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol01Goo0P000Woo00<007oo000017oo000QOol00`00Oomoo`0:Ool01@00Oomo
ogoo00002Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo0`0027oo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo0`001Goo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Ioo`03001oogoo00Ioo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`80009oo`03001oo`0000Aoo`008Goo
0P002goo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`80009oo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Aoo`8000Ioo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`<0
00=oo`03001oogoo00=oo`008Goo00<007ooOol02Woo00D007ooOomoo`0000Yoo`03001oogoo009o
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Moo`008Goo00<007ooOol02Woo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007oo
Ool01goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01goo000QOol00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`07Ool0025oo`03001oogoo00Yoo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Moo`008Goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01goo000KOooo00060000025oo`03001oogoo00Uo
o`8000Aoo`03001oogoo00Aoo`03001oo`0000Ioo`04001oogoo0005Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool01@00Oomoogoo00000goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo
00@007ooOol000Moo`03001oo`0000Eoo`03001oogoo00=oo`8000Moo`05001oogooOol00003Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`001goo00<007oo000017oo
00<007ooOol017oo0P001goo00@007ooOol000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo009oo`04001oogoo0007Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Ool00006Ool01000
Oomoo`001goo000QOol00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000
Oomoo`001goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00@007ooOol000Moo`008Goo0P002goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol027oo000Q
Ool2000;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`08Ool0025oo`8000]oo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001o
ogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Qoo`008Goo0P002goo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool027oo000QOol2000;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`08Ool0025oo`8000]oo`03001oogoo009oo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Qoo`008Goo0P00
2goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0
17oo00<007ooOol027oo000QOol2000;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`08Ool0025oo`8000]oo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Qo
o`008Goo0P002goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol027oo000QOol2000;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`08Ool0025oo`8000Yoo`03
001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00Qoo`008Goo0P002Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol02Goo000QOol2000:Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00
Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`09Ool0025o
o`8000Yoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001o
ogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001o
ogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo00Uoo`008Goo00<007oo00002Goo00<007ooOol00goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo
00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol02Goo000QOol00`00Ool0
0009Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`09Ool0025oo`03001oo`0000Uoo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Uoo`008Goo00<007oo0000
2Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0
1Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol02Goo000QOol30009Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06
Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`09Ool0025oo`03001oo`0000Uoo`03001o
ogoo00Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001o
ogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001o
ogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001o
ogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00Uoo`008Goo00<007oo00002Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo
00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol02Goo000QOol00`00Ool00009Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`09Ool000aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03
001oo`0000Uoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo00Uoo`002goo00<007oo00001goo00<007oo00000Woo00<007oo0000
17oo00<007oo00002Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol02Goo000;Ool00`00Ool00007Ool00`00Ool00004Ool00`00
Oomoo`02Ool30009Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`08
Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03
001oogoo00Uoo`002goo00<007oo00001goo00<007oo00000Woo0P001Goo00<007oo00002Goo00<0
07ooOol017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<0
07ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo009o
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`08Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol02Goo000;Ool00`00Ool00007
Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00Ool00009Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`08Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`03001oogoo009oo`03
001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007oo
Ool00Woo00<007ooOol02Goo000<Ool00`00Oomoo`07Ool01000Oomoogoo0`0017oo00@007ooOol0
00Qoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000;Ool01@00
Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo
009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00
Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol02Goo000QOol01000Oomoo`0027oo00<007oo
Ool017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007oo
Ool00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000]oo`05001oogooOol0000:
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007oo
Ool027oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool0025oo`04001oogoo0008Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`03001oogoo
009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00
Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo
009oo`03001oogoo00Uoo`008Goo0P0000=oo`00Ool01goo00<007ooOol017oo00<007ooOol017oo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo
00<007ooOol027oo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol02Goo
000QOol01000Oomoo`001goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`03
001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000;
Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool00`00Oomoo`02
Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00D007oo
Oomoo`0000Yoo`03001oogoo009oo`03001oogoo00Uoo`008Goo00@007ooOol000Moo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`05001oogoo
Ool0000:Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo
00Qoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogoo
Ool0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007ooOol00Woo
00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Uoo`008Goo00@0
07ooOol000Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo00Qoo`05001oogooOol0000:Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`05
001oogooOol0000;Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`05001oogooOol0000;
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo
00002Woo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Uoo`008Goo00@007ooOol0
00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo
00Qoo`05001oogooOol0000:Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`05001oogoo
Ool0000;Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00
Oomoogoo00002goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo
00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Uoo`008Goo0P0000=oo`00Ool01Woo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo
00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002goo00@007ooOol000]o
o`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0
000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool01@00Oomo
ogoo00002Woo00<007ooOol00Woo00<007ooOol02Goo000QOol01000Oomoo`001goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00D007ooOomo
o`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002goo00@007ooOol000]oo`05001oogoo
Ool0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool01@00
Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000]oo`008Goo00@007ooOol000Moo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:Ool01@00Oomoogoo
00002goo00D007ooOomoo`0000]oo`04001oogoo000;Ool01@00Oomoogoo00002goo00D007ooOomo
o`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002goo00@007ooOol000]oo`05001oogoo
Ool0000;Ool01000Oomoo`002goo00D007ooOomoo`0000]oo`04001oogoo000<Ool0025oo`04001o
ogoo0007Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool01000
Oomoo`002goo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool01@00Oomoogoo00002goo00D0
07ooOomoo`0000]oo`04001oogoo000;Ool01000Oomoo`0037oo00@007ooOol000]oo`05001oogoo
Ool0000;Ool01000Oomoo`0037oo000QOol01000Oomoo`001goo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000]oo`04001o
ogoo000;Ool01@00Oomoogoo00002goo00@007ooOol000]oo`05001oogooOol0000;Ool01@00Oomo
ogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool01000Oomoo`002goo00@007oo
Ool000aoo`04001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol000aoo`008Goo00@007oo
Ool000Moo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00Qoo`05001oogooOol0000;Ool01000Oomoo`002goo00D007ooOomoo`0000]oo`04001oogoo
000<Ool01000Oomoo`002goo00@007ooOol000aoo`04001oogoo000;Ool01000Oomoo`0037oo00@0
07ooOol000]oo`04001oogoo000<Ool01000Oomoo`002goo00D007ooOomoo`0000]oo`04001oogoo
000<Ool0025oo`800003Ool007oo00Ioo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000;Ool01000Oomoo`002goo00@007oo
Ool000aoo`04001oogoo000<Ool01000Oomoo`002goo00@007ooOol000aoo`04001oogoo000;Ool0
1000Oomoo`0037oo00@007ooOol000]oo`04001oogoo000<Ool01000Oomoo`0037oo00@007ooOol0
00]oo`04001oogoo000<Ool0025oo`04001oogoo0007Ool00`00Oomoo`06Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002goo00@007ooOol0
00]oo`04001oogoo000<Ool01000Oomoo`0037oo00@007ooOol000]oo`04001oogoo000<Ool01000
Oomoo`002goo00@007ooOol000aoo`04001oogoo000;Ool01000Oomoo`0037oo00@007ooOol000ao
o`04001oogoo000;Ool01000Oomoo`0037oo000QOol01000Oomoo`001goo00<007ooOol01Woo00<0
07ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool01000Oomo
o`002goo00@007ooOol000aoo`04001oogoo000<Ool01000Oomoo`002goo00@007ooOol000aoo`04
001oogoo000;Ool01000Oomoo`0037oo00@007ooOol000]oo`04001oogoo000<Ool01000Oomoo`00
37oo00<007oo000037oo00@007ooOol000aoo`008Goo00D007ooOomoo`0000Ioo`03001oogoo00Io
o`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000;Ool01@00Oomoogoo00002goo00@0
07ooOol000]oo`04001oogoo000<Ool01000Oomoo`0037oo00@007ooOol000]oo`04001oogoo000<
Ool01000Oomoo`0037oo00<007oo000037oo00@007ooOol000aoo`03001oo`0000aoo`04001oogoo
000<Ool00`00Ool0000<Ool01000Oomoo`0037oo000QOol01@00Oomoogoo00001Woo00<007ooOol0
1Woo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool0
1000Oomoo`0037oo00<007oo000037oo00@007ooOol000aoo`03001oo`0000eoo`03001oo`0000ao
o`04001oogoo000<Ool00`00Ool0000<Ool01000Oomoo`0037oo00<007oo000037oo00@007ooOol0
00aoo`03001oo`0000aoo`04001oogoo000<Ool0025oo`80009oo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000;Ool01000Oomoo`0037oo00@0
07ooOol000aoo`03001oo`0000aoo`04001oogoo000<Ool00`00Ool0000=Ool00`00Ool0000<Ool0
0`00Ool0000=Ool00`00Ool0000<Ool01000Oomoo`0037oo00<007oo000037oo00@007ooOol000ao
o`03001oo`0000aoo`04001oogoo000<Ool0025oo`05001oogooOol00006Ool00`00Oomoo`06Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool01000Oomoo`002goo00@007ooOol000aoo`04001oogoo000<
Ool00`00Ool0000<Ool01000Oomoo`0037oo00<007oo00003Goo00<007oo000037oo00<007oo0000
3Goo00<007oo000037oo00<007oo00003Goo00<007oo000037oo00<007oo00003Goo00<007oo0000
3Goo00<007oo000037oo000QOol01@00Oomoogoo00001Woo00<007ooOol01Woo00<007ooOol00Woo
00<007ooOol02Goo00@007ooOol000]oo`04001oogoo000<Ool01000Oomoo`0037oo00<007oo0000
37oo00@007ooOol000aoo`03001oo`0000eoo`03001oo`0000aoo`03001oo`0000eoo`03001oo`00
00eoo`8000eoo`03001oo`0000eoo`8000eoo`03001oo`0000eoo`8000eoo`008Goo00D007ooOomo
o`0000Ioo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo000;Ool01000
Oomoo`0037oo00@007ooOol000aoo`03001oo`0000eoo`8000eoo`03001oo`0000eoo`8000eoo`03
001oo`0000eoo`03001oo`0000eoo`8000eoo`03001oo`0000eoo`8000eoo`03001oo`0000eoo`80
00eoo`004Goo00<007ooOol00Woo00<007ooOol01@000goo00D007ooOomoo`0000Ioo`03001oogoo
00Ioo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo000;Ool01000Oomoo`0037oo00@007oo
Ool000aoo`03001oo`0000eoo`8000ioo`8000eoo`8000ioo`8000eoo`8000ioo`8000eoo`8000io
o`8000eoo`03001oo`0000eoo`8000eoo`0047oo00<007oo000027oo00<007ooOol00goo00D007oo
Oomoo`0000Ioo`03001oogoo00Moo`05001oogooOol0000;Ool01000Oomoo`0037oo00<007oo0000
37oo00<007oo00003Goo00<007oo00003Goo0P003Woo0P003Goo0P003Woo0P003Woo00<007ooOol0
37oo0P003Woo00<007ooOol037oo0P003Woo0P003Goo0P003Goo000@Ool00`00Ool00008Ool00`00
Oomoo`03Ool20002Ool00`00Oomoo`04Ool00`00Oomoo`07Ool01@00Oomoogoo00002goo00@007oo
Ool000aoo`03001oo`0000eoo`8000eoo`03001oo`0000eoo`8000ioo`03001oogoo00eoo`03001o
ogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`8000ioo`03001oogoo00aoo`03001oogoo00eo
o`03001oogoo00eoo`03001oogoo00]oo`0047oo00<007oo000027oo00<007ooOol00goo00D007oo
Oomoo`0000Eoo`03001oogoo00Qoo`05001oogooOol0000;Ool01000Oomoo`0037oo00<007oo0000
3Goo0P003Woo00<007ooOol037oo0P00VGoo000@Ool00`00Ool00008Ool00`00Oomoo`03Ool01@00
Oomoogoo00001Goo00<007ooOol027oo00D007ooOomoo`0000]oo`04001oogoo000<Ool00`00Ool0
000=Ool2000>Ool00`00Oomoo`2WOol0015oo`03001oogoo00Ioo`8000Eoo`05001oogooOol00005
Ool00`00Oomoo`08Ool01@00Oomoogoo00002goo00@007ooOol000aoo`03001oo`0000eoo`800;Qo
o`008Goo00D007ooOomoo`0000Eoo`03001oogoo00Qoo`05001oogooOol0000;Ool00`00Ool0000=
Ool00`00Ool00037Ool0025oo`05001oogooOol00005Ool00`00Oomoo`08Ool01@00Oomoogoo0000
2goo00<007oo00003Goo0P00b7oo000QOol20002Ool00`00Oomoo`03Ool00`00Oomoo`08Ool01@00
Oomoogoo00002goo00<007oo00003Woo00<007ooOol0aWoo000QOol01@00Oomoogoo00001Goo00<0
07ooOol027oo00D007ooOomoo`0000]oo`03001oo`000=Moo`008Goo00D007ooOomoo`0000Eoo`03
001oogoo00Qoo`04001oogoo000<Ool00`00Ool0003GOol0025oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Qoo`04001oogoo000=Ool2003GOol0025oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Qoo`04001oogoo000=Ool2003GOol0025oo`8000=oo`03001oogoo009oo`03
001oogoo00Qoo`04001oogoo000=Ool2003GOol0025oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Qoo`04001oogoo003VOol0025oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00Qoo`04001oogoo003VOol0025oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Qoo`04
001oogoo003VOol0025oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Qoo`04001oogoo
003VOol0025oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Uoo`03001oo`000>Ioo`00
8Goo0P000goo00D007ooOomoo`0000aoo`03001oo`000>Ioo`008Goo00<007ooOol00Woo00D007oo
Oomoo`0000aoo`800>Moo`008Goo00<007ooOol00Woo00D007ooOomoo`0000aoo`800>Moo`008Goo
00<007ooOol00Woo00D007ooOomoo`0000aoo`800>Moo`008Goo00<007ooOol00Woo00D007ooOomo
o`0000aoo`800>Moo`008Goo00<007ooOol00Woo00D007ooOomoo`0000eoo`03001oogoo0>Eoo`00
8Goo0P000goo00D007ooOomoo`000?Eoo`008Goo00<007ooOol00Woo00D007ooOomoo`000?Eoo`00
8Goo00<007ooOol00Woo00D007ooOomoo`000?Eoo`0037oo00<007ooOol00Woo00<007ooOol01@00
0Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`000?Eoo`002goo00<007oo000027oo
00L007ooOomoo`00Ool00004Ool00`00Oomoo`02Ool01@00Oomoogoo0000mGoo000;Ool00`00Ool0
0008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20003Ool01@00Oomoogoo0000mGoo000;Ool00`00
Ool00008Ool01000Oomoogoo0P001Goo00<007ooOol00Woo00D007ooOomoo`000?Eoo`002goo00<0
07oo000027oo00D007ooOomoo`0000Ioo`03001oogoo009oo`05001oogooOol0003eOol000aoo`03
001oogoo00Ioo`8000=oo`<000Aoo`03001oogoo00=oo`04001oogoo003eOol0025oo`03001oogoo
00=oo`04001oogoo003eOol0025oo`03001oogoo00=oo`03001oo`000?Ioo`008Goo0P0017oo00<0
07oo0000mWoo000QOol00`00Oomoo`03Ool00`00Ool0003fOol0025oo`03001oogoo00=oo`03001o
o`000?Ioo`008Goo00<007ooOol00goo00<007oo0000mWoo000QOol00`00Oomoo`03Ool00`00Ool0
003fOol0025oo`8000Eoo`800?Ioo`008Goo00<007ooOol017oo0P00mWoo000QOol00`00Oomoo`04
Ool00`00Oomoo`3eOol0025oo`03001oogoo0?aoo`008Goo00<007ooOol0o7oo000QOol00`00Oomo
o`3lOol0025oo`03001oogoo0?aoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.34313, -0.121626, 
  0.0403944, 0.00177946}},
  CellTags->"4.1"]
}, Open  ]],

Cell[TextData[{
  "The zero\[Hyphen]input response in Eq. (4.2) or Eq. (4.5) depends on the \
initial conditions on the state vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"x\"\>",
            "TB"], \((t\_0)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"x\"\>",
            "TB"], \((0)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", respectively. By default, ",
  StyleBox["StateResponse", "MR"],
  " and ",
  StyleBox["OutputResponse", "MR"],
  " assume zero initial conditions. If this is not the case, the initial \
conditions can be supplied using the option ",
  StyleBox["InitialConditions", "MR"],
  ". The typical format is ",
  StyleBox["InitialConditions", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["vector", "TI"],
  ", where ",
  StyleBox["vector", "TI"],
  " must have the same length as matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ". Also acceptable is ",
  StyleBox["InitialConditions", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["value", "TI"],
  ", which will cause all state variables to have the same initial value ",
  StyleBox["value", "TI"],
  ". \nAnother option, ",
  StyleBox["ResponseVariable", "MR"],
  ", allows you to name the internal variable if the state or output response \
should contain unevaluated integral(s) or sum(s). The default value for this \
option is ",
  StyleBox["Automatic", "MR"],
  ", which corresponds to the internal variable ",
  StyleBox["Tau", "MR"],
  " or ",
  StyleBox["J", "MR"],
  " for the continuous\[Hyphen] and discrete\[Hyphen]time cases, \
correspondingly. "
}], "Text",
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["InitialConditions",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["0",
                "StandardForm"],
              "Text"], 
            StyleBox[\(initial\ state\ conditions\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["ResponseVariable",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(internal\ variable\ to\ use\ in\ the\ integral\ or\ sum\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.32, 0.3, 0.38},
  RowLines->{True, False}},
  CellTags->"4.1"],

Cell[TextData[{
  "Specifying initial conditions and the response variable in ",
  StyleBox["StateResponse", "MR"],
  " and ",
  StyleBox["OutputResponse", "MR"],
  ". "
}], "Caption",
  CellTags->"4.1"],

Cell["\<\
As an example of analog time\[Hyphen]domain simulation consider the \
simple production and inventory control model from Brogan (1991):  \
\>", 
  "Text",
  CellTags->"4.1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        OverscriptBox[
          StyleBox["\<\"x\"\>",
            "TB"], "."], "=", 
        RowBox[{"[", GridBox[{
              {
                StyleBox[\(-1\),
                  "DisplayFormula"], 
                StyleBox[\(-k\),
                  "DisplayFormula"]},
              {
                StyleBox["1",
                  "DisplayFormula"], 
                StyleBox["0",
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Center}], "]"}], 
        StyleBox["\<\"x\"\>",
          "TB"], "+", 
        RowBox[{"[", GridBox[{
              {
                StyleBox["k",
                  "DisplayFormula"], 
                StyleBox["0",
                  "DisplayFormula"]},
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[\(-1\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Center}], "]"}], 
        RowBox[{"[", GridBox[{
              {
                StyleBox["c",
                  "DisplayFormula"]},
              {
                StyleBox[\(u\_2\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Center}], "]"}]}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"4.1"],

Cell[TextData[{
  "which can be represented schematically as shown in Figure\
\[NonBreakingSpace]4.1. The model assumes that ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_2\)(t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " are the scheduled production rate and the sales rate, respectively, ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " represent the actual production rate and inventory level, and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " is the desired inventory level.      \n",
  Cell["", "Message",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    CellTags->"S0.0.2"],
  "   "
}], "Text",
  CellTags->"4.1"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 437 128
%%HiResBoundingBox: 47 4 437 128
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (10:39:12 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 132 translate 1 -1 scale
gsave
47 128 translate
390 -124 scale
1 string
1549 492 1 [1549 0 0 492 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0AAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0000000000000000000000000000000000000000000
0000000000000000000000000000000000000000007FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0000000000000000000000000000000000000000000
0000000000000000000000000000000000000000007FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0555555555555555555555555555555555555555555
5555555555555555555555555555555555555555407FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFBE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDC1FDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFBC0F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEC1FBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFBE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEC1F9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFDC0F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEC1FBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFCE0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE41F3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC40C7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE01E3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE608FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01C7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0187FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000
7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000
3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000
0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF80000000000000000000007FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000001FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF05550
01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFFFFF
FFFFFFFFFFAAABFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFFFFF
FFFFFFFFFF0001FFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0555003F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAABFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF803F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
203FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8001FFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF85555555555555555555543FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF0007
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
700FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8E03
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3C03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF0701
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7E01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8F80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3F80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07C0
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FC03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FF8
0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FC
07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFE
03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
C03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD15FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
E01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFD55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
F80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD017FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FC03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000001FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF00000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000000FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE00BFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE00BFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80055001FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFC01DDDD01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC01DDDD01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFE00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFF80FFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF80FFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC017777007FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFF0177777403FFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0177777407FFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFFFC03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFE03FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFE03FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE07FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01DDDDDD01FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFC05DDDDDDC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC1DDDDDDD81FFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFC0FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFF81FFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF83FFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07777777407FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFF017777777607FFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF017777777407FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFF03FFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF07FFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FE3FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1DDDDDDDD03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFF05DDDDDDDD83FFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FD
FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF05DDDDDDDD03FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7F81FFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FF8
FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE0FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3F8DFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF077777777741FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFC077777777741FFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07F0
3FFFFFC03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFC177777777741FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FDCFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFE0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFB
BFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE3FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFCFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF05DDDDDDDDC0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFF9F1FFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFC1DDDDDDDDDC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
9FFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFC1DDDDDDDDDC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFC7FFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFF0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFF8F2FFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFC3FFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
8FFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF83FFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFEFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFF
FFFFFFEFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1777777777707FFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFCE77FFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFC3777777777707FFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
CFFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF407FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8777777777760FFFFFFFFFFFFFFFFFC5FFFFFFFFF07FF8
7FFC7FFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFC000FFFFFFFFFFFFFF
FFFFFFF05FFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF87FFFFFFF
FFFFFFFFFFFEBFFFFFFFF87FFFFFFCE7FFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFF83FFFFFFFFFF0FFFFFFFFFFFFFFFFFFBFFFFFFFFE0FFF8FFF
8FFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFF
FFFAFFFFFFFFFF83FFFFFFFFFF0FFFFFFFFFFFFFFFFFF83FFFFFFFF8FFF8
3FFEFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFFFFFFFFF
FFFFFFFE03FFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFC1DDDDDDDDDD07FFFFFFF
FFFFFFFFFFFF05FFFFFFF87FFFFFFCC7FFFFFFFFFFC3FFFFFFFFFFFFFFFF
F05FFFFFFFF85DDDDDDDDDD07FFFFFFFFFFFFFFFFFD17FFFFFFF0FFF07FF
CFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFF
FFFF05FFFFFFFF05DDDDDDDDDD07FFFFFFFFFFFFFFFFFC017FFFFFF07FF8
7FFC7FFFFFFFC03FFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFFFFFF
FFFFFFFF0017FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFC3FFFFFFFFFF87FFFFFFF
FFFFFFFFFFFFE02FFFFFF87FFFFFFECFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FE0BFFFFFFF87FFFFFFFFFF8FFFFFFFFFFFFFFFFFFF80BFFFFFE0FFF8FFF
CFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FFFFFFFFFFFFFFFFF
FFFFE0BFFFFFFF87FFFFFFFFFF0FFFFFFFFFFFFFFFFFFE000BFFFFF8FFF8
3FFEFFFFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFF80003FFFFFFFFFFFFF
FFFFFFFFE000FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFC1777777777707FFFFFFF
FFFFFFFFFFFFF0007FFFF87FFFFFFC4FFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FF0017FFFFF07777777777707FFFFFFFFFFFFFFFFFFC0017FFFF0FFF07FF
CFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFF00007FFFFFFFFFFFFFFFF
FFFFF0017FFFFF07777777777707FFFFFFFFFFFFFFFFFF000017FFF07FF8
7FFC7FFFFFFFF00755555555555555555555555555000015555555555555
55555555400005FFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80BFFFFFFC3FFFFFFFFFF83FFFFFFF
FFFFFFFFFFFFF8000BFFF87FFFFFFE6FFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FF8002BFFFF87FFFFFFFFFF8FFFFFFFFFFFFFFFFFFFF0002FFFE0FFF8FFF
CFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFF00007FFFFFFFFFFFFFFFF
FFFFF8002FFFFF87FFFFFFFFFF8AAAAAAAAAAAAAAAAAAA800002FFF8FFF8
3FFE7FFFFFFFFE0200000000000000000000000000000000000000000000
000000000000003FFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFC1DDDDDDDDDD83FFFFFFF
FFFFFFFFFFFFFC00001FF87FFFFFFF77FFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFC00005FFF05DDDDDDDDDD07FFFFFFFFFFFFFFFFFFF800005FF0FFF07FF
C7FFFFFFFF00C00000000000000000000000000000000000000000000000
00000000005FFF05DDDDDDDDDD0000000000000000000000000005F07FF8
7FFC7FFFFFFFFF0000000000000000000000000000000000000000000000
00000000000000017FFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0002FFFFC3FFFFFFFFFF800000000
00000000000000000002F87FFFFFFE3BFFFFFFFFFFC2AAAAAAAAAAAAAAAA
AAA000002FF87FFFFFFFFFF8AAAAAAAAAAAAAAAAAAAA800000BE0FFF8FFF
CFFFFFFFFFE0000000000000000000000000000000000000000000000000
000000000003FF8FFFFFFFFFFF8000000000000000000000000000B8FFF8
3FFE7FFFFFFFFF8000000000000000000000000000000000000000000000
00000000000000000BFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000005FFC37777777777400000000
00000000000000000000007FFFFFFF3DFFFFFFFFFFC00000000000000000
00000000007077777777777000000000000000000000000000000FFF07FF
C7FFFFFFFFE0000000000000000000000000000000000000000000000000
000000000000070777777777770000000000000000000000000000507FF8
7FFC7FFFFFFFFFC000000000000000000000000000000000000000000000
000000000000000017FFFFFFFFF8
FFFFFFFFAAAAAAAAAAAAAAAAAAAAAAA000000BFC3FFFFFFFFFF800000000
00000000000000000000003FFFFFFF3EFFFFFFFFFFC00000000000000000
0000000000083FFFFFFFFFF800000000000000000000000000000FFF8FFF
CFFFFFFFFFF8000000000000000000000000000000000000000000000000
0000000000000087FFFFFFFFFF000000000000000000000000003FF8FFF8
3FFE7FFFFFFFFFE02AAAAAAAAAAAAAAAAAAAAAAAAA00002AAAAAAAAAAAAA
AAAAAAAAA000000BFFFFFFFFFFF8
FFFFFFFF000000000000000000000000000000141DDDDDDDDDD800000000
00000000000000000000007FFFFFFF1D7FFFFFFFFFC00000000000000000
0000000000585DDDDDDDDDD000000000000000000000000000010FFF07FF
C7FFFFFFFFFC000000000000000000000000000000000000000000000000
0000000000000505DDDDDDDDDD00000000000000000000000005FFF07FF8
7FFC7FFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF80003FFFFFFFFFFFFF
FFFFFFFFE000017FFFFFFFFFFFF8
FFFFFFFF000000000000000000000000000000083FFFFFFFFFF800000000
00000000000000000002F87FFFFFFFBFFFFFFFFFFFC00000000000000000
000000002FF83FFFFFFFFFF000000000000000000000000000BE0FFF8FFF
CFFFFFFFFFF80AAAAAAAAAAAAAAAAAAAAAAAAAA00002AAAAAAAAAAAAAAAA
AAAAAA000002FF83FFFFFFFFFE0FFFFFFFFFFFFFFFFFFF0002FFFFF8FFF8
3FFE7FFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFF80007FFFFFFFFFFFFF
FFFFFFFFE000BFFFFFFFFFFFFFF8
FFFFFFFF0000000000000000000000000000005C17777777777055555555
5555555555555400005FF87FFFFFFF9FFFFFFFFFFFC15555555555555555
554000017FFC37777777777000000000000000000000000017FF0FFF07FF
C7FFFFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFF00007FFFFFFFFFFFFFFFF
FFFFFC000017FF8377777777760FFFFFFFFFFFFFFFFFFC0017FFFFF07FF8
7FFE7FFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFFFFFF
FFFFFFFF0005FFFFFFFFFFFFFFF8
FFFFFFFF00000000000000000000000000002FFE3FFFFFFFFFF87FFFFFFF
FFFFFFFFFFFFF8002FFFF87FFFFFFF9FFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFE000BFFFFC3FFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF0003FFFE0FFF8FFF
EFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFF8000FFFFFFFFFFFFFFFFF
FFFFF8000BFFFF83FFFFFFFFFE1FFFFFFFFFFFFFFFFFF80BFFFFFFF8FFF8
3FFE7FFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFFFFFFFFF
FFFFFFFF02FFFFFFFFFFFFFFFFF8
FFFFFFFF0000000000000000000000000005FFFC1DDDDDDDDDD07FFFFFFF
FFFFFFFFFFFFF001FFFFF87FFFFFFFDFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FF0017FFFFFC1DDDDDDDDDC1FFFFFFFFFFFFFFFFFFFC005FFFFF0FFF07FF
C7FFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFF
FFFFF0017FFFFFC1DDDDDDDDDC1FFFFFFFFFFFFFFFFFD17FFFFFFFF07FF8
7FFE7FFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFF
FFFFFFFC5FFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE002FFFFFE0FFFFFFFFFF8FFFFFFFF
FFFFFFFFFFFFE0BFFFFFF87FFFFFFFCFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FE0BFFFFFFFE1FFFFFFFFFE1FFFFFFFFFFFFFFFFFFF82FFFFFFE0FFF8FFF
EFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFF
FFFFE0BFFFFFFFC3FFFFFFFFFE1FFFFFFFFFFFFFFFFFBFFFFFFFFFF8FFF8
3FFE3FFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFF
FFFFFFEFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0017FFFFFE0777777777707FFFFFFF
FFFFFFFFFFFF17FFFFFFF87FFFFFFF07FFFFFFFFFFC3FFFFFFFFFFFFFFFF
F05FFFFFFFFC077777777741FFFFFFFFFFFFFFFFFFC5FFFFFFFF0FFF07FF
C7FFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFF
FFFF05FFFFFFFFC177777777741FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFF37FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0BFFFFFFFE0FFFFFFFFFE0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
EFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFA3FFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFFE0FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFA3FFFFFE03FFFFFFFFFFFAABFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF17FFFFFFFFF05DDDDDDDDC1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFF05DDDDDDDD03FFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
E77FFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF05DDDDDDDD07FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFF81FFFFF807FFFFFFFFFFFC03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFC1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFF83FFFFFFFF87FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
F23FFFFF80FFFFFFFFFFFFEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF07FFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFEFFFFFE01FFFFFFFFFFFFEFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF017777777741FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFF017777777607FFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
F07FFFFF007FFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF037777777407FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFFFFFFC03FFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFF83FFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FEFFFFFE03FFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF83FFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFFFFFF80FFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1DDDDDDDD07FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFC05DDDDDD81FFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFFFFFF807FFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC0DDDDDDD01FFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFFFFFF01FFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFE0FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFAFFFE03FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFFFFFF80FFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFFFE07FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFFFFFC03FFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7FFF03777777407FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFF8FFFF0177777407FFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFFFFFC01FFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF0FFFF0177777407FFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFFFFF007FFFFFFFFFFFFFFC7FDFF1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF83FFFFFF83FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFF8FFFF80FFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFFFFF80FFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8FFFF80FFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFFFFE03FFFFFFFFFFFFFFFE7FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF805DDDDC01FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFF8FFFFC01DDDD01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFFFFF01FFFFFFFFFFFFFFF3FF3FF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF0FFFFC01DDDC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFFFFC07FFFFFFFFFFFFFFFE7F7FFE7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFE03FFFF80FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE00BFE803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFFFFE03FFFFFFFFFFFFFFF3FEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8FFFFE00BFE803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFFFF80FFFFFFFFFFFFFFFBE3EFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFF007774007FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFF8FFFFF00000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFFFF007FFFFFFFFFFFFFFF3FC7FFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF0FFFFF00000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFFFC01FFFFFFFFFFFF7F7DC7CFDFF3FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFF802BA803FFFFFFFFFF
FFFBFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFEA8ABFFFE000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFFFE03FFFFFFFFFFFFFFFF3FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEA0ABFFFE000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFFF80FFFFFFFFFFFFE3E3E879F8FFBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5455FFFC0000007FFFFFFFFFF
FFF1FFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFE0003FFFF000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFFFC07FFFFFFFFFFFD7C7F3F9F9FF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFC0003FFFF000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFFF01FFFFFFFFFFFFF5C5C0F9F9FF1FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0001FFFF800003FFFFFFFFFFF
FFFBFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFE0003FFFFE800BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFFF80FFFFFFFFFFFFE3CBF3FBF8FF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE0003FFFFE800BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFFE03FFFFFFFFFFFFFEEEFFFBF8FF9FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0001FFFFC00007FFFFFFFFFFF
FFF1FFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFF5057FFFFFF57FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFFC01FFFFFFFFFFFFF5CDF3F1F17F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5057FFFFFF57FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFF007FFFFFFFFFFFFFF47FFF1FCFF9FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA82BFFFFFA82BFFFFFFFFFFFF
FFFBFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFFA07FFFFFFFFFFFFFF8FFFF3FBBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFFF03FFFFFFFFFFFFFFF8FFFF3FEFF8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFF
FFF1FFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FFF01FFFFFFFFFFFFFFF9FFFF3F9FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF0FFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFFC03FFFFFFFFFFFFFFF9FFFF1FC7F8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFF
FFFBFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FFE03FFFFFFFFFFFFFFF9FFFE3F8FF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8FFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFF80FFFFFFFFFFFFFFFF8FFFF3FEFF8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFF
FFF1FF1FFDFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FF007FFFFFFFFFFFFFFF1FFFE3FCFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF0FFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFFE01FFFFFFFFFFFFFFFF9FFFF1FE7F8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFF8EFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFF
FFFBFF3FFEFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
FF03FFFFFFFFFFFFFFFFBFFFE3FCFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8FFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFFE03FFFFFFFFFFFFFFFF8FFFF3FE3F8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFF9F7FFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFF
FFF1FE7FFE7FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
FC01FFFFFFFFFFFFFFFF1FFFE3FC7F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFF00FFFFFFFFFFFFFFFFF17FFF1FF3F9FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF
FFFBFEFFFF7FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
F80FFFFFFFFFFFFFFFFFAFFFE3FEFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FFE03FFFFFFFFFFFFFFFFFBAFFFBFE3F9FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1
E7F1FCFC7F3FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
F01FFFFFFFFFFFFFFFFF27FFF3FC7F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FFC07FFFFFFFFFFFFFFFFD3C7FF1FC071FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7FFFFFFFFFFFFFFFFFFF8
FFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2
E3FBF9F8FFBFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFF
E03FFFFFFFFFFFFFFFFF3AFFF3FE3FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3FF80FFFFFFFFFFFFFFFFFFFFFFF9FF3FBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFF8
FFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
45F9F9F9BF9FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FF
007FFFFFFFFFFFFFFFFC78FFF1FC1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7FC01FFFFFFFFFFFFFFFFFFFFFFFDFF9F3FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF5FFFDFFCFFFFFFFFFFFF8
FFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3
A7FFFBFCFF9FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FFE
03FFFFFFFFFFFFFFFFFFFFFFFBFE3F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3F80FFFFFFFFFFFFFFFFFFFFFFFFEFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3
C7FFF1FCFF9FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07FC
07FFFFFFFFFFFFFFFFFFFFFFF1FF3E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFD5557FFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7F01FFFFFFFFFFFFFFFFFFFFFFFFE7FFE7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF7FF3FFF1FFFFFFFFFFF8
FFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3
F3FFF3FEFF8FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8FF8
0FFFFFFFFFFFFFFFFFFFFFFFF9FFBEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE1FFE000FFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
3E03FFFFFFFFFFFFFFFFFFFFFFFFF3FFEFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFBFF3FFFBFFFFFFFFFFF8
FFFFFFFFF7CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1
C3FFF1FC7F8FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF07C0
1FFFFFFFFFFFFFFFFFFFFFFFFCFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFD5557FFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
7807FFFFFFFFFFFFFFFFFFFFFFFFF9FF9FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFDFF7C7FDFFFFFFFFFFF8
FFFFFFFFFBCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
E3FFF3FEFF8FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8F80
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
201FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FEFE3FCFFFFFFFFFFF8
FFFFFFFFFC5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
F1FFF1FE7F8FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF0700
7FFFFFFFFFFFFFFFFFFFFFFFFF7FF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
403FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFC7C7E5FC7FFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
FBFFF3FE3F8FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF8E03
FFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF9FEFE7FEFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
F9FFF1FF3F9FFFFFFFFFF85555555555555555555543FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF0007
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FF8
01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF97CFF7FC7FFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
F8FFFBFE2F9FFFFFFFFFF80000000000000000000003FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF800F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000
03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFBBCFF3FE7FFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4
7DFFF1FC171FFFFFFFFFF80000000000000000000003FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFF001F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000
07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF1DCFF3FC7FFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF9FFBFBFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000
3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF3F8FFBFE7FFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFF9F3FFFFFFFFFF80000000000000000000003FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000001FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000
7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF3DCFF1FC7FFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFE3ECFF9FE7FFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFE7FFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFE7CC7F9FC7FFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFE78EFF8BEFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFDFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFD7DC7F07C7FFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFEFFCFCFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE7FC7DFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF3FFFBFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF9FFF3FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFEFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC7FC7FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC411FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCC18FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFDC1CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBC1EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF9C1E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF7C1F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF7C1F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFC03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFEABFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFCFFDFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFEFFBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFE7F7FFC7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFE3E7FFE7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFDF3C7FFF3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFBE3FE3CFCFFBFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFF065C07DFC7F1FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFF3E7F0F9F8BF9FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFF3B7FFF9FCDF9FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFBE3FFF9FEFF8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFF1D3FFF1FC7FCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFBE3FFFBFE7F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFF9F1FFF1FE7FCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFF8FBFFFBFE7F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFCF1FFF1FF7FCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFCF9FFFBFF3F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFF4FDFFF9FD179FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFEFEFFF9FE2F9FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFCFF1F1FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFEFF9FBFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFC7FDF7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFE7FFEFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF3FFCFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFBFFBFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{390, 124},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000O1000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00;7oo00=W>B488@P0ob48;B4800<icWooOol0:7oo000/Ool00ekg000aS006<H`0
0bU:<H`aS00P<H`00cF]<H`aS00Q<H`00bU:<H`aS00P<H`00cF]<H`aS00Q<H`00bU:<H`aS00P<H`0
0cF]<H`aS00P<H`00bU:<H`aS00Q<H`00cF]<H`aS00P<H`00bU:<H`aS007<H`00aS68@Qoo`0YOol0
02aoo`03G_L007oo0?moobaoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0ogoo;7oo00=24248Ool0
:Goo000/Ool00ekg001oo`3oOol/Ool00d8@8@Qoo`0YOol002aoo`03G_L007oo0?moobaoo`03@Q0Q
27oo02Uoo`00;7oo00=Nm`00Ool0ogoo;7oo00=24248Ool0:Goo000/Ool00ekg001oo`3oOol/Ool0
0d8@8@Qoo`0YOol002aoo`03G_L007oo0?moobaoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0ogoo
;7oo00=24248Ool0:Goo000/Ool00ekg001oo`3oOol/Ool00d8@8@Qoo`0YOol002aoo`03G_L007oo
0?moobaoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0ogoo;7oo00=24248Ool0:Goo000/Ool00ekg
001oo`3oOol/Ool00d8@8@Qoo`0YOol002aoo`03G_L007oo0?moobaoo`03@Q0Q27oo02Uoo`00;7oo
00=Nm`00Ool0ogoo;7oo00=24248Ool0:Goo000/Ool00ekg001oo`3oOol/Ool00d8@8@Qoo`0YOol0
02aoo`03G_L007oo0?moobaoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0ogoo;7oo00=24248Ool0
:Goo000/Ool00ekg001oo`3oOol/Ool00d8@8@Qoo`0YOol002aoo`03G_L007oo0?moobaoo`03@Q0Q
27oo02Uoo`00;7oo00=Nm`00Ool0ogoo;7oo00=24248Ool0:Goo000/Ool00ekg001oo`3oOol/Ool0
0d8@8@Qoo`0YOol002aoo`03G_L007oo0?moobaoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0ogoo
;7oo00=24248Ool0:Goo000/Ool00ekg001oo`3oOol/Ool00d8@8@Qoo`0YOol002aoo`03G_L007oo
0?moobaoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0ogoo;7oo00=24248Ool0:Goo000/Ool00ekg
001oo`3oOol/Ool00d8@8@Qoo`0YOol002aoo`03G_L007oo0?moobaoo`03@Q0Q27oo02Uoo`00;7oo
00=Nm`00Ool0ogoo;7oo00=24248Ool0:Goo000/Ool00ekg001oo`3oOol/Ool00d8@8@Qoo`0YOol0
02aoo`03G_L007oo0?moobaoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0ogoo;7oo00=24248Ool0
:Goo000/Ool00ekg001oo`3oOol/Ool00d8@8@Qoo`0YOol002aoo`03G_L007oo0?moobaoo`03@Q0Q
27oo02Uoo`00;7oo00=Nm`00Ool0ogoo;7oo00=24248Ool0:Goo000/Ool00ekg001oo`3oOol/Ool0
0d8@8@Qoo`0YOol002aoo`03G_L007oo0?moobaoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0FWoo
00=g_EkgG_L0Dekg00=_NgooOol0N7oo00=24248Ool0:Goo000/Ool00ekg001oo`1JOol00e:D0000
001C00000c6<Oomoo`1hOol00d8@8@Qoo`0YOol002aoo`03G_L007oo05Yoo`03DY@006mk01=_N`03
JeY_Nfmk025_N`03Mke_Nfmk01Q_N`036<HaS7oo07Uoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0
FWoo00=BU000Ool0DWoo00<Q236<Ool0NGoo00=24248Ool0:Goo000/Ool00ekg001oo`1JOol00dYB
001oo`1BOol00b48:DYoo`1iOol00d8@8@Qoo`0YOol002aoo`03G_L007oo05Yoo`03DY@007oo059o
o`038@PaS7oo07Uoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0FWoo00=BU000Ool0DWoo00<Q236<
Ool0NGoo00=24248Ool0:Goo000/Ool00ekg001oo`1JOol00e:D001oo`1BOol00b48<Haoo`1iOol0
0d8@8@Qoo`0YOol002aoo`03G_L007oo05Yoo`03DY@007oo059oo`038@PaS7oo07Uoo`03@Q0Q27oo
02Uoo`00;7oo00=Nm`00Ool0FWoo00=BU000Ool0DWoo00<Q236<Ool0NGoo00=24248Ool0:Goo000/
Ool00ekg001oo`1JOol00e:D001oo`1BOol00b48<Haoo`1iOol00d8@8@Qoo`0YOol002aoo`03G_L0
07oo05Yoo`03DY@007oo059oo`038@PaS7oo07Uoo`03@Q0Q27oo02Uoo`00;7oo00=Nm`00Ool0FWoo
00=BU000Ool0DWoo00<Q236<Ool0NGoo00=24248Ool0:Goo000[Ool00gNmG_L0001KOol00e:D001o
o`1BOol00b48<Haoo`1iOol00d8@8@Qoo`0YOol002]oo`05MkeBU000OomS601HOol01EkgDY@007oo
Kg/0DGoo00<Q236<Ool0NGoo00=24248Ool0:Goo000/Ool01248001g_D8@F7oo00E:DS6<000aS7Nm
055oo`038@PaS7oo07Uoo`03@Q0Q27oo02Uoo`00;7oo00@YBP0048A245Qoo`04E[D000006<IBOol0
0b48<Haoo`1iOol00d8@8@Qoo`0YOol002aoo`04>Lh00000E[EHOol017Nm000002U:DWoo00<Q236<
Ool0NGoo00=24248Ool0:Goo000/Ool015Je000006mkFGoo00<@Q000@Q00DWoo00<Q236<Ool0NGoo
00=24248Ool0:Goo000/Ool00fmk0008@P1JOol00bU:001F]@1BOol00b48<Haoo`18Ool5G_L00fmk
Oomoo`0YOol00d8@8@Qoo`0YOol002eoo`03248HaWoo025oo`03MkeNmekg01ANmb5oo`03@Q0006mk
025oo`03<H`Q2248008Q2003>Lioogoo02Uoo`038@PaS7oo04Qoo`@@Q0030008@UJe02Yoo`03@Q0Q
27oo02Uoo`009Woo00AW>E:DDYABU0=oo`038@PicWoo025oo`03G_L8@Q2400@@Q003248@Q12400`@
Q003249Nmgoo01Uoo`=BU005G_MoogooE[D8@P0ROol02124>LiBU5:D8@P002U:Kg/YOol00b48<Hao
o`18Ool02A24Kg]oogoo:DXHaPQ2<Hag_@0XOol00d8@8@Qoo`0YOol002eoo`03>LiBU7oo025oo`03
G_LQ27oo01=oo`038@QNmgoo01moo`03Kg/YBWoo025oo`0948ANmgooOolaS5:D<H`8@UJe02Qoo`03
8@PaS7oo04Qoo`0:48A_NgooOolYBS6<MkdYBPQ2G_LWOol00d8@8@Qoo`0YOol002eoo`03DYAW>Goo
025oo`03G_LQ27oo01=oo`038@QNmgoo021oo`03@Q1oogoo021oo`0;48ANmgooOolaS5:DOomW>@Q2
<Hag_@0VOol00b48<Haoo`18Ool01Q24Kg]oogoo:DXaS09oo`03BU88@SW>02Ioo`03@Q0Q27oo02Uo
o`00;7oo00Ag_EJeE[Eg_B5oo`03G_LQ27oo01=oo`038@QNmgoo01ioo`06E[DicR48<HaBU7Nm7goo
00H@Q5kgOomooc6<DY@2Ool017Nm:DX8@Ukg9Goo00<Q236<Ool08Woo00Ig_E:D<H`aS3W>E[DPOol0
1Q24Kg]oogoo:DXaS0=oo`04IcTYBQS6IcTTOol00d8@8@Qoo`0YOol002Yoo`08Kg/YBP00248@Q0Q2
6<IF]Amoo`03G_LQ27oo01=oo`038@QNmgoo01aoo`04IcTHaPQ2<H`2>Lh00b4848ABU00NOol01Q24
G_Moogoo<HaBU0Aoo`03BU88@SW>02Aoo`038@PaS7oo025oo`04DY@@Q1S6<H`2>Lh00a245:EBU00N
Ool01Q24Kg]oogoo:DXaS0Eoo`03BU8@Q3W>02=oo`03@Q0Q27oo02Uoo`00:Goo00ABU0Q2<HaW>@=_
N`03@Q08@S6<01ioo`03G_LQ27oo01=oo`038@QNmgoo01]oo`03IcT8@RU:00E_N`03BU8HaTYB01eo
o`0648ANmgooOolaS5:D1Goo00AW>BU:6<IW>B9oo`038@PaS7oo021oo`03DY@@Q4YB00E_N`03@Q08
@U:D01eoo`0648A_NgooOolYBS6<1Woo00AW>AS6:DY_Nb5oo`03@Q0Q27oo02Uoo`00:7oo00=_N`00
BU801Vmk00=Nma24>Lh07Goo00=Nmb48Ool04goo00<Q25kgOol06goo00<8@S6<Kg/01Vmk00=Nm`Q2
F]H077oo00P@Q5kgOomooc6<DYAoogNm1Goo00=:DQ24>Lh08Goo00<Q236<Ool07goo00=W>@00F]H0
1Vmk00Ag_E[F001Nmaaoo`0948A_NgooOolYBS6<Oom_NdYB00Eoo`03<H`8@U:D021oo`03@Q0Q27oo
02Uoo`00:7oo00<YBS6<Kg/01fmk00=F]@Q2Kg/077oo00=Nmb48Ool01Woo00=_NgNmKg/02Woo00<Q
25kgOol06Woo00=BU1S6Kg/026mk00<icRU:Ool06goo00T@Q5kgOomooc6<DYAooe:DBU801Goo00AW
>AS6:DY_Namoo`038@PaS7oo01moo`03<H`icVmk00I_N`04Mke_NcW><H`LOol02Q24Kg]oogoo:DXa
S7ooIcUF]Ekg1Goo00AW>@Q2<Ha_Naioo`03<H`Q27oo02Uoo`0077oo00=g_GooOol027oo00=_N`00
IcT02Fmk00<YBTYBOol04Woo00=NmfLiMkd01Woo00=Nmb48Ool01Woo00<icT8@IcT02Woo00<Q25kg
Ool03goo00=g_EkgMkd027oo00<aS48@Kg/026mk00=W>@00Kg/04Goo00=_NfLiMkd01goo00H@Q5kg
Oomooc6<DY@2Ool00e:DG_Moo`05Ool00c6<249F]@0MOol0148@248HaWNm57oo00=W>EkgMkd01goo
00=g_@00G_L01fmk00Eg_FmkG_L007Nm011oo`05Kg]:DU:DIcUg_@06Ool01Q24Kg]oogoo:DXaS09o
o`03Kg]BU7oo00Ioo`03:DX8@Ukg01aoo`048@P00000BU8DOol01FLi@Q0icUkgIcT047oo000MOol0
1FmkBU8aS5:DG_L01Goo00=Nma24Kg/02Fmk00<icS6<Ool04goo00YBU0006<HYBTYBG_Mg_GooG_LQ
20Moo`03BU9BU7oo00Yoo`038@QNmgoo011oo`07IcT@Q1BU:DY245JeKg/00goo00<@Q5JeKg/02Fmk
00<@Q6mkOol04Goo00MW>AS648@Q248@E[EW>@02Ool01Q24G_Moogoo<HaBU09oo`03G_MF]Goo00Io
o`04IcT8@S6<Kg/JG_L01CW>000000008@P05Ekg00M:DPQ26<HYBU:DG_Mg_@02Ool00fmk001_N`07
Kg/01GNmKg]_N`Q2BU804E:D00a:DPQ2000001S6:DY245kgKg]ooa24Kg/2Ool01RU:<HaoogooKg]:
DPQoo`03DY@8@SW>018aS003=JdaS36<00DaS0038@P00000008001HaS00824800000248Q23W>E[EW
>@]oo`0027oo2E:D00=F]E:DDY@02e:D00X8@P000008@QS6:DYBU5kgE[DHaPY_N`03@Q00000001X0
00<HaPMoo`=F]@Yoo`038@P@Q124014@Q0032480000000<00005248Q24YB6<I>L`0:Kg/?48@00aBU
48@@Q00348@00`Q200000003000011248@P8@Ukg0Woo00HaS5:DOomooekgDY@9Ool00bU:0000000j
000011S68@QBU0Q226mk00Ag_FmkKg/8@QP0000648@aS48@IcT@Q6mk0Woo00HYBS6<Oomoofmk@Q09
Ool00e:D000Q200A<H`00bU:<H`aS005<H`00b4800000002000F<H`00a240000000200001@Q2:DXi
cU:DMkd02Goo0008OolK00001PQ2:DXicTYBE[D@Q0Y_N`03<H`YBUJe01=BU00:>Lh000006<HicTYB
E[Eg_Ekg8@P8Ool00e:DOomoo`09Ool00b48>LiBU00@DY@024YB6<H000Q26<HicTYBG_L2Ool2>Lh9
Kg/00ekg2492400B@Q002cW>248000Q2:DY245JeKg]ooa24G_L00Woo00HaS5:DOomoofLiDY@8Ool0
1FLi6<HHaVmkJeX066mk00EBU0000000036<00E_N`03Mke_Nfmk00e_N`08IcT@Q000248YBSW>BU9_
N`9oo`03249>Lfmk00I_N`04Mke_Ndic48@AOol01WNm@Q0HaSW>BU9Nm`Eoo`0648A_NgooOolYBS6<
0goo00=247ooOol01Goo00Ag_DYB001BU1Yoo`05MkdHaP00000icP0EOol01TYB8@Pe[D8@G_Mg_@io
o`007Goo00IW>D8@<Ha245kgMkd5Ool00`Q2BU9_N`08Kg/00aS6G_Moo`0BOol00fmkE[EW>@06Ool0
0ekg8@Qoo`06Ool00gNmDYAoo`0:Ool00b48G_Moo`0?Ool017NmDYANmgNm1goo00=Nm`Q2IcT026mk
00<YBS6<Ool04Goo00Ag_EJeIcUg_@Ioo`0648ANmgooOolaS5:D0Woo00=g_E:DMkd01Goo00Ag_DYB
001BU1aoo`03DY@YBTYB01Eoo`04Kg]BU5kgMkd7Ool00cW>:DY_N`06Kg/017NmKg/YBSW>4Goo00=g
_GooOol027oo00H@Q6mkOomoobU:<H`3Ool2@Q05Ool016mk6<HHaWNm2Woo00=_Ne:DF]H047oo00=W
>FmkOol057oo00=g_GooOol04Woo000XOol00d8@6<I_N`07Kg/00d8@6<Ioo`0LOol00ekg8@Qoo`0C
Ool00b48G_Moo`0KOol00b48:DYW>@06Kg/00dic48A_N`0LOol01Q24G_Moogoo<HaBU0=oo`03F]IB
U7oo00=oo`04Kg/HaQS6IcT<Ool00d8@Oomoo`0aOol00fmk249>L`06Kg/017Nm@Q08@Vmk77oo00H@
Q6mkOomoobU:<H`4Ool00gNmOomoo`02Ool00e:D0012400=Ool00ekgMkeoo`0kOol002Aoo`03JeYN
mgoo009oo`038@Pe[GNm00Eg_@03E[D8@Ukg01eoo`03G_LQ27oo01=oo`038@QNmgoo01Moo`07:DYo
ogooOomg_@Q28@P01GNm00=240Q2G_L07Goo00H8@UkgOomoocF]E[D8Ool015kg5:DQ27Nm3Goo00=2
47ooOol0;Goo00=g_BU:Ool00Woo00=Nm`00@Q001GNm00<YBP00G_L07Goo00@DYGNmOomoo`8YBPQo
o`03:DX8@TYB00ioo`04Mke:DWooJeX2Ool00ekgOomoo`0eOol002Aoo`03G_M247oo009oo`0:Kg/H
aQ24DYANmfLiCW<YBPQ2BU8<Ool00gNmOomoo`0?Ool00ekg8@Qoo`0COol00b48G_Moo`0EOol01GNm
Kg/Q26mkMkd00Woo00UW>AS6248aS3W><H`Q2124DY@07Woo00H@Q5kgOomooc6<DY@7Ool00dYB48@i
cP0?Ool0148@Oomooe:D0Woo00=_NfLiOol09Woo00Eg_EJe8@Q_NgNm009oo`09DY@@Q1S6<H`icS6<
248DYE:D01ioo`0648A_NgooOolYBS6<1Woo00AW>BU:6<IW>@]oo`06G_MooekgKg]NmcW>0fLi00=g
_GooBU80=Woo000SOol013W>6<H@Q2480goo00=g_DYB6<H00PQ200<@Q3W>Kg/03Goo00=BU6mkOol0
3goo00=Nmb48Ool04goo00<Q25kgOol05Goo00E_Nc6<248aS5[F00Aoo`06E[E:DS6<>LiF]GNm7goo
00H@Q5kgOomooc6<DY@5Ool016mk:DX@Q6Li37oo00a>Lfmk<Hag_E:DOomBU6mkE[E>LgooDY@WOol0
1E:D<H`8@S6<Kg/00goo00Ig_EJe>LhaS4YBE[DPOol01Q24Kg]oogoo:DXaS0Eoo`03DY@@Q3W>00eo
o`0=Kg]>LdYBKg]NmgNm@Q1ooe[FIcUoocW>Mkd0=Goo0008Ool00e[FG_Moo`0IOol00ekg@Q1oo`0H
Ool01E:DKg]oof<HMkd00Woo00=_NgooOol027oo00=Nmb48Ool04goo00<Q25kgOol05goo00<Q27oo
Ool0:Goo00H@Q5kgOomooc6<DY@4Ool00e:D48@icP0?Ool00eJeIcUoo`02Ool01bU:Oom_NdYBOomB
U5kg02Moo`03Kg/Q27oo00Ioo`9W>B9oo`0648A_NgooOolYBS6<17oo00<YBPQ2G_L03goo00=246mk
Ool00Woo00LaS7ooMke247oo@Q1F]@0eOol000Qoo`03>LioogNm01Uoo`03MkeW>Goo01Aoo`0<F]I_
Ne[FOomBU6mkMkeBU7NmF]Iooe:D2Woo00=Nmb48Ool04goo00<Q25kgOol05goo00=g_GooOol0:Goo
00H@Q5kgOomooc6<DY@3Ool00c6<249F]@0@Ool00dYBE[Eg_@02Ool01c6<Oomooc6<OomBU6Li02Qo
o`03Mkeoogoo00Eoo`03BU9F]Goo025oo`0648A_NgooOolYBS6<0Woo00AW>@Q2<Hag_@moo`04MkeB
U6LiIcT2Ool01SW>Oomg_BU:Kg]2425oo`03G_Moogoo019oo`0027oo00<icWooOol0<7oo00=:DVmk
<H`00gNm00MBU6mkMke:DWooG_MF]@09Ool00ekg8@Qoo`0COol00b48G_Moo`13Ool02a24G_Moogoo
<HaBU7ooIcT8@S6<Kg/04Goo00=W>GNmKg/00Woo00MBU6LiOolaS7NmBU9g_@0`Ool01CW>@Q1oogoo
JeX00e:D00=g_GooOol06Goo00X@Q6mkOomoobU:<Haooc6<249F]AMoo`06MkeJeWooKg]ooe:D8Goo
00Ig_FLiOomoofmkIcT2Ool2IcT;Ool000Uoo`03G_MBU7oo02moo`04E[ENmc6<Mkd2Ool01d8@Kg]o
ocW>OomNmd8@00Uoo`03G_LQ27oo01=oo`038@QNmgoo04=oo`0948ANmgooOolaS5:D<H`8@TYB01Uo
o`03E[Eoogoo009_Nc5oo`056<HYBWooOomg_@03Kg/00gNmOomoo`0IOol02A24Kg]oogoo:DXQ2124
8@Q_N`0IOol016mkOomoofmk8goo00U_NdYBOomBU7oo>Li_NgooBU802goo000kOol016mkDYA_Nekg
0Woo00MBU6LiOolaS6LiE[EW>@09Ool00ekg248@Q00448@00`Q248@@Q00<48@00`Q2G_Moo`13Ool0
2124AS5Nmekg8@P001S6IcU@Ool00`0048Aoo`0QOol011246<HQ22480PQ200<icWooOol0@7oo00EB
U5kgMkdicWoo009W>@03OolaS7oo00Yoo`00@Woo00EF]GooMkeg_E:D00Yoo`03MkeNmekg01ANm`03
Mkeoogoo049oo`03<H`Q2248008Q2003>Lioogoo04moo`04IcT00000MkdQOol5G_L00fmkOomoo`11
Ool02CW>Mke2448@Oomg_CW>MkdicP0;Ool004=oo`04MkeoogNmMkfmOol014YB000005kgJWoo00A_
NgooMke:DP9g_@03>LioodYB00]oo`00ogoo1Goo00@icP00001:DVioo`05CW=oogooF]Ig_@0;Ool0
0?moo`Eoo`04:DX@Q1S6<HanOol00?moo`Eoo`04F]HQ248@E[EnOol00?moo`Aoo`05Kg]oob48@Q1_
N`1nOol00?moo`Ioo`038@Q247oo07ioo`00ogoo1Woo00<Q248@Ool0OWoo003oOol6Ool00b48@Q1o
o`1nOol00?moo`Ioo`038@Q247oo07ioo`00ogoo1Woo00<Q248@Ool0OWoo003oOol6Ool00b48@Q1o
o`1nOol00?moo`Ioo`038@Q247oo07ioo`00ogoo1Woo00<Q248@Ool0OWoo003oOol6Ool00b48@Q1o
o`1nOol00?moo`Ioo`038@Q247oo07ioo`00ogoo1Woo00<Q248@Ool0OWoo003oOol6Ool00b48@Q1o
o`1nOol00?moo`Ioo`038@Q247oo07ioo`00ogoo1Woo00<Q248@Ool0OWoo003oOol6Ool00b48@Q1o
o`1nOol00?moo`Ioo`038@Q247oo07ioo`00ogoo1Woo00<Q248@Ool0OWoo003oOol6Ool00b48@Q1o
o`1nOol00?moo`Ioo`038@Q247oo00Moo`03Kg]Nmfmk07Aoo`00ogoo1Woo00<Q248@Ool01goo00=g
_EJeKg/0M7oo003oOol6Ool00b48@Q1oo`08Ool015kgMkeoofLi0Woo00=_NgNmOol0KGoo003oOol6
Ool00b48@Q1oo`04Ool02EJeIcUNmfLiCW=:DU:DKg]S6002Mkd00dYBOomoo`1/Ool00?moo`Ioo`03
8@Q247oo00Aoo`0<@Q1Nme:DOomNmgoo>Liood8@IcUoocW>KWoo003oOol6Ool00b48@Q1oo`04Ool0
0d8@MkdicP03Ool01T8@OomW>EkgOolaS6ioo`00ogoo1Woo00<Q248@Ool017oo00=BU7ooG_L00goo
00I:DWooKg/YBWNm<Ha^Ool00?moo`Ioo`038@Q247oo00Yoo`9Nm`04OomW>FLiKg]^Ool00?moo`Io
o`038@Q247oo00]oo`04Kg]oogooMke_Ool00?moo`Ioo`03DYAS67oo07ioo`00ogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00001\
\>"],
  CellTags->"4.1"],

Cell[TextData[{
  StyleBox["Figure 4.1. ",
    FontWeight->"Bold"],
  "Simple production and inventory control system."
}], "Caption",
  CellTags->"4.1"],

Cell["Here is the production and inventory control model. ", "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["StateSpace[{{-1, -k}, {1, 0}}, {{k, 0}, {0, -1}}]", "Input",
  CellLabel->"In[5]:=",
  CellTags->"4.1"],

Cell[BoxData[
    \(StateSpace[{{\(-1\), \(-k\)}, {1, 0}}, {{k, 0}, {0, \(-1\)}}]\)], 
  "Output",
  CellLabel->"Out[5]=",
  CellTags->"4.1"]
}, Open  ]],

Cell[TextData[{
  "Initially the system was in equilibrium, with the production rate ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(0)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  "  equal to the sales rate and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(0) = c\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ". We denote ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(0)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " as ",
  StyleBox["x10", "MR"],
  ". At ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ", sales increase by 10 percent. "
}], "Text",
  CellTags->"4.1"],

Cell[TextData[{
  "This finds the state response for the particular value of ",
  Cell[BoxData[
      \(TraditionalForm\`k = 3\/16\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ". The initial conditions are specified using the option ",
  StyleBox["InitialConditions", "MR"],
  ".  "
}], "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["\<\
StateResponse[% /. k -> 3/16, {c, 1.1 x10}, t,
 InitialConditions -> {x10, c}
]//Simplify\
\>", "Input",
  CellLabel->"In[6]:=",
  CellTags->"4.1"],

Cell[BoxData[
    \({\((
          \(1.10000000000000008`\[InvisibleSpace]\) + 
            2.04999999999999982`\ E\^\(\(\(-3\)\ t\)/4\) - 
            2.15000000000000035`\ E\^\(\(-t\)/4\))\)\ x10, 
      1.`\ c + \((
            \(-5.86666666666666714`\) - 
              2.73333333333333339`\ E\^\(\(\(-3\)\ t\)/4\) + 
              8.60000000000000142`\ E\^\(\(-t\)/4\))\)\ x10}\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->"4.1"]
}, Open  ]],

Cell[TextData[{
  "This plots the results for particular values of the initial production \
rate ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(0)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " and inventory level ",
  Cell[BoxData[
      \(TraditionalForm\`c\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ". To distinguish the graphs for production rate and for inventory level, \
we set ",
  StyleBox["PlotStyle", "MR"],
  " for them differently. The first is plotted as a solid line and the second \
as a dashed one. "
}], "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[% /. {x10->1, c->6}], {t, 0, 50},
 PlotStyle -> {
 Thickness[.0075],
 Dashing[{.05, .01}]
 },
 PlotRange -> All,
 PlotLabel -> \"State Response\"
]\
\>", "Input",
  CellLabel->"In[7]:=",
  CellTags->"4.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.00133445 0.100331 [
[.21429 -0.01117 -6 -9 ]
[.21429 -0.01117 6 0 ]
[.40476 -0.01117 -6 -9 ]
[.40476 -0.01117 6 0 ]
[.59524 -0.01117 -6 -9 ]
[.59524 -0.01117 6 0 ]
[.78571 -0.01117 -6 -9 ]
[.78571 -0.01117 6 0 ]
[.97619 -0.01117 -6 -9 ]
[.97619 -0.01117 6 0 ]
[.01131 .10167 -6 -4.5 ]
[.01131 .10167 0 4.5 ]
[.01131 .202 -6 -4.5 ]
[.01131 .202 0 4.5 ]
[.01131 .30233 -6 -4.5 ]
[.01131 .30233 0 4.5 ]
[.01131 .40266 -6 -4.5 ]
[.01131 .40266 0 4.5 ]
[.01131 .50299 -6 -4.5 ]
[.01131 .50299 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .00133 m
.21429 .00758 L
s
[(10)] .21429 -0.01117 0 1 Mshowa
.40476 .00133 m
.40476 .00758 L
s
[(20)] .40476 -0.01117 0 1 Mshowa
.59524 .00133 m
.59524 .00758 L
s
[(30)] .59524 -0.01117 0 1 Mshowa
.78571 .00133 m
.78571 .00758 L
s
[(40)] .78571 -0.01117 0 1 Mshowa
.97619 .00133 m
.97619 .00758 L
s
[(50)] .97619 -0.01117 0 1 Mshowa
.125 Mabswid
.0619 .00133 m
.0619 .00508 L
s
.1 .00133 m
.1 .00508 L
s
.1381 .00133 m
.1381 .00508 L
s
.17619 .00133 m
.17619 .00508 L
s
.25238 .00133 m
.25238 .00508 L
s
.29048 .00133 m
.29048 .00508 L
s
.32857 .00133 m
.32857 .00508 L
s
.36667 .00133 m
.36667 .00508 L
s
.44286 .00133 m
.44286 .00508 L
s
.48095 .00133 m
.48095 .00508 L
s
.51905 .00133 m
.51905 .00508 L
s
.55714 .00133 m
.55714 .00508 L
s
.63333 .00133 m
.63333 .00508 L
s
.67143 .00133 m
.67143 .00508 L
s
.70952 .00133 m
.70952 .00508 L
s
.74762 .00133 m
.74762 .00508 L
s
.82381 .00133 m
.82381 .00508 L
s
.8619 .00133 m
.8619 .00508 L
s
.9 .00133 m
.9 .00508 L
s
.9381 .00133 m
.9381 .00508 L
s
.25 Mabswid
0 .00133 m
1 .00133 L
s
.02381 .10167 m
.03006 .10167 L
s
[(1)] .01131 .10167 1 0 Mshowa
.02381 .202 m
.03006 .202 L
s
[(2)] .01131 .202 1 0 Mshowa
.02381 .30233 m
.03006 .30233 L
s
[(3)] .01131 .30233 1 0 Mshowa
.02381 .40266 m
.03006 .40266 L
s
[(4)] .01131 .40266 1 0 Mshowa
.02381 .50299 m
.03006 .50299 L
s
[(5)] .01131 .50299 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(6)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .0214 m
.02756 .0214 L
s
.02381 .04147 m
.02756 .04147 L
s
.02381 .06153 m
.02756 .06153 L
s
.02381 .0816 m
.02756 .0816 L
s
.02381 .12173 m
.02756 .12173 L
s
.02381 .1418 m
.02756 .1418 L
s
.02381 .16186 m
.02756 .16186 L
s
.02381 .18193 m
.02756 .18193 L
s
.02381 .22206 m
.02756 .22206 L
s
.02381 .24213 m
.02756 .24213 L
s
.02381 .26219 m
.02756 .26219 L
s
.02381 .28226 m
.02756 .28226 L
s
.02381 .32239 m
.02756 .32239 L
s
.02381 .34246 m
.02756 .34246 L
s
.02381 .36253 m
.02756 .36253 L
s
.02381 .38259 m
.02756 .38259 L
s
.02381 .42272 m
.02756 .42272 L
s
.02381 .44279 m
.02756 .44279 L
s
.02381 .46286 m
.02756 .46286 L
s
.02381 .48292 m
.02756 .48292 L
s
.02381 .52305 m
.02756 .52305 L
s
.02381 .54312 m
.02756 .54312 L
s
.02381 .56319 m
.02756 .56319 L
s
.02381 .58325 m
.02756 .58325 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(State) show
99.000000 12.812500 moveto
(Response) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.0075 w
.02381 .10166 m
.02846 .08004 L
.03279 .0644 L
.03754 .05135 L
.04262 .04125 L
.04518 .03742 L
.04795 .03406 L
.05058 .03158 L
.053 .02981 L
.05518 .0286 L
.05758 .02763 L
.05879 .02728 L
.06009 .027 L
.06132 .02682 L
.06244 .02671 L
.06314 .02668 L
.0638 .02667 L
.06504 .0267 L
.06573 .02675 L
.06636 .0268 L
.06706 .02688 L
.0678 .02699 L
.07017 .02746 L
.07277 .02817 L
.0786 .03039 L
.08405 .03305 L
.10458 .04552 L
.14349 .0687 L
.16473 .07857 L
.18485 .086 L
.20307 .09136 L
.22318 .09602 L
.24295 .09958 L
.26396 .10249 L
.28331 .10455 L
.30416 .10626 L
.3242 .10752 L
.3453 .10853 L
.36505 .10925 L
.38341 .10977 L
.40387 .11023 L
.42246 .11055 L
.44164 .1108 L
.46244 .11102 L
.48232 .11117 L
.50336 .1113 L
.52293 .11139 L
.54125 .11146 L
.56153 .11151 L
.58007 .11155 L
Mistroke
.59909 .11158 L
.61983 .11161 L
.63954 .11163 L
.66053 .11165 L
.68198 .11166 L
.70216 .11167 L
.72228 .11168 L
.74077 .11168 L
.75963 .11168 L
.78031 .11169 L
.79985 .11169 L
.82078 .11169 L
.84206 .11169 L
.8622 .11169 L
.88214 .1117 L
.90058 .1117 L
.91928 .1117 L
.9399 .1117 L
.95737 .1117 L
.97619 .1117 L
Mfstroke
.5 Mabswid
[ .05 .01 ] 0 setdash
.02381 .60332 m
.06244 .47445 L
.08255 .38667 L
.10458 .30222 L
.1253 .2374 L
.14415 .19013 L
.16372 .15113 L
.18466 .11871 L
.20381 .09575 L
.22459 .07648 L
.24443 .06235 L
.26546 .05088 L
.28499 .0427 L
.30329 .03673 L
.32354 .03159 L
.34206 .02795 L
.36105 .02503 L
.38177 .02257 L
.40145 .02078 L
.42242 .01932 L
.44383 .01819 L
.464 .01738 L
.48408 .01676 L
.50255 .01632 L
.52138 .01597 L
.54204 .01567 L
.56155 .01545 L
.58246 .01528 L
.6037 .01514 L
.62382 .01504 L
.64373 .01496 L
.66215 .01491 L
.68082 .01487 L
.70142 .01483 L
.72077 .0148 L
.74162 .01478 L
.76166 .01477 L
.78276 .01475 L
.8025 .01474 L
.82087 .01474 L
.84133 .01473 L
.85992 .01473 L
.8791 .01472 L
.8999 .01472 L
.91977 .01472 L
.94082 .01472 L
.95909 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool5
0002Ool00`00Oomoo`0UOol30003Ool00`00Oomoo`0VOol20004Ool00`00Oomoo`0VOol30002Ool0
0`00Oomoo`0VOol00`00Oomoo`02Ool00`00Oomoo`0GOol004Qoo`07001oogooOol007oo00009Woo
00<007ooOol00Woo00<007oo0000:Goo00H007ooOol007oo000XOol01P00Oomoo`00Ool002Ioo`03
001oo`00009oo`03001oo`0001Qoo`00B7oo00L007ooOomoo`00Ool0000WOol01`00Oomoogoo001o
o`0002Qoo`07001oogooOol007oo00009Woo100000Aoo`00Ool002Qoo`06001oogoo001oo`0067oo
0018Ool01`00Oomoogoo001oo`0002Moo`07001oogooOol007oo0000:Goo00H007ooOol007oo000V
Ool00`00Ool00002Ool00`00Ool0000VOol20003Ool00`00Ool0000HOol004Qoo`07001oogooOol0
07oo00009Woo00<007oo00000Woo00<007oo00009goo00<007oo00000Woo00<007oo00009goo0P00
0Woo00<007oo00009Woo00<007ooOol00Woo00<007oo000067oo0017Ool20004Ool00`00Oomoo`0V
Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`0WOol01@00Oomoogoo
00009goo0`000goo00<007ooOol05goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol001eo
o`03001oogoo0?moo`5oo`005goom0005Goo000MOol00`00Oomoo`0[Ool00`00Oomoo`0[Ool00`00
Oomoo`0/Ool00`00Oomoo`0[Ool00`00Oomoo`0[Ool00`00Oomoo`0IOol001eoo`03001oogoo0?mo
o`5oo`007Goo00<007ooOol0IWoo1@0000=oo`0000002`000Woo3@0000=oo`0000002`000Woo3@00
00=oo`0000002`000Woo3@0000=oo`0000002`000Woo3@0000=oo`0000000`006goo000MOol2001H
Ool50002Ool8002JOol001eoo`03001oogoo04moo`P00:Uoo`007Goo00<007ooOol017oo1P00?goo
1@00/Woo000MOol00`00Oomoo`04Ool00`00Oomoo`03Ool3000gOol5002gOol001eoo`03001oogoo
009oo`8000Uoo`80039oo`<00;aoo`007Goo0P000goo00<007ooOol02Woo0P00;Goo0P00`7oo000M
Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0XOol20032Ool001eoo`05001oogooOol0
000@Ool2000VOol20034Ool001eoo`05001oogooOol0000BOol00`00Oomoo`0QOol20036Ool001eo
o`04001oogoo000DOol2000OOol20038Ool001eoo`800003Ool007oo01Eoo`03001oogoo01Yoo`80
0<Yoo`007Goo00<007oo000067oo0P005goo00<007ooOol0c7oo000MOol00`00Ool0000JOol2000D
Ool00`00Oomoo`3=Ool001eoo`8001eoo`80015oo`03001oogoo0<ioo`007Goo0P007goo0`003Goo
00<007ooOol0cgoo000MOol2000ROol2000:Ool00`00Oomoo`3@Ool001eoo`8002Aoo`@000Aoo`80
0==oo`007Goo0P00:7oo1000eGoo000EOol50003Ool00`00Oomoo`0YOol3003DOol001Moo`03001o
ogoo00=oo`03001oogoo02Qoo`04001oogooOol9003;Ool001Moo`03001oogoo00=oo`<003Eoo`D0
0<Ioo`005goo00<007ooOol00goo00<007ooOol09goo00<007ooOol047oo3`00]goo000GOol00`00
Oomoo`03Ool00`00Oomoo`0VOol00`00Oomoo`0POonL000KOol001Ioo`8000Eoo`03001oogoo02Eo
o`03001oogoo0=Qoo`007Goo00<007ooOol097oo00<007ooOol0fGoo000MOol2000TOol00`00Oomo
o`3JOol001eoo`03001oogoo02=oo`03001oogoo0=Yoo`007Goo00<007ooOol08Woo00<007ooOol0
fgoo000MOol00`00Oomoo`0ROol00`00Oomoo`3KOol001eoo`03001oogoo025oo`03001oogoo0=ao
o`007Goo0P008Woo00<007ooOol0g7oo000MOol00`00Oomoo`0POol00`00Oomoo`3MOol001eoo`03
001oogoo0?moo`5oo`007Goo00<007ooOol07goo00<007ooOol0gWoo000MOol2000OOol00`00Oomo
o`3OOol001eoo`03001oogoo01ioo`03001oogoo0=moo`007Goo00<007ooOol07Goo00<007ooOol0
h7oo000MOol00`00Oomoo`0LOol00`00Oomoo`3QOol001eoo`03001oogoo01aoo`03001oogoo0>5o
o`007Goo0P0077oo00<007ooOol0hWoo000MOol00`00Oomoo`0KOol00`00Oomoo`3ROol001eoo`03
001oogoo01Yoo`03001oogoo0>=oo`005Woo0`0017oo00<007ooOol06Woo00<007ooOol0hgoo000F
Ool00`00Oomoo`04Ool00`00Oomoo`0IOol00`00Oomoo`3TOol001Moo`03001oogoo00=oo`<001Uo
o`03001oogoo0>Aoo`005goo00<007ooOol00goo00<007ooOol0ogoo0Goo000FOol00`00Ool00004
Ool00`00Oomoo`0HOol00`00Oomoo`3UOol001Moo`03001oogoo00=oo`03001oogoo01Qoo`03001o
ogoo0>Eoo`007Goo00<007ooOol05goo00<007ooOol0iWoo000MOol2000HOol00`00Oomoo`3VOol0
01eoo`03001oogoo01Moo`03001oogoo0>Ioo`007Goo00<007ooOol05goo00<007ooOol0iWoo000M
Ool00`00Oomoo`0FOol00`00Oomoo`3WOol001eoo`03001oogoo01Ioo`03001oogoo0>Moo`007Goo
0P005Woo00<007ooOol0j7oo000MOol00`00Oomoo`0EOol00`00Oomoo`3XOol001eoo`03001oogoo
01Aoo`03001oogoo0>Uoo`007Goo00<007ooOol057oo00<007ooOol0jGoo000MOol00`00Oomoo`3o
Ool1Ool001eoo`800?moo`9oo`007Goo00<007ooOol057oo00<007ooOol0jGoo000MOol00`00Oomo
o`0DOol00`00Oomoo`3YOol001eoo`03001oogoo01=oo`03001oogoo0>Yoo`007Goo00<007ooOol0
4goo00<007ooOol0jWoo000MOol2000COol00`00Oomoo`3[Ool001eoo`03001oogoo019oo`03001o
ogoo0>]oo`005Woo0P001Goo00<007ooOol04Woo00<007ooOol0jgoo000HOol00`00Oomoo`02Ool0
0`00Oomoo`0AOol00`00Oomoo`3/Ool001Moo`03001oogoo00=oo`<0015oo`03001oogoo0>aoo`00
67oo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol0k7oo000FOol00`00Ool00004Ool00`00
Oomoo`0@Ool00`00Oomoo`3]Ool001Moo`03001oogoo00=oo`03001oogoo011oo`03001oogoo0>eo
o`007Goo00<007ooOol0ogoo0Goo000MOol2003oOol2Ool001eoo`03001oogoo00moo`03001oogoo
0>ioo`007Goo00<007ooOol03goo00<007ooOol0kWoo000MOol00`00Oomoo`0>Ool00`00Oomoo`3_
Ool001eoo`03001oogoo00ioo`03001oogoo0>moo`007Goo0P003goo00<007ooOol0kgoo000MOol0
0`00Oomoo`0>Ool00`00Oomoo`3_Ool001eoo`03001oogoo00eoo`03001oogoo0?1oo`007Goo00<0
07ooOol03Goo00<007ooOol0l7oo000MOol00`00Oomoo`0=Ool00`00Oomoo`3`Ool001eoo`8000io
o`03001oogoo0?1oo`007Goo00<007ooOol037oo00<007ooOol0lGoo000MOol00`00Oomoo`0<Ool0
0`00Oomoo`3aOol001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0ogoo0Goo000MOol2000=
Ool00`00Oomoo`3aOol001eoo`03001oogoo00]oo`03001oogoo0?9oo`007Goo00<007ooOol02goo
00<007ooOol0lWoo000GOol30003Ool00`00Oomoo`0;Ool00`00Oomoo`3bOol001Qoo`03001oogoo
009oo`03001oogoo00Yoo`03001oogoo0?=oo`005Woo10000goo0`002Woo00<007ooOol0lgoo000F
Ool00`00Ool00004Ool00`00Oomoo`0:Ool00`00Oomoo`3cOol001Moo`8000Aoo`03001oogoo00Yo
o`03001oogoo0?=oo`0067oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0lgoo000MOol0
0`00Oomoo`09Ool00`00Oomoo`3dOol001eoo`8000Yoo`03001oogoo0?Aoo`007Goo00<007ooOol0
2Goo00<007ooOol0m7oo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo
0P002Goo00<007ooOol0mGoo000MOol00`00Oomoo`08Ool00`00Oomoo`3eOol001eoo`03001oogoo
00Qoo`03001oogoo0?Eoo`007Goo00<007ooOol027oo00<007ooOol0mGoo000MOol00`00Oomoo`07
Ool00`00Oomoo`3fOol001eoo`8000Qoo`03001oogoo0?Ioo`007Goo00<007ooOol01goo00<007oo
Ool0mWoo000MOol00`00Oomoo`07Ool00`00Oomoo`3fOol001eoo`03001oogoo00Moo`03001oogoo
0?Ioo`007Goo00<007ooOol01goo00<007ooOol0mWoo000MOol20007Ool00`00Oomoo`3gOol001eo
o`03001oogoo00Ioo`03001oogoo0?Moo`007Goo00<007ooOol01Woo00<007ooOol0mgoo000GOol0
0`00Oomoo`03Ool00`00Oomoo`3oOol1Ool001Ioo`03001oo`0000Aoo`03001oogoo00Eoo`03001o
ogoo0?Qoo`0067oo00<007ooOol00Woo0`001Goo00<007ooOol0n7oo000FOol20005Ool00`00Oomo
o`04Ool00`00Oomoo`3iOol001Ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo0?Uoo`00
5Woo0`0017oo00<007ooOol017oo00<007ooOol0nGoo000MOol00`00Oomoo`03Ool00`00Oomoo`3j
Ool001eoo`8000Aoo`03001oogoo0?Yoo`007Goo00<007ooOol00Woo00<007ooOol0ngoo000MOol0
0`00Oomoo`02Ool00`00Oomoo`3kOol001eoo`03001oogoo009oo`03001oogoo0?]oo`007Goo00D0
07ooOomoo`000?ioo`007Goo0P000Woo00<007ooOol0o7oo000MOol00`00Oomoo`3oOol1Ool001eo
o`03001oogoo0?moo`5oo`007Goo00D007ooOomoo`000?ioo`007Goo00D007ooOomoo`000?ioo`00
7Goo0P0000=oo`00Ool0oWoo000MOol01000Oomoo`00ogoo000MOol01000Oomoo`00ogoo000MOol0
0`00Ool0003oOol1Ool001eoo`<00?moo`5oo`007Goo0P00ogoo0Woo000MOol2003oOol2Ool001Io
o`8000Eoo`800?moo`9oo`005Woo00<007oo000017oo00<007ooOol0ogoo0Goo000FOol00`00Ool0
0004Ool3003oOol1Ool001Ioo`8000Eoo`03001oogoo0?moo`5oo`005Woo00<007ooOol017oo00<0
07ooOol0ogoo0Goo000GOol20004Ool00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol009Yoo`<008=oo`00Vgoo00<007oo
Ool0PWoo001XOol30003Ool20002Ool40002Ool20003Ool2000<Ool3000017oo001oogoo0P000Woo
0P000goo0`000goo0P0000=oo`0000000Woo00@007oo000000Aoo`8006ioo`00J7oo00<007oo0000
0Woo00D007ooOol007oo00<0009oo`06001oogoo001oo`003goo00H007ooOol007oo0006Ool01000
Oomoo`000Woo00<007oo00000Woo00<007oo00000Woo00D007ooOomoo`00009oo`03001oogoo06io
o`00JWoo00@007ooOol000Ioo`04001oogoo0004Ool3000=Ool30002Ool30003Ool01@00Oomoogoo
00000Woo00<007oo00000Woo00<007oo00000Woo00@007ooOol000=oo`<006ioo`00JGoo00<007oo
Ool010000goo0P0000=oo`0000000P000Woo0`003Goo00D007ooOol007oo00<000=oo`800003Ool0
0000008000=oo`800003Ool00000008000=oo`80009oo`<006ioo`00J7oo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol04Woo00@007ooOol0091oo`00J7oo0`0087oo1000TGoo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.44289, -0.495142, 
  0.216828, 0.0411642}},
  CellTags->"4.1"]
}, Open  ]],

Cell["\<\
We can see that (within this model) keeping initial inventory \
relatively large allows us to stabilize production rate at a new level. \
\>",
   "Text",
  CellTags->"4.1"],

Cell["Here is another discrete\[Hyphen]time system. ", "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["\<\
system = StateSpace[{{1/2, 1/4}, {1/4, 1/2}},
 DiagonalMatrix[{1, 1}],
 {{1, 2}},
 Sampled -> Period[1]
]\
\>", "Input",
  CellLabel->"In[8]:=",
  CellTags->"4.1"],

Cell[BoxData[
    \(StateSpace[{{1\/2, 1\/4}, {1\/4, 1\/2}}, {{1, 0}, {0, 1}}, {{1, 2}}, 
      Sampled \[Rule] Period[1]]\)], "Output",
  CellLabel->"Out[8]=",
  CellTags->"4.1"]
}, Open  ]],

Cell[TextData[{
  "In this input vector, the components are a ramp function and a decaying \
exponential ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(-t\)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " both sampled at a unit\[Hyphen]time interval. "
}], "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["inputs = {k, E^(-k)}", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"4.1"],

Cell[BoxData[
    \({k, E\^\(-k\)}\)], "Output",
  CellLabel->"Out[9]= ",
  CellTags->"4.1"]
}, Open  ]],

Cell["\<\
This is the state response for the particular set of initial \
conditions. \
\>", "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["\<\
StateResponse[system, inputs, k,
 InitialConditions -> {-1, 2}
]//Simplify\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"4.1"],

Cell[BoxData[
    \({\((
          \(-2560\) - 11\ 4\^\(2 - k\) + 17\ 3\^\(2 + k\)\ 4\^\(2 - k\) + 
            2560\ E - 2\^\(5 - 2\ k\)\ 3\^\(4 + k\)\ E + 5\ 4\^\(3 - k\)\ E - 
            480\ E\^2 - 141\ 4\^\(-k\)\ E\^2 + 
            55\ 3\^\(2 + k\)\ 4\^\(-k\)\ E\^2 + 72\ E\^\(2 - k\) + 
            48\ \((16 - 16\ E + 3\ E\^2)\)\ k)\)/
        \((18\ \((\(-4\) + E)\)\ \((\(-4\) + 3\ E)\))\), 
      \((\(-2048\) + 11\ 4\^\(2 - k\) + 17\ 3\^\(2 + k\)\ 4\^\(2 - k\) + 
            2048\ E - 2\^\(5 - 2\ k\)\ 3\^\(4 + k\)\ E - 5\ 4\^\(3 - k\)\ E - 
            384\ E\^2 + 141\ 4\^\(-k\)\ E\^2 + 
            55\ 3\^\(2 + k\)\ 4\^\(-k\)\ E\^2 + 288\ E\^\(1 - k\) - 
            144\ E\^\(2 - k\) + 24\ \((16 - 16\ E + 3\ E\^2)\)\ k)\)/
        \((18\ \((\(-4\) + E)\)\ \((\(-4\) + 3\ E)\))\)}\)], "Output",
  CellLabel->"Out[10]= ",
  CellTags->"4.1"]
}, Open  ]],

Cell["\<\
Once the state response vector is available, the output response \
can be found. \
\>", "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["OutputResponse[{{1, 2}}, %]//Simplify", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"4.1"],

Cell[BoxData[
    \({\((
          \(-3328\) + 11\ 2\^\(3 - 2\ k\) + 
            17\ 2\^\(3 - 2\ k\)\ 3\^\(3 + k\) + 3328\ E - 
            5\ 2\^\(5 - 2\ k\)\ E - 3\^\(5 + k\)\ 4\^\(2 - k\)\ E - 
            624\ E\^2 + 141\ 2\^\(\(-1\) - 2\ k\)\ E\^2 + 
            55\ 2\^\(\(-1\) - 2\ k\)\ 3\^\(3 + k\)\ E\^2 + 
            288\ E\^\(1 - k\) - 108\ E\^\(2 - k\) + 
            48\ \((16 - 16\ E + 3\ E\^2)\)\ k)\)/
        \((9\ \((\(-4\) + E)\)\ \((\(-4\) + 3\ E)\))\)}\)], "Output",
  CellLabel->"Out[11]= ",
  CellTags->"4.1"]
}, Open  ]],

Cell["The same result can be obtained directly. ", "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["\<\
OutputResponse[system, inputs, k,
 InitialConditions -> {-1, 2}
]//Simplify\
\>", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"4.1"],

Cell[BoxData[
    \({\((
          \(-3328\) + 11\ 2\^\(3 - 2\ k\) + 
            17\ 2\^\(3 - 2\ k\)\ 3\^\(3 + k\) + 3328\ E - 
            5\ 2\^\(5 - 2\ k\)\ E - 3\^\(5 + k\)\ 4\^\(2 - k\)\ E - 
            624\ E\^2 + 141\ 2\^\(\(-1\) - 2\ k\)\ E\^2 + 
            55\ 2\^\(\(-1\) - 2\ k\)\ 3\^\(3 + k\)\ E\^2 + 
            288\ E\^\(1 - k\) - 108\ E\^\(2 - k\) + 
            48\ \((16 - 16\ E + 3\ E\^2)\)\ k)\)/
        \((9\ \((\(-4\) + E)\)\ \((\(-4\) + 3\ E)\))\)}\)], "Output",
  CellLabel->"Out[12]= ",
  CellTags->"4.1"]
}, Open  ]],

Cell[TextData[{
  "Note that for both ",
  StyleBox["StateResponse", "MR"],
  " and ",
  StyleBox["OutputResponse", "MR"],
  ", the number of input signals must be equal to the number of inputs. For \
multi\[Hyphen]input systems, an input signal must be supplied as a vector of \
functions, but for single\[Hyphen]input systems, a function without the ",
  StyleBox["List", "MR"],
  " wrapping is also acceptable (in the simulation mode, the same rule of \
correspondence between the number of input signals and the number of inputs \
applies). If only the response from one or several, but not all, inputs must \
be studied, the function ",
  StyleBox["Subsystem", "MR"],
  " (or ",
  StyleBox["DeleteSubsystem", "MR"],
  ") may be used to select the subsystem of interest. For further examples \
when the same input signal is to be applied to all inputs in turn, see \
Section\[NonBreakingSpace]4.3. "
}], "Text",
  CellTags->"4.1"],

Cell["Here is a two\[Hyphen]input system. ", "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["TransferFunction[s, {{1/s, 1/(s^2+2s+10)}}]", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"4.1"],

Cell[BoxData[
    \(TransferFunction[s, {{1\/s, 1\/\(10 + 2\ s + s\^2\)}}]\)], "Output",
  CellLabel->"Out[13]= ",
  CellTags->"4.1"]
}, Open  ]],

Cell["\<\
This selects the subsystem associated with the second input and \
computes the output response to a delayed step function. \
\>", "MathCaption",\

  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["resp = OutputResponse[Subsystem[%, 2], UnitStep[t-1], t]", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"4.1"],

Cell[BoxData[
    \({1\/60\ 
        \((6 - \((3 + I)\)\ E\^\(\((\(-1\) - 3\ I)\)\ \((\(-1\) + t)\)\) - 
            \((3 - I)\)\ E\^\(\((\(-1\) + 3\ I)\)\ \((\(-1\) + t)\)\))\)\ 
        UnitStep[\(-1\) + t]}\)], "Output",
  CellLabel->"Out[14]= ",
  CellTags->"4.1"]
}, Open  ]],

Cell["This is a plot of the response. ", "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["Plot[%, {t, 0, 7}, PlotRange->All]", "Input",
  CellLabel->"In[15]:=",
  CellTags->"4.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0147151 4.35707 [
[.15986 .00222 -3 -9 ]
[.15986 .00222 3 0 ]
[.29592 .00222 -3 -9 ]
[.29592 .00222 3 0 ]
[.43197 .00222 -3 -9 ]
[.43197 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.70408 .00222 -3 -9 ]
[.70408 .00222 3 0 ]
[.84014 .00222 -3 -9 ]
[.84014 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .10186 -24 -4.5 ]
[.01131 .10186 0 4.5 ]
[.01131 .189 -24 -4.5 ]
[.01131 .189 0 4.5 ]
[.01131 .27614 -24 -4.5 ]
[.01131 .27614 0 4.5 ]
[.01131 .36328 -24 -4.5 ]
[.01131 .36328 0 4.5 ]
[.01131 .45042 -18 -4.5 ]
[.01131 .45042 0 4.5 ]
[.01131 .53756 -24 -4.5 ]
[.01131 .53756 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .01472 m
.15986 .02097 L
s
[(1)] .15986 .00222 0 1 Mshowa
.29592 .01472 m
.29592 .02097 L
s
[(2)] .29592 .00222 0 1 Mshowa
.43197 .01472 m
.43197 .02097 L
s
[(3)] .43197 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(4)] .56803 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(5)] .70408 .00222 0 1 Mshowa
.84014 .01472 m
.84014 .02097 L
s
[(6)] .84014 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(7)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05102 .01472 m
.05102 .01847 L
s
.07823 .01472 m
.07823 .01847 L
s
.10544 .01472 m
.10544 .01847 L
s
.13265 .01472 m
.13265 .01847 L
s
.18707 .01472 m
.18707 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2415 .01472 m
.2415 .01847 L
s
.26871 .01472 m
.26871 .01847 L
s
.32313 .01472 m
.32313 .01847 L
s
.35034 .01472 m
.35034 .01847 L
s
.37755 .01472 m
.37755 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45918 .01472 m
.45918 .01847 L
s
.48639 .01472 m
.48639 .01847 L
s
.51361 .01472 m
.51361 .01847 L
s
.54082 .01472 m
.54082 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62245 .01472 m
.62245 .01847 L
s
.64966 .01472 m
.64966 .01847 L
s
.67687 .01472 m
.67687 .01847 L
s
.73129 .01472 m
.73129 .01847 L
s
.7585 .01472 m
.7585 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.81293 .01472 m
.81293 .01847 L
s
.86735 .01472 m
.86735 .01847 L
s
.89456 .01472 m
.89456 .01847 L
s
.92177 .01472 m
.92177 .01847 L
s
.94898 .01472 m
.94898 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10186 m
.03006 .10186 L
s
[(0.02)] .01131 .10186 1 0 Mshowa
.02381 .189 m
.03006 .189 L
s
[(0.04)] .01131 .189 1 0 Mshowa
.02381 .27614 m
.03006 .27614 L
s
[(0.06)] .01131 .27614 1 0 Mshowa
.02381 .36328 m
.03006 .36328 L
s
[(0.08)] .01131 .36328 1 0 Mshowa
.02381 .45042 m
.03006 .45042 L
s
[(0.1)] .01131 .45042 1 0 Mshowa
.02381 .53756 m
.03006 .53756 L
s
[(0.12)] .01131 .53756 1 0 Mshowa
.125 Mabswid
.02381 .0365 m
.02756 .0365 L
s
.02381 .05829 m
.02756 .05829 L
s
.02381 .08007 m
.02756 .08007 L
s
.02381 .12364 m
.02756 .12364 L
s
.02381 .14543 m
.02756 .14543 L
s
.02381 .16721 m
.02756 .16721 L
s
.02381 .21078 m
.02756 .21078 L
s
.02381 .23257 m
.02756 .23257 L
s
.02381 .25435 m
.02756 .25435 L
s
.02381 .29792 m
.02756 .29792 L
s
.02381 .31971 m
.02756 .31971 L
s
.02381 .3415 m
.02756 .3415 L
s
.02381 .38507 m
.02756 .38507 L
s
.02381 .40685 m
.02756 .40685 L
s
.02381 .42864 m
.02756 .42864 L
s
.02381 .47221 m
.02756 .47221 L
s
.02381 .49399 m
.02756 .49399 L
s
.02381 .51578 m
.02756 .51578 L
s
.02381 .55935 m
.02756 .55935 L
s
.02381 .58113 m
.02756 .58113 L
s
.02381 .60292 m
.02756 .60292 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.12507 .01472 L
.13506 .01472 L
.14415 .01472 L
.14868 .01472 L
.1536 .01472 L
.15586 .01472 L
.15709 .01472 L
.15825 .01472 L
.15923 .01472 L
.16029 .01474 L
.16146 .01501 L
.16254 .01555 L
.16375 .01646 L
.16504 .01778 L
.16736 .02108 L
.17012 .02644 L
.17262 .0326 L
.17756 .0481 L
.18221 .06638 L
.20229 .17552 L
.22076 .29703 L
.24118 .42532 L
.25115 .47862 L
.26025 .51969 L
.26966 .55374 L
.27857 .5777 L
.28346 .5874 L
.28798 .59426 L
.29034 .59705 L
.29295 .59952 L
.29425 .60052 L
.29566 .60142 L
.297 .60211 L
.29822 .60261 L
.29945 .60297 L
.30062 .6032 L
.30184 .60331 L
.30254 .60332 L
.30318 .60329 L
.30424 .60317 L
.30542 .60294 L
.30664 .60257 L
.30779 .60213 L
.31043 .60073 L
.31284 .59902 L
.31826 .59373 L
.32344 .58702 L
Mistroke
.32908 .57811 L
.33936 .55849 L
.36072 .51014 L
.38006 .46662 L
.38976 .44745 L
.40024 .42977 L
.41014 .41643 L
.41924 .40724 L
.42395 .40363 L
.429 .40065 L
.43145 .39951 L
.43376 .39863 L
.43583 .39799 L
.4381 .39744 L
.43939 .3972 L
.4406 .39703 L
.44188 .39689 L
.44259 .39684 L
.44325 .3968 L
.44436 .39677 L
.44557 .39678 L
.44684 .39683 L
.44801 .39691 L
.44869 .39698 L
.44942 .39707 L
.45074 .39726 L
.45322 .39775 L
.45611 .39851 L
.45878 .39939 L
.4685 .40385 L
.47758 .40949 L
.49823 .42539 L
.51685 .44044 L
.53711 .4545 L
.54812 .46037 L
.55297 .46249 L
.55832 .4645 L
.56301 .46595 L
.56807 .46722 L
.57086 .46778 L
.57342 .46821 L
.57605 .46857 L
.57844 .46884 L
.5796 .46894 L
.58087 .46903 L
.58196 .4691 L
.58317 .46916 L
.58444 .46921 L
.58514 .46923 L
.5858 .46924 L
Mistroke
.58697 .46925 L
.58822 .46925 L
.58939 .46923 L
.59067 .46919 L
.59187 .46915 L
.59298 .46909 L
.59509 .46895 L
.59734 .46876 L
.60293 .46811 L
.60819 .46728 L
.61803 .46526 L
.6566 .45467 L
.67616 .44973 L
.68652 .44764 L
.69222 .44667 L
.69762 .44589 L
.70275 .44526 L
.70832 .44471 L
.71338 .44433 L
.71579 .44419 L
.71806 .44407 L
.72035 .44398 L
.72246 .44391 L
.72357 .44389 L
.72479 .44386 L
.72602 .44384 L
.72731 .44383 L
.7286 .44382 L
.72977 .44381 L
.73042 .44382 L
.73112 .44382 L
.7324 .44383 L
.73359 .44384 L
.73486 .44386 L
.73713 .44391 L
.73966 .44398 L
.74207 .44407 L
.74658 .44427 L
.75672 .44492 L
.77504 .44653 L
.8133 .45023 L
.82347 .45103 L
.83303 .45164 L
.83833 .45193 L
.84405 .45219 L
.84921 .45238 L
.85402 .45252 L
.85863 .45262 L
.86121 .45266 L
.86356 .45269 L
Mistroke
.86614 .45272 L
.86759 .45273 L
.86828 .45273 L
.86893 .45273 L
.87011 .45274 L
.8714 .45274 L
.87266 .45274 L
.87337 .45274 L
.87401 .45274 L
.87531 .45274 L
.87603 .45273 L
.87669 .45273 L
.87918 .45271 L
.88057 .4527 L
.88208 .45268 L
.88482 .45265 L
.89017 .45256 L
.8951 .45245 L
.91391 .45191 L
.93457 .45119 L
.95571 .45049 L
.97498 .45 L
.97619 .44998 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00?Goo1@0087oo0`008Goo0P008goo0`008Goo00<007ooOol087oo0P0097oo00<0
07ooOol01Goo000oOol00`00Oomoo`0POol00`00Oomoo`0SOol00`00Oomoo`0QOol00`00Oomoo`0O
Ool00`00Ool0000QOol00`00Ool0000SOol00`00Oomoo`05Ool003moo`03001oogoo025oo`03001o
ogoo025oo`03001oogoo021oo`@0029oo`03001oogoo01moo`03001oo`0002=oo`03001oogoo00Eo
o`00?goo00<007ooOol08Goo00<007ooOol08Woo00<007ooOol07goo00<007oo00008Goo0P008Woo
0P009Goo00<007ooOol017oo000oOol00`00Oomoo`0POol00`00Ool0000QOol00`00Ool0000ROol2
000QOol00`00Oomoo`0QOol00`00Oomoo`0ROol00`00Ool00006Ool003ioo`8002=oo`03001oogoo
025oo`03001oogoo029oo`03001oogoo01moo`<0029oo`80029oo`<000Ioo`00ogoo8Goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001Aoool000d000006goo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol017oo0P001Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo000KOol00`00Oomoo`0QOol00`00Ool0
000QOol00`00Oomoo`0QOol00`00Oomoo`0ROol00`00Oomoo`0QOol00`00Oomoo`0QOol00`00Oomo
o`0QOol00`00Oomoo`05Ool001]oo`03001oogoo02Aoo`03001oogoo0=]oo`006goo00<007ooOol0
97oo00<007ooOol0fgoo000KOol00`00Oomoo`0TOol00`00Oomoo`3KOol001]oo`8002Ioo`03001o
ogoo0=Yoo`006goo00<007ooOol09Goo00<007ooOol0fWoo000KOol00`00Oomoo`0VOol00`00Oomo
o`3IOol001]oo`03001oogoo02Ioo`03001oogoo0=Uoo`006goo00<007ooOol09Woo00<007ooOol0
fGoo000KOol00`00Oomoo`0VOol00`00Oomoo`3IOol001]oo`8002Qoo`03001oogoo0=Qoo`006goo
00<007ooOol09goo00<007ooOol0f7oo000KOol00`00Oomoo`0WOol00`00Oomoo`3HOol001]oo`03
001oogoo02Moo`03001oogoo0=Qoo`006goo00<007ooOol09goo00<007ooOol0f7oo000KOol2000Y
Ool00`00Oomoo`3GOol001]oo`03001oogoo02Qoo`03001oogoo0=Moo`006goo00<007ooOol0:7oo
00<007ooOol0egoo000KOol00`00Oomoo`0XOol00`00Oomoo`3GOol000Ioo`03001oogoo009oo`03
001oogoo009oo`04001oogooOol30004Ool00`00Oomoo`0XOol00`00Oomoo`3GOol000Eoo`03001o
o`0000Moo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo02Qoo`03001oogoo0=Moo`001Goo
00<007oo00001goo00<007oo00000goo00<007ooOol00goo0P00:Woo00<007ooOol0eWoo0005Ool0
0`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`3FOol0
00Eoo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo02Uoo`03001oogoo
0=Ioo`001Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0:Goo00<0
07ooOol0eWoo000KOol00`00Oomoo`0YOol00`00Oomoo`3FOol001]oo`03001oogoo02Uoo`03001o
ogoo0=Ioo`006goo0P00:goo00<007ooOol0eGoo000KOol00`00Oomoo`0ZOol00`00Oomoo`3EOol0
01]oo`03001oogoo02Yoo`03001oogoo0=Eoo`006goo00<007ooOol0:Woo00<007ooOol0eGoo000K
Ool00`00Oomoo`0ZOol00`00Oomoo`3EOol001]oo`03001oogoo02Yoo`03001oogoo0=Eoo`006goo
0P00;7oo00<007ooOol0e7oo000KOol00`00Oomoo`0[Ool00`00Oomoo`3DOol001]oo`03001oogoo
02]oo`03001oogoo0=Aoo`006goo00<007ooOol0:goo00<007ooOol0e7oo000KOol00`00Oomoo`0[
Ool00`00Oomoo`3DOol001]oo`03001oogoo02]oo`03001oogoo0=Aoo`006goo0P00;Goo00<007oo
Ool0dgoo000KOol00`00Oomoo`0/Ool00`00Oomoo`3COol001]oo`03001oogoo02aoo`03001oogoo
0==oo`001Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo0`000goo00<007ooOol0
;7oo00<007ooOol0dgoo0005Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`02Ool00`00
Oomoo`0/Ool00`00Oomoo`3COol000Eoo`03001oo`0000Moo`03001oo`00009oo`@000=oo`8002eo
o`03001oogoo0==oo`001Goo00<007oo00001goo00<007oo00000Woo00<007oo000017oo00<007oo
Ool0;Goo00<007ooOol0dWoo0005Ool00`00Ool00007Ool00`00Ool00003Ool20004Ool00`00Oomo
o`0]Ool00`00Oomoo`3BOol000Ioo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo02eoo`03001oogoo0=9oo`006goo00<007ooOol0;Goo00<007ooOol0dWoo000KOol00`00
Oomoo`0]Ool00`00Oomoo`3BOol001]oo`8002ioo`03001oogoo0=9oo`006goo00<007ooOol0;Woo
00<007ooOol0dGoo000KOol00`00Oomoo`0^Ool00`00Oomoo`3AOol001]oo`03001oogoo02ioo`03
001oogoo0=5oo`006goo00<007ooOol0;Woo00<007ooOol0dGoo000KOol00`00Oomoo`0^Ool00`00
Oomoo`3AOol001]oo`8002moo`03001oogoo0=5oo`006goo00<007ooOol0;goo00<007ooOol0d7oo
000KOol00`00Oomoo`0_Ool00`00Oomoo`3@Ool001]oo`03001oogoo02moo`03001oogoo0=1oo`00
6goo00<007ooOol0;goo00<007ooOol0d7oo000KOol00`00Oomoo`0_Ool00`00Oomoo`3@Ool001]o
o`80031oo`03001oogoo0=1oo`006goo00<007ooOol0;goo00<007ooOol0d7oo000KOol00`00Oomo
o`0`Ool00`00Oomoo`3?Ool000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20005
Ool00`00Oomoo`0`Ool00`00Oomoo`3?Ool000Eoo`03001oo`0000Moo`03001oo`00009oo`03001o
o`0000Aoo`03001oogoo031oo`03001oogoo0<moo`001Goo00<007oo00001goo00<007oo00000Woo
00<007oo000017oo0P00<Goo00<007ooOol0cgoo0005Ool00`00Ool00007Ool00`00Ool00002Ool2
0005Ool00`00Oomoo`0`Ool00`00Oomoo`3?Ool000Eoo`03001oo`0000Moo`03001oo`00009oo`03
001oogoo00Aoo`03001oogoo031oo`03001oogoo0<moo`001Woo00<007ooOol01goo00<007ooOol0
0Woo0P0017oo00<007ooOol0<Goo00<007ooOol0cWoo000KOol00`00Oomoo`0aOol00`00Oomoo`3>
Ool001]oo`03001oogoo035oo`03001oogoo0<ioo`006goo0P00<Woo00<007ooOol0cWoo000KOol0
0`00Oomoo`0aOol00`00Oomoo`3>Ool001]oo`03001oogoo035oo`03001oogoo0<ioo`006goo00<0
07ooOol0<Woo00<007ooOol0cGoo000KOol00`00Oomoo`0bOol00`00Oomoo`3=Ool001]oo`03001o
ogoo039oo`03001oogoo0<eoo`006goo0P00<goo00<007ooOol0cGoo000KOol00`00Oomoo`0bOol0
0`00Oomoo`3=Ool001]oo`03001oogoo039oo`03001oogoo0<eoo`006goo00<007ooOol0<goo00<0
07ooOol0c7oo000KOol00`00Oomoo`0cOol00`00Oomoo`3<Ool001]oo`03001oogoo03=oo`03001o
ogoo0<aoo`006goo0P00=7oo00<007ooOol0c7oo000KOol00`00Oomoo`0cOol00`00Oomoo`3<Ool0
01]oo`03001oogoo03=oo`03001oogoo0<aoo`006goo00<007ooOol0=7oo00<007ooOol0bgoo0006
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0d
Ool00`00Oomoo`3;Ool000Eoo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`03001o
ogoo03Aoo`03001oogoo0<]oo`001Goo00<007oo00001goo00<007oo00000Woo00<007oo000017oo
0P00=Goo00<007ooOol0bgoo0005Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`03Ool0
0`00Oomoo`0dOol00`00Oomoo`3;Ool000Eoo`03001oo`0000Moo`03001oo`00009oo`03001oo`00
00Aoo`03001oogoo03Eoo`03001oogoo0<Yoo`001Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0=Goo00<007ooOol0bWoo000KOol00`00Oomoo`0eOol00`00Oomoo`3:
Ool001]oo`8003Ioo`03001oogoo0<Yoo`006goo00<007ooOol0=Goo00<007ooOol0bWoo000KOol0
0`00Oomoo`0eOol00`00Oomoo`3:Ool001]oo`03001oogoo03Ioo`03001oogoo0<Uoo`006goo00<0
07ooOol0=Woo00<007ooOol0<7oo2@00T7oo000KOol00`00Oomoo`0fOol00`00Oomoo`0^Ool30008
Ool2002>Ool001]oo`8003Moo`03001oogoo02eoo`03001oogoo00]oo`8008aoo`006goo00<007oo
Ool0=Woo00<007ooOol0;7oo00<007ooOol03Woo00<007ooOol0RGoo000KOol00`00Oomoo`0fOol0
0`00Oomoo`0/Ool00`00Oomoo`0?Ool00`00Oomoo`28Ool001]oo`03001oogoo03Moo`03001oogoo
02Yoo`03001oogoo015oo`8008Qoo`006goo00<007ooOol0=goo00<007ooOol0:Goo00<007ooOol0
57oo00<007ooOol0QGoo000KOol00`00Oomoo`0gOol00`00Oomoo`0XOol00`00Oomoo`0FOol00`00
Oomoo`24Ool001]oo`8003Qoo`03001oogoo02Moo`03001oogoo01Qoo`03001oogoo08=oo`006goo
00<007ooOol0=goo00<007ooOol09Woo00<007ooOol06Woo0P00Pgoo000KOol00`00Oomoo`0gOol0
0`00Oomoo`0VOol00`00Oomoo`0LOol00`00Oomoo`20Ool001]oo`03001oogoo03Qoo`03001oogoo
02Aoo`03001oogoo01ioo`03001oogoo07moo`002goo00<007ooOol00Woo00<007ooOol01@000goo
00<007ooOol0>7oo00<007ooOol097oo00<007ooOol07goo00<007ooOol0;Goo4P00?goo000:Ool0
0`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`0hOol00`00Oomoo`0SOol00`00Oomoo`0QOol2
000XOol5000BOol7000hOol000Yoo`03001oo`0000Qoo`03001oogoo00=oo`8003Uoo`03001oogoo
02=oo`03001oogoo02=oo`03001oogoo025oo`@001iooc4000Moo`002Woo00<007oo000027oo00<0
07ooOol00goo00<007ooOol0>7oo00<007ooOol08Woo00<007ooOol09Goo0P007Goo1000FWoo000:
Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`0hOol00`00Oomoo`0ROol00`00Oomoo`0W
Ool2000HOol3001NOol000]oo`03001oogoo00Ioo`8000Eoo`03001oogoo03Qoo`03001oogoo025o
o`03001oogoo02Yoo`80019oo`@0065oo`006goo00<007ooOol0>Goo00<007ooOol087oo00<007oo
Ool0;7oo10002Goo1@00IGoo000KOol00`00Oomoo`0iOol00`00Oomoo`0OOol00`00Oomoo`0aOol9
001ZOol001]oo`8003Yoo`03001oogoo01moo`03001oogoo0:Aoo`006goo00<007ooOol0>Goo00<0
07ooOol07Woo00<007ooOol0YGoo000KOol00`00Oomoo`0iOol00`00Oomoo`0NOol00`00Oomoo`2U
Ool001]oo`03001oogoo03Yoo`03001oogoo01aoo`03001oogoo0:Ioo`006goo00<007ooOol0>Woo
00<007ooOol077oo00<007ooOol0YWoo000KOol2000kOol00`00Oomoo`0KOol00`00Oomoo`2WOol0
01]oo`03001oogoo03Yoo`03001oogoo01]oo`03001oogoo0:Moo`006goo00<007ooOol0>goo00<0
07ooOol06Goo00<007ooOol0Z7oo000KOol00`00Oomoo`0kOol00`00Oomoo`0IOol00`00Oomoo`2X
Ool001]oo`03001oogoo03]oo`03001oogoo01Qoo`03001oogoo0:Uoo`006goo00<007ooOol0>goo
00<007ooOol067oo00<007ooOol0ZGoo000KOol2000mOol00`00Oomoo`0GOol00`00Oomoo`2YOol0
01]oo`03001oogoo03aoo`03001oogoo01Ioo`03001oogoo0:Yoo`006goo00<007ooOol0?7oo00<0
07ooOol05Woo00<007ooOol0ZWoo000KOol00`00Oomoo`0lOol00`00Oomoo`0EOol00`00Oomoo`2[
Ool000Ioo`03001oogoo009oo`03001oogoo00D00004Ool000000004Ool00`00Oomoo`0mOol00`00
Oomoo`0DOol00`00Oomoo`2[Ool000Eoo`03001oo`0000Qoo`05001oogooOol00006Ool00`00Oomo
o`0mOol00`00Oomoo`0DOol00`00Oomoo`2[Ool000Eoo`03001oo`0000Qoo`03001oogoo009oo`03
001oogoo00=oo`8003ioo`03001oogoo01=oo`03001oogoo0:aoo`001Goo00<007oo000027oo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol0?Goo00<007ooOol04goo00<007ooOol0[7oo0005
Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo03ioo`03001oogoo019oo`03
001oogoo0:aoo`001Woo00<007ooOol01Woo0P0017oo00<007ooOol00goo00<007ooOol0?Woo00<0
07ooOol04Goo00<007ooOol0[Goo000KOol00`00Oomoo`0nOol00`00Oomoo`0AOol00`00Oomoo`2]
Ool001]oo`03001oogoo03ioo`03001oogoo011oo`03001oogoo0:ioo`006goo0P00@7oo00<007oo
Ool03goo00<007ooOol0[Woo000KOol00`00Oomoo`0oOol00`00Oomoo`0>Ool00`00Oomoo`2_Ool0
01]oo`03001oogoo041oo`03001oogoo00eoo`03001oogoo0:moo`006goo00<007ooOol0@7oo00<0
07ooOol037oo00<007ooOol0/7oo000KOol00`00Oomoo`11Ool00`00Oomoo`0;Ool00`00Oomoo`2`
Ool001]oo`03001oogoo045oo`03001oogoo00Yoo`03001oogoo0;5oo`006goo0P00@goo00<007oo
Ool027oo00<007ooOol0/Woo000KOol00`00Oomoo`12Ool00`00Oomoo`08Ool00`00Oomoo`2bOol0
01]oo`03001oogoo04=oo`03001oogoo00Ioo`03001oogoo0;=oo`006goo00<007ooOol0@goo00<0
07ooOol01Goo00<007ooOol0]7oo000KOol00`00Oomoo`14Ool00`00Oomoo`03Ool00`00Oomoo`2e
Ool001]oo`8004Eoo`H00;Qoo`006goo00<007ooOol0Agoo00<007ooOol0^7oo000KOol00`00Oomo
o`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.755053, -0.0124141, 
  0.0276311, 0.000862808}},
  CellTags->"4.1"]
}, Open  ]],

Cell[TextData[{
  "Returning to the analytical form of the response, ",
  StyleBox["ComplexExpand", "MR"],
  " may be used to reduce the complex exponentials to the trigonometric \
functions."
}], "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell["ComplexExpand[resp]", "Input",
  CellLabel->"In[16]:=",
  CellTags->"4.1"],

Cell[BoxData[
    \({1\/10\ UnitStep[\(-1\) + t] - 
        1\/10\ E\^\(1 - t\)\ Cos[3\ \((\(-1\) + t)\)]\ UnitStep[\(-1\) + t] - 
        1\/30\ E\^\(1 - t\)\ Sin[3\ \((\(-1\) + t)\)]\ UnitStep[\(-1\) + t]}
      \)], "Output",
  CellLabel->"Out[16]=",
  CellTags->"4.1"]
}, Open  ]],

Cell["This simplifies the result. ", "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // Simplify\)], "Input",
  CellLabel->"In[17]:=",
  CellTags->"4.1"],

Cell[BoxData[
    \({1\/30\ E\^\(-t\)\ 
        \((3\ E\^t - 3\ E\ Cos[3 - 3\ t] + E\ Sin[3 - 3\ t])\)\ 
        UnitStep[\(-1\) + t]}\)], "Output",
  CellLabel->"Out[17]=",
  CellTags->"4.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Simulating System Behavior", "Subsection",
  CellTags->"4.2"],

Cell[TextData[{
  "Once input signals are supplied to ",
  StyleBox["StateResponse", "MR"],
  " or ",
  StyleBox["OutputResponse", "MR"],
  " in a functional form, a symbolic solution based on Eq. (4.2) or Eq. (4.5) \
is attempted. There are, however, situations when the symbolic solution is \
either impossible or just too time consuming. In such cases, a ",
  StyleBox["simulation", "TI"],
  " of the state and output responses on some uniform time grid can be \
derived by supplying the input signal(s) on that time grid. The grid starts \
at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " (or ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0\)], "InlineFormula",
    CellTags->"S0.0.3"],
  "), the point at which the initial condition is set by ",
  StyleBox["InitialConditions", "MR"],
  ". For discrete\[Hyphen]time systems, the simulation then proceeds in a \
straightforward manner according to Eq. (4.4) starting from the initial \
conditions (with ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ") and then iterating for ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1, 2, \(\[Ellipsis]\ \)\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " . Continuous\[Hyphen]time systems are first converted to discrete time, \
and then the simulation is performed. To facilitate the conversion, the \
response functions accept the options pertinent to ",
  StyleBox["ToDiscreteTime", "MR"],
  ", notably ",
  StyleBox["Sampled", "MR"],
  " may be used to set the sampling period, and ",
  StyleBox["Method", "MR"],
  " to choose the conversion method. In the simulation mode, responses can \
currently be found for time\[Hyphen]invariant systems only. "
}], "Text",
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["StateResponse",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["u",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], " "}
          }], NotebookDefault]], "TopSpanBox",
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["state",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["response",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["discrete",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["input",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["sequences",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["u",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["OutputResponse",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["u",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["output",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["response",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["discrete",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["sequence",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["u",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["OutputResponse",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["c",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["d",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["x",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["u",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["output",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["response",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrices",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["c",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["and",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["d",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["from",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["simulated",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["state",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["response",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["x",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["and",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["input",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["sequences",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["u",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["OutputResponse",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["c",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["x",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["output",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["response",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["when",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["d",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["is",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["zero",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"4.2"],

Cell["State and output responses in the simulation mode. ", "Caption",
  CellTags->"4.2"],

Cell[TextData[{
  "When input signals are discretized, the input sequences ",
  StyleBox["u", "TI"],
  " must represent a ",
  StyleBox["matrix", "TI"],
  " each row of which corresponds to a signal at one input, and the number of \
rows must be equal to the number of inputs. For single\[Hyphen]input systems, \
the matrix may be reduced to a vector.   "
}], "Text",
  CellTags->"4.2"],

Cell[TextData[{
  "Here is a simple utility function that creates some ",
  StyleBox["-1", "MR"],
  " and ",
  StyleBox["1", "MR"],
  " points and rearranges them in such a way that the sequence simulates a \
square wave with period ",
  StyleBox["tau", "MR"],
  " sampled every ",
  StyleBox["delta", "MR"],
  " seconds, with a total duration somewhere around ",
  StyleBox["t", "MR"],
  ". "
}], "MathCaption",
  CellTags->"4.2"],

Cell["\<\
square[t_,tau_,delta_] := Flatten[
 Transpose /@ Partition[
 Table[{-1, 1}, {t/(2delta)}],
 tau/(2delta)
 ]
]\
\>", "Input",
  CellLabel->"In[18]:=",
  CellTags->"4.2"],

Cell[TextData[{
  "This is a sample output of this function for a chosen sampling period ",
  StyleBox["ts", "MR"],
  ". "
}], "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["ts = 1/8;  square[1.8, 1, ts]", "Input",
  CellLabel->"In[19]:=",
  CellTags->"4.2"],

Cell[BoxData[
    \({\(-1\), \(-1\), \(-1\), \(-1\), 1, 1, 1, 1}\)], "Output",
  CellLabel->"Out[19]=",
  CellTags->"4.2"]
}, Open  ]],

Cell["\<\
Consider the transfer function for the T\[Hyphen]bridge network in \
Figure\[NonBreakingSpace]4.2. \
\>", "MathCaption",
  CellTags->"4.2"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 195 92
%%HiResBoundingBox: 47 4 195 92
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (11:28:00 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 96 translate 1 -1 scale
gsave
47 92 translate
148 -88 scale
1 string
588 349 1 [588 0 0 349 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFC17FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC5FFFFFFFFFFFFFFF0
FFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF003FFFFFFFFFFFFFF0
FFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFC001FFFFFFFFFFFFFF0
FFFFFFFFFFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8000FFFFFFFFFFFFFF0
FFFFFFFFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF00007FFFFFFFFFFFFF0
FFFFFFFFFFFF03F03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03E07FFFFFFFFFFFFF0
FFFFFFFFFFFF07F81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE07F03FFFFFFFFFFFFF0
FFFFFFFFFFFE0FFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE0FF83FFFFFFFFFFFFF0
FFFFFFFFFFFE1FFC00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000001FFC1FFFFFFFFFFFFF0
FFFFFFFFFFFE1FFE00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000003FFE3FFFFFFFFFFFFF0
FFFFFFFFFFFC1FFC00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000001FFC1FFFFFFFFFFFFF0
FFFFFFFFFFFE1FFE00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000001FFC3FFFFFFFFFFFFF0
FFFFFFFFFFFE0FFC15555555555555555555555555555555555555555555
555555555500155555555555555555555555555555555555555555555555
5555555541FFC3FFFFFFFFFFFFF0
FFFFFFFFFFFE0FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE0FF83FFFFFFFFFFFFF0
FFFFFFFFFFFF07F03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF07F07FFFFFFFFFFFFF0
FFFFFFFFFFFF83E07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83E0FFFFFFFFFFFFFF0
FFFFFFFFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF00007FFFFFFFFFFFFF0
FFFFFFFFFFFFE000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFA001FFFFFFFFFFFFFF0
FFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFC001FFFFFFFFFFFFFF0
FFFFFFFFFFFFFA0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF80FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFF9
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE83FF9
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5C7F9
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFBF9
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFDF9
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFF9
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFD
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FF7F
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FF7F
FFF8000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FE7F
FFF8000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7C7F
FFF8000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF82BF
FFF8000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFD555555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC7FFFFFFFFF0
FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFBFFFFFFFFFF0
FFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF3CFFFFFFFFF0
FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE7EFFFFFFFFF0
FFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE7C7FFFFFFFF0
FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE7EFFFFFFFFF0
FFFFFFFFFDFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF7CFFFFFFFFF0
FFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFB8FFFFFFFFF0
FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7FF11FFFFFFFFF0
FFFFFFFFFC3FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF3FFFFFFFFFFFFF0
FFFFFFFFFC1FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF1FFFFFFFFFFFFF0
FFFFFFFFF8BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF1FFFFFFFFFFFFF0
FFFFFFFFF8DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFD555555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF0FFFFFFFFFFFFF0
FFFFFFFFF8EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE2FFFFFFFFFFFFF0
FFFFFFFFF9E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF17FFFFFFFFFFFF0
FFFFFFFFF8F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE3BFFFFFFFFFFFF0
FFFFFFFFF1F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFD555555405555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE33FFFFFFFFFFFF0
FFFFFFFFF9FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE3BFFFFFFFFFFFF0
FFFFFFFFF1FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC7DFFFFFFFFFFFF0
FFFFFFFFF9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE7EFFFFFFFFFFFF0
FFFFFFFFF1FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC7E7FFFFFFFFFFF0
FFFFFFFFF3FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE7F7FFFFFFFFFFF0
FFFFFFFFF1FF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC7F3FFFFFFFFFFF0
FFFFFFFFE3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCFFBFFFFFFFFFFF0
FFFFFFFFD57D5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC7F9FFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8FF8FFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF05F07FFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFD5FD7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFE3F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFE1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFF3F3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD57D5FFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFF1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FC7FFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFF9E3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FC7FFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFF1E3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFF8E3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFF8C7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFF8CFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC71FFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF3FFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFCFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC71FFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFC7C7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE63FFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFE7E7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFC7C3FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE38FFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C3FFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFE3C7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F3FFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFE3C7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F1FFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F1FFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F1FFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E3FFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFBFF
FFFFFFFFFFE0FFFFFFFFFEFFFFFFFBFFFBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFDFFF3FF
F7FFFFFFFFE1FFFFFFFFFE7FFDFFF9FFF3FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFF9FFFBFF
F3FFFFFFFFE0FFFFFFFFFE7FFCFFFBFFF3FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FF9FFF1FF
F3FFFFFFFFE1FFFFFFFFFC7FFCFFF1FFF1FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF8FFF1FF
E3FFFFFFFFE0FFFFFFFFFE7FF8FFF8FFE3FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FF07FF1FF
C1FFFFFFFFE1FFFFFFFFFC3FF87FF0FFE1FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FF0FFE0FF
E3FFFFFFFFE0FFFFFFFFF83FF87FF0FFE1FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FF07FC0FF
C1FFFFFFFFE1FFFFFFFFFC1FF07FF07FC1FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FE07FE0FF
C0FFFFFFFFE0FFFFFFFFF83FF83FE0FFE0FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFEFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFF417FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FE07FC07F
C0FFFFFFFFE1FFFFFFFFF01FF03FC07FC07FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF007FFFFFFFFFFFFFF0
FFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FE03FC07F
80FFFFFFFFE0FFFFFFFFF81FE03FE03F80FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE003FFFFFFFFFFFFFF0
FFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FC03FC07F
807FFFFFFFE1FFFFFFFFF01FE01FC03F807FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8001FFFFFFFFFFFFFF0
FFFFFFFFFFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FE03F803F
80FFFFFFFFE0FFFFFFFFF00FE01FC03F807FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8080FFFFFFFFFFFFFF0
FFFFFFFFFFFF01407FFFFFFFFFFFFFFFFF57FFFFFFFFFFFFE00FC01F803F
007FFFFFFFE1FFFFFFFFF007C01FC01F007FFFFFFFFFFFC7FFFFFFFFFFFF
FFFFFFFFF01C07FFFFFFFFFFFFF0
FFFFFFFFFFFF03F83FFFFFFFFFFFFFFFFE03FFFFFFFFFFFFE00FC23F803F
083FFFFFFFE0FFFFFFFFE00FE21F823F803FFFFFFFFFFF83FFFFFFFFFFFF
FFFFFFFFE0FF83FFFFFFFFFFFFF0
FFFFFFFFFFFF07F81FFFFFFFFFFFFFFFFC01FFFFFFFFFFFFC107C01F041F
083FFFFFFFE1FFFFFFFFE107C10F841F041FFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFE0FF83FFFFFFFFFFFFF0
FFFFFFFFFFFE0FFC3FFFFFFFFFFFFFFFF803FFFFFFFFFFFFC38F820F8E3E
083FFFFFFFE0FFFFFFFFE187C20F861F0C3FFFFFFFFFFE00FFFFFFFFFFFF
FFFFFFFFE1FFC3FFFFFFFFFFFFF0
FFFFFFFFFFFE1FFC00000000000000000000000000000007C107060F041E
0C000000000000000007C1078307060F0400000000000000000000000000
0000000001FFC1FFFFFFFFFFFFF0
FFFFFFFFFFFE1FFE0000000000000000000000000000000B8387870E0E1E
1E000000000000000003E383830F0E0E0E00000000000000000000000000
0000000003FFE3FFFFFFFFFFFFF0
FFFFFFFFFFFC1FFC00000000000000000000000000000001838707061E1C
1D000000000000000001C1C307070F0E1F00000000000000000000000000
0000000001FFC1FFFFFFFFFFFFF0
FFFFFFFFFFFE0FFE0000000000000000000000000000000387830F8E0E0C
3F80000000000000000183C38F860F0E1F80000000000000000000000000
0000000001FFC3FFFFFFFFFFFFF0
FFFFFFFFFFFE0FFC1FFFFFFFFFFFFFFFFC03FFFFFFFFFFC107C307041F04
1FFFFFFFFFFFFFFFFFE087C107860F041FFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFE0FF83FFFFFFFFFFFFF0
FFFFFFFFFFFE0FF83FFFFFFFFFFFFFFFFE0FFFFFFFFFFFE187C20F823F08
3FFFFFFFFFFFFFFFFFE083E30F821F843FFFFFFFFFFFFF83FFFFFFFFFFFF
FFFFFFFFE0FF83FFFFFFFFFFFFF0
FFFFFFFFFFFF07F03FFFFFFFFFFFFFFFFF0FFFFFFFFFFFF007C01F801F00
3FFFFFFFFFFFFFFFFFF007C00FC01F801FFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFF01C07FFFFFFFFFFFFF0
FFFFFFFFFFFF80A07FFFFFFFFFFFFFFFFF0FFFFFFFFFFFE00FE01F803F80
7FFFFFFFFFFFFFFFFFF00FE00FC03F803FFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFF8080FFFFFFFFFFFFFF0
FFFFFFFFFFFF80007FFFFFFFFFFFFFFFFF0FFFFFFFFFFFF00FE01FC03F80
7FFFFFFFFFFFFFFFFFF007E01FC01FC07FFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFC000FFFFFFFFFFFFFF0
FFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFF0FFFFFFFFFFFF00FE03FE03F80
FFFFFFFFFFFFFFFFFFF80FF01FE03FC07FFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFE003FFFFFFFFFFFFFF0
FFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFF0FFFFFFFFFFFF01FF01FC07FC0
7FFFFFFFFFFFFFFFFFF81FF01FE03FC07FFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFF007FFFFFFFFFFFFFF0
FFFFFFFFFFFFFE2FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFF81FF03FE0FFC0
FFFFFFFFFFFFFFFFFFF80FF83FE07FE0FFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFF81FF07FE07FC0
FFFFFFFFFFFFFFFFFFFC1FF03FF07FC07FFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFF83FF83FE0FFE0
FFFFFFFFFFFFFFFFFFFC3FF83FF07FE0FFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFC3FF07FF0FFC1
FFFFFFFFFFFFFFFFFFFC1FF87FF07FF1FFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFC3FF8FFF0FFE1
FFFFFFFFFFFFFFFFFFFE3FF87FF8FFF0FFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFC7FFC7FF1FFF1
FFFFFFFFFFFFFFFFFFFE3FFC7FF0FFF1FFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFE7FF8FFF9FFF3
FFFFFFFFFFFFFFFFFFFE3FFEFFF8FFFBFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFE7FFDFFF9FFF3
FFFFFFFFFFFFFFFFFFFF7FFCFFFDFFF1FFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFEFFFEFFFBFFFB
FFFFFFFFFFFFFFFFFFFF7FFEFFFDFFFBFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFF7FFDFFFFFFF7
FFFFFFFFFFFFFFFFFFFF7FFFFFFDFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFD5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF05555555555555555555555555
5555555507FFFC1555555555555555555555555555555541FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000FFFFE0000000000000000000000000000000003FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
0000000007FFFC0000000000000000000000000000000001FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000FFFFE0000000000000000000000000000000003FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
0000000007FFFC0000000000000000000000000000000001FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FC1FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8AFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E1F1EF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E7FFEF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C7FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8FFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
87FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
87FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8FF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FE3FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF041FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{148, 88},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002D0000F1000`40O003h00OU7oo002DOol009Ao
o`0037oo00AJeQ24248aS79oo`04F]H@Q124>Lh>Ool000]oo`06Mkd004YBG_LHaT8@=Goo00=g_B48
>Lh0>7oo00I[FP00BU9F]@Q2DY@=Ool000]oo`05E[DQ27ooOomBU01b00001BU:OomoodYB<H`03Goo
000;Ool026mk249W>GNm6<I246mkJeXTKg/00gNmKg]_N`0<Kg/00fLi6<HicP0CKg/00f]JKg]_N`0R
Kg/01Ukg48AW>GNm6<IJePeoo`0037oo00EF]A24000YBWNm03Ioo`038@QBU7oo03Qoo`05@Q08@P00
<Hag_@0=Ool000ioo`03Mkeoogoo03Ioo`038@QBU7oo03Yoo`03Mkeoogoo00eoo`00Agoo00<Q25:D
Ool0BWoo0017Ool00b48DYAoo`1:Ool004Moo`038@QBU7oo04Yoo`00Agoo00<Q25:DOol0BWoo0017
Ool00b48DYAoo`1:Ool004Moo`038@QF]Goo04Yoo`00Agoo00<Q25:DOol0BWoo0017Ool00b48DYAo
o`1:Ool003]oo`03G_MF]Goo00Uoo`038@QBU7oo04Yoo`00>7oo00=g_GooOol00Ukg2Woo00<Q25:D
Ool0BWoo000fOol01E[FBU9F]EkgMkd00Ukg2Woo00<Q25:DOol0BWoo000fOol00bU:Oomoo`02Ool0
0gNmKg]oo`09Ool00b48DYAoo`1:Ool003Ioo`03<Ha[FWoo00ioo`038@QBU7oo04Yoo`00=Woo00EW
>BU:Mkeoofmk00Aoo`03MkeNmekg00ENm`036<HicUkg00ENm`03Mkeoogoo049oo`00=goo00Ag_E:D
G_M:DPAoo`03IcT@Q12400d@Q003DYAoogoo049oo`0037oo00=NmgooOol0QGoo000<Ool00e:DOomo
o`1jOol00eJeIcUoo`08Ool000Uoo`04MkeoogooF]IkOol016LiG_MBU7Nm27oo0009Ool0148@DYAo
ofLiNGoo00EBU7ooOomNme:D00Uoo`002Goo00<YBUkgMkd0<goo00=_Nc6<<H`03C6<00=NmgooOol0
<goo00=g_AS6Mkd037oo0009Ool00bU:OomJeP0cOol00gNmDYABU005DY@00a24<HaBU005DY@00fLi
Oomoo`0cOol00eJeBU9F]@0<Ool000Uoo`04<Haooe[FKg/jOol00b48DYAoo`0kOol015:DG_M_Nekg
2goo0008Ool01FmkG_Mg_FmkG_L0>Woo00<Q25:DOol0>goo00DYBVLiOolaS7Nm00Yoo`00Agoo00<Q
25:DOol03goo00A_NgNmOom[FSMoo`00<7oo00Eg_FmkMkeg_Fmk019oo`038@QBU7oo00moo`04<Ha_
NdYBE[DgOol0035oo`04<HaW>E:DDY@BOol00b48DYAoo`0?Ool00eJeDY@Q200hOol0035oo`04E[EB
U36<MkdBOol00b48DYAoo`0?Ool017Nm:DYBU5Je=goo000aOol017Nm8@PaS5kg4Woo00<Q25:DOol0
47oo00@YBWoo5:E_NcIoo`00<Woo00<Q27oo:DX04Woo00<Q25:DOol047oo00=:DUkg@Q00=goo000b
Ool00e[FE[EJeP0BOol00b48DYAoo`1:Ool004Moo`038@QBU7oo04Yoo`00Agoo00<Q25:DOol0BWoo
000aOol01FmkE[EoogooF]H00goo00EBU7NmOomooe[F00Uoo`038@QBU7oo00Qoo`05@Q1oogooOomJ
eP02Ool01UJeKg]oogooIcUF]CEoo`00<Goo00IBU3W>OomoobU:DY@2Ool01RU:DYAoogoo48A_N`Qo
o`038@QBU7oo00Moo`06Mkd@Q7NmOomF]BU:0Woo00I:DSW>OomoocW>BU8eOol000eoo`8e[@03G_Mo
ogoo01moo`06:DXDYGooOol003F]0Woo00H8@RU:Oomg_@00@Q08Ool00b48BU9oo`07Ool01UJe001[
FWoo@Q00009oo`065:DQ27ooOolQ21BU8goo00Ag_B48:DYNm`ioo`0037oo0QS600<YBQ24IcT04Goo
00=BU5kgOol037oo00h8@P00IcUW>@Q26<IoofLi0008@WooDY@8@R4827oo00<Q25:DOol01goo00Xi
cP00@Q1ooaS6249NmgNm0008@P9g_@800003Mkeoogoo00Uoo`03BU9g_Goo01=oo`06Mkd@Q2U:>Lh@
Q6Li3Goo000;Ool01VLi48Ag_Goo@Q0HaQ124003:DX000Q200]2400@G_MF]A24<Ha:DT8@:DX8@Ukg
@Q0aS124IcTYBSW>2488@Q000a24:DY24005@Q003dYBOolHaSW>6<I_N`00<H`icU:D:DXHaU:DBU8@
Q002:DX:@Q000bU:000@Q00D@Q001RU:8@Qoogoo@Q0icPeoo`002goo00IF]@Q2Oomood8@6<H@@Q00
0cW>000Q200:@Q004CW>248icSW>DY@YBQS6DY@aS2U:6<INmc6<>Lh006mkG_L0448@00X@Q3W>249g
_@Q2@Q0aS5Je6<HYBP9:DP04<H`DYDYBMkd;@Q000cW>000Q200D@Q001RU:48Aoogoo<H`icPeoo`00
37oo00DYBQS6<H`@Q5kg015oo`038@QNmgoo00Yoo`086<H005JeMkd000Q2OomJeP800004MkeF]@00
8@PBOol02TYB000aS7oo8@P005:DOol8@P000Vmk0P0000=W>GooOol02goo00<aS5:DOol057oo00Da
S0Q26<H@Q7Nm00eoo`003Goo00=F]DYBIcT04Woo00<Q25kgOol02Woo00XicPQ2OomoobU:8@QoogNm
000aS09oo`03248icWoo015oo`0:Kg/005kgOomBU000Mkeooc6<6<H2Ool00a245:Eoo`0=Ool00c6<
DYAoo`0EOol2G_L00gNmOomoo`0<Ool0029oo`038@QNmgoo00Yoo`06IcTaS7ooOom245:D0Woo00He
[E:DOomoobU:IcTCOol01AS6Mkeoofmk<H`00Woo00IBU3W>OomoodYBE[D>Ool00c6<DYAoo`0VOol0
029oo`038@QNmgoo00]oo`05HaQoogooKg]g_@02Ool01F]JMkeoogooHaP057oo00EW>GooOomoofLi
00=oo`05IcUoogooIcUg_@0>Ool00c6<DYAoo`0VOol0029oo`038@QNmgoo04Ioo`03<HaBU7oo02Io
o`008Woo00<Q25kgOol0AWoo00<aS5:DOol09Woo000ROol00b48G_Moo`16Ool00c6<DYAoo`0VOol0
029oo`038@QNmgoo04Ioo`03<HaBU7oo02Ioo`008Woo00<Q25kgOol0AWoo00<aS5:DOol09Woo000R
Ool00b48G_Moo`16Ool00c6<DYAoo`0VOol0029oo`038@QNmgoo04Ioo`03<HaBU7oo02Ioo`008Woo
00<Q25kgOol07goo00=W>E[FOol00goo00=F]GNmOol07Woo00<aS5:DOol09Woo000ROol00b48G_Mo
o`0OOol00e:D<Haoo`03Ool00a24Kg]oo`0NOol00c6<DYAoo`0VOol0029oo`038@QNmgoo01moo`03
DY@aS7oo00=oo`0348A_Ngoo01ioo`03<HaBU7oo02Ioo`008Woo00<Q25kgOol07goo00=BU36<Ool0
0goo00<@Q6mkOol07Woo00<aS5:DOol09Woo000ROol00b48G_Moo`0OOol00e:D<Haoo`03Ool00a24
Kg]oo`0NOol00c6<DYAoo`0VOol0029oo`038@QNmgoo01moo`03DY@aS7oo00=oo`0348A_Ngoo01io
o`03<HaBU7oo02Ioo`008Woo00<Q25kgOol07goo00=BU36<Ool00goo00<@Q6mkOol07Woo00<aS5:D
Ool09Woo000ROol00b48G_Moo`0OOol00e:D<Haoo`03Ool00a24Kg]oo`0NOol00c6<DYAoo`0VOol0
029oo`038@P8@Q24018@Q0035:D@Q12400X@Q003248aS7oo00=ooa8@Q003248@Q12400`@Q003249B
U7oo02Ioo`008Woo00=W>EkgG_L07ekg00=2436<Ool00goo00<@Q5JeG_L07ekg00=_NgooOol09Goo
0014Ool00e:D<Haoo`03Ool00a24Kg]oo`17Ool004Aoo`03DY@aS7oo00=oo`0348A_Ngoo04Moo`00
A7oo00=BU36<Ool00goo00<@Q6mkOol0Agoo0014Ool00e:D<Haoo`03Ool00a24Kg]oo`17Ool004Ao
o`03DY@aS7oo00=oo`0348A_Ngoo04Moo`00A7oo00=:DRU:Ool00goo00<8@V]JOol0Agoo0014Ool0
0fLiF]Ioo`03Ool00dYBMkeoo`17Ool0045oo`924003IcUoogoo04ioo`00@Goo00=g_FLiOol0D7oo
000mOol00ekg@Q1Nm`02Mkd00e:DKg]oo`1?Ool003aoo`03Kg/aS7oo009oo`03G_M:DWoo051oo`00
?7oo00=W>C6<Ool0EGoo000mOol00bU:Mkeoo`1DOol003eoo`05Kg]:DVLiAS5_N`1BOol003moo`03
Mkeoogoo059oo`00U7oo002DOol009Aoo`00U7oo002DOol00001\
\>"],
  CellTags->"4.2"],

Cell[TextData[{
  StyleBox["Figure 4.2. ",
    FontWeight->"Bold"],
  "A T\[Hyphen]bridge."
}], "Caption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["\<\
bridge = TransferFunction[s,
 (r^2 c1 c2 s^2 + 2 r c2 s + 1)/
 (r^2 c1 c2 s^2 +(r c1 + 2 r c2)s + 1)
]\
\>", "Input",
  CellLabel->"In[20]:=",
  CellTags->"4.2"],

Cell[BoxData[
    \(TransferFunction[
      s, {{\(1 + 2\ c2\ r\ s + c1\ c2\ r\^2\ s\^2\)\/\(1 + 
              \((c1\ r + 2\ c2\ r)\)\ s + c1\ c2\ r\^2\ s\^2\)}}]\)], "Output",\

  CellLabel->"Out[20]=",
  CellTags->"4.2"]
}, Open  ]],

Cell["\<\
Here is the transfer function for a given set of parameters. \
\>", 
  "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["% /. {r -> 1, c1 -> 10, c2 -> .1}", "Input",
  CellLabel->"In[21]:=",
  CellTags->"4.2"],

Cell[BoxData[
    \(TransferFunction[
      s, {{\(1 + 0.2`\ s + 1.`\ s\^2\)\/\(1 + 10.2000000000000001`\ s + 
              1.`\ s\^2\)}}]\)], "Output",
  CellLabel->"Out[21]=",
  CellTags->"4.2"]
}, Open  ]],

Cell[TextData[{
  "Supplying a sampled input to ",
  StyleBox["OutputResponse", "MR"],
  " causes it to perform in the simulation mode. Note that the sampling \
period is supplied to specify the distance between points in the input \
vector; this is necessary to convert the system to discrete time properly. \
The output is a list of simulated responses. In this case, there is only one \
vector in the list since we are dealing with a system with one output. "
}], "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["\<\
outs = OutputResponse[%, square[3, 1, ts],
 Sampled -> Period[ts] ]\
\>", "Input",
  CellLabel->"In[22]:=",
  CellTags->"4.2"],

Cell[BoxData[
    \({{\(-1.`\), \(-0.295350087439501063`\), \(-0.10466360648290407`\), 
        \(-0.0592761481320418504`\), 1.94510997756281867`, 
        0.528700553449885113`, 0.137068432826103592`, 0.035244751598197066`, 
        \(-1.98469946215035708`\), \(-0.57228829768912961`\), 
        \(-0.181389000780915683`\), \(-0.0793792163433927377`\), 
        1.94100623595321746`, 0.529103711334936921`, 0.138727402426057189`, 
        0.0372400029135500076`, \(-1.98262784005053571`\), 
        \(-0.570213605505581355`\), \(-0.179331748075441943`\), 
        \(-0.0773449803185335404`\), 1.94301609984560919`, 
        0.531089039285041142`, 0.140688365050430697`, 0.0391768627731150509`}}
      \)], "Output",
  CellLabel->"Out[22]=",
  CellTags->"4.2"]
}, Open  ]],

Cell[TextData[{
  "The result can be drawn with the built\[Hyphen]in function ",
  StyleBox["ListPlot", "MR"],
  " (",
  StyleBox["MultipleListPlot", "MR"],
  " for multiple outputs). Here, however, we use a convenient utility \
function, ",
  StyleBox["SimulationPlot", "MR"],
  ", described later in this section. "
}], "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["SimulationPlot[%, Sampled -> Period[ts]]", "Input",
  CellLabel->"In[23]:=",
  CellTags->"4.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.331263 0.311982 0.149779 [
[.18944 .29948 -9 -9 ]
[.18944 .29948 9 0 ]
[.35507 .29948 -3 -9 ]
[.35507 .29948 3 0 ]
[.5207 .29948 -9 -9 ]
[.5207 .29948 9 0 ]
[.68634 .29948 -3 -9 ]
[.68634 .29948 3 0 ]
[.85197 .29948 -9 -9 ]
[.85197 .29948 9 0 ]
[.01131 .01242 -12 -4.5 ]
[.01131 .01242 0 4.5 ]
[.01131 .1622 -12 -4.5 ]
[.01131 .1622 0 4.5 ]
[.01131 .46176 -6 -4.5 ]
[.01131 .46176 0 4.5 ]
[.01131 .61154 -6 -4.5 ]
[.01131 .61154 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18944 .31198 m
.18944 .31823 L
s
[(0.5)] .18944 .29948 0 1 Mshowa
.35507 .31198 m
.35507 .31823 L
s
[(1)] .35507 .29948 0 1 Mshowa
.5207 .31198 m
.5207 .31823 L
s
[(1.5)] .5207 .29948 0 1 Mshowa
.68634 .31198 m
.68634 .31823 L
s
[(2)] .68634 .29948 0 1 Mshowa
.85197 .31198 m
.85197 .31823 L
s
[(2.5)] .85197 .29948 0 1 Mshowa
.125 Mabswid
.05694 .31198 m
.05694 .31573 L
s
.09006 .31198 m
.09006 .31573 L
s
.12319 .31198 m
.12319 .31573 L
s
.15631 .31198 m
.15631 .31573 L
s
.22257 .31198 m
.22257 .31573 L
s
.25569 .31198 m
.25569 .31573 L
s
.28882 .31198 m
.28882 .31573 L
s
.32195 .31198 m
.32195 .31573 L
s
.3882 .31198 m
.3882 .31573 L
s
.42133 .31198 m
.42133 .31573 L
s
.45445 .31198 m
.45445 .31573 L
s
.48758 .31198 m
.48758 .31573 L
s
.55383 .31198 m
.55383 .31573 L
s
.58696 .31198 m
.58696 .31573 L
s
.62008 .31198 m
.62008 .31573 L
s
.65321 .31198 m
.65321 .31573 L
s
.71946 .31198 m
.71946 .31573 L
s
.75259 .31198 m
.75259 .31573 L
s
.78571 .31198 m
.78571 .31573 L
s
.81884 .31198 m
.81884 .31573 L
s
.88509 .31198 m
.88509 .31573 L
s
.91822 .31198 m
.91822 .31573 L
s
.95135 .31198 m
.95135 .31573 L
s
.98447 .31198 m
.98447 .31573 L
s
.25 Mabswid
0 .31198 m
1 .31198 L
s
.02381 .01242 m
.03006 .01242 L
s
[(-2)] .01131 .01242 1 0 Mshowa
.02381 .1622 m
.03006 .1622 L
s
[(-1)] .01131 .1622 1 0 Mshowa
.02381 .46176 m
.03006 .46176 L
s
[(1)] .01131 .46176 1 0 Mshowa
.02381 .61154 m
.03006 .61154 L
s
[(2)] .01131 .61154 1 0 Mshowa
.125 Mabswid
.02381 .04238 m
.02756 .04238 L
s
.02381 .07234 m
.02756 .07234 L
s
.02381 .10229 m
.02756 .10229 L
s
.02381 .13225 m
.02756 .13225 L
s
.02381 .19216 m
.02756 .19216 L
s
.02381 .22211 m
.02756 .22211 L
s
.02381 .25207 m
.02756 .25207 L
s
.02381 .28203 m
.02756 .28203 L
s
.02381 .34194 m
.02756 .34194 L
s
.02381 .37189 m
.02756 .37189 L
s
.02381 .40185 m
.02756 .40185 L
s
.02381 .43181 m
.02756 .43181 L
s
.02381 .49172 m
.02756 .49172 L
s
.02381 .52167 m
.02756 .52167 L
s
.02381 .55163 m
.02756 .55163 L
s
.02381 .58158 m
.02756 .58158 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .1622 m
.06522 .26774 L
.10663 .29631 L
.14803 .3031 L
.18944 .60332 L
.23085 .39117 L
.27226 .33251 L
.31366 .31726 L
.35507 .01472 L
.39648 .22626 L
.43789 .28481 L
.4793 .30009 L
.5207 .6027 L
.56211 .39123 L
.60352 .33276 L
.64493 .31756 L
.68634 .01503 L
.72774 .22658 L
.76915 .28512 L
.81056 .3004 L
.85197 .60301 L
.89337 .39153 L
.93478 .33305 L
.97619 .31785 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000?Ool0
0`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`0027oo0`0017oo00<007ooOol0ogoo3goo
0008Ool00`00Oomoo`04Ool00`00Oomoo`3oOol?Ool000=oo`<000=oo`03001oogoo00=oo`<005Uo
o`03001oogoo05Uoo`03001oogoo05Ioo`002Goo00<007ooOol00goo00<007ooOol0FGoo00<007oo
Ool0FGoo00<007ooOol0EWoo0008Ool00`00Ool00004Ool00`00Oomoo`1IOol00`00Oomoo`1IOol0
0`00Oomoo`1FOol000Uoo`03001oogoo00=oo`03001oogoo05Uoo`8005Yoo`8005Moo`003goo00<0
07ooOol0F7oo00<007oo0000FGoo00<007oo0000Egoo000?Ool00`00Oomoo`1HOol00`00Ool0001I
Ool00`00Ool0001GOol000moo`03001oogoo05Qoo`03001oo`0005Uoo`03001oo`0005Moo`003goo
00<007ooOol0F7oo00<007oo0000FGoo00<007oo0000Egoo000?Ool2001IOol01000Oomoo`00F7oo
00@007ooOol005Ioo`003goo00<007ooOol0F7oo00@007ooOol005Qoo`04001oogoo001FOol000mo
o`03001oogoo05Qoo`04001oogoo001HOol01000Oomoo`00EWoo000?Ool00`00Oomoo`1HOol01000
Oomoo`00F7oo00@007ooOol005Ioo`003goo00<007ooOol0Egoo00D007ooOomoo`0005Moo`05001o
ogooOol0001FOol000moo`03001oogoo05Moo`03001oogoo009oo`03001oogoo05Aoo`03001oogoo
009oo`03001oogoo05=oo`003goo00<007ooOol0Egoo00<007ooOol00Woo00<007ooOol0E7oo00<0
07ooOol00Woo00<007ooOol0Dgoo000?Ool00`00Oomoo`1GOol00`00Oomoo`02Ool00`00Oomoo`1D
Ool00`00Oomoo`02Ool00`00Oomoo`1COol000moo`8005Qoo`03001oogoo009oo`03001oogoo05Ao
o`03001oogoo009oo`03001oogoo05=oo`003goo00<007ooOol0Egoo00<007ooOol00Woo00<007oo
Ool0E7oo00<007ooOol00Woo00<007ooOol0Dgoo000?Ool00`00Oomoo`1GOol00`00Oomoo`03Ool0
0`00Oomoo`1COol00`00Oomoo`03Ool00`00Oomoo`1BOol000moo`03001oogoo05Moo`03001oogoo
00=oo`03001oogoo05=oo`03001oogoo00=oo`03001oogoo059oo`003goo00<007ooOol0EWoo00<0
07ooOol017oo00<007ooOol0DWoo00<007ooOol017oo00<007ooOol0DWoo000?Ool00`00Oomoo`1F
Ool00`00Oomoo`04Ool00`00Oomoo`1BOol00`00Oomoo`04Ool00`00Oomoo`1BOol000moo`03001o
ogoo05Ioo`03001oogoo00Aoo`03001oogoo059oo`03001oogoo00Aoo`03001oogoo059oo`003goo
00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0DGoo00<007ooOol01Goo00<007ooOol0DGoo
000?Ool00`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomoo`1AOol00`00Oomoo`05Ool00`00Oomo
o`1AOol000moo`8005Moo`03001oogoo00Eoo`03001oogoo055oo`03001oogoo00Eoo`03001oogoo
055oo`003goo00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0DGoo00<007ooOol01Goo00<0
07ooOol0DGoo000?Ool00`00Oomoo`1EOol00`00Oomoo`06Ool00`00Oomoo`1AOol00`00Oomoo`05
Ool00`00Oomoo`1AOol000moo`03001oogoo05Eoo`03001oogoo00Moo`03001oogoo04moo`03001o
ogoo00Moo`03001oogoo051oo`003goo00<007ooOol0EGoo00<007ooOol01goo00<007ooOol0Cgoo
00<007ooOol01goo00<007ooOol0D7oo000?Ool00`00Oomoo`1EOol00`00Oomoo`07Ool00`00Oomo
o`1?Ool00`00Oomoo`07Ool00`00Oomoo`1@Ool000moo`03001oogoo05Eoo`03001oogoo00Moo`03
001oogoo04moo`03001oogoo00Moo`03001oogoo051oo`003goo00<007ooOol0EGoo00<007ooOol0
27oo00<007ooOol0CWoo00<007ooOol027oo00<007ooOol0Cgoo000?Ool2001FOol00`00Oomoo`08
Ool00`00Oomoo`1>Ool00`00Oomoo`08Ool00`00Oomoo`1?Ool000moo`03001oogoo05Eoo`03001o
ogoo00Qoo`03001oogoo04ioo`03001oogoo00Qoo`03001oogoo04moo`003goo00<007ooOol0E7oo
00<007ooOol02Goo00<007ooOol0CGoo00<007ooOol02Goo00<007ooOol0Cgoo000?Ool00`00Oomo
o`1DOol00`00Oomoo`09Ool00`00Oomoo`1=Ool00`00Oomoo`09Ool00`00Oomoo`1?Ool000moo`03
001oogoo05Aoo`03001oogoo00Yoo`03001oogoo04aoo`03001oogoo00Yoo`03001oogoo04ioo`00
3goo00<007ooOol0E7oo00<007ooOol02Woo00<007ooOol0C7oo00<007ooOol02Woo00<007ooOol0
CWoo0007Ool50003Ool00`00Oomoo`1DOol00`00Oomoo`0:Ool00`00Oomoo`1<Ool00`00Oomoo`0:
Ool00`00Oomoo`1>Ool000Uoo`03001oogoo00=oo`03001oogoo05Aoo`03001oogoo00Yoo`03001o
ogoo04aoo`03001oogoo00Yoo`03001oogoo04ioo`000goo0`000goo00<007ooOol00goo0`00E7oo
00<007ooOol02Woo00<007ooOol0C7oo00<007ooOol02Woo00<007ooOol0CWoo0009Ool00`00Oomo
o`03Ool00`00Oomoo`1COol00`00Oomoo`0<Ool00`00Oomoo`1;Ool00`00Oomoo`0;Ool00`00Oomo
o`1=Ool000Uoo`03001oogoo00=oo`8005Aoo`03001oogoo00aoo`03001oogoo04Yoo`03001oogoo
00aoo`03001oogoo04eoo`0027oo0P001Goo0P00E7oo00<007ooOol037oo00<007ooOol0BWoo00<0
07ooOol037oo00<007ooOol0CGoo000?Ool2001DOol00`00Oomoo`0<Ool00`00Oomoo`1:Ool00`00
Oomoo`0<Ool00`00Oomoo`1=Ool000moo`03001oo`0005=oo`03001oogoo00aoo`03001oogoo04Yo
o`03001oogoo00aoo`03001oogoo04eoo`003goo00<007oo0000Dgoo00<007ooOol03Goo00<007oo
Ool0BGoo00<007ooOol03Goo00<007ooOol0C7oo000?Ool01000Oomoo`00DWoo00<007ooOol03Goo
00<007ooOol0BGoo00<007ooOol03Goo00<007ooOol0C7oo000?Ool01000Oomoo`00DWoo00<007oo
Ool03Goo00<007ooOol0BGoo00<007ooOol03Goo00<007ooOol0C7oo000?Ool200000goo001oo`1@
Ool00`00Oomoo`0>Ool00`00Oomoo`19Ool00`00Oomoo`0=Ool00`00Oomoo`1<Ool000moo`05001o
ogooOol0001@Ool00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomoo`0>Ool00`00Oomoo`1<Ool0
00moo`05001oogooOol0001@Ool00`00Oomoo`0?Ool00`00Oomoo`17Ool00`00Oomoo`0?Ool00`00
Oomoo`1;Ool000moo`05001oogooOol0001@Ool00`00Oomoo`0?Ool00`00Oomoo`17Ool00`00Oomo
o`0?Ool00`00Oomoo`1;Ool000moo`03001oogoo009oo`03001oogoo04eoo`03001oogoo00moo`03
001oogoo04Moo`03001oogoo00moo`03001oogoo04]oo`003goo00<007ooOol00Woo00<007ooOol0
CGoo00<007ooOol03goo00<007ooOol0Agoo00<007ooOol03goo00<007ooOol0Bgoo000?Ool00`00
Oomoo`03Ool00`00Oomoo`1<Ool00`00Oomoo`0?Ool00`00Oomoo`17Ool00`00Oomoo`0?Ool00`00
Oomoo`1;Ool000moo`03001oogoo00=oo`03001oogoo04aoo`03001oogoo011oo`03001oogoo04Io
o`03001oogoo011oo`03001oogoo04Yoo`003goo0P0017oo00<007ooOol0Bgoo00<007ooOol04Goo
00<007ooOol0AGoo00<007ooOol04Goo00<007ooOol0BWoo000?Ool00`00Oomoo`04Ool00`00Oomo
o`1:Ool00`00Oomoo`0AOol00`00Oomoo`15Ool00`00Oomoo`0AOol00`00Oomoo`1:Ool000moo`03
001oogoo00Aoo`03001oogoo04Yoo`03001oogoo019oo`03001oogoo04Aoo`03001oogoo019oo`03
001oogoo04Uoo`003goo00<007ooOol017oo00<007ooOol0BWoo00<007ooOol04Woo00<007ooOol0
A7oo00<007ooOol04Woo00<007ooOol0BGoo000?Ool00`00Oomoo`05Ool00`00Oomoo`19Ool00`00
Oomoo`0COol00`00Oomoo`13Ool00`00Oomoo`0COol00`00Oomoo`18Ool000moo`03001oogoo00Eo
o`03001oogoo04Uoo`03001oogoo01Aoo`03001oogoo049oo`03001oogoo01Aoo`03001oogoo04Mo
o`003goo00<007ooOol01Goo00<007ooOol0BGoo00<007ooOol057oo00<007ooOol0@Woo00<007oo
Ool057oo00<007ooOol0Agoo000?Ool00`00Oomoo`06Ool00`00Oomoo`17Ool00`00Oomoo`0FOol0
0`00Oomoo`11Ool00`00Oomoo`0EOol00`00Oomoo`16Ool000moo`8000Moo`03001oogoo04Moo`03
001oogoo01Moo`03001oogoo03moo`03001oogoo01Moo`03001oogoo04Eoo`003goo00<007ooOol0
1goo00<007ooOol0AWoo00<007ooOol067oo00<007ooOol0?Woo00<007ooOol05goo00<007ooOol0
AGoo000?Ool00`00Oomoo`07Ool00`00Oomoo`16Ool00`00Oomoo`0HOol00`00Oomoo`0nOol00`00
Oomoo`0HOol00`00Oomoo`14Ool000moo`03001oogoo00Moo`03001oogoo04Ioo`03001oogoo01Uo
o`03001oogoo03eoo`03001oogoo01Qoo`03001oogoo04Aoo`003goo00<007ooOol027oo00<007oo
Ool0AGoo00<007ooOol06Woo00<007ooOol0?7oo00<007ooOol06Goo00<007ooOol0@goo000?Ool0
0`00Oomoo`08Ool00`00Oomoo`15Ool00`00Oomoo`0JOol00`00Oomoo`0lOol00`00Oomoo`0JOol0
0`00Oomoo`12Ool000moo`03001oogoo00Uoo`8001]oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo01eoo`03001oogoo00Aoo`D0019oo`03001oogoo00moo`D0009oo`03001oogoo009oo`03
001oogoo01eoo`03001oogoo00Eoo`<0019oo`03001oogoo015oo`<000=oo`03001oogoo009oo`03
001oogoo02=oo`003goo00<007ooOol02goo00<007ooOol05goo00<007oo00001goo00<007oo0000
7Goo00<007ooOol01goo00<007ooOol04goo00<007ooOol047oo00<007ooOol01Woo00<007oo0000
7Woo00<007ooOol01Goo00<007ooOol04goo00<007ooOol047oo00<007ooOol01goo00<007oo0000
97oo000?Ool00`00Oomoo`0<Ool2000GOol00`00Ool00009Ool00`00Oomoo`0KOol00`00Oomoo`07
Ool00`00Oomoo`0COol00`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`0KOol00`00Oomoo`07
Ool00`00Oomoo`0COol00`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`0ROol000moo`8000mo
o`03001oogoo01Aoo`03001oo`0000Moo`8001ioo`03001oogoo00Moo`03001oogoo01Aoo`80011o
o`03001oogoo00Ioo`8001ioo`03001oogoo00Moo`03001oogoo01=oo`03001oogoo011oo`03001o
ogoo00Ioo`8002Eoo`003goo00<007ooOol03goo0P0057oo00<007oo00001goo00<007ooOol07Goo
00<007ooOol01goo00<007ooOol05Woo0P003Woo00<007ooOol01Woo00<007ooOol07Goo00<007oo
Ool01Woo00<007oo00005Goo0P003goo00<007oo00001goo00<007ooOol097oo000?Ool00`00Oomo
o`0AOol00`00Oomoo`0BOol00`00Oomoo`06Ool3000MOol00`00Oomoo`06Ool2000JOol2000;Ool2
0008Ool3000MOol00`00Oomoo`07Ool00`00Oomoo`0FOol3000=Ool00`00Oomoo`06Ool3000TOol0
00moo`03001oogoo019oo`8003]oo`03001oogoo02Aoo`<0039oo`03001oogoo02=oo`<003Yoo`00
3goo00<007ooOol057oo0`00>7oo00<007ooOol09goo0P00<7oo00<007ooOol09Woo0`00=goo000?
Ool00`00Oomoo`0GOol6000bOol00`00Oomoo`0YOol2000^Ool00`00Oomoo`0YOol2000eOol000mo
o`03001oogoo01eoo`@002eoo`03001oogoo02]oo`03001oogoo02aoo`03001oogoo02Yoo`03001o
ogoo03=oo`003goo00<007ooOol087oo00<007ooOol0:goo00<007ooOol0:goo00<007ooOol0:goo
00<007ooOol0:goo00<007ooOol0<goo0008Oooo000I000000moo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo00Aoo`03001oo`0000Qoo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo00=oo`800003Ool007oo00Moo`03001oogoo00Ioo`03001o
ogoo00Moo`03001oogoo00Ioo`03001oogoo00Eoo`8000Qoo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oo`0000Qoo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Eoo`8000Qoo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Ioo`03001oogoo00Ioo`03001oogoo00=oo`003goo00<007ooOol08Goo00<007ooOol01goo
00<007ooOol07Goo0P0037oo00<007ooOol08Goo00<007ooOol01goo00<007ooOol07goo0P002Woo
00<007ooOol08Goo00<007ooOol01goo00<007ooOol07goo0P001goo000?Ool00`00Oomoo`0QOol0
0`00Oomoo`0UOol2000bOol00`00Oomoo`0VOol3000`Ool00`00Oomoo`0VOol30009Ool000moo`03
001oogoo025oo`03001oogoo029oo`<003Aoo`03001oogoo02=oo`<003=oo`03001oogoo02=oo`<0
00aoo`003goo00<007ooOol08Goo00<007ooOol087oo0P00=goo00<007ooOol087oo0`00=Woo00<0
07ooOol087oo0`003goo000?Ool00`00Oomoo`0QOol00`00Oomoo`0NOol2000iOol00`00Oomoo`0N
Ool2000iOol00`00Oomoo`0NOol2000BOol000moo`03001oogoo025oo`03001oogoo01eoo`03001o
ogoo03Uoo`03001oogoo01eoo`03001oogoo03Uoo`03001oogoo01eoo`03001oogoo019oo`003goo
0P008Woo00<007ooOol07Goo00<007ooOol0>Goo00<007ooOol07Goo00<007ooOol0>Goo00<007oo
Ool07Goo00<007ooOol04Woo000?Ool00`00Oomoo`0QOol00`00Oomoo`0LOol00`00Oomoo`0kOol0
0`00Oomoo`0KOol00`00Oomoo`0kOol00`00Oomoo`0KOol00`00Oomoo`0COol000moo`03001oogoo
029oo`03001oogoo01Yoo`03001oogoo03aoo`03001oogoo01Yoo`03001oogoo03aoo`03001oogoo
01Yoo`03001oogoo01Aoo`003goo00<007ooOol08Woo00<007ooOol06Woo00<007ooOol0?7oo00<0
07ooOol06Woo00<007ooOol0?7oo00<007ooOol06Woo00<007ooOol057oo000?Ool00`00Oomoo`0R
Ool00`00Oomoo`0IOol00`00Oomoo`0mOol00`00Oomoo`0IOol00`00Oomoo`0mOol00`00Oomoo`0I
Ool00`00Oomoo`0EOol000moo`03001oogoo029oo`03001oogoo01Qoo`03001oogoo03ioo`03001o
ogoo01Qoo`03001oogoo03ioo`03001oogoo01Qoo`03001oogoo01Ioo`003goo00<007ooOol08Woo
00<007ooOol05goo00<007ooOol0?goo00<007ooOol05goo00<007ooOol0?goo00<007ooOol05goo
00<007ooOol05goo000?Ool00`00Oomoo`0ROol00`00Oomoo`0GOol00`00Oomoo`0oOol00`00Oomo
o`0GOol00`00Oomoo`0oOol00`00Oomoo`0GOol00`00Oomoo`0GOol000moo`03001oogoo029oo`03
001oogoo01Ioo`03001oogoo041oo`03001oogoo01Ioo`03001oogoo041oo`03001oogoo01Ioo`03
001oogoo01Qoo`003goo0P0097oo00<007ooOol057oo00<007ooOol0@Woo00<007ooOol057oo00<0
07ooOol0@Woo00<007ooOol057oo00<007ooOol06Goo000?Ool00`00Oomoo`0SOol00`00Oomoo`0D
Ool00`00Oomoo`12Ool00`00Oomoo`0DOol00`00Oomoo`12Ool00`00Oomoo`0DOol00`00Oomoo`0I
Ool000moo`03001oogoo02=oo`03001oogoo01=oo`03001oogoo04=oo`03001oogoo01=oo`03001o
ogoo04=oo`03001oogoo01=oo`03001oogoo01Yoo`003goo00<007ooOol08goo00<007ooOol04Woo
00<007ooOol0A7oo00<007ooOol04Woo00<007ooOol0A7oo00<007ooOol04Woo00<007ooOol06goo
000?Ool00`00Oomoo`0SOol00`00Oomoo`0BOol00`00Oomoo`14Ool00`00Oomoo`0BOol00`00Oomo
o`14Ool00`00Oomoo`0BOol00`00Oomoo`0KOol000moo`03001oogoo02=oo`03001oogoo015oo`03
001oogoo04Eoo`03001oogoo015oo`03001oogoo04Eoo`03001oogoo015oo`03001oogoo01aoo`00
3goo00<007ooOol08goo00<007ooOol04Goo00<007ooOol0AGoo00<007ooOol04Goo00<007ooOol0
AGoo00<007ooOol04Goo00<007ooOol077oo000?Ool00`00Oomoo`0SOol00`00Oomoo`0AOol00`00
Oomoo`16Ool00`00Oomoo`0@Ool00`00Oomoo`16Ool00`00Oomoo`0@Ool00`00Oomoo`0LOol000mo
o`8002Eoo`03001oogoo00moo`03001oogoo04Moo`03001oogoo00moo`03001oogoo04Moo`03001o
ogoo00moo`03001oogoo01eoo`003goo00<007ooOol097oo00<007ooOol03goo00<007ooOol0Agoo
00<007ooOol03goo00<007ooOol0Agoo00<007ooOol03goo00<007ooOol07Goo000?Ool00`00Oomo
o`0TOol00`00Oomoo`0?Ool00`00Oomoo`17Ool00`00Oomoo`0?Ool00`00Oomoo`17Ool00`00Oomo
o`0?Ool00`00Oomoo`0MOol000moo`03001oogoo02Aoo`03001oogoo00moo`03001oogoo04Moo`03
001oogoo00moo`03001oogoo04Moo`03001oogoo00moo`03001oogoo01eoo`003goo00<007ooOol0
97oo00<007ooOol03goo00<007ooOol0Agoo00<007ooOol03goo00<007ooOol0Agoo00<007ooOol0
3goo00<007ooOol07Goo000?Ool00`00Oomoo`0TOol00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00
Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomoo`0>Ool00`00Oomoo`0NOol000moo`03001oogoo02Ao
o`03001oogoo00ioo`03001oogoo04Qoo`03001oogoo00ioo`03001oogoo04Qoo`03001oogoo00io
o`03001oogoo01ioo`003goo00<007ooOol09Goo00<007ooOol03Goo00<007ooOol0BGoo00<007oo
Ool03Goo00<007ooOol0BGoo00<007ooOol03Goo00<007ooOol07Woo000?Ool2000VOol00`00Oomo
o`0=Ool00`00Oomoo`19Ool00`00Oomoo`0=Ool00`00Oomoo`19Ool00`00Oomoo`0=Ool00`00Oomo
o`0NOol000moo`03001oogoo02Eoo`03001oogoo00eoo`03001oogoo04Uoo`03001oogoo00eoo`03
001oogoo04Uoo`03001oogoo00eoo`03001oogoo01ioo`003goo00<007ooOol09Goo00<007ooOol0
37oo00<007ooOol0BWoo00<007ooOol037oo00<007ooOol0BWoo00<007ooOol037oo00<007ooOol0
7goo000?Ool00`00Oomoo`0UOol00`00Oomoo`0<Ool00`00Oomoo`1:Ool00`00Oomoo`0<Ool00`00
Oomoo`1:Ool00`00Oomoo`0<Ool00`00Oomoo`0OOol000moo`03001oogoo02Eoo`03001oogoo00ao
o`03001oogoo04Yoo`03001oogoo00aoo`03001oogoo04Yoo`03001oogoo00aoo`03001oogoo01mo
o`003goo00<007ooOol09Goo00<007ooOol037oo00<007ooOol0BWoo00<007ooOol037oo00<007oo
Ool0BWoo00<007ooOol037oo00<007ooOol07goo000?Ool00`00Oomoo`0UOol00`00Oomoo`0<Ool0
0`00Oomoo`1;Ool00`00Oomoo`0;Ool00`00Oomoo`1;Ool00`00Oomoo`0;Ool00`00Oomoo`0OOol0
00Moo`D000=oo`03001oogoo02Ioo`03001oogoo00Yoo`03001oogoo04aoo`03001oogoo00Yoo`03
001oogoo04aoo`03001oogoo00Yoo`03001oogoo021oo`002Goo00<007ooOol00goo00<007ooOol0
9Woo00<007ooOol02Woo00<007ooOol0C7oo00<007ooOol02Woo00<007ooOol0C7oo00<007ooOol0
2Woo00<007ooOol087oo0009Ool00`00Oomoo`03Ool3000VOol00`00Oomoo`0:Ool00`00Oomoo`1<
Ool00`00Oomoo`0:Ool00`00Oomoo`1<Ool00`00Oomoo`0:Ool00`00Oomoo`0POol000Uoo`03001o
ogoo00=oo`03001oogoo02Ioo`03001oogoo00Yoo`03001oogoo04aoo`03001oogoo00Yoo`03001o
ogoo04aoo`03001oogoo00Yoo`03001oogoo021oo`002Goo00<007ooOol00goo00<007ooOol09Woo
00<007ooOol02Woo00<007ooOol0C7oo00<007ooOol02Woo00<007ooOol0C7oo00<007ooOol02Woo
00<007ooOol087oo0008Ool20005Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`1=Ool0
0`00Oomoo`09Ool00`00Oomoo`1=Ool00`00Oomoo`09Ool00`00Oomoo`0QOol000moo`03001oogoo
02Ioo`03001oogoo00Uoo`03001oogoo04eoo`03001oogoo00Uoo`03001oogoo04eoo`03001oogoo
00Uoo`03001oogoo025oo`003goo00<007ooOol09Woo00<007ooOol02Goo00<007ooOol0CWoo00<0
07ooOol027oo00<007ooOol0CWoo00<007ooOol027oo00<007ooOol08Goo000?Ool00`00Oomoo`0W
Ool00`00Oomoo`08Ool00`00Oomoo`1>Ool00`00Oomoo`08Ool00`00Oomoo`1>Ool00`00Oomoo`08
Ool00`00Oomoo`0QOol000moo`03001oogoo02Moo`03001oogoo00Qoo`03001oogoo04ioo`03001o
ogoo00Qoo`03001oogoo04ioo`03001oogoo00Qoo`03001oogoo025oo`003goo0P00:7oo00<007oo
Ool01goo00<007ooOol0Cgoo00<007ooOol01goo00<007ooOol0Cgoo00<007ooOol01goo00<007oo
Ool08Woo000?Ool00`00Oomoo`0WOol00`00Oomoo`07Ool00`00Oomoo`1?Ool00`00Oomoo`07Ool0
0`00Oomoo`1?Ool00`00Oomoo`07Ool00`00Oomoo`0ROol000moo`03001oogoo02Moo`03001oogoo
00Moo`03001oogoo04moo`03001oogoo00Moo`03001oogoo04moo`03001oogoo00Moo`03001oogoo
029oo`003goo00<007ooOol09goo00<007ooOol01goo00<007ooOol0Cgoo00<007ooOol01goo00<0
07ooOol0Cgoo00<007ooOol01goo00<007ooOol08Woo000?Ool00`00Oomoo`0WOol00`00Oomoo`06
Ool00`00Oomoo`1@Ool00`00Oomoo`06Ool00`00Oomoo`1@Ool00`00Oomoo`06Ool00`00Oomoo`0S
Ool000moo`03001oogoo02Qoo`03001oogoo00Eoo`03001oogoo055oo`03001oogoo00Eoo`03001o
ogoo055oo`03001oogoo00Eoo`03001oogoo02=oo`003goo00<007ooOol0:7oo00<007ooOol01Goo
00<007ooOol0DGoo00<007ooOol01Goo00<007ooOol0DGoo00<007ooOol01Goo00<007ooOol08goo
000?Ool00`00Oomoo`0XOol00`00Oomoo`05Ool00`00Oomoo`1AOol00`00Oomoo`05Ool00`00Oomo
o`1AOol00`00Oomoo`05Ool00`00Oomoo`0SOol000moo`8002Uoo`03001oogoo00Eoo`03001oogoo
055oo`03001oogoo00Eoo`03001oogoo055oo`03001oogoo00Eoo`03001oogoo02=oo`003goo00<0
07ooOol0:7oo00<007ooOol017oo00<007ooOol0DWoo00<007ooOol017oo00<007ooOol0DWoo00<0
07ooOol017oo00<007ooOol097oo000?Ool00`00Oomoo`0XOol00`00Oomoo`04Ool00`00Oomoo`1B
Ool00`00Oomoo`04Ool00`00Oomoo`1BOol00`00Oomoo`04Ool00`00Oomoo`0TOol000moo`03001o
ogoo02Qoo`03001oogoo00Aoo`03001oogoo059oo`03001oogoo00Aoo`03001oogoo059oo`03001o
ogoo00Aoo`03001oogoo02Aoo`003goo00<007ooOol0:7oo00<007ooOol017oo00<007ooOol0Dgoo
00<007ooOol00goo00<007ooOol0Dgoo00<007ooOol00goo00<007ooOol097oo000?Ool00`00Oomo
o`0YOol00`00Oomoo`03Ool00`00Oomoo`1COol00`00Oomoo`03Ool00`00Oomoo`1COol00`00Oomo
o`03Ool00`00Oomoo`0TOol000moo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo05Aoo`03
001oogoo009oo`03001oogoo05Aoo`03001oogoo009oo`03001oogoo02Eoo`003goo00<007ooOol0
:Goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol0
0Woo00<007ooOol09Goo000?Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`1DOol00`00
Oomoo`02Ool00`00Oomoo`1DOol00`00Oomoo`02Ool00`00Oomoo`0UOol000moo`8002Yoo`03001o
ogoo009oo`03001oogoo05Aoo`03001oogoo009oo`03001oogoo05Aoo`03001oogoo009oo`03001o
ogoo02Eoo`003goo00<007ooOol0:Goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol00Woo
00<007ooOol0E7oo00<007ooOol00Woo00<007ooOol09Goo000?Ool00`00Oomoo`0YOol01@00Oomo
ogoo0000Egoo00D007ooOomoo`0005Moo`05001oogooOol0000XOol000moo`03001oogoo02Yoo`04
001oogoo001HOol01000Oomoo`00F7oo00@007ooOol002Qoo`003goo00<007ooOol0:Woo00@007oo
Ool005Qoo`04001oogoo001HOol01000Oomoo`00:7oo000?Ool00`00Oomoo`0ZOol01000Oomoo`00
F7oo00@007ooOol005Qoo`04001oogoo000XOol000moo`03001oogoo02Yoo`04001oogoo001HOol0
1000Oomoo`00F7oo00@007ooOol002Qoo`003goo00<007ooOol0:Woo00<007oo0000FGoo00<007oo
0000FGoo00<007oo0000:Goo000?Ool2000[Ool00`00Ool0001IOol00`00Ool0001IOol00`00Ool0
000YOol000moo`03001oogoo02Yoo`03001oo`0005Uoo`03001oo`0005Uoo`03001oo`0002Uoo`00
3goo00<007ooOol0:Woo00<007oo0000FGoo00<007oo0000FGoo00<007oo0000:Goo000?Ool00`00
Oomoo`0[Ool2001JOol2001JOol2000YOol000moo`03001oogoo02]oo`03001oogoo05Uoo`03001o
ogoo05Uoo`03001oogoo02Qoo`003goo00<007ooOol0:goo00<007ooOol0FGoo00<007ooOol0FGoo
00<007ooOol0:7oo0008Ool30004Ool00`00Oomoo`0[Ool00`00Oomoo`1IOol00`00Oomoo`1IOol0
0`00Oomoo`0XOol000Qoo`03001oogoo00Aoo`03001oogoo0?moo`moo`002Goo00<007ooOol00goo
0`00ogoo3goo0009Ool00`00Oomoo`03Ool00`00Oomoo`3oOol?Ool000Qoo`03001oo`0000Aoo`03
001oogoo0?moo`moo`002Goo00<007ooOol0ogoo5Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.167986, -2.1236, 
  0.0108532, 0.0240038}},
  CellTags->"4.2"]
}, Open  ]],

Cell[TextData[{
  StyleBox["SimulationPlot", "MR"],
  " can also be used to plot the input signal on the same time scale. "
}], "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["\<\
SimulationPlot[square[3, 1, ts],
 Sampled -> Period[ts],
 PlotStyle -> Dashing[{.05, .01}]
]\
\>", "Input",
  CellLabel->"In[24]:=",
  CellTags->"4.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.331263 0.309017 0.294302 [
[.18944 .29652 -9 -9 ]
[.18944 .29652 9 0 ]
[.35507 .29652 -3 -9 ]
[.35507 .29652 3 0 ]
[.5207 .29652 -9 -9 ]
[.5207 .29652 9 0 ]
[.68634 .29652 -3 -9 ]
[.68634 .29652 3 0 ]
[.85197 .29652 -9 -9 ]
[.85197 .29652 9 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18944 .30902 m
.18944 .31527 L
s
[(0.5)] .18944 .29652 0 1 Mshowa
.35507 .30902 m
.35507 .31527 L
s
[(1)] .35507 .29652 0 1 Mshowa
.5207 .30902 m
.5207 .31527 L
s
[(1.5)] .5207 .29652 0 1 Mshowa
.68634 .30902 m
.68634 .31527 L
s
[(2)] .68634 .29652 0 1 Mshowa
.85197 .30902 m
.85197 .31527 L
s
[(2.5)] .85197 .29652 0 1 Mshowa
.125 Mabswid
.05694 .30902 m
.05694 .31277 L
s
.09006 .30902 m
.09006 .31277 L
s
.12319 .30902 m
.12319 .31277 L
s
.15631 .30902 m
.15631 .31277 L
s
.22257 .30902 m
.22257 .31277 L
s
.25569 .30902 m
.25569 .31277 L
s
.28882 .30902 m
.28882 .31277 L
s
.32195 .30902 m
.32195 .31277 L
s
.3882 .30902 m
.3882 .31277 L
s
.42133 .30902 m
.42133 .31277 L
s
.45445 .30902 m
.45445 .31277 L
s
.48758 .30902 m
.48758 .31277 L
s
.55383 .30902 m
.55383 .31277 L
s
.58696 .30902 m
.58696 .31277 L
s
.62008 .30902 m
.62008 .31277 L
s
.65321 .30902 m
.65321 .31277 L
s
.71946 .30902 m
.71946 .31277 L
s
.75259 .30902 m
.75259 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81884 .30902 m
.81884 .31277 L
s
.88509 .30902 m
.88509 .31277 L
s
.91822 .30902 m
.91822 .31277 L
s
.95135 .30902 m
.95135 .31277 L
s
.98447 .30902 m
.98447 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .05 .01 ] 0 setdash
.02381 .01472 m
.06522 .01472 L
.10663 .01472 L
.14803 .01472 L
.18944 .60332 L
.23085 .60332 L
.27226 .60332 L
.31366 .60332 L
.35507 .01472 L
.39648 .01472 L
.43789 .01472 L
.4793 .01472 L
.5207 .60332 L
.56211 .60332 L
.60352 .60332 L
.64493 .60332 L
.68634 .01472 L
.72774 .01472 L
.76915 .01472 L
.81056 .01472 L
.85197 .60332 L
.89337 .60332 L
.93478 .60332 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001=oo`D000=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo00<0
07ooOol0ogoo0goo000?Ool30003Ool00`00Oomoo`03Ool>0002Ool>0002Ool2000fOol00`00Oomo
o`0>0002Ool>000gOol40002Ool>0002Ool<000cOol001Eoo`03001oogoo00=oo`03001oogoo01io
o`03001oogoo03Aoo`03001oogoo05Eoo`03001oogoo01ioo`03001oogoo035oo`005Goo00<007oo
Ool00goo00<007ooOol07Woo00<007ooOol0=7oo00<007ooOol07Woo00<007ooOol0=7oo00<007oo
Ool07Woo00<007ooOol0<Goo000DOol20005Ool00`00Oomoo`0NOol00`00Oomoo`0dOol00`00Oomo
o`0NOol00`00Oomoo`0dOol00`00Oomoo`1BOol001]oo`03001oogoo01ioo`03001oogoo03Aoo`03
001oogoo01ioo`03001oogoo03Aoo`03001oogoo059oo`006goo00<007ooOol07Woo00<007ooOol0
=7oo00<007ooOol07Woo00<007ooOol0<goo00<007ooOol07goo00<007ooOol0<Goo000KOol00`00
Oomoo`0OOol00`00Oomoo`0cOol00`00Oomoo`0NOol00`00Oomoo`0cOol00`00Oomoo`0OOol00`00
Oomoo`0aOol001]oo`03001oogoo01moo`03001oogoo039oo`03001oogoo01moo`03001oogoo03=o
o`03001oogoo01moo`03001oogoo035oo`006goo0P0087oo00<007ooOol0<Woo00<007ooOol07goo
00<007ooOol0<goo00<007ooOol07goo00<007ooOol0<Goo000KOol00`00Oomoo`0OOol00`00Oomo
o`0bOol00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomoo`0OOol00`00Oomoo`0aOol001]oo`03
001oogoo01moo`03001oogoo039oo`03001oogoo021oo`03001oogoo039oo`03001oogoo01moo`03
001oogoo035oo`006goo00<007ooOol07goo00<007ooOol0<Woo00<007ooOol087oo00<007ooOol0
E7oo00<007ooOol0<Goo000KOol00`00Oomoo`0OOol00`00Oomoo`0bOol00`00Oomoo`0POol00`00
Oomoo`0bOol00`00Oomoo`0POol00`00Oomoo`0`Ool001]oo`03001oogoo05Aoo`03001oogoo021o
o`03001oogoo039oo`03001oogoo021oo`03001oogoo031oo`006goo00<007ooOol0Mgoo00<007oo
Ool0<Woo00<007ooOol087oo00<007ooOol0<7oo000KOol2000POol00`00Oomoo`0bOol00`00Oomo
o`0POol00`00Oomoo`0bOol00`00Oomoo`0POol00`00Oomoo`0`Ool001]oo`03001oogoo01moo`03
001oogoo039oo`03001oogoo05Eoo`03001oogoo021oo`03001oogoo031oo`006goo00<007ooOol0
7goo00<007ooOol0<Woo00<007ooOol0EGoo00<007ooOol087oo00<007ooOol0<7oo000KOol00`00
Oomoo`0OOol00`00Oomoo`0bOol00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomoo`0POol00`00
Oomoo`0`Ool001]oo`03001oogoo01moo`03001oogoo039oo`03001oogoo021oo`03001oogoo035o
o`03001oogoo05Aoo`006goo00<007ooOol07goo00<007ooOol0<Woo00<007ooOol087oo00<007oo
Ool0<Goo00<007ooOol0E7oo000KOol00`00Oomoo`0OOol00`00Oomoo`0bOol00`00Oomoo`0POol0
0`00Oomoo`0aOol00`00Oomoo`0ROol00`00Oomoo`0_Ool001]oo`03001oogoo021oo`03001oogoo
031oo`03001oogoo025oo`03001oogoo035oo`03001oogoo029oo`03001oogoo02moo`006goo0P00
8Goo00<007ooOol0<7oo00<007ooOol08Goo00<007ooOol0<Goo00<007ooOol08Woo00<007ooOol0
;goo000KOol00`00Oomoo`0POol00`00Oomoo`0`Ool00`00Oomoo`0QOol00`00Oomoo`0aOol00`00
Oomoo`0ROol00`00Oomoo`0_Ool001]oo`03001oogoo021oo`03001oogoo031oo`03001oogoo029o
o`03001oogoo031oo`03001oogoo029oo`03001oogoo02moo`006goo00<007ooOol087oo00<007oo
Ool0<7oo00<007ooOol08Woo00<007ooOol0<7oo00<007ooOol08Woo00<007ooOol0;goo000KOol0
0`00Oomoo`0POol00`00Oomoo`0`Ool00`00Oomoo`0ROol00`00Oomoo`1EOol00`00Oomoo`0_Ool0
01]oo`03001oogoo021oo`03001oogoo031oo`03001oogoo029oo`03001oogoo031oo`03001oogoo
029oo`03001oogoo02moo`006goo00<007ooOol0Dgoo00<007ooOol08Woo00<007ooOol0<7oo00<0
07ooOol08Woo00<007ooOol0;goo000KOol00`00Oomoo`1hOol00`00Oomoo`0`Ool00`00Oomoo`0R
Ool00`00Oomoo`0_Ool001]oo`80025oo`03001oogoo031oo`03001oogoo029oo`03001oogoo031o
o`03001oogoo029oo`03001oogoo02moo`006goo00<007ooOol087oo00<007ooOol0<7oo00<007oo
Ool0EGoo00<007ooOol08Woo00<007ooOol0;goo000KOol00`00Oomoo`0POol00`00Oomoo`0`Ool0
0`00Oomoo`1EOol00`00Oomoo`0ROol00`00Oomoo`0_Ool001]oo`03001oogoo021oo`03001oogoo
031oo`03001oogoo029oo`03001oogoo031oo`03001oogoo029oo`03001oogoo02moo`006goo00<0
07ooOol087oo00<007ooOol0<7oo00<007ooOol08Woo00<007ooOol0;goo00<007ooOol0EGoo000K
Ool00`00Oomoo`0POol00`00Oomoo`0`Ool00`00Oomoo`0ROol00`00Oomoo`0_Ool00`00Oomoo`1E
Ool000]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo021oo`03001o
ogoo031oo`03001oogoo029oo`03001oogoo02moo`03001oogoo02Aoo`03001oogoo02ioo`002Woo
00<007oo00001goo00<007oo000017oo00<007ooOol08Goo00<007ooOol0;Woo00<007ooOol08goo
00<007ooOol0;goo00<007ooOol097oo00<007ooOol0;Woo0005Ool30002Ool00`00Ool00009Ool0
0`00Oomoo`02Ool2000ROol00`00Oomoo`0^Ool00`00Oomoo`0SOol00`00Oomoo`0_Ool00`00Oomo
o`0TOol00`00Oomoo`0^Ool000Yoo`03001oo`0000Moo`8000Eoo`03001oogoo025oo`03001oogoo
02ioo`03001oogoo02=oo`03001oogoo02moo`03001oogoo02Aoo`03001oogoo02ioo`002Woo00<0
07oo00001goo00<007ooOol017oo00<007ooOol08Goo00<007ooOol0;Woo00<007ooOol097oo00<0
07ooOol0;Woo00<007ooOol097oo00<007ooOol0;Woo000;Ool00`00Oomoo`06Ool30004Ool00`00
Oomoo`0QOol00`00Oomoo`0^Ool00`00Oomoo`0TOol00`00Oomoo`1EOol00`00Oomoo`0^Ool001]o
o`03001oogoo025oo`03001oogoo02ioo`03001oogoo02Aoo`03001oogoo05Eoo`03001oogoo02io
o`006goo00<007ooOol08Goo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0;Woo00<007oo
Ool09Goo00<007ooOol0;Goo000KOol00`00Oomoo`1iOol00`00Oomoo`0^Ool00`00Oomoo`0UOol0
0`00Oomoo`0]Ool001]oo`03001oogoo025oo`03001oogoo05Eoo`03001oogoo02ioo`03001oogoo
02Eoo`03001oogoo02eoo`006goo0P008Woo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0
;Woo00<007ooOol09Goo00<007ooOol0;Goo000KOol00`00Oomoo`0QOol00`00Oomoo`0^Ool00`00
Oomoo`1EOol00`00Oomoo`0UOol00`00Oomoo`0]Ool001]oo`03001oogoo025oo`03001oogoo02io
o`03001oogoo02Aoo`03001oogoo02ioo`03001oogoo02Eoo`03001oogoo02eoo`006goo00<007oo
Ool08Goo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0;Woo00<007ooOol09Goo00<007oo
Ool0;Goo000KOol00`00Oomoo`0QOol00`00Oomoo`0^Ool00`00Oomoo`0TOol00`00Oomoo`0]Ool0
0`00Oomoo`1FOol001]oo`03001oogoo025oo`03001oogoo02ioo`03001oogoo02Aoo`03001oogoo
02eoo`03001oogoo02Ioo`03001oogoo02eoo`006goo00<007ooOol08Woo00<007ooOol0;Goo00<0
07ooOol097oo00<007ooOol0;Goo00<007ooOol09Woo00<007ooOol0;Goo000KOol00`00Oomoo`0R
Ool00`00Oomoo`0/Ool00`00Oomoo`0UOol00`00Oomoo`0]Ool00`00Oomoo`0VOol00`00Oomoo`0]
Ool001]oo`8002=oo`03001oogoo02aoo`03001oogoo02Eoo`03001oogoo02eoo`03001oogoo02Io
o`03001oogoo02eoo`006goo00<007ooOol08Woo00<007ooOol0;7oo00<007ooOol09Woo00<007oo
Ool0;7oo00<007ooOol09Woo00<007ooOol0;Goo000KOol00`00Oomoo`0ROol00`00Oomoo`0/Ool0
0`00Oomoo`0VOol00`00Oomoo`0/Ool00`00Oomoo`0VOol00`00Oomoo`0]Ool001]oo`03001oogoo
029oo`03001oogoo02aoo`03001oogoo02Ioo`03001oogoo05Eoo`03001oogoo02eoo`006goo00<0
07ooOol08Woo00<007ooOol0;7oo00<007ooOol09Woo00<007ooOol0EWoo00<007ooOol0;7oo000K
Ool00`00Oomoo`0ROol00`00Oomoo`0/Ool00`00Oomoo`0VOol00`00Oomoo`0/Ool00`00Oomoo`0W
Ool00`00Oomoo`0/Ool001]oo`03001oogoo07Yoo`03001oogoo02aoo`03001oogoo02Moo`03001o
ogoo02aoo`006goo0P008goo00<007ooOol0EGoo00<007ooOol0;7oo00<007ooOol09goo00<007oo
Ool0;7oo000KOol00`00Oomoo`0ROol00`00Oomoo`0[Ool00`00Oomoo`0WOol00`00Oomoo`0/Ool0
0`00Oomoo`0WOol00`00Oomoo`0/Ool001]oo`03001oogoo029oo`03001oogoo02]oo`03001oogoo
05Ioo`03001oogoo02Moo`03001oogoo02aoo`006goo00<007ooOol08Woo00<007ooOol0:goo00<0
07ooOol0:7oo00<007ooOol0:goo00<007ooOol09goo00<007ooOol0;7oo000KOol00`00Oomoo`0R
Ool00`00Oomoo`0[Ool00`00Oomoo`0XOol00`00Oomoo`0[Ool00`00Oomoo`0WOol00`00Oomoo`0/
Ool001]oo`03001oogoo029oo`8000Aoo`03001oogoo009oo`03001oogoo021oo`03001oo`0000@0
02=oo`D0009oo`03001oogoo009oo`03001oogoo01moo`04001oogooOol3000TOol30003Ool00`00
Oomoo`02Ool00`00Oomoo`0QOol001]oo`03001oogoo029oo`03001oo`0000Moo`03001oo`00025o
o`05001oogooOol0000VOol20008Ool00`00Ool0000POol01@00Oomoogoo00009Woo00<007ooOol0
1goo00<007oo00008Woo000KOol00`00Oomoo`0ROol30009Ool00`00Oomoo`0OOol01@00Oomoogoo
00009Woo0P002Woo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol08goo0P002Woo00<007oo
Ool087oo000KOol2000SOol30007Ool2000ROol01@00Oomoogoo00009Woo0P0027oo0P008Goo00<0
07ooOol00Woo00<007ooOol08goo0P0027oo0P008goo000KOol00`00Oomoo`0ROol30007Ool00`00
Oomoo`0QOol01@00Oomoogoo00009Woo0P0027oo00<007ooOol087oo00L007ooOomoo`00Ool0000T
Ool00`00Ool00007Ool00`00Oomoo`0ROol001]oo`03001oogoo02=oo`03001oogoo00Ioo`<0025o
o`03001oogoo008002Ioo`8000Qoo`<0021oo`03001oogoo009oo`03001oogoo02=oo`8000Qoo`<0
029oo`006goo00<007ooOol08goo00<007ooOol0:Woo00<007ooOol0:Goo00<007ooOol0:Goo00<0
07ooOol0:7oo00<007ooOol0;7oo000KOol00`00Oomoo`0SOol00`00Oomoo`0ZOol00`00Oomoo`0Y
Ool00`00Oomoo`1DOol00`00Oomoo`0/Ool001]oo`03001oogoo02=oo`03001oogoo02Yoo`03001o
ogoo02Uoo`03001oogoo05Eoo`03001oogoo02]oo`006goo00<007ooOol08goo00<007ooOol0:Woo
00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:goo000KOol00`00Oomo
o`1lOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0[Ool001Aoool000d000006goo00<0
07ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00@007ooOol000Eoo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`04001oogoo0005Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomoogoo0000
17oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00D007ooOomo
o`0000Aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`05001o
ogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool0
0`00Oomoo`03Ool001]oo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo02=oo`03001oogoo
00=oo`03001oogoo02Uoo`03001oogoo02Aoo`03001oogoo009oo`03001oogoo02Aoo`03001oogoo
009oo`03001oogoo02Ioo`006goo00<007ooOol08goo00<007ooOol0:Goo00<007ooOol0:Woo00<0
07ooOol0:Goo00<007ooOol0:Goo00<007ooOol0:goo000KOol00`00Oomoo`0SOol00`00Oomoo`0Y
Ool00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0[Ool001]oo`03001o
ogoo02=oo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo02Qoo`03001oogoo05Qoo`006goo
00<007ooOol08goo00<007ooOol0:Goo00<007ooOol0:Woo00<007ooOol0:7oo00<007ooOol0:Woo
00<007ooOol0:goo000KOol00`00Oomoo`0TOol00`00Oomoo`0XOol00`00Oomoo`0ZOol00`00Oomo
o`0XOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool001]oo`8002Eoo`03001oogoo02Moo`03001oogoo
02]oo`03001oogoo02Qoo`03001oogoo02Yoo`03001oogoo02]oo`006goo00<007ooOol097oo00<0
07ooOol09goo00<007ooOol0:goo00<007ooOol0:7oo00<007ooOol0:Woo00<007ooOol0:goo000K
Ool00`00Oomoo`0TOol00`00Oomoo`0WOol00`00Oomoo`0/Ool00`00Oomoo`0WOol00`00Oomoo`0Z
Ool00`00Oomoo`0[Ool001]oo`03001oogoo02Aoo`03001oogoo02Moo`03001oogoo02aoo`03001o
ogoo02Moo`03001oogoo02Yoo`03001oogoo02]oo`006goo00<007ooOol097oo00<007ooOol09goo
00<007ooOol0;7oo00<007ooOol0E7oo00<007ooOol0:goo000KOol00`00Oomoo`0TOol00`00Oomo
o`0WOol00`00Oomoo`0/Ool00`00Oomoo`1EOol00`00Oomoo`0ZOol001]oo`03001oogoo02Aoo`03
001oogoo02Moo`03001oogoo02aoo`03001oogoo02Moo`03001oogoo02]oo`03001oogoo02Yoo`00
6goo00<007ooOol0OGoo00<007ooOol09goo00<007ooOol0:goo00<007ooOol0:Woo000KOol2000U
Ool00`00Oomoo`1FOol00`00Oomoo`0WOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol001]oo`03001o
ogoo02Aoo`03001oogoo02Moo`03001oogoo02aoo`03001oogoo02Moo`03001oogoo02]oo`03001o
ogoo02Yoo`006goo00<007ooOol097oo00<007ooOol09goo00<007ooOol0EWoo00<007ooOol0:goo
00<007ooOol0:Woo000KOol00`00Oomoo`0TOol00`00Oomoo`0WOol00`00Oomoo`0/Ool00`00Oomo
o`0WOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol001]oo`03001oogoo02Aoo`03001oogoo02Moo`03
001oogoo02aoo`03001oogoo02Moo`03001oogoo02]oo`03001oogoo02Yoo`006goo00<007ooOol0
97oo00<007ooOol09goo00<007ooOol0;7oo00<007ooOol09Woo00<007ooOol0FGoo000KOol00`00
Oomoo`0TOol00`00Oomoo`0WOol00`00Oomoo`0/Ool00`00Oomoo`0VOol00`00Oomoo`0/Ool00`00
Oomoo`0ZOol001]oo`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo02aoo`03001oogoo02Io
o`03001oogoo02aoo`03001oogoo02Yoo`006goo0P009Woo00<007ooOol09Goo00<007ooOol0;Goo
00<007ooOol09Woo00<007ooOol0;7oo00<007ooOol0:Woo000KOol00`00Oomoo`0UOol00`00Oomo
o`0UOol00`00Oomoo`0]Ool00`00Oomoo`0VOol00`00Oomoo`0/Ool00`00Oomoo`0ZOol001]oo`03
001oogoo02Eoo`03001oogoo02Eoo`03001oogoo02ioo`03001oogoo02Eoo`03001oogoo02aoo`03
001oogoo02Yoo`006goo00<007ooOol09Goo00<007ooOol09Goo00<007ooOol0;Woo00<007ooOol0
9Goo00<007ooOol0;7oo00<007ooOol0:Woo000KOol00`00Oomoo`0UOol00`00Oomoo`0UOol00`00
Oomoo`0^Ool00`00Oomoo`1DOol00`00Oomoo`0ZOol001]oo`03001oogoo02Eoo`03001oogoo02Eo
o`03001oogoo02ioo`03001oogoo05Eoo`03001oogoo02Uoo`006goo00<007ooOol0CGoo00<007oo
Ool0;Woo00<007ooOol097oo00<007ooOol0;Woo00<007ooOol0:Goo000KOol2001oOol00`00Oomo
o`0TOol00`00Oomoo`0^Ool00`00Oomoo`0YOol001]oo`03001oogoo02Ioo`03001oogoo05Eoo`03
001oogoo02Aoo`03001oogoo02ioo`03001oogoo02Uoo`006goo00<007ooOol09Woo00<007ooOol0
97oo00<007ooOol0EGoo00<007ooOol0;Woo00<007ooOol0:Goo000KOol00`00Oomoo`0VOol00`00
Oomoo`0TOol00`00Oomoo`1EOol00`00Oomoo`0^Ool00`00Oomoo`0YOol001]oo`03001oogoo02Io
o`03001oogoo02Aoo`03001oogoo02ioo`03001oogoo02Aoo`03001oogoo02ioo`03001oogoo02Uo
o`006goo00<007ooOol09Woo00<007ooOol097oo00<007ooOol0;Woo00<007ooOol097oo00<007oo
Ool0FWoo000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0VOol0
0`00Oomoo`0TOol00`00Oomoo`0^Ool00`00Oomoo`0SOol00`00Oomoo`1KOol000Yoo`03001oo`00
00Moo`03001oo`0000Aoo`03001oogoo02Ioo`03001oogoo02Aoo`03001oogoo02ioo`03001oogoo
02=oo`03001oogoo02moo`03001oogoo02Uoo`002Woo00<007oo00002Goo00<007ooOol00Woo0P00
:7oo00<007ooOol08goo00<007ooOol0;Woo00<007ooOol08goo00<007ooOol0;goo00<007ooOol0
:Goo000:Ool00`00Ool00007Ool20005Ool00`00Oomoo`0WOol00`00Oomoo`0ROol00`00Oomoo`0_
Ool00`00Oomoo`0SOol00`00Oomoo`0_Ool00`00Oomoo`0YOol000Yoo`03001oo`0000Moo`03001o
ogoo00Aoo`03001oogoo02Moo`03001oogoo029oo`03001oogoo02moo`03001oogoo02=oo`03001o
ogoo02moo`03001oogoo02Uoo`002goo00<007ooOol01Woo0`0017oo00<007ooOol09goo00<007oo
Ool08Woo00<007ooOol0<7oo00<007ooOol08Woo00<007ooOol0;goo00<007ooOol0:Goo000KOol0
0`00Oomoo`0WOol00`00Oomoo`0ROol00`00Oomoo`0`Ool00`00Oomoo`0ROol00`00Oomoo`0_Ool0
0`00Oomoo`0YOol001]oo`03001oogoo02Moo`03001oogoo029oo`03001oogoo031oo`03001oogoo
05Aoo`03001oogoo02Uoo`006goo00<007ooOol09goo00<007ooOol08Woo00<007ooOol0<7oo00<0
07ooOol0EGoo00<007ooOol0:7oo000KOol00`00Oomoo`1<Ool00`00Oomoo`0`Ool00`00Oomoo`0R
Ool00`00Oomoo`0`Ool00`00Oomoo`0XOol001]oo`80081oo`03001oogoo029oo`03001oogoo031o
o`03001oogoo02Qoo`006goo00<007ooOol09goo00<007ooOol0EGoo00<007ooOol08Woo00<007oo
Ool0<7oo00<007ooOol0:7oo000KOol00`00Oomoo`0WOol00`00Oomoo`0ROol00`00Oomoo`1EOol0
0`00Oomoo`0`Ool00`00Oomoo`0XOol001]oo`03001oogoo02Moo`03001oogoo029oo`03001oogoo
05Eoo`03001oogoo031oo`03001oogoo02Qoo`006goo00<007ooOol09goo00<007ooOol08Woo00<0
07ooOol0<7oo00<007ooOol08Woo00<007ooOol0<7oo00<007ooOol0:7oo000KOol00`00Oomoo`0W
Ool00`00Oomoo`0ROol00`00Oomoo`0`Ool00`00Oomoo`0ROol00`00Oomoo`1KOol001]oo`03001o
ogoo02Moo`03001oogoo029oo`03001oogoo031oo`03001oogoo025oo`03001oogoo05aoo`006goo
00<007ooOol09goo00<007ooOol08Woo00<007ooOol0<7oo00<007ooOol08Goo00<007ooOol0<Goo
00<007ooOol0:7oo000KOol2000YOol00`00Oomoo`0QOol00`00Oomoo`0`Ool00`00Oomoo`0QOol0
0`00Oomoo`0aOol00`00Oomoo`0XOol001]oo`03001oogoo02Qoo`03001oogoo021oo`03001oogoo
035oo`03001oogoo025oo`03001oogoo035oo`03001oogoo02Qoo`006goo00<007ooOol0:7oo00<0
07ooOol087oo00<007ooOol0<Goo00<007ooOol08Goo00<007ooOol0<Goo00<007ooOol0:7oo000K
Ool00`00Oomoo`0XOol00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomoo`0POol00`00Oomoo`0a
Ool00`00Oomoo`0XOol001]oo`03001oogoo02Qoo`03001oogoo021oo`03001oogoo039oo`03001o
ogoo021oo`03001oogoo035oo`03001oogoo02Qoo`006goo00<007ooOol0:7oo00<007ooOol087oo
00<007ooOol0<Woo00<007ooOol0E7oo00<007ooOol0:7oo000KOol00`00Oomoo`0XOol00`00Oomo
o`0POol00`00Oomoo`0bOol00`00Oomoo`1EOol00`00Oomoo`0WOol001]oo`03001oogoo04]oo`03
001oogoo039oo`03001oogoo021oo`03001oogoo039oo`03001oogoo02Moo`006goo0P00PGoo00<0
07ooOol087oo00<007ooOol0<Woo00<007ooOol09goo000KOol00`00Oomoo`0XOol00`00Oomoo`1E
Ool00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomoo`0WOol001]oo`03001oogoo02Qoo`03001o
ogoo021oo`03001oogoo05Eoo`03001oogoo039oo`03001oogoo02Moo`006goo00<007ooOol0:7oo
00<007ooOol087oo00<007ooOol0EGoo00<007ooOol0<Woo00<007ooOol09goo000KOol00`00Oomo
o`0XOol00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomo
o`0WOol001]oo`03001oogoo02Qoo`03001oogoo021oo`03001oogoo039oo`03001oogoo021oo`03
001oogoo05aoo`006goo00<007ooOol0:7oo00<007ooOol087oo00<007ooOol0<Woo00<007ooOol0
7goo00<007ooOol0GGoo000KOol2000YOol00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomoo`0O
Ool00`00Oomoo`0cOol00`00Oomoo`0WOol001]oo`03001oogoo02Uoo`03001oogoo01moo`03001o
ogoo039oo`03001oogoo01moo`03001oogoo03=oo`03001oogoo02Moo`006goo00<007ooOol0:Goo
00<007ooOol07Woo00<007ooOol0<goo00<007ooOol07goo00<007ooOol0<goo00<007ooOol09goo
000KOol00`00Oomoo`0YOol00`00Oomoo`0NOol00`00Oomoo`0dOol00`00Oomoo`0NOol00`00Oomo
o`0cOol00`00Oomoo`0WOol001]oo`03001oogoo02Uoo`03001oogoo01ioo`03001oogoo03Aoo`03
001oogoo01ioo`03001oogoo03Aoo`03001oogoo02Ioo`006goo00<007ooOol0:Goo00<007ooOol0
7Woo00<007ooOol0=7oo00<007ooOol07Woo00<007ooOol0=7oo00<007ooOol09Woo000COol50003
Ool00`00Oomoo`0YOol00`00Oomoo`0NOol00`00Oomoo`0dOol00`00Oomoo`1EOol00`00Oomoo`0V
Ool001Eoo`03001oogoo00=oo`03001oogoo02Uoo`03001oogoo01ioo`03001oogoo03Aoo`03001o
ogoo05Eoo`03001oogoo02Ioo`005Goo00<007ooOol00goo0P00:goo3`0000=oo`0000003@0000=o
o`00Ool0=Goo0`000Woo3P0000=oo`0000003000=Woo1P000Woo3P000Woo2P001goo000EOol00`00
Oomoo`03Ool00`00Oomoo`3oOol3Ool001Eoo`03001oogoo00=oo`03001oogoo0?moo`=oo`0057oo
0P001Goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.31011, -1.13006, 
  0.0113484, 0.0127737}},
  CellTags->"4.2"]
}, Open  ]],

Cell[TextData[{
  "The two plots may be combined using the built\[Hyphen]in ",
  StyleBox["Mathematica", "TI"],
  " function ",
  StyleBox["Show", "MR"],
  ". "
}], "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["Show[%, %%]", "Input",
  CellLabel->"In[25]:=",
  CellTags->"4.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.331263 0.311982 0.149779 [
[.18944 .29948 -9 -9 ]
[.18944 .29948 9 0 ]
[.35507 .29948 -3 -9 ]
[.35507 .29948 3 0 ]
[.5207 .29948 -9 -9 ]
[.5207 .29948 9 0 ]
[.68634 .29948 -3 -9 ]
[.68634 .29948 3 0 ]
[.85197 .29948 -9 -9 ]
[.85197 .29948 9 0 ]
[.01131 .01242 -12 -4.5 ]
[.01131 .01242 0 4.5 ]
[.01131 .1622 -12 -4.5 ]
[.01131 .1622 0 4.5 ]
[.01131 .46176 -6 -4.5 ]
[.01131 .46176 0 4.5 ]
[.01131 .61154 -6 -4.5 ]
[.01131 .61154 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18944 .31198 m
.18944 .31823 L
s
[(0.5)] .18944 .29948 0 1 Mshowa
.35507 .31198 m
.35507 .31823 L
s
[(1)] .35507 .29948 0 1 Mshowa
.5207 .31198 m
.5207 .31823 L
s
[(1.5)] .5207 .29948 0 1 Mshowa
.68634 .31198 m
.68634 .31823 L
s
[(2)] .68634 .29948 0 1 Mshowa
.85197 .31198 m
.85197 .31823 L
s
[(2.5)] .85197 .29948 0 1 Mshowa
.125 Mabswid
.05694 .31198 m
.05694 .31573 L
s
.09006 .31198 m
.09006 .31573 L
s
.12319 .31198 m
.12319 .31573 L
s
.15631 .31198 m
.15631 .31573 L
s
.22257 .31198 m
.22257 .31573 L
s
.25569 .31198 m
.25569 .31573 L
s
.28882 .31198 m
.28882 .31573 L
s
.32195 .31198 m
.32195 .31573 L
s
.3882 .31198 m
.3882 .31573 L
s
.42133 .31198 m
.42133 .31573 L
s
.45445 .31198 m
.45445 .31573 L
s
.48758 .31198 m
.48758 .31573 L
s
.55383 .31198 m
.55383 .31573 L
s
.58696 .31198 m
.58696 .31573 L
s
.62008 .31198 m
.62008 .31573 L
s
.65321 .31198 m
.65321 .31573 L
s
.71946 .31198 m
.71946 .31573 L
s
.75259 .31198 m
.75259 .31573 L
s
.78571 .31198 m
.78571 .31573 L
s
.81884 .31198 m
.81884 .31573 L
s
.88509 .31198 m
.88509 .31573 L
s
.91822 .31198 m
.91822 .31573 L
s
.95135 .31198 m
.95135 .31573 L
s
.98447 .31198 m
.98447 .31573 L
s
.25 Mabswid
0 .31198 m
1 .31198 L
s
.02381 .01242 m
.03006 .01242 L
s
[(-2)] .01131 .01242 1 0 Mshowa
.02381 .1622 m
.03006 .1622 L
s
[(-1)] .01131 .1622 1 0 Mshowa
.02381 .46176 m
.03006 .46176 L
s
[(1)] .01131 .46176 1 0 Mshowa
.02381 .61154 m
.03006 .61154 L
s
[(2)] .01131 .61154 1 0 Mshowa
.125 Mabswid
.02381 .04238 m
.02756 .04238 L
s
.02381 .07234 m
.02756 .07234 L
s
.02381 .10229 m
.02756 .10229 L
s
.02381 .13225 m
.02756 .13225 L
s
.02381 .19216 m
.02756 .19216 L
s
.02381 .22211 m
.02756 .22211 L
s
.02381 .25207 m
.02756 .25207 L
s
.02381 .28203 m
.02756 .28203 L
s
.02381 .34194 m
.02756 .34194 L
s
.02381 .37189 m
.02756 .37189 L
s
.02381 .40185 m
.02756 .40185 L
s
.02381 .43181 m
.02756 .43181 L
s
.02381 .49172 m
.02756 .49172 L
s
.02381 .52167 m
.02756 .52167 L
s
.02381 .55163 m
.02756 .55163 L
s
.02381 .58158 m
.02756 .58158 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .05 .01 ] 0 setdash
.02381 .1622 m
.06522 .1622 L
.10663 .1622 L
.14803 .1622 L
.18944 .46176 L
.23085 .46176 L
.27226 .46176 L
.31366 .46176 L
.35507 .1622 L
.39648 .1622 L
.43789 .1622 L
.4793 .1622 L
.5207 .46176 L
.56211 .46176 L
.60352 .46176 L
.64493 .46176 L
.68634 .1622 L
.72774 .1622 L
.76915 .1622 L
.81056 .1622 L
.85197 .46176 L
.89337 .46176 L
.93478 .46176 L
.97619 .46176 L
s
[ ] 0 setdash
.02381 .1622 m
.06522 .26774 L
.10663 .29631 L
.14803 .3031 L
.18944 .60332 L
.23085 .39117 L
.27226 .33251 L
.31366 .31726 L
.35507 .01472 L
.39648 .22626 L
.43789 .28481 L
.4793 .30009 L
.5207 .6027 L
.56211 .39123 L
.60352 .33276 L
.64493 .31756 L
.68634 .01503 L
.72774 .22658 L
.76915 .28512 L
.81056 .3004 L
.85197 .60301 L
.89337 .39153 L
.93478 .33305 L
.97619 .31785 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000?Ool0
0`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`0027oo0`0017oo00<007ooOol0ogoo3goo
0008Ool00`00Oomoo`04Ool00`00Oomoo`3oOol?Ool000=oo`<000=oo`03001oogoo00=oo`<005Uo
o`03001oogoo05Uoo`03001oogoo05Ioo`002Goo00<007ooOol00goo00<007ooOol0FGoo00<007oo
Ool0FGoo00<007ooOol0EWoo0008Ool00`00Ool00004Ool00`00Oomoo`1IOol00`00Oomoo`1IOol0
0`00Oomoo`1FOol000Uoo`03001oogoo00=oo`03001oogoo05Uoo`8005Yoo`8005Moo`003goo00<0
07ooOol0F7oo00<007oo0000FGoo00<007oo0000Egoo000?Ool00`00Oomoo`1HOol00`00Ool0001I
Ool00`00Ool0001GOol000moo`03001oogoo05Qoo`03001oo`0005Uoo`03001oo`0005Moo`003goo
00<007ooOol0F7oo00<007oo0000FGoo00<007oo0000Egoo000?Ool2001IOol01000Oomoo`00F7oo
00@007ooOol005Ioo`003goo00<007ooOol0F7oo00@007ooOol005Qoo`04001oogoo001FOol000mo
o`03001oogoo05Qoo`04001oogoo001HOol01000Oomoo`00EWoo000?Ool00`00Oomoo`1HOol01000
Oomoo`00F7oo00@007ooOol005Ioo`003goo00<007ooOol0Egoo00D007ooOomoo`0005Moo`05001o
ogooOol0001FOol000moo`03001oogoo05Moo`03001oogoo009oo`03001oogoo05Aoo`03001oogoo
009oo`03001oogoo05=oo`003goo00<007ooOol0Egoo00<007ooOol00Woo00<007ooOol0E7oo00<0
07ooOol00Woo00<007ooOol0Dgoo000?Ool00`00Oomoo`1GOol00`00Oomoo`02Ool00`00Oomoo`1D
Ool00`00Oomoo`02Ool00`00Oomoo`1COol000moo`8005Qoo`03001oogoo009oo`03001oogoo05Ao
o`03001oogoo009oo`03001oogoo05=oo`003goo00<007ooOol0Egoo00<007ooOol00Woo00<007oo
Ool0E7oo00<007ooOol00Woo00<007ooOol0Dgoo000?Ool00`00Oomoo`1GOol00`00Oomoo`03Ool0
0`00Oomoo`1COol00`00Oomoo`03Ool00`00Oomoo`1BOol000moo`03001oogoo05Moo`03001oogoo
00=oo`03001oogoo05=oo`03001oogoo00=oo`03001oogoo059oo`003goo00<007ooOol0EWoo00<0
07ooOol017oo00<007ooOol0DWoo00<007ooOol017oo00<007ooOol0DWoo000?Ool00`00Oomoo`1F
Ool00`00Oomoo`04Ool00`00Oomoo`1BOol00`00Oomoo`04Ool00`00Oomoo`1BOol000moo`03001o
ogoo05Ioo`03001oogoo00Aoo`03001oogoo059oo`03001oogoo00Aoo`03001oogoo059oo`003goo
00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0DGoo00<007ooOol01Goo00<007ooOol0DGoo
000?Ool00`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomoo`1AOol00`00Oomoo`05Ool00`00Oomo
o`1AOol000moo`8005Moo`03001oogoo00Eoo`03001oogoo055oo`03001oogoo00Eoo`03001oogoo
055oo`003goo00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0DGoo00<007ooOol01Goo00<0
07ooOol0DGoo000?Ool00`00Oomoo`1EOol00`00Oomoo`06Ool00`00Oomoo`1AOol00`00Oomoo`05
Ool00`00Oomoo`1AOol000moo`03001oogoo05Eoo`03001oogoo00Moo`03001oogoo04moo`03001o
ogoo00Moo`03001oogoo051oo`003goo00<007ooOol0EGoo00<007ooOol01goo00<007ooOol0Cgoo
00<007ooOol01goo00<007ooOol0D7oo000?Ool00`00Oomoo`1EOol00`00Oomoo`07Ool00`00Oomo
o`1?Ool00`00Oomoo`07Ool00`00Oomoo`1@Ool000moo`03001oogoo05Eoo`03001oogoo00Moo`03
001oogoo04moo`03001oogoo00Moo`03001oogoo051oo`003goo00<007ooOol0EGoo00<007ooOol0
27oo00<007ooOol0CWoo00<007ooOol027oo00<007ooOol0Cgoo000?Ool2001FOol00`00Oomoo`08
Ool00`00Oomoo`1>Ool00`00Oomoo`08Ool00`00Oomoo`1?Ool000moo`03001oogoo05Eoo`03001o
ogoo00Qoo`03001oogoo04ioo`03001oogoo00Qoo`03001oogoo04moo`003goo00<007ooOol0E7oo
00<007ooOol02Goo00<007ooOol0CGoo00<007ooOol02Goo00<007ooOol0Cgoo000?Ool00`00Oomo
o`1DOol00`00Oomoo`09Ool00`00Oomoo`1=Ool00`00Oomoo`09Ool00`00Oomoo`1?Ool000moo`03
001oogoo05Aoo`03001oogoo00Yoo`03001oogoo04aoo`03001oogoo00Yoo`03001oogoo04ioo`00
3goo00<007ooOol0E7oo00<007ooOol02Woo00<007ooOol0C7oo00<007ooOol02Woo00<007ooOol0
CWoo0007Ool50003Ool00`00Oomoo`1DOol00`00Oomoo`0:Ool00`00Oomoo`1<Ool00`00Oomoo`0:
Ool00`00Oomoo`1>Ool000Uoo`03001oogoo00=oo`03001oogoo05Aoo`03001oogoo00Yoo`03001o
ogoo04aoo`03001oogoo00Yoo`03001oogoo04ioo`000goo0`000goo00<007ooOol00goo3`000Woo
3`0000Aoo`00000003=oo`03001oogoo009oo`/0009oo`l0009oo`H003=oo`03001oogoo009ooaP0
009oo`X003Eoo`002Goo00<007ooOol00goo00<007ooOol087oo00<007ooOol0<7oo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol05goo00<007ooOol0<Goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol05goo00<007ooOol0<goo0009Ool00`00Oomoo`03Ool2000QOol00`00Oomoo`0`
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0GOol00`00Oomoo`0`Ool00`00Oomoo`03
Ool00`00Oomoo`06Ool00`00Oomoo`0GOol00`00Oomoo`0cOol000Qoo`8000Eoo`80025oo`03001o
ogoo031oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo01Moo`03001oogoo031oo`03001o
ogoo00=oo`03001oogoo00Ioo`03001oogoo01Moo`03001oogoo03=oo`003goo0P008Goo00<007oo
Ool0<7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol05goo00<007ooOol0<7oo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol05goo00<007ooOol0<goo000?Ool00`00Ool0000POol0
0`00Oomoo`0`Ool00`00Oomoo`0<Ool00`00Oomoo`0HOol00`00Oomoo`0_Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`0GOol00`00Oomoo`0cOol000moo`03001oo`00021oo`03001oogoo
031oo`03001oogoo00eoo`03001oogoo01Moo`03001oogoo02moo`03001oogoo009oo`03001oogoo
00Qoo`03001oogoo04aoo`003goo00@007ooOol0021oo`03001oogoo02moo`03001oogoo009oo`03
001oogoo00Qoo`03001oogoo01Moo`03001oogoo02moo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo04aoo`003goo00@007ooOol0021oo`03001oogoo02moo`03001oogoo009oo`03001oogoo
00Qoo`03001oogoo01Moo`03001oogoo02moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo
01Moo`03001oogoo039oo`003goo0P0000=oo`00Ool07goo00<007ooOol0;Woo00<007ooOol00goo
00<007ooOol027oo00<007ooOol05goo00<007ooOol0;goo00<007ooOol03Goo00<007ooOol05goo
00<007ooOol0<Woo000?Ool01@00Oomoogoo00007goo00<007ooOol0;Woo00<007ooOol00goo00<0
07ooOol027oo00<007ooOol0B7oo00<007ooOol03Woo00<007ooOol05goo00<007ooOol0<Woo000?
Ool01@00Oomoogoo00007goo00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol02Woo00<007oo
Ool0Agoo00<007ooOol00goo00<007ooOol02Goo00<007ooOol05Woo00<007ooOol0<Woo000?Ool0
1@00Oomoogoo00007goo00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0
5Woo00<007ooOol0;Woo00<007ooOol00goo00<007ooOol02Goo00<007ooOol05goo00<007ooOol0
<Goo000?Ool00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`0^Ool00`00Oomoo`02Ool00`00
Oomoo`0:Ool00`00Oomoo`0FOol00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00
Oomoo`0GOol00`00Oomoo`0aOol000moo`03001oogoo009oo`03001oogoo04eoo`03001oogoo009o
o`03001oogoo00Yoo`03001oogoo01Ioo`03001oogoo02ioo`03001oogoo00=oo`03001oogoo00Uo
o`03001oogoo01Moo`03001oogoo035oo`003goo00<007ooOol00goo00<007ooOol0C7oo00<007oo
Ool00Woo00<007ooOol02Woo00<007ooOol05Woo00<007ooOol0;Woo00<007ooOol00Woo00<007oo
Ool02Woo00<007ooOol05goo00<007ooOol0<Goo000?Ool00`00Oomoo`03Ool00`00Oomoo`0LOol0
0`00Oomoo`0]Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0FOol00`00Oomoo`0]Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0FOol00`00Oomoo`0aOol000moo`8000Aoo`03
001oogoo01aoo`03001oogoo02aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo01Ioo`03
001oogoo02aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo01Ioo`03001oogoo035oo`00
3goo00<007ooOol017oo00<007ooOol06goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol0
37oo00<007ooOol05Woo00<007ooOol0;7oo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
5Woo00<007ooOol0<Goo000?Ool00`00Oomoo`04Ool00`00Oomoo`0KOol00`00Oomoo`0/Ool00`00
Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0EOol00`00Oomoo`0/Ool00`00Oomoo`03Ool00`00
Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`0`Ool000moo`03001oogoo00Aoo`03001oogoo01ao
o`03001oogoo02]oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo01Eoo`03001oogoo02ao
o`03001oogoo00=oo`03001oogoo00aoo`03001oogoo01Ioo`03001oogoo031oo`003goo00<007oo
Ool01Goo00<007ooOol06goo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol03Woo00<007oo
Ool057oo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol05Goo00<007oo
Ool0<7oo000?Ool00`00Oomoo`05Ool00`00Oomoo`0KOol00`00Oomoo`0[Ool00`00Oomoo`0DOol0
0`00Oomoo`0COol00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`0DOol0
0`00Oomoo`0`Ool000moo`03001oogoo00Eoo`03001oogoo01]oo`03001oogoo02]oo`03001oogoo
009oo`03001oogoo00moo`03001oogoo01Aoo`03001oogoo02]oo`03001oogoo009oo`03001oogoo
00moo`03001oogoo04Moo`003goo00<007ooOol01Woo00<007ooOol06Woo00<007ooOol0:Woo00<0
07ooOol00goo00<007ooOol047oo00<007ooOol04goo00<007ooOol0:goo00<007ooOol00Woo00<0
07ooOol047oo00<007ooOol0AWoo000?Ool20007Ool00`00Oomoo`0JOol00`00Oomoo`0ZOol00`00
Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0ZOol00`00Oomoo`0GOol00`00
Oomoo`0BOol00`00Oomoo`0`Ool000moo`03001oogoo00Moo`03001oogoo01Uoo`03001oogoo02Yo
o`03001oogoo00=oo`03001oogoo019oo`03001oogoo015oo`03001oogoo02Yoo`03001oogoo01Mo
o`03001oogoo019oo`03001oogoo031oo`003goo00<007ooOol01goo00<007ooOol06Woo00<007oo
Ool0:Goo00<007ooOol00Woo00<007ooOol04goo00<007ooOol0?Woo00<007ooOol00goo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol0<7oo000?Ool00`00Oomoo`07Ool00`00Oomoo`0JOol0
0`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`0AOol00`00Oomoo`0YOol0
0`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0`Ool000moo`03001oogoo
00Qoo`03001oogoo01Uoo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo
011oo`03001oogoo02Uoo`03001oogoo00=oo`03001oogoo01=oo`03001oogoo015oo`03001oogoo
02moo`003goo00<007ooOol027oo00<007ooOol06Goo00<007ooOol0:Goo00<007ooOol00Woo00<0
07ooOol05Goo00<007ooOol047oo00<007ooOol0:Goo00<007ooOol00goo00<007ooOol057oo00<0
07ooOol047oo00<007ooOol0;goo000?Ool00`00Oomoo`09Ool2000KOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`02Ool00`00Ool00004000BOol00`00Oomoo`0?Ool5
0002Ool00`00Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`02Ool00`00Oomoo`03000BOol00`00
Oomoo`0@Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`0SOol000moo`03001oogoo00]oo`03001o
ogoo01Ioo`800003Ool007oo00Ioo`03001oo`0001eoo`03001oogoo00=oo`05001oogooOol0000E
Ool00`00Oomoo`0>Ool00`00Ool00008Ool00`00Ool0000NOol00`00Oomoo`02Ool01000Oomoo`00
5Goo00<007ooOol03goo0P002Goo00<007oo000097oo000?Ool00`00Oomoo`0<Ool2000FOol20000
0goo001oo`08Ool00`00Oomoo`0KOol00`00Oomoo`03Ool01@00Oomoogoo00005Goo00<007ooOol0
3Woo00<007oo00002Woo00<007ooOol06goo00<007ooOol00goo00D007ooOomoo`0001Eoo`03001o
ogoo00ioo`03001oo`0000Yoo`03001oogoo029oo`003goo0P003goo00<007ooOol04goo0P0000=o
o`00Ool01Woo0P007Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol057oo0P003Woo00<0
07oo000027oo0P007Woo00<007ooOol00goo00D007ooOomoo`0001Eoo`03001oogoo00ioo`03001o
o`0000Qoo`8002Eoo`003goo00<007ooOol03goo0P004goo0P0000=oo`00Ool01Woo00<007ooOol0
7Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol05Woo0P003Goo0P0027oo00<007ooOol0
7Goo00<007ooOol00goo00H007ooOol007oo000EOol2000>Ool200000goo001oo`06Ool00`00Oomo
o`0TOol000moo`03001oogoo015oo`03001oogoo015oo`8000Qoo`<001eoo`03001oogoo009oo`04
001oogooOol2000JOol2000;Ool20008Ool3000MOol00`00Oomoo`03Ool01@00Oomoogoo000067oo
0`0037oo0P0027oo0`0097oo000?Ool00`00Oomoo`0BOol2000AOol00`00Oomoo`0WOol00`00Oomo
o`02Ool00`00Oomoo`0OOol30008Ool00`00Oomoo`0WOol00`00Oomoo`03Ool00`00Oomoo`0MOol3
0009Ool00`00Oomoo`0^Ool000moo`03001oogoo01Aoo`<000ioo`03001oogoo02Moo`03001oogoo
02Moo`8000Ioo`03001oogoo02Moo`03001oogoo009oo`03001oogoo025oo`<000Ioo`03001oogoo
02ioo`003goo00<007ooOol05goo1P0027oo00<007ooOol09goo00<007ooOol0:Goo0P0017oo00<0
07ooOol09goo00<007ooOol00Woo00<007ooOol097oo0P0017oo00<007ooOol0;Woo000?Ool00`00
Oomoo`0MOol40004Ool00`00Oomoo`0VOol00`00Oomoo`03Ool00`00Oomoo`0UOol00`00Oomoo`02
Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`0UOol00`00Oomoo`0cOol000moo`03001o
ogoo021oo`03001oogoo009oo`03001oogoo02Ioo`03001oogoo00=oo`03001oogoo02Eoo`03001o
ogoo009oo`03001oogoo02Ioo`03001oogoo00=oo`03001oogoo02Eoo`03001oogoo009oo`03001o
ogoo02ioo`0027ooo`006@00000?Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`04Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`03Ool200000goo001oo`02Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`05Ool20008Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Ool00008Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`05Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`03Ool000moo`03001o
ogoo025oo`03001oogoo009oo`03001oogoo009oo`03001oogoo01eoo`8000Ioo`03001oogoo00=o
o`03001oogoo025oo`03001oogoo00Moo`03001oogoo01moo`8000Aoo`03001oogoo00=oo`03001o
ogoo025oo`05001oogooOol00005Ool00`00Oomoo`0OOol20007Ool000moo`03001oogoo025oo`03
001oogoo009oo`03001oogoo021oo`8000Qoo`03001oogoo02Moo`03001oogoo009oo`03001oogoo
025oo`<000Ioo`03001oogoo02Moo`03001oogoo009oo`03001oogoo025oo`<000Uoo`003goo00<0
07ooOol08Goo00<007ooOol00Woo00<007ooOol07Goo0`002Woo00<007ooOol09goo00<007ooOol0
0Woo00<007ooOol07Woo0`002Goo00<007ooOol09goo00<007ooOol00Woo00<007ooOol07Woo0`00
37oo000?Ool00`00Oomoo`0QOol00`00Oomoo`0POol2000=Ool00`00Oomoo`0WOol00`00Oomoo`02
Ool00`00Oomoo`0KOol3000<Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`0KOol3000?
Ool000moo`03001oogoo025oo`03001oogoo01ioo`8000moo`03001oogoo02Moo`03001oogoo009o
o`03001oogoo01Uoo`8000ioo`03001oogoo02Qoo`03001oogoo009oo`03001oogoo01Uoo`80019o
o`003goo00<007ooOol08Goo00<007ooOol00Woo00<007ooOol067oo00<007ooOol03goo00<007oo
Ool09goo00<007ooOol00goo00<007ooOol05goo00<007ooOol03Woo00<007ooOol0:7oo00<007oo
Ool00Woo00<007ooOol067oo00<007ooOol04Woo000?Ool2000ROol00`00Oomoo`02Ool00`00Oomo
o`0HOol00`00Oomoo`0?Ool00`00Oomoo`0WOol00`00Oomoo`03Ool00`00Oomoo`0GOol00`00Oomo
o`0>Ool00`00Oomoo`0XOol00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`0BOol000moo`03
001oogoo025oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo00moo`03001oogoo02Uoo`03
001oogoo009oo`03001oogoo01Ioo`03001oogoo00moo`03001oogoo02Uoo`05001oogooOol0000I
Ool00`00Oomoo`0COol000moo`03001oogoo029oo`05001oogooOol0000HOol00`00Oomoo`0@Ool0
0`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0YOol0
0`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`0DOol000moo`03001oogoo029oo`03001oogoo
009oo`03001oogoo01Eoo`03001oogoo011oo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo
01Eoo`03001oogoo011oo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo
01Aoo`003goo00<007ooOol08Woo00<007ooOol00Woo00<007ooOol057oo00<007ooOol04Goo00<0
07ooOol0:Goo00<007ooOol00Woo00<007ooOol057oo00<007ooOol04Goo00<007ooOol0:Goo00<0
07ooOol00Woo00<007ooOol057oo00<007ooOol05Goo000?Ool00`00Oomoo`0ROol00`00Oomoo`02
Ool00`00Oomoo`0COol00`00Oomoo`0nOol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`0A
Ool00`00Oomoo`0ZOol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`0FOol000moo`03001o
ogoo029oo`03001oogoo009oo`03001oogoo019oo`03001oogoo03moo`03001oogoo00=oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo02Yoo`03001oogoo01Moo`03001oogoo01Moo`003goo
00<007ooOol08Woo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0:Woo
00<007ooOol00goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol0:Woo00<007ooOol05goo
00<007ooOol05goo000?Ool00`00Oomoo`0ROol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomo
o`0COol00`00Oomoo`0ZOol00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`0COol00`00Oomo
o`0ZOol00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`0HOol000moo`8002Aoo`05001oogoo
Ool0000BOol00`00Oomoo`0DOol00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00
Oomoo`12Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`0IOol000moo`03001oogoo02=o
o`03001oogoo009oo`03001oogoo00moo`03001oogoo01Aoo`03001oogoo02]oo`03001oogoo01Ao
o`03001oogoo01Aoo`03001oogoo02]oo`03001oogoo009oo`03001oogoo00moo`03001oogoo01Uo
o`003goo00<007ooOol08goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol057oo00<007oo
Ool0;7oo00<007ooOol04goo00<007ooOol05Goo00<007ooOol0:goo00<007ooOol00Woo00<007oo
Ool03Woo00<007ooOol06Woo000?Ool00`00Oomoo`0SOol00`00Oomoo`02Ool00`00Oomoo`0=Ool0
0`00Oomoo`0EOol00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0FOol0
0`00Oomoo`0[Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0KOol000moo`03001oogoo
02=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo01Eoo`03001oogoo02aoo`03001oogoo
009oo`03001oogoo00eoo`03001oogoo01Ioo`03001oogoo02]oo`03001oogoo00=oo`03001oogoo
00aoo`03001oogoo01]oo`003goo00<007ooOol08goo00<007ooOol04Goo00<007ooOol05Woo00<0
07ooOol0;7oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol05Woo00<007ooOol0;7oo00<0
07ooOol00goo00<007ooOol02goo00<007ooOol077oo000?Ool00`00Oomoo`0SOol00`00Oomoo`02
Ool00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool00`00Oomoo`0FOol00`00Oomoo`0/Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0L
Ool000moo`03001oogoo02=oo`03001oogoo009oo`03001oogoo00aoo`03001oogoo01Ioo`03001o
ogoo02eoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo01Ioo`03001oogoo02eoo`03001o
ogoo009oo`03001oogoo00]oo`03001oogoo01aoo`003goo0P009Goo00D007ooOomoo`0000eoo`03
001oogoo01Ioo`03001oogoo02ioo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo01Moo`03
001oogoo02eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo01eoo`003goo00<007ooOol0
97oo00D007ooOomoo`0000eoo`03001oogoo01Ioo`03001oogoo02ioo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo01Moo`03001oogoo02eoo`03001oogoo009oo`03001oogoo00Yoo`03001o
ogoo01eoo`003goo00<007ooOol097oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol05Woo
00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol05goo00<007ooOol0;Goo
00<007ooOol00goo00<007ooOol02Goo00<007ooOol07Goo000?Ool00`00Oomoo`0TOol00`00Oomo
o`02Ool00`00Oomoo`0:Ool00`00Oomoo`0FOol00`00Oomoo`0^Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool00`00Oomoo`0GOol00`00Oomoo`0]Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomo
o`0MOol000moo`03001oogoo02Aoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo04Moo`03
001oogoo009oo`03001oogoo00Yoo`03001oogoo01Ioo`03001oogoo02ioo`03001oogoo00=oo`03
001oogoo00Uoo`03001oogoo01eoo`003goo00<007ooOol097oo00<007ooOol00Woo00<007ooOol0
2Goo00<007ooOol0B7oo00<007ooOol00goo00<007ooOol027oo00<007ooOol05goo00<007ooOol0
;Woo00<007ooOol00goo00<007ooOol027oo00<007ooOol07Woo000?Ool00`00Oomoo`0TOol00`00
Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0GOol00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00
Oomoo`08Ool00`00Oomoo`0GOol00`00Oomoo`0^Ool00`00Oomoo`0>Ool00`00Oomoo`0NOol000mo
o`03001oogoo02Eoo`05001oogooOol0000;Ool00`00Oomoo`0GOol00`00Oomoo`0_Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool00`00Oomoo`0GOol00`00Oomoo`0_Ool00`00Oomoo`02Ool00`00Oomo
o`08Ool00`00Oomoo`0NOol000moo`8002Ioo`05001oogooOol0000;Ool00`00Oomoo`0GOol00`00
Oomoo`0_Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`19Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Oomoo`0NOol000moo`03001oogoo02Eoo`03001oogoo009oo`03001oogoo00Qo
o`03001oogoo01Moo`03001oogoo02moo`03001oogoo00eoo`03001oogoo04Uoo`03001oogoo009o
o`03001oogoo00Qoo`03001oogoo01ioo`003goo00<007ooOol09Goo00<007ooOol00Woo00<007oo
Ool01goo00<007ooOol067oo00<007ooOol0;goo00<007ooOol037oo00<007ooOol067oo00<007oo
Ool0;goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol07goo000?Ool00`00Oomoo`0UOol0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0HOol00`00Oomoo`0_Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`0HOol00`00Oomoo`0_Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`0OOol000moo`03001oogoo02Eoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
01Moo`03001oogoo031oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo01Qoo`03001oogoo
02moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo01moo`003goo00<007ooOol09Goo00<0
07ooOol037oo00<007ooOol05goo00<007ooOol0<7oo00<007ooOol00Woo00<007ooOol01goo00<0
07ooOol067oo00<007ooOol0;goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol07goo000?
Ool00`00Oomoo`0UOol00`00Oomoo`0<Ool00`00Oomoo`0GOol00`00Oomoo`0aOol00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`0GOol00`00Oomoo`0aOol00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`0OOol000Moo`D000=oo`03001oogoo02Ioo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo01Qoo`03001oogoo035oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo01Qo
o`03001oogoo035oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo021oo`002Goo00<007oo
Ool00goo00<007ooOol09Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol067oo00<007oo
Ool0<Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol067oo00<007ooOol0<Goo00<007oo
Ool00Woo00<007ooOol01Goo00<007ooOol087oo0009Ool00`00Oomoo`03Ool3000VOol00`00Oomo
o`02Ool=0002Ool?00000goo00000003000cOol00`00Oomoo`02Ool90002Ool?0002Ool8000cOol0
0`00Oomoo`02Ool60002Ool>0002Ool<0007Ool000Uoo`03001oogoo00=oo`03001oogoo02Ioo`03
001oogoo00Yoo`03001oogoo04aoo`03001oogoo00Yoo`03001oogoo04aoo`03001oogoo00Yoo`03
001oogoo021oo`002Goo00<007ooOol00goo00<007ooOol09Woo00<007ooOol02Woo00<007ooOol0
C7oo00<007ooOol02Woo00<007ooOol0C7oo00<007ooOol02Woo00<007ooOol087oo0008Ool20005
Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`1=Ool00`00Oomoo`09Ool00`00Oomoo`1=
Ool00`00Oomoo`09Ool00`00Oomoo`0QOol000moo`03001oogoo02Ioo`03001oogoo00Uoo`03001o
ogoo04eoo`03001oogoo00Uoo`03001oogoo04eoo`03001oogoo00Uoo`03001oogoo025oo`003goo
00<007ooOol09Woo00<007ooOol02Goo00<007ooOol0CWoo00<007ooOol027oo00<007ooOol0CWoo
00<007ooOol027oo00<007ooOol08Goo000?Ool00`00Oomoo`0WOol00`00Oomoo`08Ool00`00Oomo
o`1>Ool00`00Oomoo`08Ool00`00Oomoo`1>Ool00`00Oomoo`08Ool00`00Oomoo`0QOol000moo`03
001oogoo02Moo`03001oogoo00Qoo`03001oogoo04ioo`03001oogoo00Qoo`03001oogoo04ioo`03
001oogoo00Qoo`03001oogoo025oo`003goo0P00:7oo00<007ooOol01goo00<007ooOol0Cgoo00<0
07ooOol01goo00<007ooOol0Cgoo00<007ooOol01goo00<007ooOol08Woo000?Ool00`00Oomoo`0W
Ool00`00Oomoo`07Ool00`00Oomoo`1?Ool00`00Oomoo`07Ool00`00Oomoo`1?Ool00`00Oomoo`07
Ool00`00Oomoo`0ROol000moo`03001oogoo02Moo`03001oogoo00Moo`03001oogoo04moo`03001o
ogoo00Moo`03001oogoo04moo`03001oogoo00Moo`03001oogoo029oo`003goo00<007ooOol09goo
00<007ooOol01goo00<007ooOol0Cgoo00<007ooOol01goo00<007ooOol0Cgoo00<007ooOol01goo
00<007ooOol08Woo000?Ool00`00Oomoo`0WOol00`00Oomoo`06Ool00`00Oomoo`1@Ool00`00Oomo
o`06Ool00`00Oomoo`1@Ool00`00Oomoo`06Ool00`00Oomoo`0SOol000moo`03001oogoo02Qoo`03
001oogoo00Eoo`03001oogoo055oo`03001oogoo00Eoo`03001oogoo055oo`03001oogoo00Eoo`03
001oogoo02=oo`003goo00<007ooOol0:7oo00<007ooOol01Goo00<007ooOol0DGoo00<007ooOol0
1Goo00<007ooOol0DGoo00<007ooOol01Goo00<007ooOol08goo000?Ool00`00Oomoo`0XOol00`00
Oomoo`05Ool00`00Oomoo`1AOol00`00Oomoo`05Ool00`00Oomoo`1AOol00`00Oomoo`05Ool00`00
Oomoo`0SOol000moo`8002Uoo`03001oogoo00Eoo`03001oogoo055oo`03001oogoo00Eoo`03001o
ogoo055oo`03001oogoo00Eoo`03001oogoo02=oo`003goo00<007ooOol0:7oo00<007ooOol017oo
00<007ooOol0DWoo00<007ooOol017oo00<007ooOol0DWoo00<007ooOol017oo00<007ooOol097oo
000?Ool00`00Oomoo`0XOol00`00Oomoo`04Ool00`00Oomoo`1BOol00`00Oomoo`04Ool00`00Oomo
o`1BOol00`00Oomoo`04Ool00`00Oomoo`0TOol000moo`03001oogoo02Qoo`03001oogoo00Aoo`03
001oogoo059oo`03001oogoo00Aoo`03001oogoo059oo`03001oogoo00Aoo`03001oogoo02Aoo`00
3goo00<007ooOol0:7oo00<007ooOol017oo00<007ooOol0Dgoo00<007ooOol00goo00<007ooOol0
Dgoo00<007ooOol00goo00<007ooOol097oo000?Ool00`00Oomoo`0YOol00`00Oomoo`03Ool00`00
Oomoo`1COol00`00Oomoo`03Ool00`00Oomoo`1COol00`00Oomoo`03Ool00`00Oomoo`0TOol000mo
o`03001oogoo02Uoo`03001oogoo009oo`03001oogoo05Aoo`03001oogoo009oo`03001oogoo05Ao
o`03001oogoo009oo`03001oogoo02Eoo`003goo00<007ooOol0:Goo00<007ooOol00Woo00<007oo
Ool0E7oo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol00Woo00<007ooOol09Goo000?Ool0
0`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`1DOol00`00Oomoo`02Ool00`00Oomoo`1DOol0
0`00Oomoo`02Ool00`00Oomoo`0UOol000moo`8002Yoo`03001oogoo009oo`03001oogoo05Aoo`03
001oogoo009oo`03001oogoo05Aoo`03001oogoo009oo`03001oogoo02Eoo`003goo00<007ooOol0
:Goo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol00Woo00<007ooOol0E7oo00<007ooOol0
0Woo00<007ooOol09Goo000?Ool00`00Oomoo`0YOol01@00Oomoogoo0000Egoo00D007ooOomoo`00
05Moo`05001oogooOol0000XOol000moo`03001oogoo02Yoo`04001oogoo001HOol01000Oomoo`00
F7oo00@007ooOol002Qoo`003goo00<007ooOol0:Woo00@007ooOol005Qoo`04001oogoo001HOol0
1000Oomoo`00:7oo000?Ool00`00Oomoo`0ZOol01000Oomoo`00F7oo00@007ooOol005Qoo`04001o
ogoo000XOol000moo`03001oogoo02Yoo`04001oogoo001HOol01000Oomoo`00F7oo00@007ooOol0
02Qoo`003goo00<007ooOol0:Woo00<007oo0000FGoo00<007oo0000FGoo00<007oo0000:Goo000?
Ool2000[Ool00`00Ool0001IOol00`00Ool0001IOol00`00Ool0000YOol000moo`03001oogoo02Yo
o`03001oo`0005Uoo`03001oo`0005Uoo`03001oo`0002Uoo`003goo00<007ooOol0:Woo00<007oo
0000FGoo00<007oo0000FGoo00<007oo0000:Goo000?Ool00`00Oomoo`0[Ool2001JOol2001JOol2
000YOol000moo`03001oogoo02]oo`03001oogoo05Uoo`03001oogoo05Uoo`03001oogoo02Qoo`00
3goo00<007ooOol0:goo00<007ooOol0FGoo00<007ooOol0FGoo00<007ooOol0:7oo0008Ool30004
Ool00`00Oomoo`0[Ool00`00Oomoo`1IOol00`00Oomoo`1IOol00`00Oomoo`0XOol000Qoo`03001o
ogoo00Aoo`03001oogoo0?moo`moo`002Goo00<007ooOol00goo0`00ogoo3goo0009Ool00`00Oomo
o`03Ool00`00Oomoo`3oOol?Ool000Qoo`03001oo`0000Aoo`03001oogoo0?moo`moo`002Goo00<0
07ooOol0ogoo5Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.167986, -2.1236, 
  0.0108532, 0.0240038}},
  CellTags->"4.2"]
}, Open  ]],

Cell[TextData[{
  StyleBox["SimulationPlot", "MR"],
  " is a plotting routine that calls either ",
  StyleBox["ListPlot", "MR"],
  " or ",
  StyleBox["MultipleListPlot", "MR"],
  " to present the results of a simulation in graphic form in the appropriate \
time scale. The simulation is always assumed to start at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " and to contain exactly ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " points, where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " is determined from the length of the input sequences. The time step is \
assumed to be the sampling period, which may be supplied to ",
  StyleBox["SimulationPlot", "MR"],
  " using the ",
  StyleBox["Sampled", "MR"],
  " option or taken from the global ",
  StyleBox["$Sampled", "MR"],
  " variable. For the purpose of simulation, the sampling period cannot take \
symbolic values. \n",
  StyleBox["SimulationPlot", "MR"],
  " also accepts the system to be simulated along with the input sequences \
(similarly to ",
  StyleBox["OutputResponse", "MR"],
  "), so that the call to ",
  StyleBox["OutputResponse", "MR"],
  " is performed in a transparent way and the simulation can be automated. \n\
Finally, ",
  StyleBox["SimulationPlot", "MR"],
  " accepts the input vectors in symbolic form (again, similar to ",
  StyleBox["OutputResponse", "MR"],
  "), but, unlike ",
  StyleBox["OutputResponse", "MR"],
  ", the output is ",
  StyleBox["simulated", "TI"],
  " instead of being obtained in the symbolic form from the solution of \
system equations. In this case, the symbolic inputs are sampled and then the \
simulation is performed. It is important, therefore, to restrict the symbolic \
input to ",
  StyleBox["SimulationPlot", "MR"],
  " to those that have numeric values on the selected time grid. \nIn all \
cases, the step of the simulation is determined by the ",
  StyleBox["Sampled", "MR"],
  " option, which may either come from the system itself or be supplied as an \
option to ",
  StyleBox["SimulationPlot", "MR"],
  " (the system\[Hyphen]supplied value takes precedence should both be \
encountered). The system may be either continuous\[Hyphen] or discrete\
\[Hyphen]time and can be either in state\[Hyphen]space or \
transfer\[Hyphen]function form. ",
  StyleBox["SimulationPlot", "MR"],
  " accepts options pertinent to ",
  StyleBox["OutputResponse", "MR"],
  " as well as to the plotting functions and routes the options to \
appropriate channels. "
}], "Text",
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["SimulationPlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["v",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["plot",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["vector",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["or",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["list",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["vectors",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["v",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "TopBox",
  GeneratedCell->True,
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["SimulationPlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["u",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["plot",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["simulated",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["output",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["response",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["discrete",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["input",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["sequences",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["u",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["SimulationPLot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["u",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{"t", 
                        StyleBox[",",
                          "MR"], " ", "tmax"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"4.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["simulate",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["output",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["response",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["input",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["function",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["u",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["variable",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["t",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["varying",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["from",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["0",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["tmax",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"4.2"],

Cell["Output response simulation plots. ", "Caption",
  CellTags->"4.2"],

Cell[TextData[{
  "The fact that ",
  StyleBox["SimulationPlot", "MR"],
  " accepts input in continuous functional form does not mean that the analog \
simulation takes place. On the contrary, ",
  StyleBox["SimulationPlot", "MR"],
  " ",
  StyleBox["always", "TI"],
  " carries out the discrete\[Hyphen]time simulation, and the continuous \
signals are always sampled prior to the execution. If the analog simulation \
is desired, one may try to compute the solution in symbolic form using ",
  StyleBox["OutputResponse", "MR"],
  " and then use the built\[Hyphen]in ",
  StyleBox["Plot", "MR"],
  " function as described in the preceding section.  "
}], "Text",
  CellTags->"4.2"],

Cell[TextData[{
  "We can use ",
  StyleBox["SimulationPlot", "MR"],
  " to obtain the output. Here is the simulation for another set of \
parameters. "
}], "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["\<\
SimulationPlot[
 bridge /. {r -> 1, c1 -> 10, c2 -> 1},
 square[3, 1, ts],
 Sampled -> Period[ts]
]\
\>", "Input",
  CellLabel->"In[26]:=",
  CellTags->"4.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.331263 0.293035 0.225754 [
[.18944 .28054 -9 -9 ]
[.18944 .28054 9 0 ]
[.35507 .28054 -3 -9 ]
[.35507 .28054 3 0 ]
[.5207 .28054 -9 -9 ]
[.5207 .28054 9 0 ]
[.68634 .28054 -3 -9 ]
[.68634 .28054 3 0 ]
[.85197 .28054 -9 -9 ]
[.85197 .28054 9 0 ]
[.01131 .06728 -12 -4.5 ]
[.01131 .06728 0 4.5 ]
[.01131 .18016 -24 -4.5 ]
[.01131 .18016 0 4.5 ]
[.01131 .40591 -18 -4.5 ]
[.01131 .40591 0 4.5 ]
[.01131 .51879 -6 -4.5 ]
[.01131 .51879 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18944 .29304 m
.18944 .29929 L
s
[(0.5)] .18944 .28054 0 1 Mshowa
.35507 .29304 m
.35507 .29929 L
s
[(1)] .35507 .28054 0 1 Mshowa
.5207 .29304 m
.5207 .29929 L
s
[(1.5)] .5207 .28054 0 1 Mshowa
.68634 .29304 m
.68634 .29929 L
s
[(2)] .68634 .28054 0 1 Mshowa
.85197 .29304 m
.85197 .29929 L
s
[(2.5)] .85197 .28054 0 1 Mshowa
.125 Mabswid
.05694 .29304 m
.05694 .29679 L
s
.09006 .29304 m
.09006 .29679 L
s
.12319 .29304 m
.12319 .29679 L
s
.15631 .29304 m
.15631 .29679 L
s
.22257 .29304 m
.22257 .29679 L
s
.25569 .29304 m
.25569 .29679 L
s
.28882 .29304 m
.28882 .29679 L
s
.32195 .29304 m
.32195 .29679 L
s
.3882 .29304 m
.3882 .29679 L
s
.42133 .29304 m
.42133 .29679 L
s
.45445 .29304 m
.45445 .29679 L
s
.48758 .29304 m
.48758 .29679 L
s
.55383 .29304 m
.55383 .29679 L
s
.58696 .29304 m
.58696 .29679 L
s
.62008 .29304 m
.62008 .29679 L
s
.65321 .29304 m
.65321 .29679 L
s
.71946 .29304 m
.71946 .29679 L
s
.75259 .29304 m
.75259 .29679 L
s
.78571 .29304 m
.78571 .29679 L
s
.81884 .29304 m
.81884 .29679 L
s
.88509 .29304 m
.88509 .29679 L
s
.91822 .29304 m
.91822 .29679 L
s
.95135 .29304 m
.95135 .29679 L
s
.98447 .29304 m
.98447 .29679 L
s
.25 Mabswid
0 .29304 m
1 .29304 L
s
.02381 .06728 m
.03006 .06728 L
s
[(-1)] .01131 .06728 1 0 Mshowa
.02381 .18016 m
.03006 .18016 L
s
[(-0.5)] .01131 .18016 1 0 Mshowa
.02381 .40591 m
.03006 .40591 L
s
[(0.5)] .01131 .40591 1 0 Mshowa
.02381 .51879 m
.03006 .51879 L
s
[(1)] .01131 .51879 1 0 Mshowa
.125 Mabswid
.02381 .08986 m
.02756 .08986 L
s
.02381 .11243 m
.02756 .11243 L
s
.02381 .13501 m
.02756 .13501 L
s
.02381 .15758 m
.02756 .15758 L
s
.02381 .20273 m
.02756 .20273 L
s
.02381 .22531 m
.02756 .22531 L
s
.02381 .24788 m
.02756 .24788 L
s
.02381 .27046 m
.02756 .27046 L
s
.02381 .31561 m
.02756 .31561 L
s
.02381 .33819 m
.02756 .33819 L
s
.02381 .36076 m
.02756 .36076 L
s
.02381 .38334 m
.02756 .38334 L
s
.02381 .42849 m
.02756 .42849 L
s
.02381 .45106 m
.02756 .45106 L
s
.02381 .47364 m
.02756 .47364 L
s
.02381 .49621 m
.02756 .49621 L
s
.02381 .04471 m
.02756 .04471 L
s
.02381 .02213 m
.02756 .02213 L
s
.02381 .54136 m
.02756 .54136 L
s
.02381 .56394 m
.02756 .56394 L
s
.02381 .58651 m
.02756 .58651 L
s
.02381 .60909 m
.02756 .60909 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .06728 m
.06522 .09348 L
.10663 .11599 L
.14803 .1353 L
.18944 .60332 L
.23085 .56502 L
.27226 .53198 L
.31366 .50353 L
.35507 .02756 L
.39648 .05895 L
.43789 .08599 L
.4793 .10923 L
.5207 .58068 L
.56211 .54536 L
.60352 .51492 L
.64493 .48872 L
.68634 .01472 L
.72774 .04782 L
.76915 .07634 L
.81056 .10088 L
.85197 .57345 L
.89337 .53911 L
.93478 .50953 L
.97619 .48408 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`2]Ool00`00Oomoo`1BOol001]oo`03001oogoo0:eoo`8005=oo`006goo0P00[Woo00@0
07oo0000055oo`006goo00<007ooOol0EGoo00<007ooOol0EGoo00D007ooOomoo`00051oo`006goo
00<007ooOol0EGoo0P00EWoo00<007ooOol00Woo00<007ooOol0CGoo000KOol00`00Oomoo`1EOol0
1000Ool00000E7oo00<007ooOol00goo00<007ooOol0C7oo000KOol00`00Oomoo`1EOol01@00Oomo
ogoo0000DWoo00<007ooOol01Goo00<007ooOol0Bgoo000KOol00`00Oomoo`1EOol00`00Oomoo`02
Ool00`00Oomoo`1?Ool00`00Oomoo`06Ool2001;Ool001]oo`8005Ioo`03001oogoo00=oo`03001o
ogoo04ioo`03001oogoo00Qoo`03001oogoo04Qoo`006goo00<007ooOol0E7oo00<007ooOol01Goo
00<007ooOol0CGoo00<007ooOol02Goo00<007ooOol0Agoo000KOol00`00Oomoo`1DOol00`00Oomo
o`06Ool2001=Ool00`00Oomoo`0:Ool20017Ool001]oo`03001oogoo05Aoo`03001oogoo00Qoo`03
001oogoo04Yoo`03001oogoo00aoo`03001oogoo04Aoo`004goo1@000goo00<007ooOol0E7oo00<0
07ooOol02Goo00<007ooOol0BGoo00<007ooOol03Goo0P00A7oo000EOol00`00Oomoo`03Ool00`00
Oomoo`1DOol00`00Oomoo`0:Ool20019Ool00`00Oomoo`0?Ool20012Ool000moo`<000=oo`03001o
ogoo00=oo`8005Eoo`03001oogoo00aoo`03001oogoo04Ioo`03001oogoo015oo`03001oogoo03mo
o`005Goo00<007ooOol00goo0`00E7oo00<007ooOol03Goo0P00AWoo00<007ooOol04Woo0P00?goo
000EOol00`00Oomoo`03Ool01000Oomoo`00Dgoo00<007ooOol03goo0P00A7oo00<007ooOol057oo
00<007ooOol0?7oo000DOol20005Ool01000Oomoogoo0P00DGoo00<007ooOol04Goo00<007ooOol0
@Goo00<007ooOol05Goo0P00?7oo000KOol00`00Oomoo`03Ool2001?Ool00`00Oomoo`0BOol20010
Ool00`00Oomoo`0HOol00`00Oomoo`0iOol001]oo`03001oogoo00Eoo`03001oogoo04aoo`03001o
ogoo01Aoo`03001oogoo03eoo`03001oogoo01Uoo`8003Uoo`006goo0P001goo0P00C7oo00<007oo
Ool05Goo0P00?Goo00<007ooOol06goo0P00=goo000KOol00`00Oomoo`08Ool00`00Oomoo`18Ool0
0`00Oomoo`0HOol2000kOol00`00Oomoo`0MOol00`00Oomoo`0dOol001]oo`03001oogoo00Uoo`80
04Qoo`03001oogoo01Yoo`8003Uoo`03001oogoo01ioo`8003Aoo`006goo00<007ooOol02goo0P00
AWoo00<007ooOol077oo0P00=goo00<007ooOol087oo00<007ooOol0<Goo000KOol00`00Oomoo`0=
Ool20014Ool00`00Oomoo`0NOol2000eOol00`00Oomoo`0POol00`00Oomoo`0aOol001]oo`03001o
ogoo00moo`80049oo`03001oogoo021oo`03001oogoo039oo`03001oogoo021oo`03001oogoo035o
o`006goo0P004Woo0P00@7oo00<007ooOol087oo00<007ooOol0<Woo00<007ooOol087oo00<007oo
Ool0<Goo000KOol00`00Oomoo`0COol2000nOol00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomo
o`0POol00`00Oomoo`0aOol001]oo`03001oogoo01Eoo`8003aoo`03001oogoo021oo`03001oogoo
039oo`03001oogoo021oo`03001oogoo035oo`006goo00<007ooOol05goo0P00>Woo00<007ooOol0
87oo00<007ooOol0<Goo00<007ooOol08Woo00<007ooOol0<7oo000KOol00`00Oomoo`0IOol2000h
Ool00`00Oomoo`0POol00`00Oomoo`0aOol00`00Oomoo`0ROol00`00Oomoo`0`Ool001]oo`03001o
ogoo01]oo`8003Ioo`03001oogoo025oo`03001oogoo031oo`03001oogoo029oo`03001oogoo031o
o`006goo0P007Woo0P00<goo00<007ooOol08Woo00<007ooOol0<7oo00<007ooOol08Woo00<007oo
Ool0<7oo000KOol00`00Oomoo`0NOol00`00Oomoo`0aOol00`00Oomoo`0ROol00`00Oomoo`0`Ool0
0`00Oomoo`0ROol00`00Oomoo`0`Ool001]oo`03001oogoo01ioo`03001oogoo035oo`03001oogoo
029oo`03001oogoo031oo`03001oogoo029oo`03001oogoo031oo`006goo00<007ooOol07Woo00<0
07ooOol0<Goo00<007ooOol08Woo00<007ooOol0<7oo00<007ooOol08Woo00<007ooOol0<7oo000K
Ool00`00Oomoo`0NOol00`00Oomoo`0aOol00`00Oomoo`0ROol00`00Oomoo`0`Ool00`00Oomoo`0R
Ool00`00Oomoo`0`Ool001]oo`03001oogoo01ioo`03001oogoo035oo`03001oogoo029oo`03001o
ogoo031oo`03001oogoo029oo`03001oogoo031oo`006goo0P0087oo00<007ooOol0<7oo00<007oo
Ool08Woo00<007ooOol0<7oo00<007ooOol08Woo00<007ooOol0<7oo000KOol00`00Oomoo`0OOol0
0`00Oomoo`0`Ool00`00Oomoo`0ROol00`00Oomoo`0`Ool00`00Oomoo`0ROol00`00Oomoo`0`Ool0
01]oo`03001oogoo01moo`03001oogoo031oo`03001oogoo029oo`03001oogoo031oo`03001oogoo
029oo`03001oogoo031oo`006goo00<007ooOol07goo00<007ooOol0<7oo00<007ooOol08Woo00<0
07ooOol0;goo00<007ooOol097oo00<007ooOol0;goo000;Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`0OOol00`00Oomoo`0`Ool00`00Oomoo`0ROol00`00Oomoo`0_
Ool00`00Oomoo`0TOol00`00Oomoo`0_Ool000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001o
ogoo01moo`03001oogoo031oo`03001oogoo02=oo`03001oogoo02ioo`03001oogoo02Aoo`03001o
ogoo02moo`001Goo0`000Woo00<007oo00002Goo00<007ooOol00Woo0P0087oo00<007ooOol0;goo
00<007ooOol097oo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0;goo000:Ool00`00Ool0
0007Ool20005Ool00`00Oomoo`0OOol00`00Oomoo`0_Ool00`00Oomoo`0TOol00`00Oomoo`0^Ool0
0`00Oomoo`0TOol00`00Oomoo`0_Ool000Yoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo
01moo`03001oogoo02moo`03001oogoo02Aoo`03001oogoo02ioo`03001oogoo02Aoo`03001oogoo
02moo`002goo00<007ooOol01Woo0`0017oo00<007ooOol07goo00<007ooOol0;goo00<007ooOol0
97oo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0;goo000KOol00`00Oomoo`0OOol00`00
Oomoo`0_Ool00`00Oomoo`0TOol00`00Oomoo`0^Ool00`00Oomoo`0TOol00`00Oomoo`0_Ool001]o
o`03001oogoo021oo`03001oogoo02ioo`03001oogoo02Aoo`03001oogoo02ioo`03001oogoo02Ao
o`03001oogoo02moo`006goo0P008Goo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0;Woo
00<007ooOol097oo00<007ooOol0;goo000KOol00`00Oomoo`0POol00`00Oomoo`0^Ool00`00Oomo
o`0TOol00`00Oomoo`0^Ool00`00Oomoo`0TOol00`00Oomoo`0_Ool001]oo`03001oogoo021oo`03
001oogoo02ioo`03001oogoo02Aoo`03001oogoo02eoo`03001oogoo02Ioo`03001oogoo02ioo`00
6goo00<007ooOol087oo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0;Goo00<007ooOol0
9Woo00<007ooOol0;Woo000KOol00`00Oomoo`0POol00`00Oomoo`0^Ool00`00Oomoo`0UOol00`00
Oomoo`0/Ool00`00Oomoo`0VOol00`00Oomoo`0^Ool001]oo`03001oogoo021oo`03001oogoo02eo
o`03001oogoo02Ioo`03001oogoo02aoo`03001oogoo02Ioo`03001oogoo02ioo`006goo0P008Goo
00<007ooOol0;Goo00<007ooOol09Woo00<007ooOol0;7oo00<007ooOol09Woo00<007ooOol0;Woo
000KOol00`00Oomoo`0POol00`00Oomoo`0]Ool00`00Oomoo`0VOol00`00Oomoo`0/Ool00`00Oomo
o`0VOol00`00Oomoo`0^Ool001]oo`03001oogoo021oo`03001oogoo02eoo`03001oogoo02Ioo`03
001oogoo02aoo`03001oogoo02Ioo`03001oogoo02ioo`006goo00<007ooOol087oo00<007ooOol0
;Goo00<007ooOol09Woo00<007ooOol0;7oo00<007ooOol09Woo00<007ooOol0;Woo000KOol00`00
Oomoo`0POol00`00Oomoo`0]Ool00`00Oomoo`0VOol00`00Oomoo`0/Ool00`00Oomoo`0VOol00`00
Oomoo`0^Ool001]oo`03001oogoo025oo`03001oogoo02aoo`03001oogoo02Ioo`03001oogoo02ao
o`03001oogoo02Ioo`03001oogoo02ioo`006goo0P008Woo00<007oo000017oo00<007ooOol00Woo
00<007ooOol087oo00<007oo000010008Woo1P000Woo00<007ooOol00Woo00<007ooOol07goo00@0
07ooOomoo`<0029oo`03001oo`00008000=oo`03001oogoo009oo`03001oogoo025oo`006goo00<0
07ooOol08Goo0P0000=oo`00Ool01Woo00<007oo00008Goo00D007ooOomoo`0002Aoo`04001oogoo
0008Ool00`00Ool0000OOol00`00Oomoo`02Ool00`00Oomoo`0SOol20009Ool00`00Ool0000ROol0
01]oo`03001oogoo025oo`800003Ool007oo00Qoo`03001oogoo01moo`05001oogooOol0000TOol0
1000Oomoo`002Woo00<007ooOol07Goo00<007ooOol00goo00<007ooOol08Woo00<007oo00002Woo
00<007ooOol087oo000KOol00`00Oomoo`0QOol200000goo001oo`06Ool2000ROol01@00Oomoogoo
00009Goo00<007oo000027oo0P0087oo00<007ooOol00goo00<007ooOol08Woo00<007oo000027oo
0P008goo000KOol00`00Oomoo`0QOol200000goo001oo`06Ool00`00Oomoo`0QOol01@00Oomoogoo
00009Goo00<007oo000027oo00<007ooOol07goo00<007ooOol00Woo00<007oo00008goo0P0000=o
o`00Ool01Woo00<007ooOol08Woo000KOol00`00Oomoo`0QOol00`00Ool00008Ool3000POol01000
Oomoogoo0P009Goo0`0027oo0`007goo00<007ooOol00goo00<007ooOol08Woo00<007oo000027oo
0`008Woo000KOol2000ROol00`00Oomoo`0[Ool00`00Oomoo`0XOol00`00Oomoo`0ZOol00`00Oomo
o`0XOol00`00Oomoo`0]Ool001]oo`03001oogoo025oo`03001oogoo02]oo`03001oogoo02Qoo`03
001oogoo02Yoo`03001oogoo02Qoo`03001oogoo02eoo`006goo00<007ooOol08Goo00<007ooOol0
:goo00<007ooOol0:7oo00<007ooOol0:Woo00<007ooOol0:7oo00<007ooOol0;Goo000KOol00`00
Oomoo`0QOol00`00Oomoo`0[Ool00`00Oomoo`0XOol00`00Oomoo`0ZOol00`00Oomoo`0XOol00`00
Oomoo`0]Ool001]oo`03001oogoo029oo`03001oogoo02Yoo`03001oogoo02Qoo`03001oogoo02Yo
o`03001oogoo02Qoo`03001oogoo02eoo`006goo00<007ooOol08Woo00<007ooOol0:Woo00<007oo
Ool0:7oo00<007ooOol0:Woo00<007ooOol0:7oo00<007ooOol0;Goo000DOooo000=000001]oo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oo`0000Ioo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`04001oogoo0005Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Ool00006Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Ool00006Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool01000Oomoo`001Goo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00goo
000KOol00`00Oomoo`0ROol00`00Oomoo`0ZOol00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomo
o`0ZOol00`00Oomoo`0/Ool001]oo`03001oogoo029oo`03001oogoo02Yoo`03001oogoo02Uoo`03
001oogoo02Qoo`03001oogoo02Yoo`03001oogoo02aoo`006goo00<007ooOol08Woo00<007ooOol0
:Woo00<007ooOol0:Goo00<007ooOol0:7oo00<007ooOol0:Woo00<007ooOol0;7oo000KOol00`00
Oomoo`0ROol00`00Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomoo`0XOol00`00Oomoo`0ZOol00`00
Oomoo`0/Ool001]oo`8002=oo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo02Qoo`03001o
ogoo02Yoo`03001oogoo02aoo`006goo00<007ooOol08Woo00<007ooOol0:Goo00<007ooOol0:Woo
00<007ooOol0:7oo00<007ooOol0:Woo00<007ooOol0;7oo000KOol00`00Oomoo`0ROol00`00Oomo
o`0YOol00`00Oomoo`0ZOol00`00Oomoo`0XOol00`00Oomoo`0ZOol00`00Oomoo`0/Ool001]oo`03
001oogoo02=oo`03001oogoo02Qoo`03001oogoo02Yoo`03001oogoo02Qoo`03001oogoo02Yoo`03
001oogoo02aoo`006goo00<007ooOol08goo00<007ooOol0:7oo00<007ooOol0:Woo00<007ooOol0
:7oo00<007ooOol0:Woo00<007ooOol0;7oo000KOol00`00Oomoo`0SOol00`00Oomoo`0XOol00`00
Oomoo`0ZOol00`00Oomoo`0XOol00`00Oomoo`0ZOol00`00Oomoo`0/Ool001]oo`8002Aoo`03001o
ogoo02Qoo`03001oogoo02Yoo`03001oogoo02Moo`03001oogoo02aoo`03001oogoo02]oo`006goo
00<007ooOol08goo00<007ooOol0:7oo00<007ooOol0:Woo00<007ooOol09goo00<007ooOol0;7oo
00<007ooOol0:goo000KOol00`00Oomoo`0SOol00`00Oomoo`0XOol00`00Oomoo`0[Ool00`00Oomo
o`0VOol00`00Oomoo`0/Ool00`00Oomoo`0[Ool001]oo`03001oogoo02=oo`03001oogoo02Qoo`03
001oogoo02]oo`03001oogoo02Ioo`03001oogoo02aoo`03001oogoo02]oo`006goo00<007ooOol0
8goo00<007ooOol09goo00<007ooOol0;7oo00<007ooOol09Woo00<007ooOol0;7oo00<007ooOol0
:goo000KOol00`00Oomoo`0SOol00`00Oomoo`0WOol00`00Oomoo`0/Ool00`00Oomoo`0VOol00`00
Oomoo`0/Ool00`00Oomoo`0[Ool001]oo`8002Aoo`03001oogoo02Moo`03001oogoo02aoo`03001o
ogoo02Ioo`03001oogoo02aoo`03001oogoo02]oo`006goo00<007ooOol08goo00<007ooOol09goo
00<007ooOol0;7oo00<007ooOol09Woo00<007ooOol0;7oo00<007ooOol0:goo000KOol00`00Oomo
o`0TOol00`00Oomoo`0VOol00`00Oomoo`0/Ool00`00Oomoo`0VOol00`00Oomoo`0/Ool00`00Oomo
o`0[Ool001]oo`03001oogoo02Aoo`03001oogoo02Ioo`03001oogoo02aoo`03001oogoo02Ioo`03
001oogoo02aoo`03001oogoo02]oo`006goo00<007ooOol097oo00<007ooOol09Woo00<007ooOol0
;7oo00<007ooOol09Woo00<007ooOol0;7oo00<007ooOol0:goo000KOol00`00Oomoo`0TOol00`00
Oomoo`0VOol00`00Oomoo`0/Ool00`00Oomoo`0VOol00`00Oomoo`0]Ool00`00Oomoo`0ZOol001]o
o`8002Eoo`03001oogoo02Ioo`03001oogoo02aoo`03001oogoo02Eoo`03001oogoo02ioo`03001o
ogoo02Yoo`006goo00<007ooOol097oo00<007ooOol09Woo00<007ooOol0;Goo00<007ooOol097oo
00<007ooOol0;Woo00<007ooOol0:Woo000KOol00`00Oomoo`0TOol00`00Oomoo`0VOol00`00Oomo
o`0]Ool00`00Oomoo`0TOol00`00Oomoo`0^Ool00`00Oomoo`0ZOol001]oo`03001oogoo02Aoo`03
001oogoo02Ioo`03001oogoo02eoo`03001oogoo02Aoo`03001oogoo02ioo`03001oogoo02Yoo`00
2goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol097oo00<007ooOol0
9Goo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0;Woo00<007ooOol0:Woo000:Ool00`00
Ool00007Ool00`00Ool00004Ool00`00Oomoo`0TOol00`00Oomoo`0UOol00`00Oomoo`0^Ool00`00
Oomoo`0TOol00`00Oomoo`0^Ool00`00Oomoo`0ZOol000Yoo`03001oo`0000Uoo`03001oogoo009o
o`8002Eoo`03001oogoo02Eoo`03001oogoo02ioo`03001oogoo02Aoo`03001oogoo02ioo`03001o
ogoo02Yoo`002Woo00<007oo00001goo0P001Goo00<007ooOol097oo00<007ooOol09Goo00<007oo
Ool0;Woo00<007ooOol097oo00<007ooOol0;Woo00<007ooOol0:Woo000:Ool00`00Ool00007Ool0
0`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`0TOol00`00Oomoo`0^Ool00`00Oomoo`0TOol0
0`00Oomoo`0^Ool00`00Oomoo`0ZOol000]oo`03001oogoo00Ioo`<000Aoo`03001oogoo02Eoo`03
001oogoo02Aoo`03001oogoo02ioo`03001oogoo02Aoo`03001oogoo02ioo`03001oogoo02Yoo`00
6goo00<007ooOol09Goo00<007ooOol097oo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0
;Woo00<007ooOol0:Woo000KOol00`00Oomoo`0UOol00`00Oomoo`0TOol00`00Oomoo`0^Ool00`00
Oomoo`0SOol00`00Oomoo`0`Ool00`00Oomoo`0YOol001]oo`8002Ioo`03001oogoo02Aoo`03001o
ogoo02ioo`03001oogoo02=oo`03001oogoo031oo`03001oogoo02Uoo`006goo00<007ooOol09Goo
00<007ooOol097oo00<007ooOol0;goo00<007ooOol08Woo00<007ooOol0<7oo00<007ooOol0:Goo
000KOol00`00Oomoo`0UOol00`00Oomoo`0TOol00`00Oomoo`0_Ool00`00Oomoo`0ROol00`00Oomo
o`0`Ool00`00Oomoo`0YOol001]oo`03001oogoo02Eoo`03001oogoo02=oo`03001oogoo031oo`03
001oogoo029oo`03001oogoo031oo`03001oogoo02Uoo`006goo00<007ooOol09Goo00<007ooOol0
8goo00<007ooOol0<7oo00<007ooOol08Woo00<007ooOol0<7oo00<007ooOol0:Goo000KOol00`00
Oomoo`0UOol00`00Oomoo`0SOol00`00Oomoo`0`Ool00`00Oomoo`0ROol00`00Oomoo`0`Ool00`00
Oomoo`0YOol001]oo`8002Ioo`03001oogoo02=oo`03001oogoo031oo`03001oogoo029oo`03001o
ogoo031oo`03001oogoo02Uoo`006goo00<007ooOol09Woo00<007ooOol08Woo00<007ooOol0<7oo
00<007ooOol08Woo00<007ooOol0<7oo00<007ooOol0:Goo000KOol00`00Oomoo`0VOol00`00Oomo
o`0ROol00`00Oomoo`0`Ool00`00Oomoo`0ROol00`00Oomoo`0`Ool00`00Oomoo`0YOol001]oo`03
001oogoo02Ioo`03001oogoo029oo`03001oogoo031oo`03001oogoo029oo`03001oogoo031oo`03
001oogoo02Uoo`006goo00<007ooOol09Woo00<007ooOol08Woo00<007ooOol0<7oo00<007ooOol0
8Woo00<007ooOol0<Goo00<007ooOol0:7oo000KOol00`00Oomoo`0VOol00`00Oomoo`0ROol00`00
Oomoo`0`Ool00`00Oomoo`0QOol00`00Oomoo`0bOol00`00Oomoo`0XOol001]oo`8002Moo`03001o
ogoo029oo`03001oogoo035oo`03001oogoo021oo`03001oogoo039oo`03001oogoo02Qoo`006goo
00<007ooOol09Woo00<007ooOol08Woo00<007ooOol0<Goo00<007ooOol087oo00<007ooOol0<Woo
00<007ooOol0:7oo000KOol00`00Oomoo`0VOol00`00Oomoo`0ROol00`00Oomoo`0aOol00`00Oomo
o`0POol00`00Oomoo`0bOol00`00Oomoo`0XOol001]oo`03001oogoo02Ioo`03001oogoo025oo`03
001oogoo039oo`03001oogoo021oo`03001oogoo039oo`03001oogoo021oo`03001oogoo00Eoo`00
6goo00<007ooOol09Woo00<007ooOol08Goo00<007ooOol0<Woo00<007ooOol087oo00<007ooOol0
<Woo00<007ooOol07Woo0P0027oo000KOol00`00Oomoo`0VOol00`00Oomoo`0QOol00`00Oomoo`0b
Ool00`00Oomoo`0NOol2000eOol00`00Oomoo`0LOol2000:Ool001]oo`8002Qoo`03001oogoo021o
o`03001oogoo039oo`03001oogoo01eoo`03001oogoo03Eoo`03001oogoo01Yoo`8000aoo`006goo
00<007ooOol09goo00<007ooOol087oo00<007ooOol0<Woo00<007ooOol06goo0P00>7oo00<007oo
Ool067oo0P003Woo000KOol00`00Oomoo`0WOol00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomo
o`0IOol2000jOol00`00Oomoo`0FOol2000@Ool001]oo`03001oogoo02Moo`03001oogoo01ioo`80
03Eoo`03001oogoo01Qoo`03001oogoo03]oo`03001oogoo01Aoo`03001oogoo011oo`004goo1@00
0goo00<007ooOol09goo00<007ooOol07Goo00<007ooOol0=Goo00<007ooOol05Woo0P00?Woo00<0
07ooOol04Woo0P004goo000EOol00`00Oomoo`03Ool00`00Oomoo`0WOol00`00Oomoo`0KOol2000i
Ool00`00Oomoo`0DOol00`00Oomoo`0nOol00`00Oomoo`0AOol00`00Oomoo`0COol001Eoo`03001o
ogoo00=oo`8002Qoo`03001oogoo01Uoo`8003]oo`03001oogoo019oo`80045oo`03001oogoo011o
o`03001oogoo01Aoo`005Goo00<007ooOol00goo00<007ooOol09goo00<007ooOol067oo00<007oo
Ool0>goo00<007ooOol04Goo00<007ooOol0@Goo00<007ooOol03Woo0P005goo000EOol00`00Oomo
o`03Ool00`00Oomoo`0WOol00`00Oomoo`0FOol2000nOol00`00Oomoo`0@Ool00`00Oomoo`12Ool0
0`00Oomoo`0=Ool00`00Oomoo`0GOol001Aoo`8000Eoo`03001oogoo02Moo`03001oogoo01Eoo`03
001oogoo03ioo`03001oogoo00ioo`8004Eoo`03001oogoo00aoo`03001oogoo01Qoo`006goo00<0
07ooOol09goo00<007ooOol057oo00<007ooOol0?goo00<007ooOol03Goo00<007ooOol0AGoo00<0
07ooOol02Woo0P006goo000KOol00`00Oomoo`0WOol00`00Oomoo`0BOol20012Ool00`00Oomoo`0<
Ool00`00Oomoo`16Ool00`00Oomoo`09Ool00`00Oomoo`0KOol001]oo`8002Uoo`03001oogoo011o
o`03001oogoo049oo`03001oogoo00Yoo`8004Uoo`03001oogoo00Qoo`03001oogoo01aoo`006goo
00<007ooOol0:7oo00<007ooOol03goo00<007ooOol0@goo00<007ooOol02Goo00<007ooOol0BGoo
00<007ooOol01Woo0P007goo000KOol00`00Oomoo`0XOol00`00Oomoo`0>Ool00`00Oomoo`14Ool0
0`00Oomoo`08Ool00`00Oomoo`1:Ool00`00Oomoo`05Ool00`00Oomoo`0OOol001]oo`03001oogoo
02Qoo`03001oogoo00eoo`03001oogoo04Eoo`03001oogoo00Ioo`8004ioo`03001oogoo00=oo`03
001oogoo021oo`006goo00<007ooOol0:7oo00<007ooOol02goo0P00B7oo00<007ooOol01Goo00<0
07ooOol0CWoo00<007ooOol00Woo00<007ooOol08Goo000KOol00`00Oomoo`0XOol00`00Oomoo`0:
Ool00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`1?Ool01@00Oomoogoo000097oo000KOol2
000YOol00`00Oomoo`09Ool00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool01000Ool0
00009Goo000KOol00`00Oomoo`0XOol00`00Oomoo`08Ool00`00Oomoo`1;Ool01@00Oomoogoo0000
Dgoo0P009goo000KOol00`00Oomoo`0XOol00`00Oomoo`07Ool00`00Oomoo`1<Ool01000Ool00000
E7oo00<007ooOol09Woo000KOol00`00Oomoo`0XOol00`00Oomoo`06Ool00`00Oomoo`1=Ool2001o
Ool001]oo`03001oogoo02Qoo`03001oogoo00Eoo`03001oogoo04ioo`03001oogoo07ioo`006goo
00<007ooOol0:Goo00<007ooOol00Woo0P00dWoo000KOol2000ZOol01@00Oomoogoo0000e7oo000K
Ool00`00Oomoo`0YOol01000Oomoo`00eGoo000KOol00`00Oomoo`0YOol00`00Ool0003FOol001]o
o`03001oogoo02Uoo`800=Moo`006goo00<007ooOol0:Goo00<007ooOol0eWoo000KOol00`00Oomo
o`3oOol3Ool001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.31011, -1.40242, 
  0.0113484, 0.0166523}},
  CellTags->"4.2"]
}, Open  ]],

Cell["This is a pulse function. ", "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["UnitStep[t-.5]-UnitStep[t-1]", "Input",
  CellLabel->"In[27]:=",
  CellTags->"4.2"],

Cell[BoxData[
    RowBox[{\(-UnitStep[\(-1\) + t]\), "+", 
      RowBox[{"UnitStep", "[", 
        RowBox[{
          RowBox[{"-", 
            StyleBox["0.5`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}], "+", "t"}], "]"}]}]], "Output",
  CellLabel->"Out[27]=",
  CellTags->"4.2"]
}, Open  ]],

Cell[TextData[{
  StyleBox["SimulationPlot", "MR"],
  " also accepts input signals in symbolic form. This simulates the bridge \
behavior for yet another set of parameters. "
}], "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["\<\
SimulationPlot[
 bridge /. {r -> 1, c1 -> 10, c2 -> 10},
 %, {t, 3},
 Sampled -> Period[.05],
 PlotRange -> All
]\
\>", "Input",
  CellLabel->"In[28]:=",
  CellTags->"4.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0408214 0.562498 [
[.18254 .02832 -9 -9 ]
[.18254 .02832 9 0 ]
[.34127 .02832 -3 -9 ]
[.34127 .02832 3 0 ]
[.5 .02832 -9 -9 ]
[.5 .02832 9 0 ]
[.65873 .02832 -3 -9 ]
[.65873 .02832 3 0 ]
[.81746 .02832 -9 -9 ]
[.81746 .02832 9 0 ]
[.97619 .02832 -3 -9 ]
[.97619 .02832 3 0 ]
[.01131 .15332 -18 -4.5 ]
[.01131 .15332 0 4.5 ]
[.01131 .26582 -18 -4.5 ]
[.01131 .26582 0 4.5 ]
[.01131 .37832 -18 -4.5 ]
[.01131 .37832 0 4.5 ]
[.01131 .49082 -18 -4.5 ]
[.01131 .49082 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18254 .04082 m
.18254 .04707 L
s
[(0.5)] .18254 .02832 0 1 Mshowa
.34127 .04082 m
.34127 .04707 L
s
[(1)] .34127 .02832 0 1 Mshowa
.5 .04082 m
.5 .04707 L
s
[(1.5)] .5 .02832 0 1 Mshowa
.65873 .04082 m
.65873 .04707 L
s
[(2)] .65873 .02832 0 1 Mshowa
.81746 .04082 m
.81746 .04707 L
s
[(2.5)] .81746 .02832 0 1 Mshowa
.97619 .04082 m
.97619 .04707 L
s
[(3)] .97619 .02832 0 1 Mshowa
.125 Mabswid
.05556 .04082 m
.05556 .04457 L
s
.0873 .04082 m
.0873 .04457 L
s
.11905 .04082 m
.11905 .04457 L
s
.15079 .04082 m
.15079 .04457 L
s
.21429 .04082 m
.21429 .04457 L
s
.24603 .04082 m
.24603 .04457 L
s
.27778 .04082 m
.27778 .04457 L
s
.30952 .04082 m
.30952 .04457 L
s
.37302 .04082 m
.37302 .04457 L
s
.40476 .04082 m
.40476 .04457 L
s
.43651 .04082 m
.43651 .04457 L
s
.46825 .04082 m
.46825 .04457 L
s
.53175 .04082 m
.53175 .04457 L
s
.56349 .04082 m
.56349 .04457 L
s
.59524 .04082 m
.59524 .04457 L
s
.62698 .04082 m
.62698 .04457 L
s
.69048 .04082 m
.69048 .04457 L
s
.72222 .04082 m
.72222 .04457 L
s
.75397 .04082 m
.75397 .04457 L
s
.78571 .04082 m
.78571 .04457 L
s
.84921 .04082 m
.84921 .04457 L
s
.88095 .04082 m
.88095 .04457 L
s
.9127 .04082 m
.9127 .04457 L
s
.94444 .04082 m
.94444 .04457 L
s
.25 Mabswid
0 .04082 m
1 .04082 L
s
.02381 .15332 m
.03006 .15332 L
s
[(0.2)] .01131 .15332 1 0 Mshowa
.02381 .26582 m
.03006 .26582 L
s
[(0.4)] .01131 .26582 1 0 Mshowa
.02381 .37832 m
.03006 .37832 L
s
[(0.6)] .01131 .37832 1 0 Mshowa
.02381 .49082 m
.03006 .49082 L
s
[(0.8)] .01131 .49082 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .06895 m
.02756 .06895 L
s
.02381 .09707 m
.02756 .09707 L
s
.02381 .1252 m
.02756 .1252 L
s
.02381 .18145 m
.02756 .18145 L
s
.02381 .20957 m
.02756 .20957 L
s
.02381 .2377 m
.02756 .2377 L
s
.02381 .29395 m
.02756 .29395 L
s
.02381 .32207 m
.02756 .32207 L
s
.02381 .3502 m
.02756 .3502 L
s
.02381 .40644 m
.02756 .40644 L
s
.02381 .43457 m
.02756 .43457 L
s
.02381 .46269 m
.02756 .46269 L
s
.02381 .51894 m
.02756 .51894 L
s
.02381 .54707 m
.02756 .54707 L
s
.02381 .57519 m
.02756 .57519 L
s
.02381 .0127 m
.02756 .0127 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .04082 m
.03968 .04082 L
.05556 .04082 L
.07143 .04082 L
.0873 .04082 L
.10317 .04082 L
.11905 .04082 L
.13492 .04082 L
.15079 .04082 L
.16667 .04082 L
.18254 .60332 L
.19841 .60053 L
.21429 .59778 L
.23016 .59507 L
.24603 .5924 L
.2619 .58977 L
.27778 .58718 L
.29365 .58463 L
.30952 .58212 L
.3254 .57965 L
.34127 .01472 L
.35714 .01511 L
.37302 .01549 L
.38889 .01588 L
.40476 .01625 L
.42063 .01663 L
.43651 .01699 L
.45238 .01735 L
.46825 .01771 L
.48413 .01806 L
.5 .01841 L
.51587 .01876 L
.53175 .01909 L
.54762 .01943 L
.56349 .01976 L
.57937 .02008 L
.59524 .0204 L
.61111 .02072 L
.62698 .02103 L
.64286 .02134 L
.65873 .02165 L
.6746 .02195 L
.69048 .02224 L
.70635 .02253 L
.72222 .02282 L
.7381 .02311 L
.75397 .02339 L
.76984 .02367 L
.78571 .02394 L
.80159 .02421 L
Mistroke
.81746 .02447 L
.83333 .02474 L
.84921 .025 L
.86508 .02525 L
.88095 .0255 L
.89683 .02575 L
.9127 .026 L
.92857 .02624 L
.94444 .02648 L
.96032 .02671 L
.97619 .02695 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000EOol00`00Oomoo`0SOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0QOol5000QOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0ROol3000SOol30003Ool0
0`00Oomoo`02Ool00`00Oomoo`0SOol20007Ool001Eoo`03001oogoo029oo`03001oo`0000Moo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo00Ioo`03001oo`0002=oo`03001oogoo02=oo`03
001oogoo00Moo`03001oo`0002Ioo`03001oogoo00Aoo`005Goo00<007ooOol08Woo00<007oo0000
2Goo00<007ooOol08Woo00<007ooOol08goo00<007ooOol027oo00<007ooOol08Woo00<007ooOol0
8goo00<007ooOol027oo00<007ooOol08goo00<007ooOol01Goo000EOol00`00Oomoo`0ROol00`00
Ool00007Ool2000UOol00`00Oomoo`0SOol00`00Oomoo`06Ool2000UOol00`00Oomoo`0SOol00`00
Oomoo`06Ool2000WOol00`00Oomoo`04Ool001Eoo`8002=oo`03001oo`0000Moo`03001oogoo02Ao
o`L001moo`03001oogoo00Ioo`03001oogoo02=oo`03001oo`0002=oo`03001oo`0000Moo`03001o
ogoo02Aoo`03001oo`0000Ioo`005Goo00<007ooOol08goo00<007ooOol01Woo0`008goo0P001Woo
:`0097oo00<007ooOol08goo00<007ooOol01Woo0`009Goo00<007ooOol01Goo000EOol00`00Oomo
o`1COol00`00Oomoo`0_Oold001?Ool001Eoo`03001oogoo05=oo`03001oogoo06=ooc`001=oo`00
5Goo00<007ooOol0Dgoo00<007ooOol0Wgoo30001goo000EOol00`00Oomoo`1COol00`00Oomoo`2b
Ool001Eoo`03001oogoo05=oo`03001oogoo0;9oo`003Wooo`004`00000EOol00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo0000
27oo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
1Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
1Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
1Goo000EOol00`00Oomoo`0TOol01@00Oomoogoo0000:Woo00<007ooOol0:7oo00<007ooOol0:Goo
00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol01Goo000EOol00`00Oomoo`0TOol00`00Oomo
o`0/Ool00`00Oomoo`2bOol001Eoo`03001oogoo02Aoo`03001oogoo02aoo`03001oogoo0;9oo`00
5Goo00<007ooOol097oo00<007ooOol0;7oo00<007ooOol0/Woo000EOol00`00Oomoo`0TOol00`00
Oomoo`0/Ool00`00Oomoo`2bOol001Eoo`03001oogoo02Aoo`03001oogoo02aoo`03001oogoo0;9o
o`005Goo0P009Goo00<007ooOol0;7oo00<007ooOol0/Woo000EOol00`00Oomoo`0TOol00`00Oomo
o`0/Ool00`00Oomoo`2bOol001Eoo`03001oogoo02Aoo`03001oogoo02aoo`03001oogoo0;9oo`00
5Goo00<007ooOol097oo00<007ooOol0;7oo00<007ooOol0/Woo000EOol00`00Oomoo`0TOol00`00
Oomoo`0/Ool00`00Oomoo`2bOol001Eoo`03001oogoo02Aoo`03001oogoo02]oo`03001oogoo0;=o
o`005Goo00<007ooOol097oo00<007ooOol0:goo00<007ooOol0/goo000EOol00`00Oomoo`0TOol0
0`00Oomoo`0[Ool00`00Oomoo`2cOol001Eoo`8002Eoo`03001oogoo02]oo`03001oogoo0;=oo`00
5Goo00<007ooOol097oo00<007ooOol0:goo00<007ooOol0/goo000EOol00`00Oomoo`0TOol00`00
Oomoo`0[Ool00`00Oomoo`2cOol001Eoo`03001oogoo02Aoo`03001oogoo02]oo`03001oogoo0;=o
o`005Goo00<007ooOol09Goo00<007ooOol0:Woo00<007ooOol0/goo000EOol00`00Oomoo`0UOol0
0`00Oomoo`0ZOol00`00Oomoo`2cOol001Eoo`03001oogoo02Eoo`03001oogoo02Yoo`03001oogoo
0;=oo`005Goo0P009Woo00<007ooOol0:Woo00<007ooOol0/goo000EOol00`00Oomoo`0UOol00`00
Oomoo`0ZOol00`00Oomoo`2cOol001Eoo`03001oogoo02Eoo`03001oogoo02Yoo`03001oogoo0;=o
o`005Goo00<007ooOol09Goo00<007ooOol0:Woo00<007ooOol0/goo000EOol00`00Oomoo`0UOol0
0`00Oomoo`0ZOol00`00Oomoo`2cOol001Eoo`03001oogoo02Eoo`03001oogoo02Yoo`03001oogoo
0;=oo`001Goo00<007ooOol00Woo00@007ooOomoo`<000Aoo`03001oogoo02Eoo`03001oogoo02Yo
o`03001oogoo0;=oo`0017oo00<007oo00001goo00<007ooOol017oo00<007ooOol09Goo00<007oo
Ool0:Woo00<007ooOol0/goo0004Ool00`00Ool00008Ool00`00Oomoo`03Ool3000UOol00`00Oomo
o`0ZOol00`00Oomoo`2cOol000Aoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo02Eoo`03
001oogoo02Yoo`03001oogoo0;=oo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol0
9Goo00<007ooOol0:Woo00<007ooOol0/goo0005Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00
Oomoo`0UOol00`00Oomoo`0ZOol00`00Oomoo`2cOol001Eoo`03001oogoo02Eoo`03001oogoo02Yo
o`03001oogoo0;=oo`005Goo00<007ooOol09Goo00<007ooOol0:Woo00<007ooOol0/goo000EOol0
0`00Oomoo`0UOol00`00Oomoo`0ZOol00`00Oomoo`2cOol001Eoo`03001oogoo02Eoo`03001oogoo
02Yoo`03001oogoo0;=oo`005Goo0P009Woo00<007ooOol0:Woo00<007ooOol0/goo000EOol00`00
Oomoo`0UOol00`00Oomoo`0ZOol00`00Oomoo`2cOol001Eoo`03001oogoo02Eoo`03001oogoo02Yo
o`03001oogoo0;=oo`005Goo00<007ooOol09Goo00<007ooOol0:Woo00<007ooOol0/goo000EOol0
0`00Oomoo`0UOol00`00Oomoo`0ZOol00`00Oomoo`2cOol001Eoo`03001oogoo02Eoo`03001oogoo
02Yoo`03001oogoo0;=oo`005Goo00<007ooOol09Goo00<007ooOol0:Woo00<007ooOol0/goo000E
Ool2000VOol00`00Oomoo`0ZOol00`00Oomoo`2cOol001Eoo`03001oogoo02Eoo`03001oogoo02Yo
o`03001oogoo0;=oo`005Goo00<007ooOol09Goo00<007ooOol0:Woo00<007ooOol0/goo000EOol0
0`00Oomoo`0UOol00`00Oomoo`0ZOol00`00Oomoo`2cOol001Eoo`03001oogoo02Eoo`03001oogoo
02Yoo`03001oogoo0;=oo`005Goo00<007ooOol09Goo00<007ooOol0:Goo00<007ooOol0]7oo000E
Ool00`00Oomoo`0UOol00`00Oomoo`0YOol00`00Oomoo`2dOol001Eoo`03001oogoo02Eoo`03001o
ogoo02Uoo`03001oogoo0;Aoo`005Goo0P009Woo00<007ooOol0:Goo00<007ooOol0]7oo000EOol0
0`00Oomoo`0UOol00`00Oomoo`0YOol00`00Oomoo`2dOol001Eoo`03001oogoo02Eoo`03001oogoo
02Uoo`03001oogoo0;Aoo`005Goo00<007ooOol09Goo00<007ooOol0:Goo00<007ooOol0]7oo000E
Ool00`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`2dOol001Eoo`03001oogoo02Ioo`03001o
ogoo02Qoo`03001oogoo0;Aoo`001Goo00<007ooOol00Woo00<007ooOol00Woo0`000goo00<007oo
Ool09Woo00<007ooOol0:7oo00<007ooOol0]7oo0004Ool00`00Ool00009Ool00`00Oomoo`02Ool0
0`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`2dOol000Aoo`03001oo`0000Moo`@000=oo`<0
02Ioo`03001oogoo02Qoo`03001oogoo0;Aoo`0017oo00<007oo00001goo00<007oo000017oo00<0
07ooOol09Woo00<007ooOol0:7oo00<007ooOol0]7oo0004Ool00`00Ool00008Ool20004Ool00`00
Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`2dOol000Eoo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo02Ioo`03001oogoo02Qoo`03001oogoo0;Aoo`005Goo00<007ooOol09Woo00<007oo
Ool0:7oo00<007ooOol0]7oo000EOol00`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`2dOol0
01Eoo`03001oogoo02Ioo`03001oogoo02Qoo`03001oogoo0;Aoo`005Goo0P009goo00<007ooOol0
:7oo00<007ooOol0]7oo000EOol00`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`2dOol001Eo
o`03001oogoo02Ioo`03001oogoo02Qoo`03001oogoo0;Aoo`005Goo00<007ooOol09Woo00<007oo
Ool0:7oo00<007ooOol0]7oo000EOol00`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`2dOol0
01Eoo`03001oogoo02Ioo`03001oogoo02Qoo`03001oogoo0;Aoo`005Goo00<007ooOol09Woo00<0
07ooOol0:7oo00<007ooOol0]7oo000EOol00`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`2d
Ool001Eoo`8002Moo`03001oogoo02Qoo`03001oogoo0;Aoo`005Goo00<007ooOol09Woo00<007oo
Ool0:7oo00<007ooOol0]7oo000EOol00`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`2dOol0
01Eoo`03001oogoo02Ioo`03001oogoo02Qoo`03001oogoo0;Aoo`005Goo00<007ooOol09Woo00<0
07ooOol0:7oo00<007ooOol0]7oo000EOol00`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`2d
Ool001Eoo`03001oogoo02Ioo`03001oogoo02Qoo`03001oogoo0;Aoo`005Goo00<007ooOol09Woo
00<007ooOol0:7oo00<007ooOol0]7oo000EOol2000WOol00`00Oomoo`0XOol00`00Oomoo`2dOol0
01Eoo`03001oogoo02Ioo`03001oogoo02Qoo`03001oogoo0;Aoo`005Goo00<007ooOol09Woo00<0
07ooOol0:7oo00<007ooOol0]7oo000EOol00`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomoo`2d
Ool001Eoo`03001oogoo02Ioo`03001oogoo02Qoo`03001oogoo0;Aoo`001Goo00<007ooOol00Woo
00@007ooOomoo`8000Eoo`03001oogoo02Ioo`03001oogoo02Moo`03001oogoo0;Eoo`0017oo00<0
07oo00001goo00<007oo000017oo00<007ooOol09Woo00<007ooOol09goo00<007ooOol0]Goo0004
Ool00`00Ool00007Ool00`00Ool00004Ool3000VOol00`00Oomoo`0WOol00`00Oomoo`2eOol000Ao
o`03001oo`0000Moo`8000Eoo`03001oogoo02Ioo`03001oogoo02Moo`03001oogoo0;Eoo`0017oo
00<007oo00001goo00<007ooOol017oo00<007ooOol09Woo00<007ooOol09goo00<007ooOol0]Goo
0005Ool00`00Oomoo`07Ool20004Ool00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`2eOol0
01Eoo`03001oogoo02Ioo`03001oogoo02Moo`03001oogoo0;Eoo`005Goo00<007ooOol09goo00<0
07ooOol09Woo00<007ooOol0]Goo000EOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`2e
Ool001Eoo`03001oogoo02Moo`03001oogoo02Ioo`03001oogoo0;Eoo`005Goo0P00:7oo00<007oo
Ool09Woo00<007ooOol0]Goo000EOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`2eOol0
01Eoo`03001oogoo02Moo`03001oogoo02Ioo`03001oogoo0;Eoo`005Goo00<007ooOol09goo00<0
07ooOol09Woo00<007ooOol0]Goo000EOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`2e
Ool001Eoo`03001oogoo02Moo`03001oogoo02Ioo`03001oogoo0;Eoo`005Goo00<007ooOol09goo
00<007ooOol09Woo00<007ooOol0]Goo000EOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomo
o`2eOol001Eoo`8002Qoo`03001oogoo02Ioo`03001oogoo0;Eoo`005Goo00<007ooOol09goo00<0
07ooOol09Woo00<007ooOol0]Goo000EOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`2e
Ool001Eoo`03001oogoo02Moo`03001oogoo02Ioo`03001oogoo0;Eoo`005Goo00<007ooOol09goo
00<007ooOol09Woo00<007ooOol0]Goo000EOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomo
o`2eOol001Eoo`03001oogoo02Moo`03001oogoo02Ioo`03001oogoo0;Eoo`005Goo0P00:7oo00<0
07ooOol09Woo00<007ooOol0]Goo000EOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`2e
Ool001Eoo`03001oogoo02Moo`03001oogoo02Ioo`03001oogoo0;Eoo`005Goo00<007ooOol09goo
00<007ooOol09Woo00<007ooOol0]Goo000EOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomo
o`2eOol001Eoo`03001oogoo02Moo`03001oogoo02Ioo`03001oogoo0;Eoo`001Goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol09goo00<007ooOol09Woo00<007ooOol0
]Goo0004Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0WOol00`00Oomoo`0VOol00`00
Oomoo`2eOol000Aoo`03001oo`0000Moo`03001oo`0000Aoo`<002Moo`03001oogoo02Ioo`03001o
ogoo0;Eoo`0017oo00<007oo000027oo00<007ooOol00goo00<007ooOol09goo00<007ooOol09Woo
00<007ooOol0]Goo0004Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0WOol00`00Oomo
o`0VOol00`00Oomoo`2eOol000Eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo02Moo`03
001oogoo02Ioo`03001oogoo0;Eoo`005Goo00<007ooOol09goo00<007ooOol09Woo00<007ooOol0
]Goo000EOol00`00Oomoo`0WOol00`00Oomoo`0UOol00`00Oomoo`2fOol001Eoo`03001oogoo02Mo
o`03001oogoo02Eoo`03001oogoo0;Ioo`005Goo00<007ooOol09goo00<007ooOol09Goo00<007oo
Ool0]Woo000EOol2000XOol00`00Oomoo`0UOol00`00Oomoo`2fOol001Eoo`03001oogoo02Moo`03
001oogoo02Eoo`03001oogoo0;Ioo`005Goo00<007ooOol09goo00<007ooOol09Goo00<007ooOol0
]Woo000EOol00`00Oomoo`0WOol00`00Oomoo`0UOol00`00Oomoo`2fOol001Eoo`03001oogoo02Qo
o`03001oogoo02Aoo`03001oogoo0;Ioo`005Goo00<007ooOol0:7oo00<007ooOol097oo00<007oo
Ool0]Woo000EOol00`00Oomoo`0XOol00`00Oomoo`0TOol00`00Oomoo`2fOol001Eoo`8002Uoo`03
001oogoo02Aoo`03001oogoo0;Ioo`005Goo00<007ooOol0:7oo00<007ooOol097oo00<007ooOol0
]Woo000EOol00`00Oomoo`0XOol00`00Oomoo`0TOol00`00Oomoo`2fOol001Eoo`03001oogoo02Qo
o`03001oogoo02Aoo`03001oogoo0;Ioo`005Goo00<007ooOol0:7oo00<007ooOol097oo00<007oo
Ool0]Woo000EOol00`00Oomoo`0XOol00`00Oomoo`0TOol00`00Oomoo`2fOol001Eoo`03001oogoo
02Qoo`03001oogoo02Aoo`03001oogoo0;Ioo`005Goo00<007ooOol0:7oo00<007ooOol097oo00<0
07ooOol0]Woo000EOol2000YOol00`00Oomoo`0TOol00`00Oomoo`2fOol001Eoo`03001oogoo02Qo
o`03001oogoo02=oo`800;Qoo`005Goo00<007ooOol0:7oo00<007ooOol06Woo2@00^Woo000EOol0
0`00Oomoo`0XOol00`00Oomoo`0FOol40033Ool001Eoo`03001oogoo02Qoo`03001oogoo015oo`D0
0<Moo`005Goo00<007ooOol0:7oo00<007ooOol02Goo2000c7oo000=Ool50003Ool00`00Oomoo`0X
Ool00`00Oomoo`04Ool5003DOol000moo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo00@0
0=Uoo`003goo00<007ooOol00goo0`00:7oo0`00gGoo000?Ool00`00Oomoo`03Ool00`00Oomoo`3o
Ool9Ool000moo`03001oogoo00=oo`03001oogoo0?moo`Uoo`003Woo0P001Goo00<007ooOol0ogoo
2Goo000EOol00`00Oomoo`3oOol9Ool00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.247788, -0.103885, 
  0.0115777, 0.00653418}},
  CellTags->"4.2"]
}, Open  ]],

Cell["\<\
This converts a particular bridge circuit to the \
discrete\[Hyphen]time domain. \
\>", "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["\<\
ToDiscreteTime[bridge /. {r -> 1, c1 -> 10, c2 -> 1},
 Sampled -> Period[.2]]\
\>", "Input",
  CellLabel->"In[29]:=",
  CellTags->"4.2"],

Cell[BoxData[
    RowBox[{"TransferFunction", "[", 
      RowBox[{
      "s", ",", 
        \({{\(\(0.964319574083166308`\[InvisibleSpace]\) - 
                1.96076455587412858`\ s + s\^2\)\/\(\(0.786627861066553268`
                \[InvisibleSpace]\) - 1.78307284285751554`\ s + s\^2\)}}\), 
        ",", 
        RowBox[{"Sampled", "\[Rule]", 
          RowBox[{"Period", "[", 
            StyleBox["0.2`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], "]"}]}]}], "]"}]], "Output",
  CellLabel->"Out[29]=",
  CellTags->"4.2"]
}, Open  ]],

Cell[TextData[{
  "Here is the response of this circuit to random noise. Note that ",
  StyleBox["SimulationPlot", "MR"],
  " picks up the sampling period from the input system so we do not need to \
specify it again. "
}], "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["SimulationPlot[%, Table[Random[] - .5, {100}]]", "Input",
  CellLabel->"In[30]:=",
  CellTags->"4.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0481 0.317974 0.51778 [
[.26431 .30547 -3 -9 ]
[.26431 .30547 3 0 ]
[.50481 .30547 -6 -9 ]
[.50481 .30547 6 0 ]
[.74531 .30547 -6 -9 ]
[.74531 .30547 6 0 ]
[.98581 .30547 -6 -9 ]
[.98581 .30547 6 0 ]
[.01131 .00731 -24 -4.5 ]
[.01131 .00731 0 4.5 ]
[.01131 .11086 -24 -4.5 ]
[.01131 .11086 0 4.5 ]
[.01131 .21442 -24 -4.5 ]
[.01131 .21442 0 4.5 ]
[.01131 .42153 -18 -4.5 ]
[.01131 .42153 0 4.5 ]
[.01131 .52509 -18 -4.5 ]
[.01131 .52509 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.26431 .31797 m
.26431 .32422 L
s
[(5)] .26431 .30547 0 1 Mshowa
.50481 .31797 m
.50481 .32422 L
s
[(10)] .50481 .30547 0 1 Mshowa
.74531 .31797 m
.74531 .32422 L
s
[(15)] .74531 .30547 0 1 Mshowa
.98581 .31797 m
.98581 .32422 L
s
[(20)] .98581 .30547 0 1 Mshowa
.125 Mabswid
.07191 .31797 m
.07191 .32172 L
s
.12001 .31797 m
.12001 .32172 L
s
.16811 .31797 m
.16811 .32172 L
s
.21621 .31797 m
.21621 .32172 L
s
.31241 .31797 m
.31241 .32172 L
s
.36051 .31797 m
.36051 .32172 L
s
.40861 .31797 m
.40861 .32172 L
s
.45671 .31797 m
.45671 .32172 L
s
.55291 .31797 m
.55291 .32172 L
s
.60101 .31797 m
.60101 .32172 L
s
.64911 .31797 m
.64911 .32172 L
s
.69721 .31797 m
.69721 .32172 L
s
.79341 .31797 m
.79341 .32172 L
s
.84151 .31797 m
.84151 .32172 L
s
.88961 .31797 m
.88961 .32172 L
s
.93771 .31797 m
.93771 .32172 L
s
.25 Mabswid
0 .31797 m
1 .31797 L
s
.02381 .00731 m
.03006 .00731 L
s
[(-0.6)] .01131 .00731 1 0 Mshowa
.02381 .11086 m
.03006 .11086 L
s
[(-0.4)] .01131 .11086 1 0 Mshowa
.02381 .21442 m
.03006 .21442 L
s
[(-0.2)] .01131 .21442 1 0 Mshowa
.02381 .42153 m
.03006 .42153 L
s
[(0.2)] .01131 .42153 1 0 Mshowa
.02381 .52509 m
.03006 .52509 L
s
[(0.4)] .01131 .52509 1 0 Mshowa
.125 Mabswid
.02381 .0332 m
.02756 .0332 L
s
.02381 .05908 m
.02756 .05908 L
s
.02381 .08497 m
.02756 .08497 L
s
.02381 .13675 m
.02756 .13675 L
s
.02381 .16264 m
.02756 .16264 L
s
.02381 .18853 m
.02756 .18853 L
s
.02381 .24031 m
.02756 .24031 L
s
.02381 .2662 m
.02756 .2662 L
s
.02381 .29209 m
.02756 .29209 L
s
.02381 .34386 m
.02756 .34386 L
s
.02381 .36975 m
.02756 .36975 L
s
.02381 .39564 m
.02756 .39564 L
s
.02381 .44742 m
.02756 .44742 L
s
.02381 .47331 m
.02756 .47331 L
s
.02381 .4992 m
.02756 .4992 L
s
.02381 .55098 m
.02756 .55098 L
s
.02381 .57686 m
.02756 .57686 L
s
.02381 .60275 m
.02756 .60275 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .33874 m
.03343 .33347 L
.04305 .53062 L
.05267 .11623 L
.06229 .44966 L
.07191 .37432 L
.08153 .44099 L
.09115 .23506 L
.10077 .27975 L
.11039 .08453 L
.12001 .58298 L
.12963 .34648 L
.13925 .48251 L
.14887 .21677 L
.15849 .34976 L
.16811 .08794 L
.17773 .06876 L
.18735 .33823 L
.19697 .44132 L
.20659 .42357 L
.21621 .40294 L
.22583 .20888 L
.23545 .43868 L
.24507 .05156 L
.25469 .15928 L
.26431 .52651 L
.27393 .49699 L
.28355 .47531 L
.29317 .21121 L
.30279 .10608 L
.31241 .59651 L
.32203 .22525 L
.33165 .49684 L
.34127 .02643 L
.35089 .59478 L
.36051 .41408 L
.37013 .51365 L
.37975 .28095 L
.38937 .17685 L
.39899 .33338 L
.40861 .51163 L
.41823 .05625 L
.42785 .40344 L
.43747 .51418 L
.44709 .14521 L
.45671 .45436 L
.46633 .52109 L
.47595 .46139 L
.48557 .04562 L
.49519 .03547 L
Mistroke
.50481 .16925 L
.51443 .16044 L
.52405 .54913 L
.53367 .56936 L
.54329 .1537 L
.55291 .46971 L
.56253 .55043 L
.57215 .49495 L
.58177 .09882 L
.59139 .04102 L
.60101 .60332 L
.61063 .22063 L
.62025 .50544 L
.62987 .24554 L
.63949 .0761 L
.64911 .21297 L
.65873 .20111 L
.66835 .38785 L
.67797 .52625 L
.68759 .30581 L
.69721 .18945 L
.70683 .40641 L
.71645 .41995 L
.72607 .28413 L
.73569 .09272 L
.74531 .36465 L
.75493 .54337 L
.76455 .32337 L
.77417 .49721 L
.78379 .41352 L
.79341 .48059 L
.80303 .29204 L
.81265 .32574 L
.82227 .37779 L
.83189 .46182 L
.84151 .09452 L
.85113 .41898 L
.86075 .16652 L
.87037 .47541 L
.87999 .5325 L
.88961 .29298 L
.89923 .41783 L
.90885 .01472 L
.91847 .34031 L
.92809 .25477 L
.93771 .19192 L
.94733 .31563 L
.95695 .18452 L
.96657 .32335 L
.97619 .53192 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000]oo`03001o
ogoo009oo`04001oogooOol20005Ool00`00Oomoo`3oOol3Ool000Yoo`03001oo`0000Moo`03001o
o`0000Aoo`03001oogoo0?moo`=oo`001Goo0`000Woo00<007oo00001goo00<007oo000017oo0P00
ogoo17oo000:Ool00`00Ool00007Ool20005Ool00`00Oomoo`3oOol3Ool000Yoo`03001oo`0000Mo
o`03001oogoo00Aoo`03001oogoo0>Ioo`03001oogoo01Uoo`002goo00<007ooOol01goo0P0017oo
00<007ooOol0iWoo00<007ooOol06Goo000KOol00`00Oomoo`3VOol00`00Oomoo`0IOol001]oo`03
001oogoo055oo`03001oogoo099oo`03001oogoo01Uoo`006goo00<007ooOol0DGoo00<007ooOol0
TWoo00<007ooOol06Goo000KOol2001BOol00`00Oomoo`0UOol00`00Oomoo`1ZOol00`00Oomoo`0I
Ool001]oo`03001oogoo055oo`03001oogoo02Aoo`8006aoo`03001oogoo01Uoo`006goo00<007oo
Ool0DGoo00<007ooOol097oo0P0067oo00<007ooOol0DGoo00<007ooOol06Goo000KOol00`00Oomo
o`1AOol00`00Oomoo`0SOol00`00Ool0000HOol00`00Oomoo`1AOol00`00Oomoo`0IOol001]oo`03
001oogoo03Moo`03001oogoo01Moo`03001oogoo02=oo`03001oo`0001Qoo`03001oogoo055oo`03
001oogoo01Uoo`006goo00<007ooOol0=goo00<007ooOol05goo00<007ooOol08goo00<007oo0000
67oo00<007ooOol0DGoo00<007ooOol06Goo000KOol2000hOol00`00Oomoo`0GOol00`00Oomoo`0A
Ool00`00Oomoo`0?Ool01000Oomoo`005Woo0P00Dgoo00<007ooOol06Goo000KOol00`00Oomoo`0g
Ool00`00Oomoo`0GOol00`00Oomoo`0AOol00`00Oomoo`0?Ool01000Oomoo`005Woo0P00Dgoo00<0
07ooOol06Goo000KOol00`00Oomoo`0gOol00`00Oomoo`0GOol00`00Oomoo`0AOol00`00Oomoo`0?
Ool01000Oomoo`005Woo0P00Dgoo00<007ooOol06Goo000KOol00`00Oomoo`0UOol00`00Oomoo`0?
Ool2000HOol00`00Oomoo`0AOol00`00Oomoo`0?Ool01000Oomoo`005Woo0P00Dgoo00<007ooOol0
6Goo000KOol00`00Oomoo`0UOol00`00Oomoo`0?Ool2000HOol00`00Oomoo`0AOol00`00Oomoo`0?
Ool01000Oomoo`005Woo0P00Dgoo0P006Woo000KOol00`00Oomoo`0TOol2000AOol2000HOol00`00
Oomoo`0AOol00`00Oomoo`0?Ool01000Oomoo`005Woo0P0037oo00<007ooOol0A7oo0P006Woo000K
Ool00`00Oomoo`0TOol2000AOol2000HOol00`00Oomoo`0AOol00`00Oomoo`0?Ool01000Oomoo`00
5Woo0P0037oo00<007ooOol0A7oo0P006Woo000KOol2000EOol00`00Oomoo`0<Ool00`00Ool0000A
Ool2000HOol00`00Oomoo`0AOol00`00Oomoo`0?Ool01000Oomoo`005Woo0P0037oo00<007ooOol0
A7oo0P006Woo000KOol00`00Oomoo`0DOol00`00Oomoo`0<Ool00`00Ool0000AOol2000HOol00`00
Oomoo`0AOol00`00Oomoo`0?Ool01000Oomoo`005Goo00<007oo000037oo00<007ooOol0A7oo0P00
6Woo000KOol00`00Oomoo`0DOol00`00Oomoo`0<Ool00`00Ool0000AOol2000HOol00`00Oomoo`0A
Ool00`00Oomoo`0?Ool01000Oomoo`005Goo00<007oo000037oo00<007ooOol05goo00<007ooOol0
:Woo0P006Woo000KOol00`00Oomoo`0DOol00`00Oomoo`0<Ool00`00Ool0000AOol2000HOol00`00
Oomoo`0AOol00`00Oomoo`0?Ool01000Oomoo`005Goo00<007oo000037oo00<007ooOol05goo00<0
07ooOol067oo00<007ooOol03goo0P006Woo000KOol00`00Oomoo`0DOol00`00Oomoo`0<Ool00`00
Ool0000AOol2000HOol00`00Oomoo`0AOol00`00Oomoo`0?Ool01000Oomoo`005Goo00<007oo0000
37oo0P0067oo00<007ooOol067oo00<007ooOol03goo0P006Woo000;Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool30003Ool00`00Oomoo`0DOol00`00Oomoo`0<Ool00`00Ool0000AOol2000HOol00`00
Oomoo`0AOol00`00Oomoo`0?Ool01@00Oomoogoo000057oo00<007oo000037oo0P0067oo00<007oo
Ool067oo00<007ooOol03goo0P006Woo000:Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomo
o`0DOol00`00Oomoo`0<Ool00`00Ool0000AOol00`00Ool0000<Ool00`00Oomoo`07Ool2000COol0
0`00Oomoo`0?Ool01@00Oomoogoo000057oo00<007oo000037oo0P0067oo00<007ooOol067oo00<0
07ooOol03goo0P006Woo0005Ool30002Ool00`00Ool00007Ool40003Ool2000EOol00`00Oomoo`0<
Ool00`00Ool0000AOol00`00Ool0000<Ool00`00Oomoo`07Ool2000COol00`00Oomoo`0?Ool01@00
Oomoogoo000057oo00<007oo000037oo0P0067oo00<007ooOol067oo00<007ooOol03goo0P006Woo
000:Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomo
o`0<Ool01000Oomoo`0047oo00<007oo000037oo00<007ooOol01goo0P004goo00<007ooOol03goo
00D007ooOomoo`0001Aoo`03001oo`0000aoo`8001Qoo`03001oogoo01Qoo`03001oogoo00moo`80
01Yoo`002Woo00<007oo000027oo0P0017oo00<007ooOol017oo00<007ooOol037oo0P003Woo00@0
07ooOol0011oo`03001oo`0000aoo`03001oogoo00Moo`8001=oo`03001oogoo00ioo`03001oogoo
009oo`03001oogoo019oo`03001oo`0000aoo`8001Qoo`03001oogoo01Qoo`03001oogoo00ioo`03
001oo`0001Yoo`002goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
37oo0P003Woo00@007ooOol0011oo`03001oo`0000aoo`03001oogoo00Moo`8001=oo`03001oogoo
00ioo`03001oogoo009oo`03001oogoo019oo`03001oo`0000]oo`03001oo`0001Qoo`03001oogoo
01Qoo`03001oogoo00ioo`03001oo`0001Yoo`006goo00<007ooOol017oo00<007ooOol037oo0P00
3Woo00@007ooOol0011oo`03001oo`0000aoo`03001oogoo00Moo`8001=oo`03001oogoo00ioo`03
001oogoo009oo`03001oogoo019oo`03001oo`0000]oo`03001oo`0001Moo`8001Yoo`03001oogoo
00ioo`03001oo`0001Yoo`006goo00<007ooOol017oo00<007ooOol037oo0P003Woo00@007ooOol0
011oo`03001oo`0000aoo`03001oogoo00Moo`8001=oo`03001oogoo00ioo`03001oogoo009oo`03
001oogoo019oo`03001oo`0000]oo`03001oo`0001Moo`8001Yoo`03001oogoo00ioo`03001oo`00
01Yoo`006goo00<007ooOol017oo00<007ooOol037oo0P003Goo00D007ooOomoo`00011oo`03001o
o`0000]oo`8000Uoo`80019oo`80011oo`03001oogoo009oo`03001oogoo019oo`03001oo`0000]o
o`03001oo`0001Moo`8001Yoo`03001oogoo00ioo`03001oo`0001Yoo`006goo0P001Goo00<007oo
Ool037oo0P003Goo00D007ooOomoo`00011oo`03001oo`0000]oo`8000Uoo`80019oo`80011oo`03
001oogoo009oo`03001oogoo019oo`04001oogoo000:Ool00`00Ool0000GOol2000JOol00`00Oomo
o`0>Ool00`00Ool0000JOol001]oo`03001oogoo00Aoo`03001oogoo00aoo`8000eoo`05001oogoo
Ool0000@Ool00`00Ool0000;Ool20009Ool2000BOol2000@Ool00`00Oomoo`02Ool00`00Oomoo`0B
Ool01000Oomoo`002Woo00<007oo00005goo0P006Woo00<007ooOol03Woo00<007oo00006Woo000K
Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool2000=Ool01@00Oomoogoo000047oo00@007ooOol000Yo
o`8000Uoo`80019oo`03001oo`0000Eoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo019o
o`04001oogoo000:Ool01000Oomoo`005Woo0P006Woo00<007ooOol03Woo00<007oo00006Woo000K
Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool2000=Ool01@00Oomoogoo00003goo00D007ooOomoo`00
00Yoo`8000Uoo`80019oo`03001oo`0000Eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
015oo`04001oogoo000:Ool01000Oomoo`005Woo0P006Woo00<007ooOol03Woo00<007oo00006Woo
000KOol00`00Oomoo`04Ool00`00Oomoo`0<Ool2000=Ool01@00Oomoogoo00003goo00D007ooOomo
o`0000Yoo`8000Uoo`80019oo`03001oo`0000Eoo`03001oogoo00Moo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo00Moo`04001oogoo000:Ool01000Oomoo`005Woo0P006Woo0P003goo00<0
07oo00006Woo000KOol00`00Oomoo`04Ool00`00Oomoo`0<Ool2000=Ool01@00Oomoogoo00003goo
00D007ooOomoo`0000Yoo`8000Uoo`80019oo`03001oo`0000Eoo`03001oogoo00Moo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo00Moo`04001oogoo000:Ool01000Oomoo`005Woo0P006Woo
0P003goo00<007oo00006Woo000KOol00`00Oomoo`04Ool00`00Oomoo`0<Ool2000=Ool01@00Oomo
ogoo00003goo00D007ooOomoo`0000Yoo`8000Uoo`80019oo`03001oo`0000Eoo`03001oogoo00Mo
o`03001oogoo00=oo`03001oo`0000Moo`03001oogoo00Moo`04001oogoo000:Ool01000Oomoo`00
5Woo00<007oo00006Goo0P003goo00<007oo00006Woo000KOol20005Ool00`00Oomoo`0<Ool2000=
Ool01@00Oomoogoo00003goo00D007ooOomoo`0000Yoo`8000Uoo`80019oo`03001oo`0000Eoo`03
001oogoo00Moo`03001oogoo00=oo`<000Moo`03001oogoo00Moo`04001oogoo000:Ool01000Oomo
o`005Woo00<007oo00006Goo0P003goo00<007oo00006Woo000KOol00`00Oomoo`04Ool00`00Oomo
o`0<Ool2000=Ool01@00Oomoogoo00003goo00D007ooOomoo`0000Yoo`8000Uoo`80019oo`03001o
o`0000Eoo`03001oogoo00Moo`03001oogoo00=oo`03001oo`0000Moo`03001oogoo00Ioo`05001o
ogooOol0000:Ool01000Oomoo`005Woo00<007oo00006Goo0P0017oo00<007ooOol027oo00<007oo
00006Woo000KOol00`00Oomoo`04Ool2000=Ool2000=Ool01@00Oomoogoo00003goo00D007ooOomo
o`0000Yoo`8000Uoo`03001oo`00015oo`03001oo`0000Eoo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Ioo`05001oogooOol0000:Ool01000Oomoo`005Woo00<007oo
00006Goo0P0017oo00<007ooOol027oo00<007oo00006Woo000KOol00`00Oomoo`04Ool2000=Ool2
000=Ool01@00Oomoogoo00003goo00D007ooOomoo`0000Yoo`8000Uoo`03001oo`0000Yoo`03001o
ogoo00Aoo`03001oo`0000Eoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Ioo`05001oogooOol0000:Ool01000Oomoo`005Woo00<007oo00006Goo0P0017oo00<007oo
Ool027oo00<007oo00006Woo000KOol00`00Oomoo`04Ool2000=Ool2000=Ool01@00Oomoogoo0000
3goo00D007ooOomoo`0000Yoo`8000Uoo`03001oo`0000Yoo`03001oogoo00Aoo`03001oo`0000Eo
o`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`05001oogooOol0
000:Ool01000Oomoo`005Woo00<007oo00006Goo0P0017oo00<007ooOol027oo00@007ooOol001Uo
o`006goo00<007ooOol017oo0P0037oo00<007oo00003Goo00D007ooOomoo`0000moo`05001oogoo
Ool0000:Ool20009Ool00`00Ool0000:Ool00`00Oomoo`04Ool00`00Ool00005Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomoogoo00002Woo00@007oo
Ool001Ioo`03001oo`0001Uoo`8000Aoo`03001oogoo00Qoo`04001oogoo000:Ool00`00Oomoo`0<
Ool001]oo`03001oogoo00Aoo`8000aoo`03001oo`0000eoo`05001oogooOol0000?Ool01@00Oomo
ogoo00002Goo00<007oo00002Goo00<007oo00002Woo00<007ooOol017oo00<007oo00001Goo00<0
07ooOol01goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00D007ooOomoo`0000Yo
o`04001oogoo000FOol00`00Ool0000IOol20004Ool00`00Oomoo`08Ool01000Oomoo`002Woo00<0
07ooOol037oo000KOol20005Ool2000<Ool00`00Ool0000=Ool01@00Oomoogoo00003goo00D007oo
Oomoo`0000Uoo`04001oogoo0008Ool00`00Ool0000:Ool00`00Oomoo`04Ool00`00Ool00005Ool0
0`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomoogoo0000
2Woo00D007ooOomoo`0000]oo`03001oogoo00Ioo`04001oogoo000HOol00`00Ool00004Ool00`00
Oomoo`08Ool01000Oomoo`001Goo00<007ooOol00Woo00<007ooOol037oo000KOol00`00Oomoo`04
Ool2000<Ool00`00Ool0000=Ool01@00Oomoogoo00003goo00D007ooOomoo`0000Uoo`04001oogoo
0008Ool00`00Ool0000:Ool00`00Oomoo`04Ool00`00Ool00005Ool00`00Oomoo`07Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]o
o`03001oogoo00Ioo`04001oogoo000HOol00`00Ool00004Ool00`00Oomoo`08Ool01000Oomoo`00
1Goo00<007ooOol00Woo00<007ooOol037oo000KOol00`00Oomoo`04Ool2000<Ool00`00Ool0000=
Ool01@00Oomoogoo00003goo00D007ooOomoo`0000Uoo`04001oogoo0008Ool00`00Ool0000:Ool0
0`00Oomoo`04Ool00`00Ool00005Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`03001oogoo00Ioo`04001oogoo000H
Ool00`00Ool00004Ool00`00Oomoo`08Ool01000Oomoo`001Goo00<007ooOol00Woo00<007ooOol0
37oo000KOol00`00Oomoo`04Ool2000<Ool00`00Ool0000=Ool01@00Oomoogoo00003goo00D007oo
Oomoo`0000Uoo`04001oogoo0008Ool00`00Ool00009Ool00`00Ool00005Ool00`00Ool00005Ool2
0008Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomoogoo00002Woo00L0
07ooOomoo`00Ool00009Ool00`00Oomoo`06Ool01000Oomoo`0067oo00<007oo000017oo00<007oo
Ool027oo00@007ooOol000Aoo`8000Aoo`03001oogoo00aoo`002goo00<007ooOol00Woo00@007oo
Oomoo`<000Aoo`03001oogoo00Aoo`8000aoo`03001oo`0000eoo`03001oogoo009oo`03001oogoo
00aoo`05001oogooOol00009Ool01000Oomoo`0027oo00<007oo00002Goo00<007oo00001Goo00<0
07oo00001Goo0P0027oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00D007ooOomo
o`0000Uoo`03001oogoo009oo`<000Uoo`03001oogoo00Ioo`04001oogoo000HOol00`00Ool00004
Ool00`00Oomoo`08Ool01000Oomoo`0017oo0P000goo0P003Woo000:Ool00`00Ool00007Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool2000<Ool01000Oomoo`0037oo00<007ooOol00Woo00<007ooOol0
27oo00D007ooOomoo`0000=oo`03001oogoo00Moo`04001oogoo0008Ool00`00Ool00009Ool00`00
Ool00005Ool00`00Ool00005Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool01@00Oomoogoo00002Goo00<007ooOol00Woo0`002Goo00<007ooOol01Woo00@007ooOol001Qo
o`03001oo`0000=oo`8000Yoo`04001oogoo0004Ool20003Ool2000>Ool000Eoo`<0009oo`03001o
o`0000Qoo`03001oogoo00=oo`8000Eoo`8000aoo`04001oogoo000<Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool01@00Oomoogoo00000goo00<007ooOol01goo00@007ooOol000Qoo`03001oo`0000Uo
o`03001oo`0000Eoo`03001oo`0000Eoo`8000Qoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Ioo`05001oogooOol00009Ool00`00Oomoo`02Ool00`00Ool00009Ool00`00Oomoo`06Ool0
1000Oomoo`0067oo00<007oo00000goo0P002Woo00@007ooOol000Aoo`8000=oo`8000ioo`002Woo
00<007oo000027oo00<007ooOol00goo00<007ooOol017oo0P0037oo00@007ooOol000Qoo`05001o
ogooOol00004Ool00`00Oomoo`08Ool01@00Oomoogoo00000goo00<007ooOol01goo00@007ooOol0
00Qoo`03001oo`0000Uoo`03001oo`0000Eoo`03001oo`0000Eoo`8000Qoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Ioo`05001oogooOol00009Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool01000Oomoo`0067oo00<007oo00000goo0P002Woo00@007ooOol000Aoo`80
00=oo`8000ioo`002Woo00<007oo00001goo00<007oo000017oo00<007ooOol00goo00<007oo0000
37oo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`08Ool01@00Oomoogoo00000goo00<0
07ooOol01goo00@007ooOol000Qoo`03001oo`0000Uoo`03001oo`0000Eoo`03001oo`0000Eoo`80
00Qoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`05001oogooOol00004Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`06Ool20008Ool01000Oomoo`0067oo00<007oo0000
0goo0P002Woo00@007ooOol000Aoo`8000=oo`03001oo`0000eoo`002goo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol00goo00<007oo000037oo00@007ooOol000Qoo`04001oogoo0005Ool0
0`00Oomoo`08Ool01@00Oomoogoo00000goo00<007ooOol01goo00@007ooOol000=oo`03001oogoo
009oo`03001oo`0000Uoo`03001oo`0000Eoo`03001oo`0000Eoo`8000Qoo`03001oogoo00Eoo`03
001oogoo00Aoo`8000Qoo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool20008Ool01000Oomoo`0067oo00<007oo00000goo0P002Woo00@007ooOol000=oo`04
001oogoo0002Ool00`00Ool0000=Ool001]oo`03001oogoo00=oo`03001oo`0000aoo`04001oogoo
0008Ool01000Oomoo`001Goo00<007ooOol027oo00D007ooOomoo`0000=oo`03001oogoo00Moo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Ool00009Ool00`00Ool00005Ool00`00Ool00005Ool2
0008Ool00`00Oomoo`06Ool00`00Oomoo`03Ool20008Ool01@00Oomoogoo000017oo00<007ooOol0
0Woo00<007ooOol017oo00<007ooOol01Woo00<007oo00001goo00@007ooOol001Qoo`03001oo`00
00=oo`8000Yoo`04001oogoo0003Ool01000Oomoo`000Woo00<007oo00003Goo000KOol00`00Oomo
o`03Ool00`00Ool0000<Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo00Qoo`05001o
ogooOol00003Ool00`00Oomoo`07Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo00002Goo
00<007oo00001Goo00<007oo00001Goo0P0027oo00<007ooOol01Woo00<007ooOol00goo00<007oo
00001goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oo`0000Moo`04001oogoo000HOol00`00Ool00003Ool2000:Ool01000Oomoo`000goo00@007oo
Ool0009oo`03001oo`0000eoo`006goo00<007ooOol00goo00<007oo00002Goo00@007ooOol0009o
o`03001oogoo00Ioo`04001oogoo0005Ool00`00Oomoo`08Ool01@00Oomoogoo00000goo00<007oo
Ool01goo00@007ooOol000=oo`03001oogoo009oo`03001oo`0000Uoo`03001oo`0000Eoo`03001o
o`0000Eoo`8000Qoo`03001oogoo00Ioo`03001oogoo00=oo`03001oo`0000Moo`05001oogooOol0
0004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Ool00007Ool01000Oomo
o`0067oo00<007oo00000goo0P002Woo00@007ooOol000=oo`04001oogoo0002Ool00`00Ool0000=
Ool001]oo`8000Aoo`03001oo`0000Uoo`04001oogoo0002Ool00`00Oomoo`06Ool01000Oomoo`00
1Goo00<007ooOol027oo00D007ooOomoo`0000=oo`03001oogoo00Moo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Ool00009Ool00`00Ool00005Ool00`00Ool00004Ool00`00Ool00008Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Ool00007Ool01@00Oomoogoo000017oo00<007ooOol00Woo
00<007ooOol01Goo00<007ooOol01Goo00<007oo00001goo00@007ooOol001Qoo`03001oo`0000=o
o`8000Yoo`04001oogoo0003Ool01000Oomoo`000Woo00<007oo00003Goo000KOol00`00Oomoo`03
Ool00`00Ool00009Ool01000Oomoo`000Woo00<007ooOol01Woo00@007ooOol000Eoo`03001oogoo
00Qoo`05001oogooOol00003Ool00`00Oomoo`07Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07oo00002Goo00<007oo00001Goo00<007oo000017oo00<007oo000027oo00<007ooOol01Woo00<0
07ooOol00goo00<007oo00001goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oo`0000Moo`04001oogoo000HOol00`00Ool00003Ool2000:Ool01000
Oomoo`000goo00@007ooOol0009oo`03001oo`0000eoo`006goo00<007ooOol00goo00<007oo0000
2Goo0P0000Eoo`00Oomoo`0000Qoo`04001oogoo0005Ool00`00Oomoo`08Ool01@00Oomoogoo0000
0goo00<007ooOol01goo00@007ooOol000=oo`03001oogoo009oo`03001oo`0000Uoo`03001oo`00
00Eoo`03001oo`0000Aoo`03001oo`0000Qoo`03001oogoo00Ioo`03001oogoo00=oo`03001oo`00
00Moo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Ool00007Ool01000Oomoo`0067oo00<007oo00000goo00<007oo00002Goo00@007ooOol0009oo`05
001oogooOol00002Ool00`00Ool0000=Ool001]oo`03001oogoo00=oo`03001oo`0000Uoo`<000=o
o`03001oogoo00Ioo`800003Ool007oo00Aoo`03001oogoo00Qoo`80009oo`05001oogooOol00009
Ool01000Oomoo`000goo00<007ooOol00Woo00<007oo00002Goo00<007oo00001Goo00<007oo0000
17oo00<007oo000027oo00<007ooOol01Woo00<007ooOol00goo00<007oo00001goo00D007ooOomo
o`0000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oo`0000Moo`04001o
ogoo000HOol00`00Ool00003Ool00`00Ool00009Ool01000Oomoo`000Woo00L007ooOomoo`00Ool0
0002Ool00`00Oomoo`0;Ool001]oo`03001oogoo00=oo`03001oo`0000Uoo`<000=oo`03001oogoo
00Ioo`800003Ool007oo00Aoo`03001oogoo00Qoo`80009oo`03001oogoo009oo`03001oogoo00Io
o`04001oogoo0003Ool00`00Oomoo`02Ool00`00Ool00008Ool01@00Oomoogoo000017oo00<007oo
000017oo00<007oo00001goo00<007ooOol01goo00<007ooOol00goo00<007oo00001goo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oo`0000Ioo`05
001oogooOol0000HOol00`00Ool00003Ool00`00Ool00009Ool01000Oomoo`000Woo00L007ooOomo
o`00Ool00002Ool00`00Oomoo`0;Ool001]oo`03001oogoo00=oo`03001oo`0000Uoo`<000=oo`03
001oogoo00Ioo`800003Ool007oo00Aoo`03001oogoo00Moo`03001oo`00009oo`03001oogoo009o
o`03001oogoo00Eoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Ool00008Ool01@00Oomo
ogoo000017oo00<007oo000017oo00<007oo00001goo00<007ooOol01goo00<007ooOol00goo00<0
07oo00001goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oo`0000Ioo`05001oogooOol0000HOol01000Oomoo`000Woo00<007oo00002Goo00@007oo
Ool0009oo`07001oogooOol007oo00000Woo00<007ooOol02goo000KOol00`00Oomoo`03Ool00`00
Ool00009Ool30003Ool00`00Oomoo`05Ool01@00Ool007oo00001Goo00<007ooOol01goo00<007oo
00000Woo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`05001oogooOol00002
Ool00`00Oomoo`06Ool01@00Oomoogoo000017oo00<007oo000017oo00<007oo00001goo00<007oo
Ool01goo00<007ooOol00goo00<007oo00001goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oo`0000Ioo`05001oogooOol0000HOol01000Oomoo`00
0Woo00<007oo00002Goo00@007ooOol0009oo`07001oogooOol007oo00000Woo00<007ooOol02goo
000KOol20004Ool00`00Ool00009Ool30003Ool00`00Oomoo`05Ool01@00Ool007oo00001Goo00<0
07ooOol01goo00<007oo00000Woo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000=o
o`05001oogooOol00002Ool00`00Oomoo`06Ool01@00Oomoogoo000017oo00<007oo000017oo00<0
07oo00001goo00<007ooOol01goo00<007ooOol00goo00<007oo00001goo00D007ooOomoo`0000Ao
o`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oo`0000Ioo`05001oogooOol0
000HOol01000Oomoo`000Woo00<007oo00002Goo00@007ooOol0009oo`07001oogooOol007oo0000
0Woo00<007ooOol02goo000KOol00`00Oomoo`03Ool00`00Ool00008Ool01000Oomoo`000goo00<0
07ooOol01Goo00D007oo001oo`0000Eoo`03001oogoo00Moo`03001oo`00009oo`03001oogoo009o
o`03001oogoo00Eoo`05001oogooOol00003Ool20002Ool01000Oomoo`0027oo00D007ooOomoo`00
00Aoo`03001oo`0000Aoo`03001oo`0000Moo`03001oogoo00Moo`03001oogoo00=oo`03001oo`00
00Moo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Ool00006Ool01@00Oomoogoo000067oo00@007ooOol0009oo`03001oo`0000Uoo`04001oogoo0002
Ool01`00Oomoogoo001oo`00009oo`03001oogoo00]oo`006goo00<007ooOol00goo00<007oo0000
27oo00@007ooOol000=oo`03001oogoo00Eoo`05001oo`00Ool00005Ool00`00Oomoo`07Ool00`00
Ool00002Ool00`00Oomoo`02Ool20006Ool01@00Oomoogoo00000goo0P000Woo00@007ooOol000Qo
o`05001oogooOol00004Ool00`00Ool00004Ool00`00Ool00007Ool00`00Ool000040002Ool20005
Ool00`00Ool00007Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol01Goo00<007oo
Ool01Goo00<007oo00001Woo1@000Woo00<007ooOol04goo00@007ooOol0009oo`03001oo`0000Uo
o`04001oogoo0002Ool01`00Oomoogoo001oo`00009oo`03001oogoo00<000=oo`03001oogoo009o
o`006goo00<007ooOol00goo00<007oo000027oo00@007ooOol000=oo`03001oogoo00Eoo`05001o
o`00Ool00005Ool00`00Oomoo`07Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Ool00005Ool0
1@00Oomoogoo00000goo0P000Woo00@007ooOol000Qoo`05001oogooOol00004Ool00`00Ool00004
Ool00`00Ool00007Ool01@00Oomoogoo00000goo00<007oo00001Goo00<007oo00001goo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0006Ool0
2@00Ool007oo001oo`00Ool0000DOol01000Oomoo`000Woo00<007oo00002Goo00H007ooOol007oo
0004Ool00`00Ool00002Ool01000Oomoo`0017oo00<007oo00000goo000KOol00`00Oomoo`03Ool0
1000Oomoo`001goo00@007ooOol000=oo`03001oogoo00Eoo`05001oo`00Ool00005Ool00`00Oomo
o`07Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Ool00005Ool01@00Oomoogoo00000goo0P00
0Woo00@007ooOol000Qoo`05001oogooOol00004Ool00`00Ool00004Ool00`00Ool00007Ool01@00
Oomoogoo00000goo00<007oo00001Goo00<007oo00001goo00D007ooOomoo`0000Aoo`03001oogoo
009oo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0006Ool01@00Ool007oo00000goo00<0
07ooOol04Woo00@007ooOol0009oo`03001oo`0000Uoo`06001oogoo001oo`0017oo00<007oo0000
0Woo00D007ooOomoo`0000=oo`03001oo`0000=oo`006goo00<007ooOol00goo00@007ooOol000Mo
o`03001oogoo00Aoo`03001oogoo00Eoo`05001oo`00Ool00005Ool00`00Oomoo`07Ool00`00Ool0
0002Ool00`00Oomoo`02Ool20006Ool01@00Oomoogoo00000goo0P000Woo00@007ooOol000Qoo`05
001oogooOol00003Ool01000Oomoo`0017oo00<007oo00001goo00D007ooOomoo`0000=oo`03001o
o`0000Eoo`03001oo`0000Moo`05001oogooOol00003Ool20004Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool01000Oomoo`001Woo00H007oo001oo`00Ool2000EOol01000Oomoo`000Woo00<007oo0000
2Goo00H007ooOol007oo0005Ool20002Ool01@00Oomoogoo00000goo00<007oo00000goo000KOol0
0`00Oomoo`03Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol01Goo00D007oo001oo`00
00Eoo`03001oogoo00Moo`03001oo`00009oo`03001oogoo009oo`03001oogoo00Eoo`05001oogoo
Ool00003Ool20002Ool01000Oomoo`0027oo00D007ooOomoo`0000=oo`04001oogoo0004Ool00`00
Ool00007Ool01@00Oomoogoo00000goo00<007oo00001Goo00<007oo00001goo00D007ooOomoo`00
00=oo`8000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo0006Ool01`00Ool007oo001o
o`0001Ioo`04001oogoo0002Ool00`00Ool00009Ool01000Oomoogoo0P001Goo0P000goo00D007oo
001oo`00009oo`03001oo`0000=oo`006goo0P0017oo00@007ooOol000Moo`03001oogoo00Aoo`03
001oogoo00Eoo`05001oo`00Ool00005Ool00`00Oomoo`07Ool00`00Ool00002Ool00`00Oomoo`02
Ool30005Ool01@00Oomoogoo00000goo0P000Woo00@007ooOol000Qoo`05001oogooOol00003Ool0
1000Oomoo`0017oo00<007oo00001goo00<007ooOol00P0017oo0P001Goo00<007oo00001goo00D0
07ooOomoo`0000=oo`03001oo`00009oo`03001oogoo00Ioo`03001oogoo00Aoo`04001oogoo0006
Ool300000goo001oo`03000;Ool00`00Oomoo`06Ool01P00Oomoo`00Ool0009oo`03001oogoo00=o
o`05001oogooOol00003Ool20005Ool20003Ool01000Oomoo`0017oo00<007ooOol00Woo000KOol0
0`00Oomoo`03Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol01Goo00D007oo001oo`00
00Ioo`03001oogoo00Ioo`03001oo`00009oo`03001oogoo009oo`03001oogoo00Eoo`05001oogoo
Ool00003Ool20002Ool01000Oomoo`0027oo00D007ooOomoo`0000=oo`04001oogoo0004Ool00`00
Ool00007Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Ool00006Ool00`00Oomoo`02Ool01`00
Oomoogoo001oo`00009oo`03001oogoo00Moo`03001oogoo00=oo`04001oogoo0006Ool00`00Oomo
o`02Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool01P00Oomoo`00Ool0009oo`03001oogoo00=oo`05
001oogooOol00003Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001]oo`03001oogoo00=o
o`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01@00Ool007oo00001Woo00<007oo
Ool01Woo00<007oo00000Woo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`80
009oo`04001oogoo0008Ool01@00Oomoogoo00000goo00@007ooOol000Aoo`04001oogoo0006Ool0
0`00Oomoo`07Ool00`00Oomoo`03Ool00`00Ool00006Ool00`00Oomoo`02Ool01`00Oomoogoo001o
o`00009oo`03001oogoo00Moo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`02Ool0
0`00Oomoo`0<Ool20007Ool01P00Oomoo`00Ool0009oo`03001oogoo00=oo`05001oogooOol00003
Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool001]oo`03001oogoo00=oo`04001oogoo0007
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01@00Ool007oo00001Woo00<007ooOol01Woo00<007oo
00000Woo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`80009oo`04001oogoo
0008Ool01@00Oomoogoo00000goo00@007ooOol000Aoo`04001oogoo0006Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool00`00Ool00006Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00009oo`03001o
ogoo00Moo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool2
0007Ool01P00Oomoo`00Ool0009oo`03001oogoo00=oo`05001oogooOol00003Ool20005Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool001]oo`03001oogoo00=oo`04001oogoo0007Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool01000Ool000001goo00<007ooOol01Woo00<007oo00000Woo00<007ooOol0
0Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`80009oo`04001oogoo0008Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo00Moo`03001oogoo
00=oo`03001oo`0000Ioo`03001oogoo009oo`07001oogooOol007oo00000Woo00<007ooOol01goo
00<007ooOol00goo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo00aoo`8000Moo`06
001oogoo001oo`000Woo00<007ooOol00goo00D007ooOomoo`0000=oo`8000Eoo`03001oogoo009o
o`03001oogoo00Yoo`006goo00<007ooOol00goo00@007ooOol000Moo`03001oogoo00Aoo`03001o
ogoo00Eoo`04001oo`000007Ool00`00Oomoo`06Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00
Oomoo`05Ool01@00Oomoogoo00000goo0P000Woo00@007ooOol000Qoo`03001oogoo009oo`04001o
ogoo0002Ool00`00Oomoo`02Ool01000Oomoo`001Woo00<007ooOol01goo00<007ooOol00goo00<0
07oo00001Woo00<007ooOol00Woo00L007ooOomoo`00Ool00002Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool01@00Oomoogoo000017oo00<007ooOol00goo00<007ooOol037oo00<007oo00001Woo00H0
07ooOol007oo0002Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo0P001Goo00<007ooOol00Woo
00<007ooOol02Woo000KOol00`00Oomoo`03Ool01000Oomoo`001goo00<007ooOol017oo00<007oo
Ool01Goo00@007oo000000Moo`03001oogoo00Ioo`03001oo`00009oo`03001oogoo009oo`03001o
ogoo00Eoo`05001oogooOol00003Ool20002Ool01000Oomoo`0027oo00<007ooOol00Woo00@007oo
Ool0009oo`03001oogoo009oo`04001oogoo0006Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00
Ool00006Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00009oo`03001oogoo00Moo`03001oogoo
00=oo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Ool00006Ool01P00
Oomoo`00Ool0009oo`03001oogoo00=oo`80009oo`04001oogooOol20005Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool001Eoool000T000=oo`006goo00<007ooOol00goo00@007ooOol0009oo`03001o
ogoo009oo`03001oogoo00Aoo`8000Ioo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool200001Goo001oogoo000017oo0P001Woo00H007ooOomoo`00Ool200001Goo001oogoo00000Woo
00D007ooOomoo`0000=oo`03001oogoo00=oo`04001oo`000003Ool01@00Oomoogoo00000Woo0P00
1Goo00<007ooOol017oo00@007ooOol000Eoo`04001oo`000005Ool00`00Oomoo`03Ool2000017oo
001oo`000Woo00<007ooOol00goo00D007ooOomoo`0000Eoo`05001oo`00Ool00004Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Ool00002Ool00`00Oomoo`03Ool2000017oo
001oo`000Woo00<007ooOol00goo0P0000=oo`00Ool00goo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol00goo00<007ooOol017oo000KOol00`00Oomoo`03Ool01000Oomoo`001goo00<007oo
Ool017oo00<007ooOol01Goo00@007ooOol000Moo`03001oogoo00Ioo`06001oogoo001oo`0017oo
00<007ooOol01Goo00D007ooOomoo`00009oo`03001oo`00009oo`04001oogoo0007Ool00`00Oomo
o`03Ool01000Oomoo`000goo00D007ooOomoo`00009oo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00=oo`03001oo`0000Ioo`03001oogoo00=oo`06001oogoo001oo`000Woo00<007ooOol0
1goo00<007ooOol00goo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00Moo`04001oogoo0005Ool01P00Oomoo`00Ool0009oo`03001oogoo00=oo`800003Ool007oo
00=oo`03001oogoo00Uoo`03001oogoo00Yoo`006goo00<007ooOol00goo00@007ooOol000Moo`03
001oogoo00Aoo`03001oogoo00Eoo`04001oogoo0007Ool00`00Oomoo`06Ool01P00Oomoo`00Ool0
00Aoo`03001oogoo00Eoo`05001oogooOol00002Ool00`00Ool00002Ool01000Oomoo`001goo00<0
07ooOol00goo00@007ooOol000=oo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`03Ool00`00Ool00006Ool00`00Oomoo`03Ool01P00Oomoo`00Ool0009oo`03001o
ogoo00Moo`03001oogoo00=oo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool01000Oomoo`001Goo00H007ooOol007oo0002Ool00`00Oomoo`03Ool200000goo
001oo`03Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool001]oo`03001oo`0000=oo`04001oogoo0007
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01000Oomoo`001goo00<007ooOol01Woo00H007ooOol0
07oo0004Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007oo00000Woo00@007ooOol000Mo
o`03001oogoo00=oo`04001oogoo0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007oo
Ool01goo00<007ooOol00goo00<007oo00001Woo00<007ooOol00goo00H007ooOol007oo0002Ool0
0`00Oomoo`07Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol01goo00@007ooOol000Eoo`06001oogoo001oo`000Woo00<007ooOol00goo0P00
00=oo`00Ool00goo00<007ooOol02Goo00<007ooOol02Woo000KOol30003Ool01000Oomoo`001Woo
00<007ooOol01Goo00<007ooOol01Goo00@007ooOol000Moo`03001oogoo00Ioo`06001oogoo001o
o`0017oo00<007ooOol01Goo00D007ooOomoo`00009oo`03001oo`00009oo`04001oogoo0007Ool0
0`00Oomoo`03Ool01000Oomoo`000goo00D007ooOomoo`00009oo`03001oogoo00Aoo`03001oogoo
00Moo`03001oogoo00=oo`03001oo`0000Ioo`03001oogoo00=oo`06001oogoo001oo`000Woo00<0
07ooOol01goo00<007ooOol00goo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00Moo`04001oogoo0005Ool01P00Oomoo`00Ool0009oo`03001oogoo00=oo`800003
Ool007oo00=oo`03001oogoo00Uoo`03001oogoo00Yoo`006goo00<007oo00000goo00@007ooOol0
00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`04001oogoo0007Ool00`00Oomoo`06Ool01P00Oomo
o`00Ool000Aoo`03001oogoo00Eoo`05001oogooOol00002Ool00`00Ool00002Ool01000Oomoo`00
1goo00<007ooOol00goo00@007ooOol000=oo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool00`00Ool00006Ool00`00Oomoo`03Ool01P00Oomoo`00Ool0009o
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo009oo`06001oogoo001o
o`000Woo00<007ooOol00goo0P0000=oo`00Ool00goo00<007ooOol02Goo00<007ooOol02Woo000K
Ool30003Ool01000Oomoo`001Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`04001oogoo0007
Ool00`00Oomoo`06Ool00`00Oomoo`020005Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01P00Oomo
o`00Ool0009oo`04001oogoo0007Ool00`00Oomoo`03Ool01000Oomoo`000goo00D007ooOomoo`00
009oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00=oo`03001oo`0000Ioo`03001oogoo
00=oo`06001oogoo001oo`000Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00Woo00<0
07ooOol00Woo00H007ooOol007oo0002Ool00`00Oomoo`03Ool200000goo001oo`0?Ool00`00Oomo
o`0:Ool001]oo`03001oo`0000=oo`04001oogoo0006Ool00`00Oomoo`05Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`0000Moo`03001oogoo00Ioo`03001oogoo008000Eoo`03001oogoo00Aoo`03
001oogoo009oo`06001oogoo001oo`000Woo00@007ooOol000Moo`03001oogoo00=oo`04001oogoo
0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol01goo00<007ooOol00goo00<0
07oo00001Woo00<007ooOol00goo00H007ooOol007oo0002Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oogoo00=oo`800003
Ool007oo00moo`03001oogoo00Yoo`006goo00<007oo00000goo00@007ooOol000Ioo`03001oogoo
00Eoo`05001oogooOol00002Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`020005Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool01@00Ool007oo00000Woo00@007ooOol000Moo`03001oogoo
00=oo`04001oogoo0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol01goo00<0
07ooOol00goo00<007oo00001Woo00<007ooOol00goo00H007ooOol007oo0002Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol00Woo0P001goo
00<007ooOol00Woo00<007ooOol00Woo00H007ooOol007oo0002Ool00`00Oomoo`02Ool01@00Ool0
07oo000047oo00<007ooOol02Woo000KOol00`00Ool00003Ool01000Oomoo`001Woo00<007ooOol0
1Goo00D007ooOomoo`00009oo`03001oogoo00Uoo`03001oogoo00Eoo`04001oogooOol20005Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool01@00Ool007oo00000Woo00@007ooOol000Moo`03001oogoo
00=oo`04001oogoo0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol027oo00<0
07ooOol00Woo00<007oo00001Woo00<007ooOol00goo00H007ooOol007oo0002Ool00`00Oomoo`08
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ioo`03001oogoo009oo`8000Moo`03001oogoo
009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007ooOol00Woo00<007ooOol00P0047oo
00<007ooOol02Woo000KOol00`00Ool00003Ool01000Oomoo`001Woo00<007ooOol01Goo00D007oo
Oomoo`00009oo`03001oogoo00Uoo`03001oogoo00Eoo`04001oogooOol20005Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool01000Oomoo`000goo00D007ooOomoo`00009oo`03001oogoo00Aoo`03001oogoo00Qoo`05001o
ogooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01P00Oomoo`00Ool0009oo`03001oogoo
00Qoo`05001oogooOol00004Ool01@00Oomoogoo00001Woo00<007ooOol00Woo0P001goo00<007oo
Ool00Woo00<007ooOol00Woo00H007ooOol007oo0002Ool00`00Oomoo`02Ool00`00Oomoo`02000A
Ool00`00Oomoo`09Ool001]oo`03001oo`0000=oo`04001oogoo0006Ool00`00Oomoo`05Ool01@00
Oomoogoo00000Woo00<007ooOol02Woo00<007ooOol017oo00@007ooOomoo`8000Eoo`03001oogoo
00Aoo`03001oogoo00=oo`03001oo`00009oo`03001oo`00009oo`03001oogoo00Eoo`03001oogoo
00=oo`04001oogoo0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol027oo00D0
07ooOomoo`00009oo`03001oogoo00Aoo`03001oogoo00=oo`06001oogoo001oo`000Woo00<007oo
Ool027oo00D007ooOomoo`0000Aoo`05001oogooOol00006Ool00`00Oomoo`02Ool20007Ool00`00
Oomoo`03Ool01@00Oomoogoo00000goo0P000Woo00<007ooOol00Woo00<007ooOol00P004Goo00<0
07ooOol02Goo000KOol200001Goo001oogoo00000Woo00<007ooOol017oo00<007ooOol01Goo00D0
07ooOomoo`00009oo`03001oogoo00Yoo`03001oogoo00Aoo`04001oogooOol20005Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`05Ool00`00Oomo
o`03Ool01000Oomoo`000goo00D007ooOomoo`00009oo`03001oogoo00Aoo`03001oogoo00Qoo`05
001oogooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01P00Oomoo`00Ool0009oo`03001o
ogoo00Qoo`05001oogooOol00004Ool01@00Oomoogoo00001Woo00<007ooOol00Woo0P001goo00<0
07ooOol00goo00D007ooOomoo`0000=oo`80009oo`03001oogoo009oo`03001oogoo0080015oo`03
001oogoo00Uoo`006goo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`05Ool01@00Oomo
ogoo00000Woo00<007ooOol02Woo00<007ooOol017oo00@007ooOomoo`8000Eoo`03001oogoo00Ao
o`03001oogoo00=oo`03001oo`00009oo`03001oo`00009oo`03001oogoo00Eoo`03001oogoo00=o
o`04001oogoo0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol027oo00D007oo
Oomoo`00009oo`03001oogoo00Aoo`03001oogoo00=oo`06001oogoo001oo`000Woo00<007ooOol0
27oo00D007ooOomoo`0000Eoo`04001oogoo0006Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`03
Ool01000Oomoo`0017oo0P000Woo00<007ooOol00Woo00<007ooOol00P004Goo00<007ooOol02Goo
000KOol01000Oomoo`000Woo00@007ooOol0009oo`05001oogooOol00007Ool01@00Oomoogoo0000
0Woo00<007ooOol02Woo00<007ooOol017oo00@007ooOomoo`8000Eoo`03001oogoo00Aoo`03001o
ogoo00=oo`03001oo`00009oo`03001oo`00009oo`03001oogoo00Eoo`03001oogoo00=oo`04001o
ogoo0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol027oo00D007ooOomoo`00
009oo`03001oogoo00Aoo`03001oogoo00=oo`08001oogoo001oo`00Ool000]oo`05001oogooOol0
0005Ool01000Oomoo`001Woo00<007ooOol00Woo0P001goo00<007ooOol00goo00@007ooOol000Ao
o`05001oogooOol00004Ool00`00Oomoo`02000AOol00`00Oomoo`09Ool001]oo`04001oogoo0002
Ool01000Oomoo`000Woo00D007ooOomoo`0000Moo`04001oogooOol200000goo001oo`0;Ool00`00
Oomoo`04Ool01000Oomoogoo0P001Goo00<007ooOol017oo00<007ooOol00goo00<007oo00000Woo
00<007oo00000Woo00<007ooOol01Goo00<007ooOol017oo00<007oo00000goo00D007ooOomoo`00
009oo`03001oogoo00Aoo`03001oogoo00Qoo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool02000Oomoo`00Ool007oo000;Ool01@00Oomoogoo00001Goo00@007ooOol000Ioo`07
001oogooOol007oo00001goo00<007ooOol00goo00@007ooOol000Aoo`05001oogooOol00004Ool0
0`00Oomoo`02000AOol00`00Oomoo`09Ool001]oo`04001oogoo0002Ool01000Oomoo`000Woo00D0
07ooOomoo`0000Moo`04001oogooOol200000goo001oo`0;Ool00`00Oomoo`04Ool01000Oomoogoo
0P001Goo00<007ooOol017oo00<007ooOol00goo00<007oo00000Woo00<007oo00000Woo00<007oo
Ool01Goo00<007ooOol017oo00<007oo00000goo00D007ooOomoo`00009oo`03001oogoo00Aoo`03
001oogoo00Qoo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`03Ool02000Oomoo`00
Ool007oo000;Ool01@00Oomoogoo00001Goo00@007ooOol000Ioo`07001oogooOol007oo00001goo
00<007ooOol00goo00@007ooOol000Aoo`05001oogooOol00004Ool00`00Oomoo`02000AOol00`00
Oomoo`09Ool001]oo`04001oogoo0002Ool01000Oomoo`000Woo0P000Woo00<007ooOol01Goo00P0
07ooOol007oo001oo`0037oo00<007ooOol017oo00@007ooOomoo`8000Eoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oo`00009oo`03001oo`00009oo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oo`0000=oo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`08Ool01@00Oomoogoo
00000Woo00<007ooOol017oo00<007ooOol00goo00P007ooOol007oo001oo`002goo00D007ooOomo
o`0000Eoo`04001oogoo0006Ool01`00Oomoogoo001oo`0000Moo`03001oogoo00=oo`04001oogoo
0004Ool01@00Oomoogoo000017oo00<007ooOol00P004Goo00<007ooOol02Goo000KOol01000Oomo
o`000Woo00@007ooOol0009oo`80009oo`03001oogoo00Eoo`08001oogoo001oo`00Ool000aoo`03
001oogoo00Aoo`04001oogooOol20005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00002
Ool00`00Ool00002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Ool00003Ool01@00Oomoogoo
00000Woo00<007ooOol017oo00<007ooOol027oo00D007ooOomoo`0000=oo`03001oogoo00=oo`03
001oogoo00=oo`08001oogoo001oo`00Ool000]oo`05001oogooOol00005Ool01000Oomoo`001Woo
00L007ooOomoo`00Ool00007Ool00`00Oomoo`04Ool00`00Ool00004Ool01@00Oomoogoo000017oo
00<007ooOol00P004Goo00<007ooOol02Goo000KOol200001Goo001oogoo00000goo0P0000Eoo`00
Oomoo`0000Moo`08001oogoo001oo`00Ool000aoo`03001oogoo00Aoo`04001oogooOol20005Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Ool00003Ool01@00Oomoogoo00000Woo00<007ooOol00goo00<007ooOol0
2Goo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo00=oo`08001oogoo001oo`00Ool0
00]oo`05001oogooOol00005Ool01000Oomoo`001goo00H007ooOol007oo0007Ool00`00Oomoo`04
Ool00`00Ool00004Ool01@00Oomoogoo000017oo00<007ooOol00P004Goo00<007ooOol02Goo000K
Ool01000Oomoo`000Woo00@007ooOomoo`800005Ool007ooOol00007Ool02000Oomoo`00Ool007oo
000<Ool00`00Oomoo`04Ool01000Oomoogoo0P001Goo00<007ooOol017oo00<007ooOol00goo00<0
07oo00000Woo00<007oo00000Woo00<007ooOol017oo00<007ooOol01Goo00<007oo00000goo00D0
07ooOomoo`00009oo`03001oogoo00=oo`03001oogoo00Uoo`05001oogooOol00003Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool02000Oomoo`00Ool007oo000;Ool01@00Oomoogoo00001Goo00<007oo
000027oo00H007ooOol007oo0007Ool00`00Oomoo`04Ool00`00Ool00004Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00<007ooOol03goo00<007ooOol02Goo000KOol01000Oomoo`000Woo00@0
07ooOomoo`800005Ool007ooOol00007Ool02000Oomoo`00Ool007oo000<Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00002Ool0
0`00Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Ool00003Ool01@00Oomoogoo0000
0Woo00<007ooOol00goo00<007ooOol02Goo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001o
ogoo00=oo`08001oogoo001oo`00Ool000]oo`05001oogooOol00005Ool00`00Ool00008Ool01P00
Oomoo`00Ool000Moo`03001oogoo00Aoo`03001oo`0000Aoo`03001oogoo009oo`05001oogooOol0
0003Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool001]oo`04001oogoo0002Ool01000Oomoogoo0P00
00Aoo`00Ool000Qoo`08001oogoo001oo`00Ool000aoo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oo`00009oo`03001oo`00009oo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol00goo00P007oo
Ool007oo001oo`002goo00D007ooOomoo`0000Eoo`03001oo`0000Qoo`06001oogoo001oo`001goo
00<007ooOol017oo00<007oo000017oo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo
00moo`03001oogoo00Uoo`006goo00@007ooOol0009oo`04001oogooOol20002Ool20008Ool02000
Oomoo`00Ool007oo000<Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol02Goo00D0
07ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo00=oo`08001oogoo001oo`00Ool000]oo`05
001oogooOol00006Ool20008Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol017oo00<0
07oo000017oo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00moo`03001oogoo00Uo
o`002goo00<007ooOol00Woo00@007ooOomoo`<000Aoo`04001oogoo0002Ool01000Oomoogoo0P00
0Woo0P0027oo00P007ooOol007oo001oo`0037oo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool00goo00<007ooOol017oo00<007ooOol00goo00<007oo00000Woo00<007oo00000Woo00D007oo
Oomoo`00009oo`03001oogoo00Eoo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol00goo00<007oo
00000Woo00<007oo00002goo00D007ooOomoo`0000Ioo`8000Qoo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol017oo00<007oo000017oo00<007ooOol00Woo00D007ooOomoo`0000=oo`03
001oogoo00moo`03001oogoo00Uoo`002Woo00<007oo00001goo00<007ooOol017oo00@007ooOol0
009oo`04001oogooOol20002Ool20008Ool02000Oomoo`00Ool007oo000=Ool01@00Oomoogoo0000
1Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo00<007oo00000Woo00<007oo0000
0Woo00D007ooOomoo`00009oo`03001oogoo00Eoo`03001oo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol0
0goo00<007oo00000Woo00<007oo00002goo00@007ooOol000Qoo`03001oogoo00Ioo`04001oogoo
0002Ool01000Oomoo`000goo00<007ooOol017oo00<007oo000017oo00<007ooOol00Woo00D007oo
Oomoo`0000=oo`03001oogoo00moo`03001oogoo00Uoo`002Woo00<007oo000027oo00<007ooOol0
0goo0P0000Eoo`00Oomoo`0000=oo`80009oo`8000Qoo`08001oogoo001oo`00Ool000eoo`04001o
ogoo0007Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00002Ool20003
Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007oo000017oo00<007oo000017oo00<007oo
Ool00Woo00<007ooOol02Goo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oo`00009oo`03001oo`0000]oo`04001oogoo0008Ool00`00Oomoo`06Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo00Eoo`8000Uoo`05001oogooOol0000EOol00`00Oomoo`09Ool0
00Yoo`03001oo`0000Qoo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoogoo0P000Woo0P00
27oo00P007ooOol007oo001oo`003Goo00@007ooOol000Moo`03001oogoo00=oo`03001oogoo00Ao
o`03001oogoo00=oo`03001oo`00009oo`8000=oo`05001oogooOol00002Ool00`00Oomoo`05Ool0
0`00Ool00004Ool00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`09Ool01@00Oomoogoo0000
0goo00<007ooOol00goo00<007ooOol00goo00<007oo00000Woo00<007oo000037oo00<007oo0000
4Goo00@007ooOol0009oo`03001oogoo0080009oo`03001oogoo00Eoo`8000Uoo`05001oogooOol0
000EOol00`00Oomoo`09Ool000Yoo`03001oo`0000Moo`03001oo`0000Aoo`06001oogoo001oo`00
17oo0P000Woo0P0027oo00P007ooOol007oo001oo`003Goo00<007oo000027oo00<007ooOol00goo
00<007ooOol017oo00<007ooOol00goo00<007oo00000Woo0P000goo00D007ooOomoo`00009oo`03
001oogoo00Eoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo00Uoo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool00002Ool00`00Ool0000<
Ool00`00Ool0000AOol01000Oomoo`000Woo00<007ooOol00P000Woo00<007ooOol01Goo0P002Goo
00D007ooOomoo`0001Ioo`03001oogoo00Qoo`002goo00<007ooOol01goo00<007ooOol00goo00@0
07ooOomoo`8000Aoo`03001oogoo009oo`03001oogoo00Ioo`08001oogoo001oo`00Ool000eoo`80
00Uoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oo`00009oo`8000=oo`05
001oogooOol00002Ool00`00Oomoo`05Ool00`00Ool00004Ool00`00Ool00004Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol017oo00<007oo
00000Woo00<007oo000037oo00<007oo00004Goo00@007ooOol0009oo`03001oogoo0080009oo`03
001oogoo00Eoo`8000Uoo`05001oogooOol0000FOol00`00Oomoo`08Ool001]oo`04001oogooOol2
0004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool02000Oomoo`00Ool007oo000=Ool20009Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool00002Ool20003Ool01@00Oomoogoo
00000Woo00<007ooOol01Goo0P001Goo00<007oo000017oo00<007ooOol00Woo00<007ooOol02Goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0000=oo`8000aoo`03
001oo`00015oo`04001oogoo0002Ool01`00Ool007oo001oo`0000Qoo`8000Uoo`05001oogooOol0
000FOol00`00Oomoo`08Ool001]oo`04001oogooOol20004Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool01@00Oomoo`00Ool00P003Woo00<007ooOol027oo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol017oo00<007oo00000Woo0P000goo00@007ooOomoo`800003Ool007oo00Ioo`8000Eoo`03
001oo`0000Aoo`03001oogoo009oo`03001oogoo00Uoo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Ool00003Ool2000<Ool00`00Ool0000AOol01000Oomoo`000Woo00L0
07oo001oo`00Ool00008Ool20009Ool01@00Oomoogoo00005Woo00<007ooOol027oo000KOol01000
Oomoogoo0P0017oo00<007ooOol02goo00D007ooOol007oo0080021oo`03001oogoo009oo`03001o
ogoo00Aoo`03001oo`00009oo`8000=oo`08001oogoo001oo`00Ool000Moo`8000Eoo`03001oo`00
00Aoo`03001oogoo009oo`03001oogoo00Uoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Ool00003Ool2000<Ool00`00Ool0000AOol01000Oomoo`000Woo00L007oo001o
o`00Ool00008Ool20009Ool01@00Oomoogoo00005Woo00<007ooOol027oo000KOol20002Ool20004
Ool00`00Oomoo`0;Ool01000Oomoo`000Woo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol0
17oo00<007oo00000Woo0P000goo00P007ooOol007oo001oo`001goo0P001Goo00<007oo000017oo
00<007ooOol00Woo00<007ooOol02Goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Aoo`03001oo`0000=oo`8000aoo`03001oo`00015oo`04001oogoo0002Ool00`00Ool00002Ool2
0008Ool20009Ool01@00Oomoogoo00005Woo00<007ooOol027oo000KOol01000Oomoogoo0P004Woo
00@007ooOol0009oo`03001oogoo01ioo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0000=o
o`05001oogooOol00002Ool01@00Ool007oo00001goo0P001Goo00<007oo000017oo00<007ooOol0
0Woo00<007ooOol02Goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Aoo`03001o
o`0000=oo`8000aoo`03001oo`00015oo`04001oogoo0002Ool00`00Ool00002Ool20009Ool00`00
Oomoo`07Ool01@00Oomoogoo00005Woo00<007ooOol027oo000KOol01000Oomoogoo0P004Woo00@0
07ooOol0009oo`03001oogoo01ioo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0000=oo`03
001oogoo009oo`07001oo`00Ool007oo00001goo0P001Goo00<007oo000017oo00<007ooOol00Woo
00<007ooOol02Goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`00
00=oo`8000aoo`03001oo`00019oo`03001oo`00009oo`03001oo`00009oo`8000Uoo`03001oogoo
00Moo`05001oogooOol0000FOol00`00Oomoo`08Ool001]oo`04001oogooOol2000COol00`00Ool0
0002Ool00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool00003Ool00`00Oomo
o`02Ool01`00Ool007oo001oo`0000Moo`8000Ioo`8000Aoo`03001oogoo009oo`03001oogoo00Uo
o`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool00003Ool2000<Ool0
0`00Ool0000BOol00`00Ool00002Ool00`00Ool00002Ool20009Ool00`00Oomoo`07Ool01@00Oomo
ogoo00005Woo00<007ooOol027oo000KOol01000Oomoogoo0P004goo00<007oo00000Woo00<007oo
Ool07Woo00<007ooOol00Woo00<007ooOol017oo00<007oo00000goo00<007ooOol00Woo00L007oo
001oo`00Ool00007Ool20006Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`09Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00<007ooOol017oo00<007oo00000goo00<007ooOol02goo00<007oo
00004Woo00<007oo00000Woo00<007oo00000Woo0P002Goo00<007ooOol01goo00D007ooOomoo`00
01Ioo`03001oogoo00Qoo`006goo00@007ooOomoo`8001=oo`8000=oo`03001oogoo01ioo`03001o
ogoo009oo`03001oogoo00Aoo`03001oo`0000=oo`03001oogoo009oo`07001oo`00Ool007oo0000
1goo0P001Woo0P001Goo00D007ooOomoo`0000]oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Ool00003Ool00`00Oomoo`0;Ool00`00Ool0000BOol00`00Ool00002Ool0
0`00Ool00002Ool2000COol01@00Oomoogoo00005Woo00<007ooOol027oo000KOol01000Oomoogoo
0P004goo0P000goo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol017oo00<007oo00000goo
00<007ooOol00Woo00L007oo001oo`00Ool00008Ool00`00Oomoo`04Ool20005Ool01@00Oomoogoo
00002goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0000=oo`03
001oogoo00]oo`03001oo`00019oo`03001oo`0000=oo`8000=oo`03001oogoo015oo`05001oogoo
Ool0000FOol00`00Oomoo`08Ool001]oo`80009oo`8001=oo`8000=oo`03001oogoo01ioo`03001o
ogoo009oo`03001oogoo00Aoo`03001oo`0000=oo`03001oogoo009oo`04001oo`00Ool20009Ool0
0`00Oomoo`04Ool20005Ool01@00Oomoogoo00002goo00D007ooOomoo`0000=oo`03001oogoo009o
o`03001oogoo00Aoo`03001oo`0000=oo`03001oogoo00]oo`03001oo`00019oo`03001oo`0000=o
o`8000=oo`03001oogoo015oo`04001oogoo000GOol00`00Oomoo`08Ool001]oo`04001oogooOol2
000COol20003Ool00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool00003Ool0
0`00Oomoo`02Ool01000Ool007oo0P002Goo00<007ooOol017oo0P001Goo00@007ooOol000aoo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool00003Ool00`00Oomoo`0;
Ool00`00Ool0000BOol00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0AOol01000Oomoo`00
5goo00<007ooOol027oo000KOol01000Oomoogoo0P004goo0P000goo00<007ooOol07Woo00D007oo
Oomoo`0000Moo`03001oo`0000=oo`03001oogoo009oo`04001oo`00Ool20009Ool00`00Oomoo`04
Ool20005Ool01000Oomoo`0037oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Ao
o`03001oo`0000=oo`03001oogoo00]oo`03001oo`00019oo`03001oo`0000=oo`03001oogoo009o
o`03001oogoo015oo`04001oogoo000GOol00`00Oomoo`08Ool001]oo`04001oogooOol2000COol2
000TOol01@00Oomoogoo00001goo00<007oo00000goo00<007ooOol00Woo00@007oo001oo`8000Uo
o`03001oogoo00Aoo`8000Eoo`04001oogoo000=Ool01000Oomoo`0017oo00D007ooOomoo`0000Io
o`03001oo`0000=oo`03001oogoo00]oo`03001oo`00019oo`03001oo`0000=oo`03001oogoo01Mo
o`03001oo`0001Moo`03001oogoo00Qoo`006goo00@007ooOomoo`8001=oo`8002Aoo`05001oogoo
Ool00007Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool20006Ool00`00Ool0000=Ool01000Oomoo`0017oo00D007ooOomoo`0000Ioo`03001o
o`0000=oo`03001oogoo00]oo`03001oo`00019oo`8000Aoo`03001oogoo01Moo`03001oo`0001Mo
o`03001oogoo00Qoo`006goo00@007ooOomoo`8001=oo`8002Aoo`04001oogoo0008Ool00`00Ool0
0003Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`07Ool00`00Oomoo`04Ool20006Ool0
0`00Ool0000=Ool01000Oomoo`0017oo00D007ooOomoo`0000Ioo`03001oo`0000=oo`03001oogoo
00aoo`03001oogoo015oo`8000Aoo`03001oogoo01Moo`03001oo`0001Moo`03001oogoo00Qoo`00
6goo0P000Woo0P004goo0P0097oo00@007ooOol000Qoo`03001oo`0000=oo`03001oogoo009oo`03
001oo`00009oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oo`0000eoo`04
001oogoo0004Ool01@00Oomoogoo00001Woo00<007oo00000goo00<007ooOol037oo00<007ooOol0
4Goo0P0017oo00<007ooOol05goo00<007oo000067oo00<007ooOol01goo000KOol00`00Oomoo`02
Ool00`00Oomoo`0AOol2000TOol01000Oomoo`0027oo00<007oo000027oo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007oo00003Goo00<007oo00001Goo00D0
07ooOomoo`0000Ioo`03001oo`0000=oo`03001oogoo00aoo`03001oogoo015oo`8001ioo`03001o
o`0001Qoo`03001oogoo00Moo`006goo00<007ooOol00Woo00<007ooOol04Goo0P0097oo00<007oo
00002Goo0P002Goo0P000goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007oo
00003Goo00<007oo00001Goo00D007ooOomoo`0000Ioo`03001oo`0000=oo`03001oogoo00aoo`03
001oogoo015oo`8001moo`8001Qoo`03001oogoo00Moo`006goo00<007ooOol00Woo00<007ooOol0
4Goo0P0097oo00<007oo00002Goo0P002Goo0P000goo00<007ooOol01goo00<007ooOol01Goo00<0
07ooOol017oo0P003Woo00<007oo00001Goo00@007ooOol000Moo`03001oo`00019oo`03001oogoo
015oo`8001moo`8001Qoo`03001oogoo00Moo`006goo00<007ooOol00Woo00<007ooOol04Goo0P00
97oo0P002Woo0P002Goo0P000goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol037oo00<007oo00001Woo00<007oo000027oo0P004Woo00<007ooOol04Goo0P007goo0P00
67oo00<007ooOol01goo000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`02
Ool00`00Oomoo`0AOol2000TOol2000;Ool00`00Oomoo`07Ool2000MOol00`00Oomoo`0<Ool00`00
Ool00006Ool00`00Ool00008Ool2000BOol00`00Oomoo`0BOol00`00Oomoo`0MOol2000HOol00`00
Oomoo`07Ool000Yoo`03001oo`0000Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo015o
o`8002Aoo`8000]oo`03001oogoo00Moo`8001eoo`03001oogoo00aoo`03001oo`0000Ioo`03001o
o`0000Qoo`80019oo`03001oogoo019oo`03001oogoo01eoo`8001Qoo`03001oogoo00Moo`002Woo
00<007oo00001goo10000goo0P000goo00<007ooOol04Goo0P0097oo00<007ooOol02Woo00<007oo
Ool01goo0P00;7oo00<007oo00001Woo00<007oo000027oo0P004Woo00<007ooOol04Woo00<007oo
Ool07Woo00<007ooOol05Woo00<007ooOol01goo000:Ool00`00Ool00007Ool00`00Ool00004Ool0
0`00Oomoo`02Ool00`00Oomoo`0AOol2000TOol00`00Oomoo`0:Ool00`00Oomoo`07Ool2000/Ool0
0`00Ool00006Ool00`00Ool00008Ool2000BOol00`00Oomoo`0BOol00`00Oomoo`0NOol00`00Oomo
o`0FOol00`00Oomoo`07Ool000Yoo`03001oo`0000Qoo`8000Aoo`03001oogoo009oo`03001oogoo
015oo`80035oo`03001oogoo00Moo`8002aoo`03001oo`0000Ioo`03001oo`0000Qoo`8002Moo`03
001oogoo01ioo`03001oogoo01Ioo`03001oogoo00Moo`002goo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol05Woo0P00<Goo00<007ooOol01goo0P00;7oo00<007oo00001Woo00<007oo0000
27oo0P009goo00<007ooOol0@Goo000KOol00`00Oomoo`0FOol2000aOol00`00Oomoo`07Ool2000/
Ool00`00Ool00007Ool00`00Oomoo`07Ool2000WOol00`00Oomoo`11Ool001]oo`03001oogoo01Io
o`80035oo`03001oogoo00Moo`8002aoo`03001oo`0000Moo`03001oogoo00Moo`03001oogoo02Io
o`03001oogoo045oo`006goo00<007ooOol05Woo00<007ooOol0<7oo00<007ooOol01goo0P00;7oo
00<007oo00001goo00<007ooOol01goo00<007ooOol0JWoo000KOol2000GOol00`00Oomoo`0`Ool0
0`00Oomoo`07Ool2000/Ool00`00Ool00007Ool00`00Oomoo`07Ool00`00Oomoo`1ZOol001]oo`03
001oogoo01Ioo`03001oogoo031oo`03001oogoo00Moo`8002aoo`03001oo`00015oo`03001oogoo
06Yoo`006goo00<007ooOol05Woo00<007ooOol0<7oo00<007ooOol01goo0P00;Goo0P004Goo00<0
07ooOol0JWoo000KOol00`00Oomoo`0FOol00`00Oomoo`0`Ool00`00Oomoo`07Ool2000]Ool2000A
Ool00`00Oomoo`1ZOol001]oo`03001oogoo01Ioo`03001oogoo031oo`03001oogoo00Moo`03001o
ogoo02eoo`03001oogoo00moo`03001oogoo06Yoo`006goo00<007ooOol05Woo00<007ooOol0<7oo
00<007ooOol01goo00<007ooOol0;Goo00<007ooOol03goo00<007ooOol0JWoo000KOol00`00Oomo
o`0FOol00`00Oomoo`0`Ool00`00Oomoo`07Ool00`00Oomoo`0oOol00`00Oomoo`1ZOol001]oo`80
01Moo`03001oogoo031oo`03001oogoo00Moo`03001oogoo03moo`03001oogoo06Yoo`006goo00<0
07ooOol05Woo00<007ooOol0<7oo00<007ooOol01goo00<007ooOol0?goo00<007ooOol0JWoo000K
Ool00`00Oomoo`0FOol00`00Oomoo`0`Ool00`00Oomoo`07Ool00`00Oomoo`0oOol00`00Oomoo`1Z
Ool001]oo`03001oogoo04Uoo`03001oogoo00Moo`03001oogoo03moo`03001oogoo06Yoo`006goo
00<007ooOol0BGoo00<007ooOol01goo00<007ooOol0?goo00<007ooOol0JWoo000KOol00`00Oomo
o`19Ool00`00Oomoo`07Ool00`00Oomoo`0oOol00`00Oomoo`1ZOol001]oo`03001oogoo09Eoo`03
001oogoo06Yoo`006goo0P00UWoo00<007ooOol0JWoo000KOol00`00Oomoo`3oOol3Ool001]oo`03
001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.15196, -0.674606, 
  0.078833, 0.00732332}},
  CellTags->"4.2"]
}, Open  ]],

Cell[TextData[{
  "Although ",
  StyleBox["SimulationPlot", "MR"],
  " generates only ",
  StyleBox["output", "TI"],
  " response curves, it is a simple matter to get it to plot the ",
  StyleBox["state", "TI"],
  " response as well (by adding an appropriate matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " to the ",
  StyleBox["StateSpace", "MR"],
  " object composed of only matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ").  In the rest of this section we give an example of how this can be \
done. \nLet us consider the linearized state\[Hyphen]space system for the \
depth control problem of a submarine (see Figure\[NonBreakingSpace]4.3) for \
small angles ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " and constant velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v = 25\)], "InlineFormula",
    CellTags->"S0.0.3"],
  "\[NonBreakingSpace]ft/s as described in Dorf (1992). We will assume that \
the state variables are ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1 = \[Theta], x\_2 = \[Theta]\& . \)], 
    "InlineFormula",
    CellTags->"S0.0.3"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_3 = \[Alpha]\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " is the angle of attack and the input variable ",
  Cell[BoxData[
      \(TraditionalForm\`u\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_s\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ", the deflection of the stern plane. We will compute the state response of \
the system to a step command for the stern plane of ",
  Cell[BoxData[
      \(TraditionalForm\`0.3  deg\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " from zero initial conditions using the discrete\[Hyphen]time \
approximation with sampling period ",
  Cell[BoxData[
      \(TraditionalForm\`2\)], "InlineFormula",
    CellTags->"S0.0.3"],
  "\[NonBreakingSpace]seconds.      \n",
  Cell["", "Message",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    CellTags->"S0.0.3"],
  "   "
}], "Text",
  CellTags->"4.2"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 402 119
%%HiResBoundingBox: 47 4 402 119
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (11:27:14 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 123 translate 1 -1 scale
gsave
47 119 translate
355 -115 scale
1 string
1410 457 1 [1410 0 0 457 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFD5FFFFFFFFFFFFD87FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFEFFFFFFFFFFFFDE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFDC7FFFFFFFFFFF1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFEFFFFFFFFFFFF3F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFCFFFFFFFFFFFE3FC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFAFF9FFFFFFFFFFFE3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFE01F1FFFFFFFFFFF07FF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFEFBF3FFFFFFFFFFF8FFF87FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFCFCF7BFFFFFFFFFF07FFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFF8FCFBBFFFFFFFFFE0FFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFF1FC7D7FFFFFFFFFC1FFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFF9FCFFFFFFFFFFFF83FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFF1FC7FFFFFFFFFFF01FFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFF9FCFFFFFFFFFFFE03FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFDFC7FFFFFFFFFFC03FFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFEF8FFFFFFFFFFF803FFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFC71FFFFFFFFFFF007FFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFA3FFFFFFFFFFE00FFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFC7FFFFFFFFFFC007FFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFF8FFFFFFFFFFF800FFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFF1FFFFFFFFFFF001FFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFE7FFFFFFFFFFE003FFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFC73FFFFFFFFFC001FFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFEFFFFFFFFFFF8003FFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFF4FFFFFFFFFF0007FFFFFFFFF87FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFE0807FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFC1807FFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFEF90FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFF9F10FFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFE38FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFF7E71FFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFE7BFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFC71FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFF8FBFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFF1F7FFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFF1F7FFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFF47FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFF7FE3FFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFE0FE7FFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFE01C7FFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFE02FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFE3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFC0
7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFE0
2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFC0
01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFF80
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFD01FFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFF80
0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFF82
0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFC7FFFFFFF03
C0005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFE3FFFFFFF83
F8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFFFFFFFFFF07FFFFFF07
FE00017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFF87FFFFFE07
FFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFC1FFFFFE07
FFF00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFE1FFFFFE0F
FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF017FFFFFFFFFFFFFFFFFFF07FFFFC07
FFFFC0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFE3FFFFE0F
FFFFFA0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFC1FFFFC1F
FFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFF8FFFF81F
FFFFFFE8002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFC7FFF81F
FFFFFFFC0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFF83F
FFFFFFFFA000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFF1FFF01F
FFFFFFFFF0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFF8FFF83F
FFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFFFFC7FF07F
FFFFFFFFFF407FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFE3FF07F
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FE07F
FFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFF8FE0FF
FFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF817FFFFFFFFFFFFFC1C07F
FFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFF1E0FF
FFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC05FFFFFFFFFFFFF841FF
FFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFE01FF
FFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF017FFFFFFFFFFFE01FF
FFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFF83FF
FFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFABFFFFFFFFFFFFFFBFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC05FFFFFFFFFFF01FF
FFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFF83FF
FFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FBFFFFFFFFFFFFFA7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF017FFFFFFFFF01FF
FFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFE7FDFFFFFFFFFFFFFF7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFF00FF
FFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC05FFFFFFFF043F
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFB51FFFFFFFFFFFFFF9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFE0E3F
FFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FE0FF8BEAEBE3E0FABFFF8BEAFFF803ABE3CFFFFAFEFFBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFC0707
7FFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F171F01F1E3C5C07C7FFC7DF1FFF007C7C407F7F8781F9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFE0F8E
3FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E3FEE3EF3E3CF8FBCFFFEFEF3FFFBFFCFCF9FE3F8F9FF9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC05FFFFC1FDC
1FFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C7FF43F71F3CF1FDC7FFCFC71FFFDFFC7CF9FE1FCF9FF0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFC1FF8
0FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8FFFE7FF3E3CF9FFCFFF8FE73FFFEBFCFEF9FE3F8F9FF2FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FF81FF0
03FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0FFFC7FF1F3CF1FFC7FF1FE71FFFC47C7E79FC5FCF9FE37FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FF83FE0
03FFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFEFFF3E3CFBFFCFFF9FE73FFF9E3CFFB9F8EF8F9FE37FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC05F01FF0
00FFFFFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFC7FF1F3CF1FFC7FF1FC71FFF1F3C7FD1F9CFCF9FC77FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80F83FF8
007FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFE00F3E3CF803CFFF9FE73FFFBF3CFEF9F9EF8F9FCFBFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFC
001FFFFFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFE7C71F3CF1F1C7FFDFC71FFF1E3C7C79F1F7CF9FC7BFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFE
000FFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFEF8F3E3CFBE3C6FFEF8F3FFFBE3C6EF9F3F78F9F8FBFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
0007FFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF
1FFFF31C047C5DC7007FC71D17FFDC100671F1F30F171FDFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFF
8003FFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8FFFFA3FB8F8BE8FEEFFFABE2FFFEAFEEFABEBEBEF8AAFAFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FF
C001FFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F
0FFF7FFFFFFCFFFFFFFFFFFF1FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0EFFF
F000FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8FFEFFFFFFFEFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFF1
F0007FFFFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C7FC7FFFFFFEFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFF8
FC003FFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
E3FCFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFF0
040007FFFFFFFC03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFF
F1707FFFFFFFFFFFFFFFFFFF98FFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFF
0F0007FFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FE0BFFFFFFFFFFFFFFFFFFFFEBFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFF
DF8001FFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFF
FFE001FFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF
FFE0007FFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF
FFF0003FFFFFFFF0002BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF
FFFC001FFFFFFFFC000017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFF
FFFE000FFFFFFFFE000000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFF
FFFF0007FFFFFFFF400000017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFF
FFFF8003FFFFFFFFF80000002BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF
FFFFC0001FFFFFFFFF500000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF
FFFFE0000FFFFFFFFFFFA0000002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF
FFFFF000007FFFFFFFFFFD00000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFF
FFFFFE00383FFFFFFFFFFFFA000000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFF
FFFFFE000D01FFFFFFFFFFFFD0000001FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFF
FFFFFF800FE0FFFFFFFFFFFFFE8000002FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFF
FFFFFFC001F007FFFFFFFFFFFFF40000007FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFF
FFFFFFE001FF83FFFFFFFFFFFFFFE000000BFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFF
FFFFFFF0007FD01FFFFFFFFFFFFFFD0000005FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFF
FFFFFFF8003FFE0BFFFFFFFFFFFFFFF8000003FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFF
FFFFFFFC001FFF407FFFFFFFFFFFFFFF40000017FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFF
FFFFFFFE000FFFF83FFFFFFFFFFFFFFFFA000002FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFF
FFFFFFFF001FFFFD01FFFFFFFFFFFFFFFFD0000005FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF
FFFFFFFFC03FFFFFE0BFFFFFFFFFFFFFFFFE800000BFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFF
FFFFFFFFC03FFFFFF407FFFFFFFFFFFFFFFFF40000017FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFF
FFFFFFFFF07FFFFFFF83FFFFFFFFFFFFFFFFFFA000002FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFF
FFFFFFFFF8FFFFFFFFD01FFFFFFFFFFFFFFFFFFD0000007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFF
FFFFFFFFFEFFFFFFFFFE0BFFFFFFFFFFFFFFFFFFE800000FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFF
FFFFFFFFFFFFFFFFFFFF41FFFFFFFFFFFFFFFFFFFF0000005FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFF
FFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFA000003FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFF
FFFFFFFFFFFFFFFFFFFFFDFDFFFFFFFFFFFFFFFFFFFFC000001FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFEBFFFFFFFFFFFFFFFFFFFFE800002FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFC0000017FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFA2BFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFF800002FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFF
FFFFFFFFFF00005FFFFFFFFFD3FFFFFFFFFFFFFFFFFFFFFFD0000007FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFF
FFFFFFFFFE00000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFF
FFFFFFFFF0000001FFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFF4000005FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFF
FFFFFFFFE0000000FFFFFFFFFFF82FFFFFFFFFFFFFFFFFFFFFFFA000003F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFF
FFFFFFFF000150001FFFFFFFFFFD01FFFFFFFFFFFFFFFFFFFFFFFC000001
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFF
FFFFFFFE003FFE800FFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFE80000
2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4001FFFFF
FFFFFFFC007FFFC001FFFFFFFFFFF407FFFFFFFFFFFFFFFFFFFFFFFC0000
017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFF
FFFFFFF803FFFFF8003FFFFFFFFFFF82FFFFFFFFFFFFFFFFFFFFFFFFF800
002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFF
FFFFFFC007FFFFFC001FFFFFFFFFFFD01FFFFFFFFFFFFFFFFFFFFFFFFD00
00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFF
FFFFFFC03FFFFFFF8003FFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFF8
00000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFF
FFFFFF007FFFFFFFC0007FFFFFFFFFFF407FFFFFFFFFFFFFFFFFFFFFFFFF
4000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FF
FFFFFF00FFFFFFFFFA003FFFFFFFFFFFF82FFFFFFFFFFFFFFFFFFFFFFFFF
FA00000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FF
FFFFFC01FFFFFFFFFF0007FFFFFFFFFFFD01FFFFFFFFFFFFFFFFFFFFFFFF
FFC000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003F
FFFFFC07FFFFFFFFFFC003FFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFF
FFFE00000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007
FFFFF007FFFFFFFFFFF0007FFFFFFFFFFFF407FFFFFFFFFFFFFFFFFFFFFF
FFFFC000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA003
FFFFF01FFFFFFFFFFFFE003FFFFFFFFFFFFF82FFFFFFFFFFFFFFFFFFFFFF
FFFFFE800003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000
7FFFE01FFFFFFFFFFFFF0007FFFFFFFFFFFFD01FFFFFFFFFFFFFFFFFFFFF
FFFFFFD000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00
3FFFE07FFFFFFFFFFFFFE000FFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFF
FFFFFFFE800003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
07FFC07FFFFFFFFFFFFFF0007FFFFFFFFFFFFF407FFFFFFFFFFFFFFFFFFF
FFFFFFFFF0000017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
02FF80FFFFFFFFFFFFFFFE000FFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFF
FFFFFFFFFF800003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0
001F01FFFFFFFFFFFFFFFF8001FFFFFFFFFFFFFF01FFFFFFFFFFFFFFFFFF
FFFFFFFFFFF0000017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
000E03FFFFFFFFFFFFFFFFE000FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFF
FFFFFFFFFFFF800002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
400007FFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFF407FFFFFFFFFFFFFFFF
FFFFFFFFFFFFF4000007FFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0000FFFFFFFFFFFFFFFFFFF000FFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFA00002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FC001FFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFF01FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF4000017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF803FFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFE03FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFA00000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFC01FFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFF407FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF4000007FFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF83FFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA00000BFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFC7FFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFF7FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC000005FFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFBFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE00000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFC0017FFFFFFFFFFFFFFFF07FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFC000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFFFFA0FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE00000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFD001FFFFFFFFFFFFFFFFF0FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFD000005FFFFFFFFFFFFFFFFDFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE80000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFF7FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFD000005FFFFFFFFFFFFFF7FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA003FFFFFFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE80000BFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFF01FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFD000005FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFE03FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE80000BFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFC05FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFD000007FFFFFFFFFDFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFA0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE80000BFFFFFFFFBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFF01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD000005FFFFFFF7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE002FFFFFFFFFFFFFFFFFFE03FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE80000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFFC05F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD000007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE002FFFFFFFFFFFFFFFFFFFA0F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000BFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFFF01
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD000005FFDFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFFFFFFFFFFFFFFE8
3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE80000FFBFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4005FFFFFFFFFFFFFFFFFFFC
05FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0000077FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFFFFFFFFFFFFFFF
A0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000BFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFF
F01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD000007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE800FFFFFFFFFFFFFFFFFFF
FE83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE80000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFF
FFC05FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFF
FFFA0BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFF
FFFF017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5000017FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFF
FFFFE83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE80000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFF
FFFFFC05FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000007FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFF
FFFFFFA0BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00003FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFF
FFFFFFF017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFD00001FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFF
FFFFFFFE83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFE00002FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0017FFFFFFFFFFFFF
FFFFFFFFC05FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFF400001FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFF
FFFFFFFFFA1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA00003FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD001FFFFFFFFFFFFF
FFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00001FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFF
FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA0000BFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFF400005F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA003FFFFFFFFFFF
FFFFFFFFFFFFE0BFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFA0000B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFF
FFFFFFFFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFF00000
7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFF
FFFFFFFFFFFFFEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0007FFFFFFFFF
FFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000
007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FFFFFFFFF
FFFFFFFFFFFFFFFF8BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00007FFFFFFFF
FFFFFFFFFFFFFFFFC17FFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFD0
0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0E003FFFFFFFF
FFFFFFFFFFFFFFFFE82FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
00003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1F0007FFFFFFF
FFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFF
C00005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FE003FFFFFFF
FFFFFFFFFFFFFFFFFFA0BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FA00003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF0007FFFFFF
FFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFC00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFE000FFFFFF
FFFFFFFFFFFFFFFFFFFE82FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF80000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFF0007FFFFF
FFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFF
FFFF000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFE002FFFFF
FFFFFFFFFFFFFFFFFFFFFA03FFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFF
FFFFF80003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFF8007FFFF
FFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFF
FFFFFD00001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFE007FFFF
FFFFFFFFFFFFFFFFFFFFFFF82FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE8000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFF407FFFF
FFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFF0FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFCFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF400017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF807FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF82FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF80002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFF7FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF00001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFA03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE00003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF415FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF40001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800BFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FF003FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF80003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07C001FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFD00005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80C001FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000007FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC00017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8002FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0000BFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0001FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000005FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000000BFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000000003FC03F800000
000000000000007F007F000000000000000000007F007F00000000000000
000001FE01FE00000000000000000001FC01FC0000000000000001FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000000003F803F800000
000000000000007F807F80000000000000000000FF00FF00000000000000
000000FE00FE00000000000000000003FE03FE0000000000000003FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0001F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFD555550000000000000017D57FD55555
555555555555557FD57FD5000055555555555555FF55FF55555555555555
555555FF55FF55555555555555555555FD55FD5555555555055557FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000000BFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0000
7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000057FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000
3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80008000000000000000BFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000
05FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001F5000000000000000017FF
FFFFFFFFFFFFFFFFFFFFFFFFF0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFF80000000000000000AF
FFFFFFFFFFFFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
0017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF407FFFF000000000000000000
17FFFFFFFFFFFFFFFFFFFFFFFF40007FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03EA0000000000000
00AFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FD000000000000
000015FFFFFFFFFFFFFFFFFFFFFD0005FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFEA000000000
000000AFFFFFFFFFFFFFFFFFFFFFE000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FC00017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF017FFFD00000000
0000000015FFFFFFFFFFFFFFFFFFF0001FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFA0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFEA00000
00000000002FFFFFFFFFFFFFFFFFFE000BFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF00005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFD0000
00000000000015FFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFEA0
000000000000002FFFFFFFFFFFFFFFE8003FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF017FFFFFFFFD
400000000000000005FFFFFFFFFFFFFC0007FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFA0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFF
FFA0000000000000002BFFFFFFFFFFFF8003FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFF
FFFD400000000000000015FFFFFFFFFFD0007FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFF
FFFFFFA0000000000000002BFFFFFFFFF8003FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF017FFFFFF
FFFFFFFD400000000000000005FFFFFFFF0007FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFA0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFF
FFFFFFFFFFA0000000000000002BFFFFFFA003FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF00001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFF
FFFFFFFFFFFD400000000000000005FFFFF0007FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFF
FFFFFFFFFFFFFFA8000000000000000BFFFE003FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF017FFF
FFFFFFFFFFFFFFFF4000000000000000057F0007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFA0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFF
FFFFFFFFFFFFFFFFFFA8000000000000002BE003FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC05FF
FFFFFFFFFFFFFFFFFFFF500000000000000000007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FF
FFFFFFFFFFFFFFFFFFFFFFE800000000000000003FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFC00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF017
FFFFFFFFFFFFFFFFFFFFFFFF4000000000000000057FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFA0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03
FFFFFFFFFFFFFFFFFFFFFFFFFFA8000000000000000BFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF00001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1
FFFFFFFFFFFFFFFFFFFFFFFFFFFF5000000000000000017FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8000000000000000AFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FD7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF5000000000000000017FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEA0000000000000002FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FC05FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD000000000000000015FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEA000000000000000AFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFD00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD000000000000000015F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000002
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFC0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFC5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000
015FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5FFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF8000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00EA000000000000
0002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FD40000000000
0000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFE0002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA00FFFFA00000000
00000002BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFC0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC05FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFD4000000
00000000015FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFF
FFFFFFFFFFFFFF9FFC1F07F17F01C1F1FF7FFF9FFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF80003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFA0000
000000000002BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFF
FFFFFFFFFFFFFFBFF827CFCFBE09F3E2FE3FFF8FFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFD400
0000000000000057FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFF
FFFFFFFFFFFFFF1FF073CF9FDC1CF3E77E3FFF87FFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFA
0000000000000002BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFF
FFFFFFFFFFFFFF1FF9FBCFBFCE3FF3E3FE3FFF9FFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC00001FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFF
F400000000000000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFF
FFFFFFFFFFFFFE0FF1FDCF1FC47FF3E7FC5FFF9BFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC380003FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFF
FFFA8000000000000000BFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFF
FFFFFFFFFFFFFE2FF3FFCF3FECFFF3E3F8DFFF9FFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1F00005FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFF
FFFFF4000000000000000057FFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFFFFFFFFC67F3FFCF1FC47FF3E7F9DFFF1DFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FF0000BFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFF
FFFFFFFA8000000000000000BFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFF
FFFFFFFFFFFFFC77F3FFCF3FCEFFF3E3F9EFFFBEFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFC00017FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFF
FFFFFFFFF5000000000000000057FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFFFFFFFFC77F001CF1FCC7DF3E7F1EFFF1F7FFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFE0002FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFA0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFF
FFFFFFFFFFFE8000000000000000BFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFFFFFFFF8FBFBE3CFBF8EFCF3E3F3EFFFBE7FFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFF00001FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFF
FFFFFFFFFFFFF4000000000000000057FFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFFFFFFFF0F3FDE7CFDF1F7C73E7E3F7FF1C7FFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFF8000BFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFF
FFFFFFFFFFFFFFFE8000000000000000BFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFFFFFFFF1FBFEAFCFEF3FB9E3E2E3F3FE3E7FFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFD00007FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFF
FFFFFFFFFFFFFFFFF5000000000000000017FFFFFFFFFFFC7FFFFFFFFFFF
FFFFFFFFFFFFF1FDFF1FCFF17FC5F3C1D5D5FFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFE0002FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFA0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFF
FFFFFFFFFFFFFFFFFFFE8000000000000000AFFFFFFFFFFEFFFFFFFFFFFF
FFFFFFFFFFFFE3FDFFFFCFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFF40001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFF
FFFFFFFFFFFFFFFFFFFFF5000000000000000017FFFFFFFC7FFFFFFFFFFF
FFFFFFFFFFFFC3FCFFFFCFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF80003FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFEA0000000000000002FFFFFFEFFFFFFFFFFFF
FFFFFFFFFFFFE3FEFFFFCFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFD00007FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFD000000000000000015FFFC7FFFFFFFFFFF
FFFFFFFFFFFFC7FC7FFFCFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFE0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFA0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEA000000000000000AFFEFFFFFFFFFFFF
FFFFFFFFFFFF87FE7FFF8FFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF400017FFFFFFFFFFF7FFFF
FFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7FD0000000000000000147FFFFFFFFFF1
7FFFFFFFFFFF55F55FFFCFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFF80003FFFFFFFFFFFAFFFF
FFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFA0000000000000002FFFFFFFFFF0
3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF00005FFFFFFFFFF01FFF
FFFFFFFFFFFFFFFFFFFFFFD07FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFD000000000000000015FFFFFFF0
05FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFE0000FFFFFFFFFF00BFF
FFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFF807FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFEA0000000000000002FFFFFF8
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFC00007FFFFFFFE0007F
FFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFD400000000000000005FFFC
0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFA0003FFFFFFFE0003F
FFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFA0000000000000002BFE
0002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFF00001FFFFFFFC0005
FFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFF007FFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFD400000000000000015
00001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFE8000FFFFFFFE8000
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFC03FFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFA800000000000000
000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFC00007FFFFFFC000
17FFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFE01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFF40000000000000
0000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFA0003FFFFFFF800
03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF9A00000000000
0000000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFF00001FFFFFFC00
007FFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFC03FF
FFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF1FF4000000000
000000017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFF8000BFFFFFF80
000FFFFFFFFFFFFFFFFFFFFFFFFFFE0BFFFFFFFFFFFFFFFFFFFFFFFE03FF
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF9FFFFA8000000
000000002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC00007FFFFFC0
0001FFFFFFFFFFFFFFFFFFFFFFFFFF407FFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFF1FFFFFF400000
0000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFE0002FFFFFF8
00003FFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFF80FF
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFBFFFFFFFFA800
00000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFC0001FFFFFC
000007FFFFFFFFFFFFFFFFFFFFFFFFFD01FFFFFFFFFFFFFFFFFFFFFFC03F
FFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFF1FFFFFFFFFF50
000000000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFF80003FFFFE
020002FFFFFFFFFFFFFFFFFFFFFFFFFFE0BFFFFFFFFFFFFFFFFFFFFFE03F
FFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFE
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF000015540
07C0001FFFFFFFFFFFFFFFFFFFFFFFFFF407FFFFFFFFFFFFFFFFFFFFF00F
FFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFF4
00000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFE00000000
03F8000BFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFF80F
FFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFE0
00000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC0000000
07FF00017FFFFFFFFFFFFFFFFFFFFFFFFFD01FFFFFFFFFFFFFFFFFFFFC07
FFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF3FFFFFFFFFF00
000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFA8000000
0FFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFE0BFFFFFFFFFFFFFFFFFFFE03
FFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFF00
000000000000000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFF03000000
5FFFF40005FFFFFFFFFFFFFFFFFFFFFFFFFF407FFFFFFFFFFFFFFFFFFF01
FFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFFFFFFFF3FFFFFFFFFF50
00000000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFF83FAAAAF
FFFFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFF82FFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFF
FFFEAAA0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFF
FFFFFFD0001FFFFFFFFFFFFFFFFFFFFFFFFFFD01FFFFFFFFFFFFFFFFFFC0
7FFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFF
FFFFFFFFD554000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFF
FFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFE0BFFFFFFFFFFFFFFFFFE0
3FFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFABFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFF
FFFFFFFF40007FFFFFFFFFFFFFFFFFFFFFFFFFF407FFFFFFFFFFFFFFFFF0
1FFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFF
FFFFFFFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFF82FFFFFFFFFFFFFFFFF8
3FFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFF
FFFFFFFFFD0001FFFFFFFFFFFFFFFFFFFFFFFFFFD01FFFFFFFFFFFFFFFF8
0FFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFE0BFFFFFFFFFFFFFFFC
0FFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC017FFFFFFFFFFFFFFFFFFFFFE07FFFFFF
FFFFFFFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFF407FFFFFFFFFFFFFFC
07FFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFF0002FFFFFFFFFFFFFFFFFFFFFFFFFFF82FFFFFFFFFFFFFFE
03FFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFFFFE07FFFFFF
FFFFFFFFFFFFC0001FFFFFFFFFFFFFFFFFFFFFFFFFFD01FFFFFFFFFFFFFF
01FFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFF8000BFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFF
83FFFFFFFFFFFFFFFFFFFFFE321FFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFFFFFFFFFFFFC0FFFFFFF
FFFFFFFFFFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFF407FFFFFFFFFFFF
81FFFFFFFFFFFFFFFFFFFFFC731FFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFA000FFFFFFFFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFE0002FFFFFFFFFFFFFFFFFFFFFFFFFFF82FFFFFFFFFFFF
C0FFFFFFFFFFFFFFFFFFFFFEE39FFFFABEFFFFFFFFFFFF8FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF0001FFFFFFFFFFFFFFFFFFC1FFFFFFF
FFFFFFFFFFFFFFFC0001FFFFFFFFFFFFFFFFFFFFFFFFFFD01FFFFFFFFFFF
C07FFFFFFFFFFFFFFFFFFFFDE79FFFF1DC7FFFFFFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFFFFFFFFFFFFFC0FFFFFFF
FFFFFFFFFFFFFFFF80003FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFF
E0FFFFFFFFFFFFFFFFFFFFFBE79FFFE7EB7FFFFFFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF40017FFFFFFFFFFFFFFFFC1FFFFFFF
FFFFFFFFFFFFFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFFFFFFFF
E07FFFFFFFFFFFFFFFFFFFF3C7DFFFC7E37FFFFFFFFFFF1FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFFFFFFFFFFF81FFFFFFF
FFFFFFFFFFFFFFFFFE0002FFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFF
F03FFFFFFFFFFFFFFFFFFFFFE7DFFF8FE3FFFFFFFFFFFFBFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFFFFFFFF81FFFFFFF
FFFFFFFFFFFFFFFFFFC0001FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFF
F03FFFFFFFFFFFFFFFFFFFF7C7DFFF87F3FFFFFFFFFFFF1FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFFF83FFFFFFF
FFFFFFFFFFFFFFFFFFF80003FFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFF
F83FFFFFFFFFFFFFFFFFFFFFCFFFFF8FF3FFFFFFFFFFFFBFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFFFFFFF01FFFFFFF
FFFFFFFFFFFFFFFFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFF41FFFFFFF
F01FFFFFFFFFFFFFFFFFFFFFC7FFFF87F1FFFFFFFFFFFF1FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA000FFFFFFFFFFFFFF83FFFFFFF
FFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFF
F83FFFFFFFFFFFFFFFFFFFFF8FFFFF8FE3FFFFFFFFFFFF3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0001FFFFFFFFFFFFF03FFFFFFF
FFFFFFFFFFFFFFFFFFFFFC0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF
F81FFFFFFFFFFFFFFFFFFFFFCFFFFFC7E1FFFFFFFFFFFF3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFFFFFFFF83FFFFFFF
FFFFFFFFFFFFFFFFFFFFFF80003FFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFF
F81FFFFFFFFFFFFFFFFFFFFF8FFFFFE7E9FFFFFFFFFFFE3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF40017FFFFFFFFFFF07FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF00005FFFFFFFFFFFFFFFFFFFFFFFFFFC07FFF
FC1FFFFFFFFFFFFFFFFFFFFF9FFFFFE7D1FFFFFFFFFFFE7FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFFFFFF07FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFE0000BFFFFFFFFFFFFFFFFFFFFFFFFFF80FFF
FC1FFFFFFFFFFFFFFFFFFFFF9FFFFFFABAFFFFFFFFFFFE3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFFF07FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFC00017FFFFFFFFFFFFFFFFFFFFFFFFFF01FF
FC1FFFFFFFFFFFFFFFFFFFFF1FFFFFFDFFFFFFFFFFFFFC7FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFE0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFA0002FFFFFFFFFFFFFFFFFFFFFFFFFFE03F
FC1FFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFE07FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00001FFFFFFFFFFFFFFFFFFFFFFFFFF407
FC1FFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA000FFFFFFFFE0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF80003FFFFFFFFFFFFFFFFFFFFFFFFFF80
F81FFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0001FFFFFFFC0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFD00005FFFFFFFFFFFFFFFFFFFFFFFFFF0
1C1FFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFFC0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFFFFFFFFFFFFFFFFFFFE
003FFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF40017FFFFFC1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF400007FFFFFFFFFFFFFFFFFFFFFFFFF
401FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA0003FFFFFFFFFFFFFFFFFFFFFFFFF
F80FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00001FFFFFFFFFFFFFFFFFFFFFFFF
F001FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE80003FFFFFFFFFFFFFFFFFFFFFFF
F0203FFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00005FFFFFFFFFFFFFFFFFFFFFF
F07407FFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA000FFE07FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA0000BFFFFFFFFFFFFFFFFFFFFF
E07FA0FFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFBFFFFFFFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0001F007FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00007FFFFFFFFFFFFFFFFFFFF
E07FF01FFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF1FFFFFFF71FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000000FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000FFFFFFFFFFFFFFFFFFFF
E0FFFE03FFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF3FFFFFFEF9FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000001FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000007FFFFFFFFFFFFFFFFFF
C0FFFFC07FFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFF3FFFFFFC7CFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00003FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000BFFFFFFFFFFFFFFFFF
80FFFFFA0FFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFE3FFFFFF8FCFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD000007FFFFFFFFFFFFFFFF
81FFFFFF01FFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFF3FFFFFFCFC7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE80000BFFFFFFFFFFFFFFF
83FFFFFFE03FFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFE7FFFFFF8FEFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF57FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000005FFFFFFFFFFFFFF
03FFFFFFFC05FFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFC7FFFFFF8FC7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000002FFFFFFFFFFFFE
03FFFFFFFFA0FFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFE7FFFFFF8FE7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD00000015FFFFFFFFFC
07FFFFFFFFF01FFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFC7FFFFFF8FC7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE80000000AAFFFFFE0
0FFFFFFFFFFE83FFFFFFFFE7FFFFFFFFFFFFFFFFFFFBCFFFFFFF8007FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0000000000000000
1FFFFFFFFFFFC7FFFFFFFFC7FFFFFFFFFFFFFFFFFFFBC7FFFFFF8FC7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA00000000000000
3FFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFB8FEFFFFF8FE7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF40000000000000
7FFFFFFFFFFFFFF1FFFFFFC7FFFFFFFFFFFFFFFFFFF19FDFFFFF8FC7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA00000000000
FFFFFFFFFFFFFFF83FFFFF8FFFFFFFFFFFFFFFFFFFFB8FBFFFFF8FEFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5400000007
FFFFFFFFFFFFFFFC07FFFF8FFFFFFFFFFFFFFFFFFFF11F3FFFFFC7C7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAABFF
FFFFFFFFFFFFFFFFAFFFFF9FFFFFFFFFFFFFFFFFFFF19E3FFFFFEF8FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFF01C7FFFFFC79FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3FFBFFFFFFFFFFFFFFFFFFFF038FFFFFFFBBFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF05F1FFFFFFFFFFFFFFFFFFFF000FFFFFFFD7FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFA0B3FFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFE001FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE83FFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFC05FFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFA0BFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF017FFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFE83FFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFC05FFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFA0BFFFFFFFFFFFFFFC03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF017FFFFFFFFFFFFFC03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE82FFFFFFFFFFFFFC07FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFC07FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFA0BFFFFFFFFFFF80FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF017FFFFFFFFFF81FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE82FFFFFFFFFF81FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFF01FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA0BFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF017FFFFFFF07FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE82FFFFFFF8FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFF07FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA0BFFFFF1FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFF1FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE82FFFE3FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFE3FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFE7FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E7FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{355, 115},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005S0000La000`40O003h00OogooI7oo003oOomT
Ool00?moofAoo`0067oo00=S67NmOol0ogooBGoo000HOol00gNm<HaJeP3oOom9Ool000]oo`03MkeW
>Goo00]oo`03Kg]245:D0?moodQoo`002Goo00E_NgooMke:DWNm00]oo`04:DYooe:DBU;oOom7Ool0
00Qoo`06BU9Nmd8@Oom:DVmk2Woo00LQ25:DOomooe:D:DYg_@3oOom5Ool000Qoo`04<Haood8@Kg/2
Mkd9Ool00c6<48Aoo`03Ool00fLi<Hag_@3oOom4Ool000Qoo`04HaQW>C6<Mkd:Ool00c6<000icP05
Ool00gNm<Hag_@3oOom3Ool000Qoo`03MkdicWNm00Yoo`04<H`000Q2IcT6Ool00gNm<HaW>@3oOom2
Ool000Qoo`03IcUNmfmk00Uoo`04<H`8@P00:DX8Ool00gNm>LiBU03oOom1Ool001=oo`05IcUF]C6<
8@QF]@0:Ool00dYBDYAoo`3oOoloOol001=oo`04MkeW>DYB@Q0<Ool00e:D<Haoo`3oOolnOol001Ao
o`03:DYoofmk00eoo`03G_LYBWNm0?mooceoo`004goo00=BU5JeOol03goo00=_Nc6<Mkd0ogoo?7oo
000COol00bU:Oomoo`0@Ool00gNmBU9oo`3oOolkOol0019oo`03G_MBU7oo01Aoo`03IcUoogoo0?mo
ocQoo`004Woo00<aS7ooOol057oo00=:DU:DOol0ogoo>7oo000AOol00g>L@Q1oo`0FOol00eJeOomo
o`3oOolgOol0015oo`03=JeW>Goo01Qoo`03E[Eoogoo0?moocEoo`003Woo00Ag_GooMkdYBQYoo`03
DY@icWoo0?moocEoo`003Goo00E_NcW>>LhaS5kg01]oo`03IcTicWoo0?moocAoo`0047oo00EJeT8@
<Ha:DVmk01Uoo`03IcTaS7Nm0?mooc=oo`004goo00EW>D8@<Ha:DVmk01Moo`03Kg/YBVLi00Uoo`04
48@YBUJeMkgoOolUOol001Ioo`05IcU:DS6<BU9_N`0FOol00cW>IcUoo`06Ool025Je000YBP0048@Y
BVLiMkgoOolROol001Uoo`05Kg]:DS6<BU9_N`0DOol00cW>@Q1oo`05Ool02SW>6<IoogNmBU8HaP00
48@aS6Liogoo87oo000LOol01FmkBU8aS48@Kg/04Woo00=243W>Ool017oo00<@Q48@Ool00goo00Mg
_CW>6<H00124>LiW>@3oOolMOol001moo`05Kg]:DWooMke_N`0@Ool00fLi:DYg_@02Ool00eJe001W
>@07Ool01Vmk>LhHaP006<IBU?mooa]oo`008Woo00=g_DYB@Q0047oo00Ig_C6<Kg]ood8@6<H;Ool0
0ekg6<HaS03oOolKOol002Ioo`04HaPaS48@IcT<Ool01GNm>LiF]A24@Q0037oo00=24248Ool0ogoo
6Woo000XOol01FmkBU8aS48@IcT02goo00<icP00IcT037oo00=F]@00Mkd0Qgoo00=W>E:DIcT03Goo
0VLiP7oo000[Ool01FmkBU8aS48@IcT027oo00=:DPQ2BU8037oo00=W>@00Kg/0Qgoo00A247NmG_M_
N`aoo`03MkeJeWNm07moo`00;Woo00E_NdYB<H`icVLi00Eoo`0648A245:DDYA247Nm2Woo00<8@SW>
Ool0JWoo019g_D8@E[ENmfLi:DYBU6mk<Hag_C6<IcU245:D=JeBU6mk<H`3Ool01DYBIcUJeT8@IcT0
0Woo01=NmcW>BU9g_C6<OolaS4icBU9oodYBMkeW>D8@IcU:DWNmE[ENm`1oOol0035oo`0>Kg]:DS6<
>Li[FWNmG_L006LiOom2400048A_N`Uoo`03>LhHaWNm06Yoo`06:DY_NgooOom_NdYB0Woo00<aS7oo
<H`00Ukg00DicWooOomooc6<009oo`06DYAF]Goo>Li246mk0Woo00iW>DYB@Q1ooc6<OomNmdicG_M_
NcW>HaQ_Nd8@0Ukg00=oobU:G_L0Ogoo000dOol036mkBU8icQS648Ag_GooMkdHaP00249BU0Qoo`03
Kg/005:D06Qoo`03Mkeoob4800Aoo`0E>LhaS5Je:DYW>C6<G_M>LdYBG_LQ26Li8@QNmgooMkeBU6Li
@Q0icVLi009oo`0>G_M_Nb48IcTQ25kgBU9F]EkgBU9W>EJeG_M2409F]@04IcU246LiMkenOol003Mo
o`0448@YBU:DOol2Kg/01248000005:D27oo00<icPQ2Mkd0Igoo01=g_Goo@Q1F]GooMkeS67NmIcUo
ogNmKg]g_FLiE[Eoof]JKg]oo`02Mkd2Ool01GNmKg]oocW>IcT00goo00=_NgNmOol00gNm00Y_Ngoo
Kg]oofmkOomg_FLiCW=_N`=g_Gioo`00=Woo00=W>@00IcT00Woo00AW>D8@DY@YBP800003<Hag_Goo
00Eoo`04MkdHaQ24IcUUOol2Mkd2Ool015:DE[EBU6Li4goo00=_NeJeKg/03Goo00=_Ne[FOol0Pgoo
000fOol00dYB48Aoo`06Ool01D8@00000248Mkd01Woo00Qg_C6<000Q23W>DYANmfmkGgoo0WNm/7oo
000fOol00a24@Q1oo`07Ool01U:D000001S6G_Mg_@Ioo`04G_LicQS6248200001PQ28@PaS5:DIcUg
_EUoo`03Mkeoogoo0:moo`00=Goo00=[FP00IcT02Goo00QJeQ24000003W><HaNmgNm1goo00Ig_FLi
BU8icRU:248200001ABU8@Q:DUJeKg/0Dgoo0WNm/Goo000eOol00cF]249oo`0:Ool02WNm6<H00124
E[EJeTYB<HaNmgNm2Woo00E_NeJe@Q0aS1240080000548@Q24YBE[Eg_@1=Ool2MkfbOol003Aoo`03
Kg/0048@00aoo`05MkdHaP00001Nm`02Ool01Ekg@Q0aS5kgMkd03Goo00AF]DYB:DX@Q08000056<HY
BU:DG_Mg_@18Ool00gNmOomoo`2aOol003Aoo`03DY@005kg00ioo`03:DXHaWoo00Eoo`05G_M2436<
G_Mg_@0>Ool02gNmE[E:DRU:48@000Q26<HYBU:DG_L0@goo00=_NgooOol0/Woo000dOol00bU:249o
o`0?Ool00gNmOomoo`07Ool01Ekg@Q1_NgooMkd047oo00]g_EJe@Q0YBPQ20008@R48>LiF]Fmk03eo
o`9g_KAoo`00<goo00=g_@00BU8047oo00I_NeJeBU9BU6LiMkd8Ool00dYB<Haoo`0COol017NmBU92
41240P0000@@Q2U:DYANmcUoo`03Mkeoogoo0;=oo`00<goo00ABU000BU9g_@eoo`0:Kg/icPQ2000@
Q0Q2000@Q4YBMkd9Ool017Nm:DYBU6mk57oo00YF]DYB:DX8@P00248Q23W>E[E_Nc=oo`03Kg]oogoo
0;Aoo`00<goo00INmaS6000@Q4YBMkd:Ool015Je2488@TYB0goo00I_NcW>000@Q3W>Mkd9Ool01FLi
BU8YBU:DKg/05Goo00Ag_DYB@Q0@Q080000548@YBU:DG_Mg_@0]Ool2MkffOol003Eoo`06MkdicP00
48@icWNm1goo00=24000<H`01goo00Ig_CW>6<H002U:IcT:Ool01FLiBU8YBU:DKg/05goo00AF]DYB
:DX8@P8000048@PaS5JeKg/YOol00gNmOomoo`2eOol003Moo`06MkdicQS6000YBVLi17oo00=:DP00
@Q002goo00EBU1S6000YBVLi00]oo`05IcU:DRU:DYA_N`0HOol017NmDY@icR480P0000@HaS6<DYAW
>BAoo`03Kg]oogoo0;Ioo`00>Woo00UJeQS6000YBUJeMkeW>@Q2>Lh03Woo00IJeR48000HaU:DMkd;
Ool01FLiBU8aS4YBKg/06Goo00Ag_FLi@Q0YBP80000548@YBTYBIcUg_@0NOol2MkfhOol003aoo`06
G_LYBP0048@8@S6<4Goo00IW>C6<000@Q4YBMkd<Ool01FLiBU8aS4YBKg/06goo00YW>DYB<H`8@P00
248Q248@IcUg_AYoo`03Mkeoogoo0;Moo`00?Woo00Ag_CW>249g_A=oo`06MkdicP00248icVmk3Goo
00=W>DYB<H`07Woo00A_NdYB<H`@Q08000048@PicUJeKg/EOol00fLiOomoo`2hOol005Moo`06Mke2
4124248YBVLi3goo00=g_CW>DY@07Woo00Ag_E:D>LhHaP8000046<HaS5JeKg/@Ool00gNmOomoo`2i
Ool005Yoo`05E[DQ20006<IF]@0?Ool01GNmOomNmdYBKg/07Woo00Ag_Ekg>LhQ208000046<HaS5Je
Kg/<Ool00gNmOomoo`2iOol005aoo`05IcTYBP006<IF]@0@Ool01FmkBU8icT8@Kg/07goo00Ag_Ekg
>LhQ208000046<HicUJeKg/7Ool00fLiOomoo`2jOol005ioo`05IcTYBP0048ABU00AOol01FmkBU8i
cT8@Kg/087oo00Ag_Ekg>LhHaP8000048@PaS5:DIcT2Ool00gNmOomoo`2kOol0061oo`05G_LQ2000
249F]@0BOol017Nm=JdYBUJe8Woo00=g_DYB:DX00`0000<Q248@E[D0_Goo001ROol01Ekg:DX001S6
F]H04Woo00Ig_EJe>Li245:DMkdQOol017NmIcU242480P0000@@Q3W>DYAg_KUoo`00I7oo00EW>BU:
000HaU[F01Aoo`05E[E243W>DYAg_@0ROol016mkIcU242480P0000<HaSW>F]H0]Woo001VOol01VLi
:DX001S6BU9g_AAoo`04E[E243W>F]HOOol00fLiOomoo`02Ool017NmIcTaS1S60P0000<YBSW>IcT0
/Woo001XOol01Vmk>Lh8@Q24>Lig_AEoo`05IcUooekgBU9g_@0JOol00fmkOomoo`07Ool017NmE[Da
S1S60P0000<aS4YBKg/0[Woo001ZOol01WNm<H`00000>Lig_AIoo`05E[ENmgooG_Mg_@0GOol00gNm
Oomoo`0;Ool026LiDY@YBQ24000@Q3W>F]J[Ool006]oo`078@PYBTYB48@003W>Mkd05goo00EW>D8@
<Ha:DWNm01=oo`03Kg]oogoo00moo`04MkeW>CW>6<H200000bU:BU9W>@2WOol006]oo`098@PicWoo
Mke:DQ24000YBVmk01Qoo`05E[DicS6<BU9_N`0?Ool00fmkOomoo`0DOol027NmDY@YBQ24000@Q3W>
F]JTOol006]oo`03@Q0006mk00=oo`03BU8Q20Q201]oo`05G_LicS6<BU9_N`0<Ool00gNmOomoo`0G
Ool017NmIcU241S60P0000<aS5:DMkd0X7oo001[Ool017Nm6<H8@U[F17oo00=_NgooOol077oo00EN
mcW><Ha:DVmk00Qoo`03JeYoogoo01aoo`03Kg]BU2U:008000035:DicUJe09eoo`00K7oo00Ig_C6<
000HaU[FMkdSOol01Ekg>LhaS4YBKg/00Woo0TYB00=NmgooOol087oo00Qg_FLi=JdHaP00248aS5Je
VWoo001^Ool01VLi:DX00124>Li_NbAoo`04Kg/icS6<8@P200000a24JeYoo`0TOol00fLiBU8HaP02
24800bU:DYAoo`2FOol0071oo`07Kg]:DQ24000HaT8@Mkd07Woo00=S648@@Q000d8@00<8@P000000
0`0000<8@R48<H`01D8@00MBU7ooIcU245:DOomS600C@Q001eJeOomW>D8@DYA_NcW>00800003248a
S48@00i24007F]Ioof<H@Q1JeWooHaP04d8@00MJeWooHaQ245[FOomS600C@Q001e[FOomW>D8@F]Io
ofLi00m24003F]Ioogoo03Uoo`00Lgoo00MW>BU:48@001S6@Q1g_@0KOol00gNmKg]_N`03Kg/01A24
0000000024802P0000HHaRU:<Ha245JeIcTCKg/00gNmOomoo`02Kg/2Ool016mkIcUBU1S60PQ200<Q
24icKg/02Vmk00Mg_GooMke_NgNmOomg_@02Kg/00f]JKg]_N`0>Kg/01gNmOomg_FmkMkeoogNm00a_
N`03Mke_Nfmk00E_N`06Oomg_FmkKg]oogNm2Vmk00<Q26mkKg/00Vmk00=g_GooOol0>Goo001eOol0
27NmG_LYBPQ2000Q24YBMkdNOol03FLi:DXQ25:DOom_NfLiDY@YBP00248Q212400X000076<HaS3W>
@Q1F]FmkMkd05Goo00I_Nd8@6<H001S6BU9>Ool00cW>Oomoo`0nOol007Qoo`08MkeF]BU:24800124
BU9W>BAoo`0<MkeBU3W>>LiF]FLiG_MBU3W>:DXQ21242P0000L@Q36<>Li245:DIcUg_@0@Ool01VLi
>Lh8@PQ2:DYNmd]oo`03<Haoogoo03ioo`00Ngoo00Qg_EJe>Lh@Q00048A246Li97oo00Eg_E:D>Lhi
cUkg00Aoo`08MkeW>EkgDY@icS6<8@PHaPX0000748@Q23W>@Q1:DUJeKg/02goo00EBU1S6000HaTYB
04Uoo`03<Haoogoo03ioo`00Ogoo00MF]CW>48@00124@Q1W>@0TOol01GNmDY@icSW>G_L02Goo00Qg
_FmkG_MF]CW><H`Q21S62P0000L@Q1S6<Ha244YBE[E_N`05Ool01Ekg:DX8@PQ2BU80Agoo00<icWoo
Ool0?Woo0022Ool01eJe>Lh@Q000249246Li02Aoo`05MkeBU3W>>LiNm`0>Ool02GNmKg]NmeJeDY@i
cR486<H@Q009000020Q26<HYBT8@BU9BU5kg>Lh224800dYBOomoo`13Ool00d8@Oomoo`0nOol008Eo
o`07G_LicQ240008@T8@IcT097oo00Eg_E:D<H`icUkg01Aoo`08MkeW>EkgDY@icR486<H@Q0`00004
249:DU:DIcU1Ool00cW>Oomoo`0nOol008Qoo`07G_LicQS60008@T8@IcT097oo00Eg_E:DOomg_Ekg
01Uoo`09MkeW>EkgDY@icRU:8@P@Q0Q200T0000748@YBSW>@Q1:DUkgKg/0>7oo00=247ooOol0?Woo
002;Ool01fmk@Q0HaP00248icVLi02Aoo`03MkeBU48@025oo`07IcUNme:DBU8YBR4824802P0000L8
@R48<Ha244YBE[E_N`0`Ool00d8@Oomoo`0YOol00fmkF]Ioo`0BOol008ioo`07Kg]:DQS60008@SW>
G_L09Goo00AW>C6<>LiJeR9oo`06Kg/aS0Q248@icTYB0RU:00<Q20Q20000200000<8@QS6<H`00T8@
00=F]FmkMkd09goo00<aS7ooOol0:Goo00=g_FLiIcT04Woo002AOol01fmkBU8@Q000248aS5Je02Ao
o`05MkeBU36<>LiJeP0QOol016Li6<H0036<17oo00Q_NfLiG_M:DS6<:DXQ20Q22@0000P8@QS6<H`i
cT8@DYA_NgNm7Woo00=g_D8@Ool067oo00TicWooOom243W>F]I>LeJeHaP00Ukg00Y_Na24@Q1_Nc6<
OolYBVmkOolaS0=oo`03G_M:DWoo00aoo`00Tgoo00U242U:BU8Q2000248aS5:DMkd08goo00Eg_E:D
:DY244YB021oo`05E[D@Q000>Lig_@09Ool027NmIcUNme:D>LhYBR4848@:00001aS6:DXicT8@DYAW
>GNm01Ioo`03IcU:DWoo01Moo`07Kg/YBU[FOolicWooMkd00Ukg00DaS7ooIcTicU:D009oo`07@Q1o
oc6<Oom:DU:DMkd00Woo00=F]EkgKg/037oo002COol01d8@<HaoogooKg]F]B480088@P038@Q:DWNm
02=oo`05MkeF]CW>>Li:DP0NOol01GNm@Q0@Q1S6F]H047oo00Qg_FmkG_MF]CW>:DXQ21S62P0000L@
Q1S6>Li245:DE[Eg_@0>Ool2G_LHOol01cW>G_MJeWooF]IBU36<009Nm`0>F]Ig_D8@IcUJeUJeIcTi
cWoo<Hag_BU:Oom:DP9oo`03@Q1_Nd8@00aoo`00Tgoo00=2436<Ool017oo00Qg_EJe:DX8@P008@Pi
cVLi97oo00AF]CW>>Li:DQeoo`05MkdYBP00>Lig_@0FOol02GNmKg]NmeJe>LhaS2486<H8@P090000
1`Q26<HaS48@BU9F]FLi00Ioo`03DYA_Ngoo01Ioo`08MkdQ27ooIcU_NgooIcUoo`9Nm`0<OomW>GNm
Oomg_FLiOom_NgNm>Lig_Fmk0gNm47oo002COol00d8@<Haoo`07Ool027NmE[DYBQ24000@Q3W>G_L;
Ool00fmkMkeoo`0FOol015Je>Li244YB77oo00ABU1246<Ig_Aioo`05MkeF]E:DDY@icP028@P00a24
0000000700001`Q248@aS48@BU8aS5Je00Yoo`03@Q1Nmgoo00Yoo`05E[EBU7ooIcUBU003Ool00ekg
IcUoo`06Ool00eJeOomoo`0EOol009=oo`03@Q0aS7oo00]oo`07IcTicQS60008@SW>F]H027oo00@@
Q000<HaJeQQoo`04IcUBU7ooKg/JOol017Nm6<H8@U[F7Woo00=246mkOol017oo00Qg_EkgE[EBU3W>
:DXQ21242@0000<8@Q24:DX00T8@00YBU6LiMkeood8@0008@SW>F]Ig_C1oo`00Tgoo00=2436<Ool0
3Woo00=W>D8@6<H00P0000<icU[FOol017oo00Mg_D8@48@000Q2>LiNm`0HOol00fmk>LiBU00IOol0
17Nm>Lh005:D7Goo00<@Q7ooOol037oo00Ig_FLiG_MBU4YB:DX248@90003248400000bU:BU9_N`0]
Ool009=oo`03@Q0aS7oo015oo`03IcU:DR4800800003<HaJeWNm00=oo`03Mke:DQ240080000348@i
cVLi01Uoo`03DY@icTYB01Moo`03DY@0048@01]oo`03G_L007oo01=oo`0;>LioogooIcUNme:DBU8Y
BR4848@8@P0:00000b48>LiW>@0ZOol009=oo`03@Q0aS7oo01Aoo`03MkeBU2U:00800003:DY245:D
009BU009>Lh00248>Lh@Q0006<HicVmk01Qoo`04IcU243W>BU8EOol00e:D0012400JOol00bU:001o
o`0COol00cW>Oomoo`08Ool00fLi:DX0000:00000`Q2>LiJeP0WOol009=oo`03@Q0aS7oo01Moo`04
BU8HaRU:6<H348@00aS6:DYW>@02Ool01fLi<H`@Q0008@Q:DWNm01Qoo`05IcU243W>BU9g_@0BOol0
0e:D001BU00HOol00gNm0008@P0COol00fmk@Q1oo`09Ool00c6<8@PQ20038@P348@800000c6<DYAg
_@0SOol009=oo`03@Q0YBWoo01Moo`03:DXaS7oo00]oo`08MkeW>C6<48@002U:DYAg_AQoo`05IcU2
43W>BU9g_@0@Ool00e:D001Nm`0GOol00bU:000HaP0COol00eJeG_Moo`0COol017NmKg]_Nfmk15kg
00=F]E:DOol08Woo002COol015:D001:DVLi5Woo00<8@U:DOol03Woo00Qg_FLi:DX8@P008@Q:DWNm
67oo00EW>D8@>Li:DWNm00ioo`038@P@Q7Nm01Eoo`04Kg/000008@PCOol00dYBKg]oo`10Ool009Ao
o`05>Lh@Q000:DYF]@0COol00gNm001F]@0BOol027NmDY@YBPQ2000Q24YBMkdHOol01FLi@Q0aS4YB
Mkd02goo00=g_@Q2@Q005Goo0TYB0RU:17oo00=_NgNmMkd037oo00<icWooOol0@7oo002FOol01UJe
:DX000Q2BU9W>A1oo`03E[D007Nm01Ioo`07E[DaS0Q2000HaTYBMkd067oo00EW>D8@E[EoogNm00Uo
o`03@Q08@WNm01=oo`05MkeW>DYBG_MBU003Ool01E:DE[ENmdYBIcT02goo00=247ooOol0@7oo002H
Ool01Vmk>Lh@Q000:DYF]@ioo`03>Lh@Q7oo01Uoo`07E[DaS0Q2000HaTYBKg/06Goo00=BU3W>G_L0
1goo00=_N`00E[D04goo00Eg_Goo8@Q_NgNm00=oo`048@Q_NgNm>Lh<Ool00cW>Oomoo`10Ool009]o
o`06BU88@P00249F]GNm2goo0RU:7Goo00M:DQBU00000248G_Mg_@0JOol00bU:BU9oo`04Ool00`Q2
@Q1oo`0DOol00acWOomoo`03Ool015JeG_MNmbU:2goo00=[FTYBOol0@Goo002MOol01U:D6<H000Q2
>Li_N`Uoo`0348A:DWoo01ioo`08IcTicQS60008@S6<E[Eg_AQoo`04E[DaS3W>E[D2Ool00b48@Q1o
o`0COol00fmk=Jeoo`05Ool00fLiMke_N`0;Ool00e:DE[Eoo`11Ool009moo`07Mke:DQ24000HaUJe
Mkd01Goo00=W>@00IcT08Woo00=g_DYB8@P00P0000<YBTYBIcT067oo00EF]C6<>Lh8@TYB01Aoo`03
DYANmgoo01=oo`03BU9g_Goo045oo`00XWoo00INmbU:0008@SW>Kg/3Ool00c6<6<Ioo`0UOol00gNm
F]HaS00200001248>LiW>GNm5Woo00EW>@00:DXicUJe019oo`03<Haoogoo01=oo`03<Haoogoo045o
o`00Y7oo00Ug_DYB248001S6@Q0YBP00F]H0:Goo00Ug_FLi>Lh@Q000248YBU:DIcT04goo00DicQ24
Oomooekg008icP03E[Eoogoo00aoo`03MkdYBWoo01Aoo`03@Q1oogoo00Aoo`03IcUNmdYB03Yoo`00
Ygoo00ENmc6<48@Q25[F02ioo`03Mke:DS6<00800005248YBTYBIcUg_@0=Ool00gNm001:DP05Ool0
1Ekg>LhicUJeMkd02Woo00=W>EJeOol04goo00=Nme:DOol01Goo00@YBWooBU9_NcUoo`00gWoo00AW
>DYB<H`8@P8000056<HQ22U:>Li:DP02DY@5G_L015:D6<HHaWNm27oo00ANmd8@>Lig_@Qoo`03>Lig
_Goo019oo`03Kg]:DVLi00Ioo`048@QNmcW>G_LiOol00>9oo`08MkeNmd8@>LhYBQS648@8@PL00003
:DYg_Goo00aoo`03MkdicUJe00Eoo`03<Haoogoo019oo`04@Q0YBWooE[D5Ool012U:MkeBU6Li>Goo
003]Ool2Kg/00gNmOomoo`0@Ool01fmkOom_NeJeMke_NdYB01Aoo`04248YBS6<IcT5Ool2IcT00dYB
Oomoo`0hOol00?moo`Ioo`05G_M241S6AS5g_@0BOol015kg0000048@@goo003oOol9Ool01Ekg@Q0Y
BTYBKg/03goo00=BU0002480A7oo003oOol<Ool01Fmk>LhicT8@IcT037oo00=24000DY@0A7oo003o
Ool?Ool01Fmk>LhicT8@IcT02Goo0QS6AGoo003oOolBOol01Fmk>LhicT8@IcT01Woo00<@Q5kgOol0
A7oo003oOolEOol016mk>LhaS4YB0goo00=_Nc6<Ool0AGoo003oOolHOol01WNmOomJeT8@CW=_NdIo
o`00ogoo6goo00=_Ne[FOol00VLiA7oo003oOolNOol00gNm@Q1BU013Ool00?moofAoo`00ogooI7oo
0000\
\>"],
  CellTags->"4.2"],

Cell[TextData[{
  StyleBox["Figure 4.3. ",
    FontWeight->"Bold"],
  "Depth control of a submarine."
}], "Caption",
  CellTags->"4.2"],

Cell["Here is the two\[Hyphen]matrix state\[Hyphen]space model. ", 
  "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["\<\
StateSpace[
   {{0, 1, 0}, {-.0071, -.111, .12}, {0, .07, -.3}},
   {{0}, {-.095}, {.072}}
]//ReviewForm\
\>", "Input",
  CellLabel->"In[31]:=",
  CellTags->"4.2"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "1", "0"},
                  {
                    RowBox[{"-", 
                      StyleBox["0.00710000000000000053`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->2]}], 
                    RowBox[{"-", 
                      StyleBox["0.111000000000000009`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->3]}], 
                    StyleBox["0.119999999999999996`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->2]},
                  {"0", 
                    StyleBox["0.0700000000000000088`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->1], 
                    RowBox[{"-", 
                      StyleBox["0.3`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->1]}]}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0"},
                  {
                    RowBox[{"-", 
                      StyleBox["0.095`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->2]}]},
                  {
                    StyleBox["0.0719999999999999928`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->2]}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[31]//ReviewForm=",
  CellTags->"4.2"]
}, Open  ]],

Cell[TextData[{
  "To display the state response, we insert a diagonal matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " containing some weighting coefficients. "
}], "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["Insert[%, DiagonalMatrix[{.01, 1, 1}], -1] //ReviewForm", "Input",
  CellLabel->"In[32]:=",
  CellTags->"4.2"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "1", "0"},
                  {
                    RowBox[{"-", 
                      StyleBox["0.00710000000000000053`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->2]}], 
                    RowBox[{"-", 
                      StyleBox["0.111000000000000009`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->3]}], 
                    StyleBox["0.119999999999999996`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->2]},
                  {"0", 
                    StyleBox["0.0700000000000000088`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->1], 
                    RowBox[{"-", 
                      StyleBox["0.3`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->1]}]}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0"},
                  {
                    RowBox[{"-", 
                      StyleBox["0.095`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->2]}]},
                  {
                    StyleBox["0.0719999999999999928`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->2]}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {
                    StyleBox["0.01`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->1], "0", "0"},
                  {"0", "1", "0"},
                  {"0", "0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[32]//ReviewForm=",
  CellTags->"4.2"]
}, Open  ]],

Cell["This finds the discrete\[Hyphen]time approximation of the system. ", 
  "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["ToDiscreteTime[%, Sampled -> Period[2]]", "Input",
  CellLabel->"In[33]:=",
  CellTags->"4.2"],

Cell[BoxData[
    RowBox[{"StateSpace", "[", 
      RowBox[{
      \({{0.986793363152577107`, 1.79373965563353738`, 
            0.183892404242946394`}, {\(-0.012735551554998028`\), 
            0.80056072967426175`, 0.160081037403140928`}, {
            \(-0.000761621040906170598`\), 0.0933806051518322455`, 
            0.559313396348688662`}}\), ",", 
        \({{\(-0.167272114947796151`\)}, {\(-0.157165014179693525`\)}, {
            0.0986634731991330937`}}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.01`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1], ",", "0", ",", "0"}], "}"}], ",", 
            \({0, 1, 0}\), ",", \({0, 0, 1}\)}], "}"}], ",", 
        \(Sampled \[Rule] Period[2]\)}], "]"}]], "Output",
  CellLabel->"Out[33]=",
  CellTags->"4.2"]
}, Open  ]],

Cell[TextData[{
  "This plots the state response. Note that we numericalize the input \
function to avoid supplying ",
  StyleBox["Degree", "MR"],
  " in symbolic form. "
}], "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{

Cell["\<\
SimulationPlot[%, N[.3 Degree], {t, 150},
 PlotLabel -> \"State Response of Submarine\" ]\
\>", "Input",
  CellLabel->"In[34]:=",
  CellTags->"4.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 0.384596 162.187 [
[.15079 .3721 -6 -9 ]
[.15079 .3721 6 0 ]
[.27778 .3721 -6 -9 ]
[.27778 .3721 6 0 ]
[.40476 .3721 -6 -9 ]
[.40476 .3721 6 0 ]
[.53175 .3721 -6 -9 ]
[.53175 .3721 6 0 ]
[.65873 .3721 -9 -9 ]
[.65873 .3721 9 0 ]
[.78571 .3721 -9 -9 ]
[.78571 .3721 9 0 ]
[.9127 .3721 -9 -9 ]
[.9127 .3721 9 0 ]
[.01131 .06022 -36 -4.5 ]
[.01131 .06022 0 4.5 ]
[.01131 .14132 -42 -4.5 ]
[.01131 .14132 0 4.5 ]
[.01131 .22241 -36 -4.5 ]
[.01131 .22241 0 4.5 ]
[.01131 .3035 -42 -4.5 ]
[.01131 .3035 0 4.5 ]
[.01131 .46569 -36 -4.5 ]
[.01131 .46569 0 4.5 ]
[.01131 .54678 -30 -4.5 ]
[.01131 .54678 0 4.5 ]
[.5 .63053 -83 0 ]
[.5 .63053 83 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15079 .3846 m
.15079 .39085 L
s
[(20)] .15079 .3721 0 1 Mshowa
.27778 .3846 m
.27778 .39085 L
s
[(40)] .27778 .3721 0 1 Mshowa
.40476 .3846 m
.40476 .39085 L
s
[(60)] .40476 .3721 0 1 Mshowa
.53175 .3846 m
.53175 .39085 L
s
[(80)] .53175 .3721 0 1 Mshowa
.65873 .3846 m
.65873 .39085 L
s
[(100)] .65873 .3721 0 1 Mshowa
.78571 .3846 m
.78571 .39085 L
s
[(120)] .78571 .3721 0 1 Mshowa
.9127 .3846 m
.9127 .39085 L
s
[(140)] .9127 .3721 0 1 Mshowa
.125 Mabswid
.05556 .3846 m
.05556 .38835 L
s
.0873 .3846 m
.0873 .38835 L
s
.11905 .3846 m
.11905 .38835 L
s
.18254 .3846 m
.18254 .38835 L
s
.21429 .3846 m
.21429 .38835 L
s
.24603 .3846 m
.24603 .38835 L
s
.30952 .3846 m
.30952 .38835 L
s
.34127 .3846 m
.34127 .38835 L
s
.37302 .3846 m
.37302 .38835 L
s
.43651 .3846 m
.43651 .38835 L
s
.46825 .3846 m
.46825 .38835 L
s
.5 .3846 m
.5 .38835 L
s
.56349 .3846 m
.56349 .38835 L
s
.59524 .3846 m
.59524 .38835 L
s
.62698 .3846 m
.62698 .38835 L
s
.69048 .3846 m
.69048 .38835 L
s
.72222 .3846 m
.72222 .38835 L
s
.75397 .3846 m
.75397 .38835 L
s
.81746 .3846 m
.81746 .38835 L
s
.84921 .3846 m
.84921 .38835 L
s
.88095 .3846 m
.88095 .38835 L
s
.94444 .3846 m
.94444 .38835 L
s
.97619 .3846 m
.97619 .38835 L
s
.25 Mabswid
0 .3846 m
1 .3846 L
s
.02381 .06022 m
.03006 .06022 L
s
[(-0.002)] .01131 .06022 1 0 Mshowa
.02381 .14132 m
.03006 .14132 L
s
[(-0.0015)] .01131 .14132 1 0 Mshowa
.02381 .22241 m
.03006 .22241 L
s
[(-0.001)] .01131 .22241 1 0 Mshowa
.02381 .3035 m
.03006 .3035 L
s
[(-0.0005)] .01131 .3035 1 0 Mshowa
.02381 .46569 m
.03006 .46569 L
s
[(0.0005)] .01131 .46569 1 0 Mshowa
.02381 .54678 m
.03006 .54678 L
s
[(0.001)] .01131 .54678 1 0 Mshowa
.125 Mabswid
.02381 .07644 m
.02756 .07644 L
s
.02381 .09266 m
.02756 .09266 L
s
.02381 .10888 m
.02756 .10888 L
s
.02381 .1251 m
.02756 .1251 L
s
.02381 .15753 m
.02756 .15753 L
s
.02381 .17375 m
.02756 .17375 L
s
.02381 .18997 m
.02756 .18997 L
s
.02381 .20619 m
.02756 .20619 L
s
.02381 .23863 m
.02756 .23863 L
s
.02381 .25485 m
.02756 .25485 L
s
.02381 .27106 m
.02756 .27106 L
s
.02381 .28728 m
.02756 .28728 L
s
.02381 .31972 m
.02756 .31972 L
s
.02381 .33594 m
.02756 .33594 L
s
.02381 .35216 m
.02756 .35216 L
s
.02381 .36838 m
.02756 .36838 L
s
.02381 .40081 m
.02756 .40081 L
s
.02381 .41703 m
.02756 .41703 L
s
.02381 .43325 m
.02756 .43325 L
s
.02381 .44947 m
.02756 .44947 L
s
.02381 .48191 m
.02756 .48191 L
s
.02381 .49813 m
.02756 .49813 L
s
.02381 .51435 m
.02756 .51435 L
s
.02381 .53056 m
.02756 .53056 L
s
.02381 .044 m
.02756 .044 L
s
.02381 .02778 m
.02756 .02778 L
s
.02381 .01157 m
.02756 .01157 L
s
.02381 .563 m
.02756 .563 L
s
.02381 .57922 m
.02756 .57922 L
s
.02381 .59544 m
.02756 .59544 L
s
.02381 .61166 m
.02756 .61166 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(State) show
99.000000 12.812500 moveto
(Response) show
153.000000 12.812500 moveto
(of) show
171.000000 12.812500 moveto
(Submarine) show
225.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.001 w
.02381 .3846 m
.03651 .38318 L
.04921 .37953 L
.0619 .37436 L
.0746 .36814 L
.0873 .36125 L
.1 .35398 L
.1127 .34658 L
.1254 .33925 L
.1381 .33215 L
.15079 .32544 L
.16349 .3192 L
.17619 .31352 L
.18889 .30846 L
.20159 .30405 L
.21429 .3003 L
.22698 .2972 L
.23968 .29473 L
.25238 .29287 L
.26508 .29157 L
.27778 .29078 L
.29048 .29044 L
.30317 .29051 L
.31587 .29092 L
.32857 .29161 L
.34127 .29253 L
.35397 .29362 L
.36667 .29484 L
.37937 .29613 L
.39206 .29746 L
.40476 .29878 L
.41746 .30008 L
.43016 .30131 L
.44286 .30247 L
.45556 .30353 L
.46825 .30449 L
.48095 .30533 L
.49365 .30605 L
.50635 .30666 L
.51905 .30715 L
.53175 .30753 L
.54444 .30781 L
.55714 .30799 L
.56984 .30808 L
.58254 .3081 L
.59524 .30805 L
.60794 .30795 L
.62063 .3078 L
.63333 .30762 L
.64603 .30741 L
Mistroke
.65873 .30718 L
.67143 .30695 L
.68413 .30671 L
.69683 .30647 L
.70952 .30625 L
.72222 .30603 L
.73492 .30583 L
.74762 .30565 L
.76032 .30549 L
.77302 .30536 L
.78571 .30524 L
.79841 .30514 L
.81111 .30506 L
.82381 .30501 L
.83651 .30497 L
.84921 .30494 L
.8619 .30494 L
.8746 .30494 L
.8873 .30495 L
.9 .30498 L
.9127 .30501 L
.9254 .30504 L
.9381 .30508 L
.95079 .30512 L
.96349 .30517 L
.97619 .30521 L
Mfstroke
0 0 1 r
.02381 .3846 m
.03651 .25113 L
.04921 .1595 L
.0619 .09631 L
.0746 .05408 L
.0873 .02829 L
.1 .01593 L
.1127 .01472 L
.1254 .02275 L
.1381 .03835 L
.15079 .06 L
.16349 .08626 L
.17619 .11586 L
.18889 .14759 L
.20159 .18041 L
.21429 .21338 L
.22698 .2457 L
.23968 .2767 L
.25238 .30584 L
.26508 .3327 L
.27778 .35696 L
.29048 .37842 L
.30317 .39698 L
.31587 .41261 L
.32857 .42536 L
.34127 .43534 L
.35397 .4427 L
.36667 .44764 L
.37937 .4504 L
.39206 .45121 L
.40476 .45034 L
.41746 .44804 L
.43016 .44457 L
.44286 .44018 L
.45556 .4351 L
.46825 .42956 L
.48095 .42374 L
.49365 .41783 L
.50635 .41197 L
.51905 .4063 L
.53175 .40093 L
.54444 .39593 L
.55714 .39138 L
.56984 .38731 L
.58254 .38376 L
.59524 .38073 L
.60794 .37823 L
.62063 .37623 L
.63333 .37471 L
.64603 .37364 L
Mistroke
.65873 .37298 L
.67143 .37269 L
.68413 .37272 L
.69683 .37303 L
.70952 .37356 L
.72222 .37428 L
.73492 .37514 L
.74762 .3761 L
.76032 .37713 L
.77302 .37818 L
.78571 .37924 L
.79841 .38027 L
.81111 .38126 L
.82381 .38218 L
.83651 .38304 L
.84921 .3838 L
.8619 .38448 L
.8746 .38506 L
.8873 .38555 L
.9 .38595 L
.9127 .38626 L
.9254 .38648 L
.9381 .38663 L
.95079 .38671 L
.96349 .38673 L
.97619 .3867 L
Mfstroke
1 0 0 r
.02381 .3846 m
.03651 .46838 L
.04921 .50289 L
.0619 .51391 L
.0746 .51457 L
.0873 .51147 L
.1 .50785 L
.1127 .50522 L
.1254 .50421 L
.1381 .50495 L
.15079 .50736 L
.16349 .51124 L
.17619 .51634 L
.18889 .52238 L
.20159 .52911 L
.21429 .53628 L
.22698 .54365 L
.23968 .55103 L
.25238 .55824 L
.26508 .56513 L
.27778 .5716 L
.29048 .57754 L
.30317 .58289 L
.31587 .58761 L
.32857 .59168 L
.34127 .5951 L
.35397 .59787 L
.36667 .60002 L
.37937 .6016 L
.39206 .60263 L
.40476 .60319 L
.41746 .60332 L
.43016 .60308 L
.44286 .60252 L
.45556 .60172 L
.46825 .60071 L
.48095 .59956 L
.49365 .59831 L
.50635 .597 L
.51905 .59567 L
.53175 .59437 L
.54444 .5931 L
.55714 .59191 L
.56984 .5908 L
.58254 .5898 L
.59524 .5889 L
.60794 .58812 L
.62063 .58746 L
.63333 .58691 L
.64603 .58648 L
Mistroke
.65873 .58615 L
.67143 .58593 L
.68413 .58579 L
.69683 .58574 L
.70952 .58575 L
.72222 .58583 L
.73492 .58595 L
.74762 .58612 L
.76032 .58632 L
.77302 .58653 L
.78571 .58676 L
.79841 .587 L
.81111 .58724 L
.82381 .58747 L
.83651 .58769 L
.84921 .58789 L
.8619 .58808 L
.8746 .58825 L
.8873 .5884 L
.9 .58853 L
.9127 .58863 L
.9254 .58872 L
.9381 .58879 L
.95079 .58883 L
.96349 .58887 L
.97619 .58888 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000]Ool00`00Oomoo`3`Ool002eoo`03001oogoo0?1oo`00;Goo0P00
lGoo000]Ool00`00Oomoo`0BOol201oLOol002eoo`03001oogoo00moo`<07`9oo`807mYoo`00;Goo
00<007ooOol03Woo00<07gooOol01Goo00<07gooOol0egoo000]Ool00`00Oomoo`0=Ool00`0OOomo
o`07Ool00`0OOomoo`3FOol002eoo`8000eoo`0301moogoo00Uoo`0301moogoo0=Eoo`00;Goo00<0
07ooOol02goo00<07gooOol02Woo00<07gooOol0eGoo000]Ool00`00Oomoo`0;Ool00`0OOomoo`0;
Ool00`0OOomoo`3DOol002eoo`03001oogoo00Yoo`0301moogoo00eoo`0301moogoo0==oo`00;Goo
0P002goo00<07gooOol03Goo00<07gooOol0dgoo000]Ool00`00Oomoo`09Ool00`0OOomoo`0?Ool0
0`0OOomoo`3BOol001=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo
Ool30004Ool00`00Oomoo`09Ool00`0OOomoo`0?Ool00`0OOomoo`3BOol0019oo`03001oo`0000Mo
o`03001oo`00009oo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo00Uoo`0301moogoo011o
o`0301moogoo0=5oo`003Goo0`000Woo00<007oo00001goo00<007oo00000Woo00<007oo00000goo
00<007ooOol00goo0P002Goo00<07gooOol04Goo00<07gooOol0dGoo000BOol00`00Ool00007Ool0
0`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`0OOomoo`0BOol0
0`0OOomoo`3@Ool0019oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`00
00Aoo`03001oogoo00Qoo`0301moogoo019oo`0301moogoo0=1oo`004goo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<07gooOol057oo00<0
7gooOol0cgoo000]Ool20008Ool00`0OOomoo`0DOol00`0OOomoo`3?Ool002eoo`03001oogoo00Mo
o`0301moogoo01Eoo`0301moogoo0<ioo`00;Goo00<007ooOol01goo00<07gooOol05Goo00<07goo
Ool0cWoo000]Ool00`00Oomoo`06Ool00`0OOomoo`0FOol00`0OOomoo`3>Ool002eoo`8000Moo`03
01moogoo01Moo`0301moogoo0<eoo`00;Goo00<007ooOol01Woo00<07gooOol05goo00<07gooOol0
cGoo000]Ool00`00Oomoo`06Ool00`0OOomoo`0HOol00`0OOomoo`3<Ool002eoo`03001oogoo00Eo
o`0301moogoo01Uoo`0301moogoo0<aoo`00;Goo0P001Woo00<07gooOol06Woo00<07gooOol0bgoo
000]Ool00`00Oomoo`05Ool00`0OOomoo`0JOol00`0OOomoo`3;Ool002eoo`03001oogoo00Eoo`03
01moogoo01]oo`0301moogoo0<Yoo`00;Goo00<007ooOol01Goo00<07gooOol06goo00<07gooOol0
bWoo000]Ool20005Ool00`0OOomoo`0MOol00`0OOomoo`39Ool002eoo`03001oogoo00Aoo`0301mo
ogoo01eoo`0301moogoo0<Uoo`003Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol01@000Woo00<007ooOol00goo00<007ooOol017oo00<07gooOol07Woo00<07gooOol0
b7oo000=Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00003Ool01`00Oomoogoo001oo`00
00Aoo`03001oogoo00Aoo`0301moogoo01ioo`0301moogoo0<Qoo`0027oo0`000Woo00<007oo0000
1goo00<007oo00000Woo00<007oo00000goo00<007ooOol00goo00<007ooOol00Woo0P001Goo00<0
7gooOol07goo00<07gooOol0agoo000=Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00003
Ool01000Oomoogoo0P001Goo00<007ooOol017oo00<07gooOol07goo00<07gooOol0agoo000=Ool0
0`00Ool00007Ool00`00Ool00002Ool00`00Ool00003Ool01@00Oomoogoo00001Woo00<007ooOol0
0goo00<07gooOol087oo00<07gooOol0agoo000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000
Oomoogoo0P000goo0`0017oo00<007ooOol00goo00<07gooOol08Goo00<07gooOol0aWoo000]Ool2
0004Ool00`0OOomoo`0QOol00`0OOomoo`36Ool002eoo`03001oogoo00=oo`0301moogoo029oo`03
01moogoo0<Eoo`00;Goo00<007ooOol00goo00<07gooOol08Woo00<07gooOol0aGoo000]Ool00`00
Oomoo`03Ool00`0OOomoo`0ROol00`0OOomoo`35Ool002eoo`8000=oo`0301moogoo02Aoo`0301mo
ogoo0<Aoo`00;Goo00<007ooOol00Woo00<07gooOol097oo00<07gooOol0a7oo000]Ool00`00Oomo
o`02Ool00`0OOomoo`0TOol00`0OOomoo`34Ool002eoo`03001oogoo009oo`0301moogoo02Eoo`03
01moogoo0<=oo`00;Goo0P000goo00<07gooOol09Goo00<07gooOol0`goo000]Ool00`00Oomoo`02
Ool00`0OOomoo`0UOol00`0OOomoo`33Ool002eoo`03001oogoo009oo`0301moogoo02Ioo`0301mo
ogoo0<9oo`00;Goo00<007ooOol00Woo00<07gooOol09Woo00<07gooOol0`Woo000]Ool20002Ool0
0`0OOomoo`0WOol00`0OOomoo`32Ool002eoo`05001oogooOol07`0ZOol00`0OOomoo`31Ool001=o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00D000=oo`05001oogoo
Ool07`0ZOol00`0OOomoo`31Ool0019oo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000=o
o`03001oogoo00=oo`05001oogooOol07`0ZOol00`0OOomoo`31Ool000eoo`<0009oo`03001oo`00
00Moo`03001oo`00009oo`03001oo`0000=oo`03001oogoo00=oo`80009oo`0301moogoo02Uoo`03
01moogoo0<1oo`004Woo00<007oo00001goo00<007oo00000Woo00<007oo00000goo00<007ooOol0
0goo00D007ooOomoo`0O02]oo`0301moogoo0<1oo`004Woo00<007oo00001goo00<007oo00000Woo
00<007oo00000goo00<007ooOol00goo00D007ooOomoo`0O02aoo`0301moogoo0;moo`004goo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOomoo`8000Eoo`05001oogooOol07`0/Ool00`0OOomo
o`2oOol002eoo`800003Ool07goo02aoo`0301moogoo0;moo`00;Goo00@007ooOol07bioo`0301mo
ogoo0;ioo`00;Goo00@007ooOol07bioo`0301moogoo0;ioo`00;Goo00@007ooOol07bioo`0301mo
ogoo0;ioo`00;Goo0P0000=oo`0OOol0;Woo00<07gooOol0_Goo000]Ool01000Oomoo`0O;goo00<0
7gooOol0_Goo000]Ool01000Oomoo`0O<7oo00<07gooOol0_7oo000]Ool01000Oomoo`0O<7oo00<0
7gooOol0_7oo000]Ool200000goo01moo`0`Ool00`0OOomoo`2kOol002eoo`03001oo`0O039oo`03
01moogoo0;]oo`00;Goo00<007oo01l0<Woo00<07gooOol0^goo000]Ool00`00Ool07`0cOol00`0O
Oomoo`2jOol002eoo`80000301moogoo035oo`0301moogoo0;Yoo`00;Goo00<007oo01l0=7oo00<0
7`?P0n006@?PX7oo000>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Ool07`0^Ool60n000`0OOomoo`0IOol:0n2F
Ool000eoo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001o
o`0000Aoo`03001oo`0O02]oo`<3h0Moo`0301moogoo029oo`T3h8eoo`0027oo0`000Woo00<007oo
00001goo00<007oo00000Woo00<007oo00000Woo00<007oo000017oo00<007ooOol00Woo0P0000<0
7gooOol09Woo0`?P2Woo00<07gooOol0:goo40?P=Woo@@?P1Woo000=Ool00`00Ool00007Ool00`00
Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool20005Ool00`00Ool07`0UOol30n0=Ool00`0O
Oomoo`0kOolf0n17Ool000eoo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001o
o`00009oo`03001oogoo00Aoo`03001oo`0O029oo`<3h15oo`0301moogoo0;Moo`003Woo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`<000Aoo`03001oo`0O021oo`83
h1Aoo`0301moogoo0;Moo`00;Goo00<0000OOol07Woo0P?P5goo00<07gooOol0]Woo000]Ool00`00
01moo`0LOol20n0IOol00`0OOomoo`2fOol002eoo`0300007goo01Yoo`83h1aoo`0301moogoo0;Eo
o`00;Goo00<0000OOol06Goo00<3h7ooOol077oo00<07gooOol0]Goo000]Ool00`0001moo`0GOol2
0n0POol00`0OOomoo`2dOol002eoo`0300007goo01Ioo`030n1oo`00008000=oo`03001oogoo01Qo
o`0301l00000009oo`03001oogoo01Ioo`8000Aoo`03001oogoo01Moo`03001oogoo009oo`03001o
ogoo01=oo`D0009oo`03001oogoo009oo`03001oogoo015oo`D00004Ool000000003Ool00`00Oomo
o`0@Ool50002Ool30002Ool00`00Oomoo`0@Ool002eoo`0300007goo01Aoo`83h09oo`03001oogoo
009oo`03001oo`0001Yoo`0601moogoo001oo`005goo00<007oo00000Woo00<007oo00005goo00<0
07oo00000Woo00<007oo00005Woo00L007ooOomoo`00Ool00002Ool00`00Ool0000DOol01@00Oomo
ogoo000017oo00<007oo00004goo00<007ooOol00goo00H007ooOol007oo000AOol002eoo`030000
7goo019oo`83h0Eoo`07001oogooOol007oo000067oo0`0000D07goo001oo`0001Moo`03001oo`00
009oo`03001oo`0001Moo`03001oo`00009oo`03001oo`0001Ioo`07001oogooOol007oo00000Woo
00<007oo000057oo00<007ooOol00Woo00L007ooOomoo`00Ool0000COol01000Oomoogoo100000Ao
o`00Ool0015oo`00;Goo00<0000OOol03goo0`?P1goo00L007ooOomoo`00Ool0000HOol02000Ool0
000OOol007oo000GOol20003Ool00`00Ool0000HOol01`00Oomoogoo001oo`0001Ioo`07001oogoo
Ool007oo00000Woo00<007oo000057oo00<007ooOol00Woo00L007ooOomoo`00Ool0000COol01`00
Oomoogoo001oo`00009oo`03001oo`00015oo`00;Goo00<0000OOol03Goo0P?P2Goo00<007oo0000
0Woo00<007oo00006Goo0P0000Eoo`0O001oo`0001Moo`03001oogoo009oo`03001oo`0001Moo`03
001oo`00009oo`03001oo`0001Ioo`07001oogooOol007oo00000Woo00<007oo000057oo00L007oo
Oomoo`00Ool00002Ool00`00Ool0000COol00`00Oomoo`02Ool20002Ool00`00Ool0000AOol002eo
o`0300007goo00aoo`030n1oogoo00Yoo`03001oogoo009oo`03001oogoo01Uoo`05001oogoo01l0
000IOol20003Ool00`00Oomoo`0GOol00`00Oomoo`02Ool00`00Oomoo`0DOol20004Ool00`00Oomo
o`02Ool00`00Oomoo`0BOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0AOol20005Ool01@00Oomo
ogoo00004Woo000]Ool00`0OOomoo`0:Ool20n0aOol00`0OOomoo`2`Ool002eoo`0301l007oo00Qo
o`83h3Aoo`0301moogoo0:moo`00;Goo00<07gooOol01Woo0P?P=Woo00<07gooOol0DWoo6@0OA7oo
000]Ool00`0OOomoo`04Ool20n0iOol00`0OOomoo`1:Ool701lIOol<01lhOol002eoo`0301moogoo
009oo`83h3aoo`0301moogoo04Ioo`<07baoo`d07b]oo`009goo1P0000=l00?P0n000P?P?P0000<0
7`000000@`000`0O?0009@0O1P00000]Ool00g`0Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool00`0OOol00007Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0100001l07`0O
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo000]Ool00g`0Oomoo`11Ool00`0O
Oomoo`0lOol301m]Ool002eoo`03O01oogoo049oo`0301moogoo03Qoo`<07g1oo`00;Goo00<007`0
Ool0@goo00<07gooOol0<goo100OLgoo000]Ool00`00O01oo`14Ool00`0OOomoo`0`Ool201mgOol0
02eoo`03001l07oo04Aoo`0301moogoo02ioo`807gUoo`00;Goo00<007`0Ool0AGoo00<07gooOol0
:goo0P0ONgoo000]Ool00`00O01oo`16Ool00`0OOomoo`0XOol201mmOol002eoo`03001l07oo04Mo
o`0301moogoo02Eoo`807gmoo`00;Goo00<007`0Ool0B7oo00<07gooOol08Woo0P0OPGoo000]Ool0
0`00Ooml0019Ool00`0OOomoo`0NOol301n3Ool002eoo`800003O01oogoo04Qoo`0301moogoo01]o
o`807hIoo`00;Goo00<007ooO000Bgoo0P0O6Goo0P0OR7oo000]Ool00`00Ooml001=Ool201lDOol3
01n:Ool002eoo`03001oog`004moo`807`moo`<07heoo`00;Goo0P0000=l07ooOol0Cgoo3`0OT7oo
000]Ool00`00Ooml003`Ool000ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`04001oogooO03_Ool000eoo`03001oo`00
00Moo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`04001oogoo
O03_Ool000eoo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`03
001oogoo009oo`800003Ooml07oo0>ioo`003Goo00<007oo00001goo00<007oo00000Woo00<007oo
00000Woo00<007oo00000Woo0P001Goo00@007ooOoml0>moo`003Goo00<007oo00001goo00<007oo
00000Woo00<007oo00000Woo00<007oo00000Woo00<007ooOol017oo00@007ooOoml0>moo`003Woo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`<000Aoo`05001oogoo
Ooml003^Ool002eoo`80009oo`03O01oogoo0>aoo`00;Goo00<007ooOol00Woo00=l07ooOol0jgoo
000]Ool00`00Oomoo`02Ool00g`0Oomoo`3[Ool002eoo`03001oogoo009oo`03O01oogoo0>]oo`00
;Goo0P0017oo00=l07ooOol0jWoo000]Ool00`00Oomoo`03Ool00g`0Oomoo`3ZOol002eoo`03001o
ogoo00Aoo`03O01oogoo00Mooa1l0=9oo`00;Goo00<007ooOol01Goo00=l07ooOol00goo0g`047oo
0W`0d7oo000]Ool20007Ool5O00EOol2O03>Ool002eoo`03001oogoo029oo`9l0<aoo`00;Goo00<0
07ooOol097oo0g`0bGoo000]Ool00`00Oomoo`0WOol2O037Ool002eoo`8002Yoo`03O01oogoo0<Ao
o`00;Goo00<007ooOol0:Woo0W`0a7oo000COol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`050003Ool00`00Oomoo`0/Ool2O032Ool0019oo`03001oo`0000Moo`03001o
o`00009oo`03001oo`0000=oo`03001oogoo00=oo`03001oogoo02ioo`9l0<1oo`004Woo00<007oo
00001goo00<007oo00000Woo00<007oo00000goo00<007ooOol00goo0P00<Goo0W`0_Woo000BOol0
0`00Ool00007Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`0bOol0
0g`0Oomoo`2kOol0019oo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000=oo`03001oogoo
00=oo`03001oogoo03=oo`9l0;]oo`004goo00<007ooOol01goo00<007ooOol00Woo00@007ooOomo
o`8000Eoo`03001oogoo03Eoo`03O01oogoo0;Qoo`00;Goo0P00=goo0W`0^7oo000]Ool00`00Oomo
o`0hOol2O02fOol002eoo`03001oogoo03Yoo`=l0;=oo`00;Goo00<007ooOol0?Goo0W`0/Goo000]
Ool20010Ool2O02_Ool002eoo`03001oogoo045oo`=l0:aoo`00;Goo00<007ooOol0A7oo0g`0AGoo
Cg`05Goo000]Ool00`00Oomoo`17Ool3O00fOol<O01?Ool?O006Ool002eoo`8004]oo`=l02Uoo`Yl
071oo`00;Goo00<007ooOol0CGoo1g`05Woo37`0NWoo000]Ool00`00Oomoo`1DOolFO026Ool002eo
o`03001oogoo0?1oo`00;Goo0P00lGoo000]Ool00`00Oomoo`3`Ool002eoo`03001oogoo0?1oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008Eoo`<009Qoo`00QWoo00<007oo
Ool0Ugoo001COol30003Ool20002Ool40002Ool20003Ool2000<Ool3000017oo001oogoo0P000Woo
0P000goo0`000goo0P0000=oo`0000000Woo00@007oo000000Aoo`80015oo`80009oo`<000Yoo`<0
00=oo`L00007Ool007oo001oo`00Ool0100000Aoo`000000009oo`<00003Ool00000009oo`03001o
ogoo008003Ioo`00Dgoo00<007oo00000Woo00D007ooOol007oo00<0009oo`06001oogoo001oo`00
3goo00H007ooOol007oo0006Ool01000Oomoo`000Woo00<007oo00000Woo00<007oo00000Woo00D0
07ooOomoo`00009oo`03001oogoo011oo`04001oogoo0002Ool00`00Oomoo`09Ool00`00Ool00002
Ool01P00Oomoo`00Ool0009oo`800005Ool007oo001oo`030003Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00<007oo0000>7oo001EOol01000Oomoo`001Woo00@007ooOol000Aoo`<000eoo`<0
009oo`<000=oo`05001oogooOol00002Ool00`00Ool00002Ool00`00Ool00002Ool01000Oomoo`00
0goo0`0047oo00@007ooOol0009oo`03001oogoo00]oo`04001oogoo0002Ool00`00Ool00002Ool2
000017oo001oo`000goo00D007ooOomoo`0000Aoo`05001oogooOol00002Ool00`00Ool00002000f
Ool005Aoo`03001oogoo00@000=oo`800003Ool000000080009oo`<000eoo`05001oogoo001oo`03
0003Ool200000goo000000020003Ool200000goo000000020003Ool20002Ool3000AOol20002Ool3
000;Ool00`00Oomoo`02000017oo000007oo0`0000Eoo`00001oo`0000=oo`80009oo`@00003Ool0
0000009oo`@0009oo`<003Ioo`00Dgoo00<007oo00000Woo00<007ooOol01goo00<007ooOol04Woo
00@007ooOol003Qoo`03001oogoo00Uoo`03001oo`0000Moo`03001oogoo05Aoo`00Dgoo0`0087oo
1000>Woo00<007ooOol027oo0`001Woo0P0057oo00<007ooOol0?goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-28.6643, -0.00247245, 
  0.635592, 2.48818}},
  CellTags->"4.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3 Step, Impulse, and Other Responses", "Subsection",
  CellTags->"4.3"],

Cell["\<\
Using the general time\[Hyphen]domain response functions defined in \
this chapter, it is easy to investigate typical problems such as step, \
impulse, and ramp responses. This section presents some examples. \
\>", 
  "Text",
  CellTags->"4.3"],

Cell[TextData[{
  "Let us create the second\[Hyphen]order system with the natural frequency ",
  
  StyleBox["wn", "MR"],
  " and damping ratio ",
  StyleBox["zeta", "MR"],
  ".  "
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
s2[wn_, zeta_]  = TransferFunction[s,
 wn^2/(s^2 + 2 zeta wn s + wn^2)]\
\>", "Input",
  CellLabel->"In[35]:=",
  CellTags->"4.3"],

Cell[BoxData[
    \(TransferFunction[s, {{wn\^2\/\(s\^2 + wn\^2 + 2\ s\ wn\ zeta\)}}]\)], 
  "Output",
  CellLabel->"Out[35]=",
  CellTags->"4.3"]
}, Open  ]],

Cell["\<\
Here is the symbolic form of the step response for the critically \
damped case. \
\>", "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["OutputResponse[s2[wn, 1], UnitStep[t], t]", "Input",
  CellLabel->"In[36]:=",
  CellTags->"4.3"],

Cell[BoxData[
    \({E\^\(\(-t\)\ wn\)\ \((\(-1\) + E\^\(t\ wn\) - t\ wn)\)\ UnitStep[t]}
      \)], "Output",
  CellLabel->"Out[36]=",
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "This is the simulation of the step response for the system with the \
natural frequency equal to unity and a particular value of ",
  StyleBox["zeta", "MR"],
  " from the underdamped case region. "
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
SimulationPlot[s2[1, .1], UnitStep[t], {t, 50},
 PlotLabel -> \"Underdamped Second-Order System\",
 PlotRange -> All]\
\>", "Input",
  CellLabel->"In[37]:=",
  CellTags->"4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0147151 0.342185 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .10026 -24 -4.5 ]
[.01131 .10026 0 4.5 ]
[.01131 .18581 -18 -4.5 ]
[.01131 .18581 0 4.5 ]
[.01131 .27135 -24 -4.5 ]
[.01131 .27135 0 4.5 ]
[.01131 .3569 -6 -4.5 ]
[.01131 .3569 0 4.5 ]
[.01131 .44245 -24 -4.5 ]
[.01131 .44245 0 4.5 ]
[.01131 .52799 -18 -4.5 ]
[.01131 .52799 0 4.5 ]
[.01131 .61354 -24 -4.5 ]
[.01131 .61354 0 4.5 ]
[.5 .63053 -95 0 ]
[.5 .63053 95 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(10)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(20)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(30)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(40)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(50)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10026 m
.03006 .10026 L
s
[(0.25)] .01131 .10026 1 0 Mshowa
.02381 .18581 m
.03006 .18581 L
s
[(0.5)] .01131 .18581 1 0 Mshowa
.02381 .27135 m
.03006 .27135 L
s
[(0.75)] .01131 .27135 1 0 Mshowa
.02381 .3569 m
.03006 .3569 L
s
[(1)] .01131 .3569 1 0 Mshowa
.02381 .44245 m
.03006 .44245 L
s
[(1.25)] .01131 .44245 1 0 Mshowa
.02381 .52799 m
.03006 .52799 L
s
[(1.5)] .01131 .52799 1 0 Mshowa
.02381 .61354 m
.03006 .61354 L
s
[(1.75)] .01131 .61354 1 0 Mshowa
.125 Mabswid
.02381 .03182 m
.02756 .03182 L
s
.02381 .04893 m
.02756 .04893 L
s
.02381 .06604 m
.02756 .06604 L
s
.02381 .08315 m
.02756 .08315 L
s
.02381 .11737 m
.02756 .11737 L
s
.02381 .13448 m
.02756 .13448 L
s
.02381 .15159 m
.02756 .15159 L
s
.02381 .1687 m
.02756 .1687 L
s
.02381 .20292 m
.02756 .20292 L
s
.02381 .22003 m
.02756 .22003 L
s
.02381 .23714 m
.02756 .23714 L
s
.02381 .25424 m
.02756 .25424 L
s
.02381 .28846 m
.02756 .28846 L
s
.02381 .30557 m
.02756 .30557 L
s
.02381 .32268 m
.02756 .32268 L
s
.02381 .33979 m
.02756 .33979 L
s
.02381 .37401 m
.02756 .37401 L
s
.02381 .39112 m
.02756 .39112 L
s
.02381 .40823 m
.02756 .40823 L
s
.02381 .42534 m
.02756 .42534 L
s
.02381 .45956 m
.02756 .45956 L
s
.02381 .47666 m
.02756 .47666 L
s
.02381 .49377 m
.02756 .49377 L
s
.02381 .51088 m
.02756 .51088 L
s
.02381 .5451 m
.02756 .5451 L
s
.02381 .56221 m
.02756 .56221 L
s
.02381 .57932 m
.02756 .57932 L
s
.02381 .59643 m
.02756 .59643 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Underdamped) show
135.000000 12.812500 moveto
(Second) show
171.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
177.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Order) show
213.000000 12.812500 moveto
(System) show
249.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math1Mono
%%+ Courier
grestore
.5 Mabswid
.02381 .01472 m
.04286 .16221 L
.0619 .44521 L
.08095 .60332 L
.1 .52742 L
.11905 .32318 L
.1381 .18406 L
.15714 .21419 L
.17619 .35779 L
.19524 .47461 L
.21429 .47217 L
.23333 .37411 L
.25238 .27948 L
.27143 .26653 L
.29048 .33123 L
.30952 .4056 L
.32857 .4259 L
.34762 .38502 L
.36667 .32812 L
.38571 .30551 L
.40476 .32983 L
.42381 .37229 L
.44286 .39423 L
.4619 .38108 L
.48095 .35016 L
.5 .33046 L
.51905 .33636 L
.5381 .35831 L
.55714 .3751 L
.57619 .37368 L
.59524 .35854 L
.61429 .34477 L
.63333 .34361 L
.65238 .35373 L
.67143 .36466 L
.69048 .36714 L
.70952 .36064 L
.72857 .3522 L
.74762 .34921 L
.76667 .35317 L
.78571 .35952 L
.80476 .36254 L
.82381 .36031 L
.84286 .35564 L
.8619 .35287 L
.88095 .35396 L
.9 .3573 L
.91905 .3597 L
.9381 .35933 L
.95714 .357 L
Mistroke
.97619 .35501 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001>Ool5
0002Ool00`00Oomoo`0VOol30003Ool00`00Oomoo`0VOol20004Ool00`00Oomoo`0WOol30002Ool0
0`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`0<Ool0051oo`07001oogooOol007oo00009goo
00<007ooOol00Woo00<007oo0000:Goo00H007ooOol007oo000YOol01P00Oomoo`00Ool002Moo`03
001oo`00009oo`03001oo`0000eoo`00D7oo00L007ooOomoo`00Ool0000XOol01`00Oomoogoo001o
o`0002Qoo`07001oogooOol007oo00009goo100000Aoo`00Ool002Uoo`06001oogoo001oo`003Goo
001@Ool01`00Oomoogoo001oo`0002Qoo`07001oogooOol007oo0000:Goo00H007ooOol007oo000W
Ool00`00Ool00002Ool00`00Ool0000WOol20003Ool00`00Ool0000=Ool0051oo`07001oogooOol0
07oo00009goo00<007oo00000Woo00<007oo00009goo00<007oo00000Woo00<007oo0000:7oo0P00
0Woo00<007oo00009goo00<007ooOol00Woo00<007oo00003Goo001?Ool20004Ool00`00Oomoo`0W
Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`0XOol01@00Oomoogoo
0000:7oo0`000goo00<007ooOol037oo003oOolQOol002Aoo`03001oogoo0?Uoo`0097oo00<007oo
Ool0nGoo000TOol00`00Oomoo`3iOol002Aoo`03001oogoo0?Uoo`007Woon0002Woo000TOol00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`0>Ool002Aoo`03001oogoo0?Uoo`0097oo00<007ooOol0nGoo000TOol2003jOol002Aoo`80
0?Yoo`0097oo0P00nWoo000TOol2003jOol002Aoo`800?Yoo`0097oo0P00nWoo000TOol2003jOol0
02Aoo`03001oo`000?Uoo`0097oo0`00nGoo000TOol00`00Ool0003iOol002Aoo`03001oo`000?Uo
o`0097oo00<007oo0000nGoo000TOol00`00Ool0003iOol002Aoo`<00?Uoo`0097oo00@007ooOol0
0?Qoo`003goo00<007ooOol00Woo00@007ooOomoo`<000=oo`03001oogoo00=oo`04001oogoo003h
Ool000ioo`03001oo`0000Moo`03001oogoo009oo`03001oo`0000Aoo`04001oogoo003hOol000io
o`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo009oo`800003Ool007oo0?Moo`003Woo00<0
07oo000027oo00@007ooOomoo`8000Eoo`04001oogoo003hOol000ioo`03001oo`0000Moo`03001o
o`00009oo`03001oogoo00Aoo`04001oogoo003hOol000moo`03001oogoo00Moo`04001oogooOol3
0004Ool01000Oomoo`00n7oo000TOol200000goo001oo`3gOol002Aoo`05001oogooOol0003gOol0
02Aoo`05001oogooOol0003gOol002Aoo`05001oogooOol0003gOol002Aoo`80009oo`03001oogoo
0?Eoo`0097oo00D007ooOomoo`000?Moo`0097oo00D007ooOomoo`000?Moo`0097oo00D007ooOomo
o`000?Moo`0097oo0P000goo00<007ooOol0m7oo000TOol00`00Oomoo`02Ool00`00Oomoo`3dOol0
02Aoo`03001oogoo009oo`03001oogoo0?Aoo`0097oo00<007ooOol00Woo00<007ooOol0m7oo000T
Ool00`00Oomoo`02Ool00`00Oomoo`3dOol002Aoo`8000=oo`03001oogoo0?Aoo`0097oo00<007oo
Ool00Woo00<007ooOol0m7oo000DOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`3dOol001=oo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo
009oo`03001oogoo0?Aoo`004goo00<007oo00002Goo00<007ooOol00Woo0P000goo00<007ooOol0
57oo00<007ooOol0gGoo000COol00`00Ool00007Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`0D
Ool2003NOol001=oo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo01Ao
o`800=ioo`0057oo00<007ooOol01Woo0`0017oo00<007ooOol00goo00<007ooOol04goo00<007oo
0000gGoo000TOol20004Ool00`00Oomoo`0BOol01@00Oomoogoo0000g7oo000TOol00`00Oomoo`03
Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`3IOol002Aoo`03001oogoo00=oo`03001o
ogoo019oo`03001oogoo009oo`03001oogoo0=Uoo`0097oo00<007ooOol00goo00<007ooOol04Woo
00<007ooOol00goo00<007ooOol0f7oo000TOol20004Ool00`00Oomoo`0BOol00`00Oomoo`03Ool0
0`00Oomoo`3HOol002Aoo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo
0=Qoo`0097oo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol0f7oo000T
Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`3HOol002Aoo`03001o
ogoo00=oo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo0=Moo`0097oo0P0017oo00<007oo
Ool04Goo00<007ooOol01Goo00<007ooOol0egoo000TOol00`00Oomoo`03Ool00`00Oomoo`0AOol0
0`00Oomoo`05Ool00`00Oomoo`3GOol002Aoo`03001oogoo00=oo`03001oogoo015oo`03001oogoo
00Eoo`03001oogoo0=Moo`0097oo00<007ooOol00goo00<007ooOol04Goo00<007ooOol01Goo00<0
07ooOol0egoo000TOol20004Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`3GOol002Ao
o`03001oogoo00=oo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo0=Moo`003goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool047oo00<007ooOol01Woo00<007ooOol0egoo000>Ool00`00Ool00008Ool01`00Oomoogoo001o
o`0000Aoo`03001oogoo00=oo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo01Qoo`03001o
ogoo0;aoo`003Woo00<007oo000027oo00<007ooOol00goo00<007ooOol00Woo0P001Goo00<007oo
Ool03goo00<007ooOol01goo00<007ooOol05Goo0`00_Woo000>Ool00`00Ool00009Ool00`00Oomo
o`020005Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`0COol20003
Ool00`00Oomoo`2kOol000ioo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00moo`03001oogoo00Moo`03001oogoo019oo`03001oogoo00=oo`03001o
ogoo0;]oo`003goo00<007ooOol01Woo0`000Woo0`0017oo00<007ooOol017oo00<007ooOol03Woo
00<007ooOol027oo00<007ooOol04Woo00<007ooOol00goo00<007ooOol0^goo000TOol20005Ool0
0`00Oomoo`0>Ool00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`2jOol0
02Aoo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Qoo`03001oogoo015oo`03001oogoo
00Eoo`03001oogoo0;Yoo`0097oo00<007ooOol017oo00<007ooOol03Woo00<007ooOol027oo00<0
07ooOol04Goo00<007ooOol01Goo00<007ooOol0^Woo000TOol00`00Oomoo`04Ool00`00Oomoo`0>
Ool00`00Oomoo`08Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`2iOol002Aoo`03001o
ogoo00Aoo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo011oo`03001oogoo00Ioo`03001o
ogoo0;Uoo`0097oo0P001Goo00<007ooOol03Woo00<007ooOol02Goo00<007ooOol047oo00<007oo
Ool01Woo00<007ooOol05Woo00<007ooOol0X7oo000TOol00`00Oomoo`04Ool00`00Oomoo`0=Ool0
0`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Ool0002QOol0
02Aoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00moo`03001oogoo
00Qoo`03001oogoo01=oo`05001oogooOol0002POol002Aoo`03001oogoo00Aoo`03001oogoo00eo
o`03001oogoo00Yoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo009o
o`03001oogoo09eoo`0097oo0P001Goo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol03goo
00<007ooOol027oo00<007ooOol04Woo00<007ooOol00goo00<007ooOol0WGoo000TOol00`00Oomo
o`04Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomo
o`0@Ool00`00Oomoo`05Ool00`00Oomoo`2LOol002Aoo`03001oogoo00Aoo`03001oogoo00eoo`03
001oogoo00Yoo`03001oogoo00moo`03001oogoo00Uoo`03001oogoo011oo`03001oogoo00Ioo`03
001oogoo01Eoo`8008Aoo`0097oo00<007ooOol017oo00<007ooOol03Goo00<007ooOol02Woo00<0
07ooOol03goo00<007ooOol02Goo00<007ooOol03goo00<007ooOol027oo00<007ooOol04goo00<0
07ooOol00`00PGoo000TOol20006Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool0
0`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`04Ool0
0`00Oomoo`1nOol002Aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo
00eoo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo011oo`03001oogoo
00Ioo`03001oogoo01=oo`H006Aoo`0077oo1@000goo00<007ooOol01Goo00<007ooOol037oo00<0
07ooOol02goo00<007ooOol03Goo00<007ooOol02goo00<007ooOol03Goo00<007ooOol02Woo00<0
07ooOol03goo00<007ooOol027oo00<007ooOol04Goo00<007ooOol017oo0P005goo1000Agoo000N
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0=
Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`09
Ool00`00Oomoo`0?Ool20009Ool2000AOol40004Ool4000DOol5000ZOol001ioo`03001oogoo00=o
o`8000Ioo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00]oo`03001o
ogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00eoo`03001o
ogoo00]oo`8000eoo`8000aoo`8000ioo`@000Eoo`T000Yoo`L0011oo`007Woo00<007ooOol00goo
00<007ooOol01Goo00<007ooOol02goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo
00<007ooOol02goo00<007ooOol03Goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo
00<007ooOol03Woo0P002Goo0P0047oo10001Goo1@004Woo2P005goo000NOol00`00Oomoo`03Ool0
0`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool0
0`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00Oomoo`08Ool2
000COol30004Ool2000FOol5000hOol001eoo`8000Eoo`03001oogoo00Eoo`03001oogoo00]oo`03
001oogoo00eoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00moo`03
001oogoo00Qoo`03001oogoo011oo`8000Ioo`8001Qoo`@005Eoo`0097oo00<007ooOol01Goo00<0
07ooOol02goo00<007ooOol03Goo00<007ooOol02goo00<007ooOol03Goo00<007ooOol02Woo00<0
07ooOol03goo00<007ooOol01goo00<007ooOol04goo00@007ooOomoo`8007=oo`0097oo0P001Woo
00<007ooOol02goo00<007ooOol03Goo00<007ooOol02goo00<007ooOol03Goo00<007ooOol02Woo
00<007ooOol047oo00<007ooOol01Woo00<007ooOol057oo0`00MGoo000TOol00`00Oomoo`05Ool0
0`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0>Ool00`00Oomoo`08Ool0
0`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`2=Ool002Aoo`03001oogoo00Eoo`03001oogoo
00]oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo00Qoo`03001oogoo
019oo`03001oogoo00=oo`03001oogoo08ioo`0097oo00<007ooOol01Goo00<007ooOol02goo00<0
07ooOol03Goo00<007ooOol02Woo00<007ooOol03goo00<007ooOol01goo00<007ooOol057oo00<0
07ooOol00P00TGoo000TOol20006Ool00`00Oomoo`0;Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool0
0`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Ool0002COol002Aoo`03001oogoo
00Eoo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo011oo`03001oogoo
00Eoo`03001oogoo01Ioo`03001oogoo099oo`0097oo00<007ooOol01Goo00<007ooOol02Woo00<0
07ooOol03goo00<007ooOol02Goo00<007ooOol047oo00<007ooOol01Goo00<007ooOol0Zgoo000T
Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`0@
Ool00`00Oomoo`04Ool00`00Oomoo`2/Ool002Aoo`8000Ioo`03001oogoo00Yoo`03001oogoo00mo
o`03001oogoo00Qoo`03001oogoo019oo`03001oogoo00=oo`03001oogoo0:aoo`0097oo00<007oo
Ool01Woo00<007ooOol02Goo00<007ooOol03goo00<007ooOol027oo00<007ooOol04goo00D007oo
Oomoo`000:moo`0097oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol047oo00<007ooOol0
1goo00<007ooOol057oo00@007ooOol00:moo`0097oo00<007ooOol01Woo00<007ooOol02Goo00<0
07ooOol047oo00<007ooOol01goo00<007ooOol05Goo0P00/7oo000TOol20007Ool00`00Oomoo`09
Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`0GOol00`00Oomoo`2^Ool002Aoo`03001o
ogoo00Ioo`03001oogoo00Uoo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo0<Qoo`003Goo
1@000Woo00@007ooOomoo`<000=oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Uoo`03
001oogoo011oo`03001oogoo00Ioo`03001oogoo0<Qoo`003goo00<007ooOol01Woo00<007ooOol0
0Woo00<007oo000017oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol047oo00<007ooOol0
1Woo00<007ooOol0b7oo000?Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20007
Ool00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`38Ool000moo`03001o
ogoo00Moo`04001oogooOol20005Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0AOol0
0`00Oomoo`04Ool00`00Oomoo`39Ool000moo`03001oogoo00Ioo`03001oo`00009oo`03001oogoo
00Aoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo
0<Uoo`003Woo0P002Goo00@007ooOomoo`<000Aoo`03001oogoo00Ioo`03001oogoo00Qoo`03001o
ogoo019oo`03001oogoo00Aoo`03001oogoo0<Uoo`0097oo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol04Woo00<007ooOol017oo00<007ooOol0bGoo000TOol20008Ool00`00Oomoo`07Ool0
0`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`39Ool002Aoo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo01=oo`03001oogoo009oo`03001oogoo0<Yoo`0097oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol04goo00<007ooOol00Woo00<007ooOol0bWoo000TOol00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`0COol6003<Ool002Aoo`8000Qoo`03001oogoo00Moo`03001o
ogoo0>Eoo`0097oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0iGoo000TOol00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`3UOol002Aoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo0>Eoo`0097oo0P002Goo00<007ooOol01Woo00<007ooOol0iGoo000TOol00`00Oomoo`08
Ool00`00Oomoo`06Ool00`00Oomoo`3UOol002Aoo`03001oogoo00Qoo`03001oogoo00Eoo`03001o
ogoo0>Ioo`0097oo00<007ooOol027oo00<007ooOol01Goo00<007ooOol0iWoo000TOol20009Ool0
0`00Oomoo`05Ool00`00Oomoo`3VOol002Aoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo
0>Ioo`0097oo00<007ooOol027oo00<007ooOol01Goo00<007ooOol0iWoo000BOol50002Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`3VOol001Ao
o`03001oogoo00Ioo`03001oo`0000Aoo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo0>Io
o`0057oo00<007ooOol027oo00<007ooOol00Woo0P002Woo00<007ooOol017oo00<007ooOol0iWoo
000DOol00`00Oomoo`06Ool20005Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`3WOol0
01Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo
0>Moo`004goo0P0027oo0`0017oo00<007ooOol02Goo00<007ooOol00goo00<007ooOol0igoo000T
Ool2000:Ool00`00Oomoo`03Ool00`00Oomoo`3WOol002Aoo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo0>Qoo`0097oo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol0j7oo000TOol0
0`00Oomoo`0:Ool01@00Oomoogoo0000jWoo000TOol2000;Ool01@00Oomoogoo0000jWoo000TOol0
0`00Oomoo`0:Ool01000Oomoo`00jgoo000TOol00`00Oomoo`0:Ool01000Oomoo`00jgoo000TOol0
0`00Oomoo`0:Ool01000Oomoo`00jgoo000TOol2000;Ool01000Oomoo`00jgoo000TOol00`00Oomo
o`0:Ool00`00Ool0003/Ool002Aoo`03001oogoo00Yoo`03001oo`000>aoo`0097oo00<007ooOol0
2goo0P00k7oo000TOol00`00Oomoo`0;Ool2003/Ool002Aoo`8000aoo`03001oogoo0>]oo`0097oo
00<007ooOol02goo00<007ooOol0jgoo000=Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`3iOol000moo`03001oogoo00Moo`07001oogooOol007oo000017oo
00<007ooOol0nGoo000?Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`02Ool2003jOol0
00moo`03001oogoo00Qoo`03001oogoo008000Eoo`03001oogoo0?Uoo`003goo00<007ooOol01Woo
00<007oo00000Woo00<007ooOol0ogoo0Goo000>Ool20008Ool30002Ool3003oOol1Ool00?moob5o
o`00ogoo8Goo003oOolQOol006Eoo`<0075oo`8004Eoo`00IWoo00<007ooOol0LGoo00<007ooOol0
@goo000oOol200000goo00000002Ool00`00Oomoo`030002Ool20002Ool30003Ool300000goo0000
000300001Goo001oo`00Ool00`000goo0P000goo0`004Woo0`000goo0P000Woo0`000goo0P0000=o
o`0000000Woo00<007ooOol00`003Woo0P000Woo0`000goo0`000Woo0P000Woo0`003Goo0`000goo
00@007ooOomoo`8000Aoo`8000=oo`800006Ool007oo001oo`00;goo000nOol01P00Oomoo`00Ool0
009oo`03001oo`00009oo`03001oo`0000Eoo`05001oogooOol00002Ool00`00Ool00002000027oo
001oo`00Ool007oo0002Ool00`00Ool00004Ool01000Oomoo`004Woo00<007oo00000Woo00<007oo
Ool00Woo00<007ooOol00Woo00H007ooOol007oo0002Ool00`00Ool00002Ool00`00Oomoo`05Ool4
0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`0000Eoo`03001oogoo00aoo`03
001oo`00009oo`03001oo`0000Aoo`04001oogoo0002Ool00`00Ool00003Ool01@00Ool007oo0000
;goo000nOol01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oo`00008000=oo`05001oogoo
Ool00002Ool03@00Oomoogoo001oo`00Ool007oo001oo`00009oo`03001oo`000080009oo`04001o
ogoo000DOol00`00Oomoo`030002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00
009oo`03001oogoo00]oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00000P000goo
00<007ooOol03Woo00H007ooOol007oo0003Ool01@00Oomoogoo000017oo0`0000Ioo`00Ool007oo
000_Ool003ioo`03001oogoo00D000=oo`<00004Ool000000002Ool40002Ool30002Ool200001Woo
000007oo001oo`@0009oo`<000=oo`<001=oo`04001oogooOol30002Ool30003Ool200000goo0000
00020003Ool3000=Ool01@00Oomoo`00Ool010000Woo0`0000Aoo`000000009oo`@000eoo`03001o
ogoo00800003Ool00000009oo`800003Ool000000080009oo`<00005Ool00000Ool0000`Ool003io
o`04001oogoo0009Ool00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`0@Ool00`00Ool0000I
Ool00`00Oomoo`0;Ool01000Oomoo`002Goo00<007ooOol057oo00<007oo000037oo00<007ooOol0
>Woo000mOol200000goo00000008Ool2000=Ool2000GOol2000BOol3000HOol2000>Ool20009Ool2
000FOol30019Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-7.70436, -0.142885, 
  0.212303, 0.0118178}},
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "This plots the response for various values of the damping ratio ",
  StyleBox["zeta", "MR"],
  ". We can see that the response changes from pure oscillation for ",
  StyleBox["zeta", "MR"],
  " ",
  StyleBox["=", "MR"],
  " ",
  StyleBox["0", "MR"],
  " (undamped case) to the exponential for ",
  StyleBox["zeta", "MR"],
  " ",
  StyleBox["=", "MR"],
  " ",
  StyleBox["1.5", "MR"],
  " (overdamped case). "
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
ListPlot3D[
 OutputResponse[s2[1., #],
 Table[1., {20}]
 ][[1]]& /@ Range[0, 1.5, .1],
 PlotLabel -> \"Second-Order System\",
 AxesLabel -> {t, \"zeta x 10\", \"y(t)\"},
 ViewPoint -> {-0.920, 3.110, 1.750},
 PlotRange -> All
]\
\>", "Input",
  CellLabel->"In[38]:=",
  CellTags->"4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.08276 -0.123347 1.08276 [
[.5 .75726 -59 0 ]
[.5 .75726 59 12.5625 ]
[.6596 .01792 -3.07212 -9 ]
[.6596 .01792 2.92788 0 ]
[.44183 .05585 -5.87947 -9 ]
[.44183 .05585 6.12053 0 ]
[.23241 .09234 -5.62867 -9 ]
[.23241 .09234 6.37133 0 ]
[.03089 .12747 -5.39076 -9 ]
[.03089 .12747 6.60924 0 ]
[.42216 -0.00809 -4.87815 -12.5625 ]
[.42216 -0.00809 5.12185 0 ]
[.2248 .6761 -6 -3.95764 ]
[.2248 .6761 0 5.04236 ]
[.12659 .57615 -12 -3.91022 ]
[.12659 .57615 0 5.08978 ]
[.0119 .4594 -12 -3.8537 ]
[.0119 .4594 0 5.1463 ]
[.09049 .6163 -58 -5.47906 ]
[.09049 .6163 0 7.08344 ]
[.01552 .1498 -6 -3.7212 ]
[.01552 .1498 0 5.2788 ]
[.00872 .21655 -18 -3.74933 ]
[.00872 .21655 0 5.25067 ]
[.00174 .28508 -6 -3.77825 ]
[.00174 .28508 0 5.22175 ]
[-0.00543 .35548 -18 -3.808 ]
[-0.00543 .35548 0 5.192 ]
[-0.0128 .42782 -6 -3.83861 ]
[-0.0128 .42782 0 5.16139 ]
[-0.06501 .29511 -28 -5.27339 ]
[-0.06501 .29511 0 7.28911 ]
[ 0 0 0 0 ]
[ 1 .74476 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .75726 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
99.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Order) show
141.000000 12.812500 moveto
(System) show
177.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math1Mono
%%+ Courier
grestore
.25 Mabswid
.84101 0 m
.02952 .14094 L
s
.65992 .03145 m
.66009 .03822 L
s
[(5)] .6596 .01792 .02404 1 Mshowa
.44155 .06938 m
.44142 .07614 L
s
[(10)] .44183 .05585 -0.02009 1 Mshowa
.23158 .10585 m
.23116 .1126 L
s
[(15)] .23241 .09234 -0.06189 1 Mshowa
.02952 .14094 m
.02884 .14767 L
s
[(20)] .03089 .12747 -0.10154 1 Mshowa
.125 Mabswid
.61555 .03916 m
.61562 .04322 L
s
.57154 .0468 m
.57156 .05086 L
s
.52787 .05439 m
.52786 .05845 L
s
.48454 .06191 m
.48449 .06597 L
s
.3989 .07679 m
.39879 .08084 L
s
.35658 .08414 m
.35643 .08819 L
s
.31459 .09143 m
.31441 .09548 L
s
.27292 .09867 m
.27271 .10272 L
s
.19055 .11297 m
.19026 .11702 L
s
.14983 .12004 m
.14952 .12409 L
s
.10942 .12706 m
.10908 .13111 L
s
.06932 .13403 m
.06894 .13807 L
s
.70465 .02368 m
.70479 .02774 L
s
.74974 .01585 m
.74991 .01991 L
s
.79519 .00796 m
.7954 .01201 L
s
gsave
.42216 -0.00809 -65.8782 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.25 Mabswid
.30719 .74476 m
0 .4317 L
s
.23823 .67448 m
.24495 .67367 L
s
[(5)] .2248 .6761 1 -0.12052 Mshowa
.14001 .57439 m
.14672 .57351 L
s
[(10)] .12659 .57615 1 -0.13106 Mshowa
.0253 .45748 m
.03199 .45652 L
s
[(15)] .0119 .4594 1 -0.14362 Mshowa
.125 Mabswid
.21974 .65563 m
.22377 .65514 L
s
.20069 .63622 m
.20472 .63572 L
s
.18107 .61623 m
.1851 .61572 L
s
.16086 .59563 m
.16488 .59511 L
s
.11852 .55248 m
.12254 .55194 L
s
.09633 .52987 m
.10035 .52932 L
s
.07342 .50652 m
.07744 .50597 L
s
.04976 .48241 m
.05378 .48184 L
s
.25621 .6928 m
.26024 .69232 L
s
.27368 .71061 m
.27771 .71013 L
s
.29067 .72792 m
.2947 .72745 L
s
gsave
.09049 .6163 -119 -9.47906 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(zeta) show
93.000000 12.812500 moveto
(x) show
105.000000 12.812500 moveto
(10) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.25 Mabswid
.02952 .14094 m
0 .4317 L
s
.02886 .14749 m
.03553 .14634 L
s
[(0)] .01552 .1498 1 -0.17307 Mshowa
.02207 .21432 m
.02875 .21321 L
s
[(0.5)] .00872 .21655 1 -0.16682 Mshowa
.0151 .28294 m
.02179 .28187 L
s
[(1)] .00174 .28508 1 -0.16039 Mshowa
.00795 .35343 m
.01464 .3524 L
s
[(1.5)] -0.00543 .35548 1 -0.15378 Mshowa
.00059 .42586 m
.00729 .42487 L
s
[(2)] -0.0128 .42782 1 -0.14698 Mshowa
.125 Mabswid
.02752 .16072 m
.03152 .16003 L
s
.02617 .17401 m
.03017 .17333 L
s
.02481 .18738 m
.02881 .1867 L
s
.02344 .20081 m
.02745 .20014 L
s
.02069 .2279 m
.0247 .22723 L
s
.01931 .24155 m
.02331 .24089 L
s
.01791 .25527 m
.02192 .25462 L
s
.01651 .26907 m
.02052 .26842 L
s
.01369 .29689 m
.0177 .29625 L
s
.01227 .31091 m
.01628 .31027 L
s
.01083 .325 m
.01485 .32438 L
s
.00939 .33918 m
.01341 .33855 L
s
.00649 .36775 m
.01051 .36714 L
s
.00503 .38216 m
.00904 .38155 L
s
.00356 .39665 m
.00757 .39605 L
s
.00208 .41121 m
.0061 .41062 L
s
gsave
-0.06501 .29511 -89 -9.27339 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
69.000000 12.812500 moveto
(H) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
81.000000 12.812500 moveto
(L) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
.97863 .407 m
1 .66631 L
s
1 .66631 m
.85971 .30581 L
s
.85971 .30581 m
.84101 0 L
s
.84101 0 m
.97863 .407 L
s
.31747 .49697 m
.02952 .14094 L
s
.02952 .14094 m
0 .4317 L
s
0 .4317 m
.30719 .74476 L
s
.30719 .74476 m
.31747 .49697 L
s
.97863 .407 m
1 .66631 L
s
1 .66631 m
.30719 .74476 L
s
.30719 .74476 m
.31747 .49697 L
s
.31747 .49697 m
.97863 .407 L
s
.84101 0 m
.02952 .14094 L
s
.02952 .14094 m
0 .4317 L
s
0 .4317 m
.85971 .30581 L
s
.85971 .30581 m
.84101 0 L
s
0 0 m
1 0 L
1 .74476 L
0 .74476 L
closepath
clip
newpath
.5 Mabswid
.75 .441 .461 r
.34878 .53711 .33075 .58613 .29714 .58259 .31719 .5039 Metetra
.808 .489 0 r
.37891 .64323 .36428 .60177 .33075 .58613 .34878 .53711 Metetra
.333 .291 .661 r
.41121 .72277 .39842 .61193 .36428 .60177 .37891 .64323 Metetra
.722 .588 .705 r
.4466 .69417 .43339 .60036 .39842 .61193 .41121 .72277 Metetra
.974 .847 .654 r
.48281 .58107 .46875 .5696 .43339 .60036 .4466 .69417 Metetra
0 0 .056 r
.5178 .4861 .50397 .54233 .46875 .5696 .48281 .58107 Metetra
.624 .313 .423 r
.55204 .48887 .53911 .54234 .50397 .54233 .5178 .4861 Metetra
.909 .529 .097 r
.58736 .58381 .57471 .57139 .53911 .54234 .55204 .48887 Metetra
.074 .131 .619 r
.62426 .68347 .611 .60223 .57471 .57139 .58736 .58381 Metetra
.634 .531 .72 r
.66072 .68838 .64733 .59866 .611 .60223 .62426 .68347 Metetra
.937 .795 .678 r
.69461 .58878 .68279 .55186 .64733 .59866 .66072 .68838 Metetra
.849 .832 .36 r
.72704 .47607 .71763 .49599 .68279 .55186 .69461 .58878 Metetra
.285 0 .214 r
.7617 .44705 .75361 .48056 .71763 .49599 .72704 .47607 Metetra
.886 .461 .076 r
.80129 .52288 .79247 .52539 .75361 .48056 .7617 .44705 Metetra
0 0 .42 r
.84415 .63435 .8336 .59542 .79247 .52539 .80129 .52288 Metetra
.402 .429 .774 r
.88436 .67294 .87323 .61922 .8336 .59542 .84415 .63435 Metetra
.924 .802 .706 r
.91746 .59544 .90766 .5557 .87323 .61922 .88436 .67294 Metetra
.995 .855 .584 r
.94641 .47284 .93826 .44827 .90766 .5557 .91746 .59544 Metetra
.95 .896 .738 r
.97912 .41289 .97174 .39113 .93826 .44827 .94641 .47284 Metetra
.27 .707 .963 r
.33075 .58613 .31428 .5769 .27994 .57936 .29714 .58259 Metetra
.338 .55 .911 r
.36428 .60177 .34881 .57601 .31428 .5769 .33075 .58613 Metetra
.541 .584 .847 r
.39842 .61193 .38365 .57342 .34881 .57601 .36428 .60177 Metetra
.714 .702 .838 r
.43339 .60036 .41885 .56614 .38365 .57342 .39842 .61193 Metetra
.851 .882 .861 r
.46875 .5696 .4543 .555 .41885 .56614 .43339 .60036 Metetra
.703 .982 .81 r
.50397 .54233 .48988 .54556 .4543 .555 .46875 .5696 Metetra
.088 0 0 r
.53911 .54234 .52561 .54419 .48988 .54556 .50397 .54233 Metetra
0 .296 .79 r
.57471 .57139 .56164 .55128 .52561 .54419 .53911 .54234 Metetra
.363 .439 .805 r
.611 .60223 .59806 .55781 .56164 .55128 .57471 .57139 Metetra
.662 .624 .802 r
.64733 .59866 .63463 .55072 .59806 .55781 .611 .60223 Metetra
.886 .83 .786 r
.68279 .55186 .671 .52601 .63463 .55072 .64733 .59866 Metetra
.898 .974 .673 r
.71763 .49599 .70723 .49773 .671 .52601 .68279 .55186 Metetra
.75361 .48056 .74418 .4906 .70723 .49773 .71763 .49599 Metetra
.632 .132 0 r
.79247 .52539 .78287 .51783 .74418 .4906 .75361 .48056 Metetra
0 .06 .622 r
.8336 .59542 .82309 .56096 .78287 .51783 .79247 .52539 Metetra
.471 .505 .812 r
.87323 .61922 .86241 .57296 .82309 .56096 .8336 .59542 Metetra
.908 .807 .737 r
.90766 .5557 .89787 .51859 .86241 .57296 .87323 .61922 Metetra
.99 .864 .616 r
.93826 .44827 .92991 .42336 .89787 .51859 .90766 .5557 Metetra
.943 .896 .751 r
.97174 .39113 .96415 .36875 .92991 .42336 .93826 .44827 Metetra
.597 .769 .962 r
.31428 .5769 .29769 .55836 .26285 .56247 .27994 .57936 Metetra
.593 .736 .943 r
.34881 .57601 .33276 .55432 .29769 .55836 .31428 .5769 Metetra
.625 .733 .925 r
.38365 .57342 .36808 .54971 .33276 .55432 .34881 .57601 Metetra
.673 .77 .923 r
.41885 .56614 .40365 .5441 .36808 .54971 .38365 .57342 Metetra
.702 .831 .944 r
.4543 .555 .43946 .53789 .40365 .5441 .41885 .56614 Metetra
.657 .862 .977 r
.48988 .54556 .47547 .53256 .43946 .53789 .4543 .555 Metetra
.529 .789 .992 r
.52561 .54419 .5117 .52965 .47547 .53256 .48988 .54556 Metetra
.47 .666 .948 r
.56164 .55128 .5482 .52889 .5117 .52965 .52561 .54419 Metetra
.546 .639 .893 r
.59806 .55781 .58498 .52701 .5482 .52889 .56164 .55128 Metetra
.679 .712 .873 r
.63463 .55072 .62197 .51943 .58498 .52701 .59806 .55781 Metetra
.81 .846 .877 r
.671 .52601 .65902 .50491 .62197 .51943 .63463 .55072 Metetra
.82 .976 .892 r
.70723 .49773 .69617 .48997 .65902 .50491 .671 .52601 Metetra
.382 .837 .916 r
.74418 .4906 .73386 .48693 .69617 .48997 .70723 .49773 Metetra
0 .311 .786 r
.78287 .51783 .77267 .50337 .73386 .48693 .74418 .4906 Metetra
.092 .303 .782 r
.82309 .56096 .81248 .52871 .77267 .50337 .78287 .51783 Metetra
.541 .578 .841 r
.86241 .57296 .85172 .53165 .81248 .52871 .82309 .56096 Metetra
.894 .813 .761 r
.89787 .51859 .88804 .4834 .85172 .53165 .86241 .57296 Metetra
.983 .871 .645 r
.92991 .42336 .92134 .39806 .88804 .4834 .89787 .51859 Metetra
.936 .895 .763 r
.96415 .36875 .95634 .34573 .92134 .39806 .92991 .42336 Metetra
.626 .772 .95 r
.29769 .55836 .28067 .53839 .24539 .54299 .26285 .56247 Metetra
.627 .767 .947 r
.33276 .55432 .3162 .53371 .28067 .53839 .29769 .55836 Metetra
.635 .769 .944 r
.36808 .54971 .35196 .52886 .3162 .53371 .33276 .55432 Metetra
.645 .78 .946 r
.40365 .5441 .38797 .52381 .35196 .52886 .36808 .54971 Metetra
.646 .794 .953 r
.43946 .53789 .42421 .51875 .38797 .52381 .40365 .5441 Metetra
.63 .795 .961 r
.47547 .53256 .46069 .51404 .42421 .51875 .43946 .53789 Metetra
.601 .771 .961 r
.5117 .52965 .4974 .50998 .46069 .51404 .47547 .53256 Metetra
.588 .736 .945 r
.5482 .52889 .53438 .50626 .4974 .50998 .5117 .52965 Metetra
.615 .726 .925 r
.58498 .52701 .57162 .50166 .53438 .50626 .5482 .52889 Metetra
.674 .762 .917 r
.62197 .51943 .60908 .49465 .57162 .50166 .58498 .52701 Metetra
.732 .836 .929 r
.65902 .50491 .64672 .48517 .60908 .49465 .62197 .51943 Metetra
.714 .899 .962 r
.69617 .48997 .68458 .47656 .64672 .48517 .65902 .50491 Metetra
.503 .82 1 r
.73386 .48693 .72289 .47497 .68458 .47656 .69617 .48997 Metetra
.244 .554 .931 r
.77267 .50337 .76196 .48422 .72289 .47497 .73386 .48693 Metetra
.311 .482 .867 r
.81248 .52871 .80169 .49752 .76196 .48422 .77267 .50337 Metetra
.603 .639 .86 r
.85172 .53165 .84102 .49361 .80169 .49752 .81248 .52871 Metetra
.882 .818 .781 r
.88804 .4834 .87811 .44956 .84102 .49361 .85172 .53165 Metetra
.975 .876 .673 r
.92134 .39806 .91256 .3723 .87811 .44956 .88804 .4834 Metetra
.928 .894 .775 r
.95634 .34573 .94831 .32203 .91256 .3723 .92134 .39806 Metetra
.631 .774 .949 r
.28067 .53839 .26317 .5179 .22743 .52271 .24539 .54299 Metetra
.632 .774 .949 r
.3162 .53371 .29915 .51304 .26317 .5179 .28067 .53839 Metetra
.633 .775 .949 r
.35196 .52886 .33537 .50812 .29915 .51304 .3162 .53371 Metetra
.634 .778 .95 r
.38797 .52381 .37183 .50316 .33537 .50812 .35196 .52886 Metetra
.633 .78 .952 r
.42421 .51875 .40854 .49821 .37183 .50316 .38797 .52381 Metetra
.628 .778 .953 r
.46069 .51404 .44549 .49336 .40854 .49821 .42421 .51875 Metetra
.622 .769 .951 r
.4974 .50998 .4827 .48862 .44549 .49336 .46069 .51404 Metetra
.622 .76 .945 r
.53438 .50626 .52016 .48378 .4827 .48862 .4974 .50998 Metetra
.635 .761 .939 r
.57162 .50166 .55789 .47843 .52016 .48378 .53438 .50626 Metetra
.659 .781 .939 r
.60908 .49465 .59586 .47213 .55789 .47843 .57162 .50166 Metetra
.677 .815 .949 r
.64672 .48517 .63406 .46518 .59586 .47213 .60908 .49465 Metetra
.651 .836 .971 r
.68458 .47656 .67254 .45939 .63406 .46518 .64672 .48517 Metetra
.545 .782 .986 r
.72289 .47497 .7114 .45775 .67254 .45939 .68458 .47656 Metetra
.427 .65 .952 r
.76196 .48422 .75082 .46184 .7114 .45775 .72289 .47497 Metetra
.457 .594 .901 r
.80169 .49752 .79068 .46679 .75082 .46184 .76196 .48422 Metetra
.651 .687 .87 r
.84102 .49361 .83023 .45775 .79068 .46679 .80169 .49752 Metetra
.873 .823 .796 r
.87811 .44956 .86803 .41665 .83023 .45775 .84102 .49361 Metetra
.966 .879 .698 r
.91256 .3723 .90354 .34605 .86803 .41665 .87811 .44956 Metetra
.921 .893 .785 r
.94831 .32203 .94003 .29763 .90354 .34605 .91256 .3723 Metetra
.632 .775 .949 r
.26317 .5179 .24515 .49688 .20896 .50184 .22743 .52271 Metetra
.632 .775 .949 r
.29915 .51304 .28159 .49189 .24515 .49688 .26317 .5179 Metetra
.632 .776 .95 r
.33537 .50812 .31828 .48686 .28159 .49189 .29915 .51304 Metetra
.632 .776 .95 r
.37183 .50316 .35522 .4818 .31828 .48686 .33537 .50812 Metetra
.631 .776 .95 r
.40854 .49821 .39241 .47673 .35522 .4818 .37183 .50316 Metetra
.63 .775 .95 r
.44549 .49336 .42985 .47164 .39241 .47673 .40854 .49821 Metetra
.629 .772 .949 r
.4827 .48862 .46756 .46652 .42985 .47164 .44549 .49336 Metetra
.631 .77 .947 r
.52016 .48378 .50553 .46128 .46756 .46652 .4827 .48862 Metetra
.637 .773 .946 r
.55789 .47843 .54376 .45578 .50553 .46128 .52016 .48378 Metetra
.645 .784 .948 r
.59586 .47213 .58225 .45 .54376 .45578 .55789 .47843 Metetra
.647 .798 .955 r
.63406 .46518 .62101 .44424 .58225 .45 .59586 .47213 Metetra
.625 .799 .966 r
.67254 .45939 .66006 .43945 .62101 .44424 .63406 .46518 Metetra
.572 .764 .969 r
.7114 .45775 .69946 .437 .66006 .43945 .67254 .45939 Metetra
.522 .695 .948 r
.75082 .46184 .73928 .43718 .69946 .437 .7114 .45775 Metetra
.549 .662 .911 r
.79068 .46679 .77941 .43617 .73928 .43718 .75082 .46184 Metetra
.687 .722 .876 r
.83023 .45775 .81928 .42328 .77941 .43617 .79068 .46679 Metetra
.865 .827 .809 r
.86803 .41665 .85777 .38432 .81928 .42328 .83023 .45775 Metetra
.956 .882 .72 r
.90354 .34605 .89427 .31924 .85777 .38432 .86803 .41665 Metetra
.913 .892 .795 r
.94003 .29763 .93151 .27249 .89427 .31924 .90354 .34605 Metetra
.632 .775 .949 r
.24515 .49688 .22661 .47527 .18995 .48037 .20896 .50184 Metetra
.632 .775 .949 r
.28159 .49189 .26352 .47013 .22661 .47527 .24515 .49688 Metetra
.632 .775 .95 r
.31828 .48686 .30069 .46495 .26352 .47013 .28159 .49189 Metetra
.632 .775 .95 r
.35522 .4818 .33811 .45974 .30069 .46495 .31828 .48686 Metetra
.631 .775 .95 r
.39241 .47673 .3758 .4545 .33811 .45974 .35522 .4818 Metetra
.631 .775 .949 r
.42985 .47164 .41375 .44922 .3758 .4545 .39241 .47673 Metetra
.632 .774 .949 r
.46756 .46652 .45196 .44388 .41375 .44922 .42985 .47164 Metetra
.633 .775 .949 r
.50553 .46128 .49045 .43847 .45196 .44388 .46756 .46652 Metetra
.635 .777 .949 r
.54376 .45578 .52921 .43296 .49045 .43847 .50553 .46128 Metetra
.636 .781 .951 r
.58225 .45 .56824 .42742 .52921 .43296 .54376 .45578 Metetra
.633 .785 .955 r
.62101 .44424 .60755 .42207 .56824 .42742 .58225 .45 Metetra
.619 .78 .959 r
.66006 .43945 .64715 .41735 .60755 .42207 .62101 .44424 Metetra
.594 .757 .956 r
.69946 .437 .68708 .41373 .64715 .41735 .66006 .43945 Metetra
.578 .72 .94 r
.73928 .43718 .72736 .41082 .68708 .41373 .69946 .437 Metetra
.609 .704 .912 r
.77941 .43617 .76786 .40544 .72736 .41082 .73928 .43718 Metetra
.713 .748 .879 r
.81928 .42328 .80813 .38965 .76786 .40544 .77941 .43617 Metetra
.858 .831 .82 r
.85777 .38432 .8473 .3523 .80813 .38965 .81928 .42328 Metetra
.946 .883 .74 r
.89427 .31924 .88473 .29182 .8473 .3523 .85777 .38432 Metetra
.906 .89 .804 r
.93151 .27249 .92273 .24659 .88473 .29182 .89427 .31924 Metetra
.632 .775 .949 r
.22661 .47527 .20751 .45301 .17037 .45826 .18995 .48037 Metetra
.632 .775 .949 r
.26352 .47013 .24491 .44771 .20751 .45301 .22661 .47527 Metetra
.632 .775 .949 r
.30069 .46495 .28257 .44238 .24491 .44771 .26352 .47013 Metetra
.632 .775 .949 r
.33811 .45974 .32049 .43701 .28257 .44238 .30069 .46495 Metetra
.632 .775 .949 r
.3758 .4545 .35869 .4316 .32049 .43701 .33811 .45974 Metetra
.632 .775 .949 r
.41375 .44922 .39715 .42615 .35869 .4316 .3758 .4545 Metetra
.632 .775 .949 r
.45196 .44388 .43589 .42065 .39715 .42615 .41375 .44922 Metetra
.632 .776 .95 r
.49045 .43847 .47491 .41512 .43589 .42065 .45196 .44388 Metetra
.632 .777 .95 r
.52921 .43296 .51421 .40955 .47491 .41512 .49045 .43847 Metetra
.632 .778 .951 r
.56824 .42742 .55379 .40402 .51421 .40955 .52921 .43296 Metetra
.628 .777 .952 r
.60755 .42207 .59365 .3986 .55379 .40402 .56824 .42742 Metetra
.621 .771 .952 r
.64715 .41735 .63382 .39346 .59365 .3986 .60755 .42207 Metetra
.613 .757 .947 r
.68708 .41373 .67429 .38855 .63382 .39346 .64715 .41735 Metetra
.614 .737 .933 r
.72736 .41082 .71506 .38311 .67429 .38855 .68708 .41373 Metetra
.648 .732 .911 r
.76786 .40544 .756 .37445 .71506 .38311 .72736 .41082 Metetra
.732 .767 .88 r
.80813 .38965 .79675 .35648 .756 .37445 .76786 .40544 Metetra
.852 .834 .828 r
.8473 .3523 .83658 .32037 .79675 .35648 .80813 .38965 Metetra
.935 .883 .757 r
.88473 .29182 .87492 .26375 .83658 .32037 .8473 .3523 Metetra
.899 .888 .812 r
.92273 .24659 .91367 .21988 .87492 .26375 .88473 .29182 Metetra
.632 .775 .949 r
.20751 .45301 .18783 .43007 .1502 .43549 .17037 .45826 Metetra
.632 .775 .949 r
.24491 .44771 .22573 .42461 .18783 .43007 .20751 .45301 Metetra
.632 .775 .949 r
.28257 .44238 .26389 .41912 .22573 .42461 .24491 .44771 Metetra
.632 .775 .949 r
.32049 .43701 .30233 .41358 .26389 .41912 .28257 .44238 Metetra
.632 .775 .949 r
.35869 .4316 .34105 .408 .30233 .41358 .32049 .43701 Metetra
.632 .775 .95 r
.39715 .42615 .38005 .40239 .34105 .408 .35869 .4316 Metetra
.632 .775 .95 r
.43589 .42065 .41932 .39674 .38005 .40239 .39715 .42615 Metetra
.632 .776 .95 r
.47491 .41512 .45889 .39105 .41932 .39674 .43589 .42065 Metetra
.631 .776 .95 r
.51421 .40955 .49874 .38534 .45889 .39105 .47491 .41512 Metetra
.631 .775 .95 r
.55379 .40402 .53888 .3796 .49874 .38534 .51421 .40955 Metetra
.629 .773 .949 r
.59365 .3986 .57932 .37386 .53888 .3796 .55379 .40402 Metetra
.628 .768 .947 r
.63382 .39346 .62005 .36803 .57932 .37386 .59365 .3986 Metetra
.629 .759 .94 r
.67429 .38855 .66108 .36181 .62005 .36803 .63382 .39346 Metetra
.64 .749 .928 r
.71506 .38311 .70238 .35428 .66108 .36181 .67429 .38855 Metetra
.675 .751 .909 r
.756 .37445 .74381 .34309 .70238 .35428 .71506 .38311 Metetra
.746 .781 .881 r
.79675 .35648 .78508 .32346 .74381 .34309 .756 .37445 Metetra
.847 .837 .836 r
.83658 .32037 .8256 .28832 .78508 .32346 .79675 .35648 Metetra
.925 .882 .773 r
.87492 .26375 .86481 .23497 .8256 .28832 .83658 .32037 Metetra
.892 .886 .819 r
.91367 .21988 .90433 .19233 .86481 .23497 .87492 .26375 Metetra
.632 .775 .949 r
.18783 .43007 .16754 .40643 .12941 .41201 .1502 .43549 Metetra
.632 .775 .949 r
.22573 .42461 .20595 .4008 .16754 .40643 .18783 .43007 Metetra
.632 .775 .949 r
.26389 .41912 .24464 .39513 .20595 .4008 .22573 .42461 Metetra
.632 .775 .949 r
.30233 .41358 .28361 .38942 .24464 .39513 .26389 .41912 Metetra
.632 .775 .949 r
.34105 .408 .32286 .38367 .28361 .38942 .30233 .41358 Metetra
.632 .775 .949 r
.38005 .40239 .3624 .37788 .32286 .38367 .34105 .408 Metetra
.632 .775 .949 r
.41932 .39674 .40223 .37203 .3624 .37788 .38005 .40239 Metetra
.632 .775 .949 r
.45889 .39105 .44236 .36614 .40223 .37203 .41932 .39674 Metetra
.632 .774 .949 r
.49874 .38534 .48278 .36018 .44236 .36614 .45889 .39105 Metetra
.632 .773 .948 r
.53888 .3796 .5235 .35411 .48278 .36018 .49874 .38534 Metetra
.633 .771 .946 r
.57932 .37386 .56452 .34786 .5235 .35411 .53888 .3796 Metetra
.636 .767 .942 r
.62005 .36803 .60584 .34122 .56452 .34786 .57932 .37386 Metetra
.643 .762 .935 r
.66108 .36181 .64745 .33375 .60584 .34122 .62005 .36803 Metetra
.659 .759 .924 r
.70238 .35428 .6893 .32446 .64745 .33375 .66108 .36181 Metetra
.693 .765 .907 r
.74381 .34309 .73127 .31128 .6893 .32446 .70238 .35428 Metetra
.755 .791 .882 r
.78508 .32346 .77311 .29037 .73127 .31128 .74381 .34309 Metetra
.842 .839 .842 r
.8256 .28832 .81432 .25602 .77311 .29037 .78508 .32346 Metetra
.915 .882 .787 r
.86481 .23497 .8544 .20543 .81432 .25602 .8256 .28832 Metetra
.885 .884 .826 r
.90433 .19233 .89468 .1639 .8544 .20543 .86481 .23497 Metetra
.632 .775 .949 r
.16754 .40643 .14662 .38204 .10797 .3878 .12941 .41201 Metetra
.632 .775 .949 r
.20595 .4008 .18556 .37624 .14662 .38204 .16754 .40643 Metetra
.632 .775 .949 r
.24464 .39513 .22478 .37038 .18556 .37624 .20595 .4008 Metetra
.632 .775 .949 r
.28361 .38942 .26429 .36449 .22478 .37038 .24464 .39513 Metetra
.632 .775 .949 r
.32286 .38367 .3041 .35854 .26429 .36449 .28361 .38942 Metetra
.632 .775 .949 r
.3624 .37788 .3442 .35254 .3041 .35854 .32286 .38367 Metetra
.632 .775 .949 r
.40223 .37203 .3846 .34646 .3442 .35254 .3624 .37788 Metetra
.632 .774 .948 r
.44236 .36614 .4253 .3403 .3846 .34646 .40223 .37203 Metetra
.633 .773 .948 r
.48278 .36018 .46631 .33401 .4253 .3403 .44236 .36614 Metetra
.635 .772 .946 r
.5235 .35411 .50763 .32751 .46631 .33401 .48278 .36018 Metetra
.638 .77 .943 r
.56452 .34786 .54925 .32065 .50763 .32751 .5235 .35411 Metetra
.643 .768 .939 r
.60584 .34122 .59118 .31316 .54925 .32065 .56452 .34786 Metetra
.654 .766 .932 r
.64745 .33375 .63338 .3045 .59118 .31316 .60584 .34122 Metetra
.673 .767 .921 r
.6893 .32446 .67581 .2937 .63338 .3045 .64745 .33375 Metetra
.707 .775 .905 r
.73127 .31128 .71837 .27892 .67581 .2937 .6893 .32446 Metetra
.762 .799 .883 r
.77311 .29037 .76081 .257 .71837 .27892 .73127 .31128 Metetra
.837 .84 .848 r
.81432 .25602 .80273 .2233 .76081 .257 .77311 .29037 Metetra
.906 .88 .799 r
.8544 .20543 .84366 .17507 .80273 .2233 .81432 .25602 Metetra
.879 .882 .833 r
.89468 .1639 .88473 .13454 .84366 .17507 .8544 .20543 Metetra
.632 .775 .949 r
.14662 .38204 .12504 .35688 .08586 .36283 .10797 .3878 Metetra
.632 .775 .949 r
.18556 .37624 .16452 .35088 .12504 .35688 .14662 .38204 Metetra
.632 .775 .949 r
.22478 .37038 .20429 .34483 .16452 .35088 .18556 .37624 Metetra
.632 .775 .949 r
.26429 .36449 .24436 .33872 .20429 .34483 .22478 .37038 Metetra
.632 .775 .949 r
.3041 .35854 .28473 .33255 .24436 .33872 .26429 .36449 Metetra
.632 .775 .949 r
.3442 .35254 .32541 .3263 .28473 .33255 .3041 .35854 Metetra
.633 .774 .948 r
.3846 .34646 .3664 .31996 .32541 .3263 .3442 .35254 Metetra
.634 .774 .947 r
.4253 .3403 .40769 .31347 .3664 .31996 .3846 .34646 Metetra
.636 .773 .946 r
.46631 .33401 .44931 .30678 .40769 .31347 .4253 .3403 Metetra
.638 .772 .944 r
.50763 .32751 .49124 .29977 .44931 .30678 .46631 .33401 Metetra
.643 .771 .941 r
.54925 .32065 .53348 .29225 .49124 .29977 .50763 .32751 Metetra
.651 .77 .936 r
.59118 .31316 .57603 .28389 .53348 .29225 .54925 .32065 Metetra
.664 .77 .929 r
.63338 .3045 .61885 .27414 .57603 .28389 .59118 .31316 Metetra
.685 .773 .918 r
.67581 .2937 .6619 .26202 .61885 .27414 .63338 .3045 Metetra
.717 .783 .904 r
.71837 .27892 .70507 .24593 .6619 .26202 .67581 .2937 Metetra
.767 .805 .884 r
.76081 .257 .74816 .22322 .70507 .24593 .71837 .27892 Metetra
.833 .841 .853 r
.80273 .2233 .7908 .19006 .74816 .22322 .76081 .257 Metetra
.897 .879 .809 r
.84366 .17507 .83257 .14385 .7908 .19006 .80273 .2233 Metetra
.872 .88 .838 r
.88473 .13454 .87444 .1042 .83257 .14385 .84366 .17507 Metetra
.632 .775 .949 r
.12504 .35688 .10276 .33088 .06303 .33704 .08586 .36283 Metetra
.632 .775 .949 r
.16452 .35088 .1428 .32467 .10276 .33088 .12504 .35688 Metetra
.632 .775 .949 r
.20429 .34483 .18313 .3184 .1428 .32467 .16452 .35088 Metetra
.632 .775 .949 r
.24436 .33872 .22378 .31207 .18313 .3184 .20429 .34483 Metetra
.633 .775 .949 r
.28473 .33255 .26473 .30564 .22378 .31207 .24436 .33872 Metetra
.633 .774 .948 r
.32541 .3263 .30601 .29912 .26473 .30564 .28473 .33255 Metetra
.634 .774 .947 r
.3664 .31996 .3476 .29245 .30601 .29912 .32541 .3263 Metetra
.636 .773 .946 r
.40769 .31347 .38951 .28559 .3476 .29245 .3664 .31996 Metetra
.638 .773 .945 r
.44931 .30678 .43175 .27845 .38951 .28559 .40769 .31347 Metetra
.642 .772 .942 r
.49124 .29977 .47431 .27089 .43175 .27845 .44931 .30678 Metetra
.648 .772 .939 r
.53348 .29225 .51719 .26268 .47431 .27089 .49124 .29977 Metetra
.658 .772 .933 r
.57603 .28389 .56038 .25347 .51719 .26268 .53348 .29225 Metetra
.672 .774 .926 r
.61885 .27414 .60385 .24269 .56038 .25347 .57603 .28389 Metetra
.693 .779 .917 r
.6619 .26202 .64754 .22943 .60385 .24269 .61885 .27414 Metetra
.725 .79 .904 r
.70507 .24593 .69136 .21224 .64754 .22943 .6619 .26202 Metetra
.77 .81 .885 r
.74816 .22322 .73512 .18889 .69136 .21224 .70507 .24593 Metetra
.829 .842 .857 r
.7908 .19006 .7785 .15619 .73512 .18889 .74816 .22322 Metetra
.888 .877 .819 r
.83257 .14385 .82113 .1117 .7785 .15619 .7908 .19006 Metetra
.866 .878 .844 r
.87444 .1042 .86381 .07285 .82113 .1117 .83257 .14385 Metetra
.632 .775 .949 r
.10276 .33088 .07976 .30401 .03947 .31038 .06303 .33704 Metetra
.632 .775 .949 r
.1428 .32467 .12036 .29758 .07976 .30401 .10276 .33088 Metetra
.632 .775 .949 r
.18313 .3184 .16128 .29107 .12036 .29758 .1428 .32467 Metetra
.633 .775 .948 r
.22378 .31207 .20252 .28447 .16128 .29107 .18313 .3184 Metetra
.634 .774 .948 r
.26473 .30564 .24408 .27777 .20252 .28447 .22378 .31207 Metetra
.634 .774 .947 r
.30601 .29912 .28596 .27093 .24408 .27777 .26473 .30564 Metetra
.636 .774 .946 r
.3476 .29245 .32818 .2639 .28596 .27093 .30601 .29912 Metetra
.638 .773 .945 r
.38951 .28559 .37072 .25663 .32818 .2639 .3476 .29245 Metetra
.641 .773 .943 r
.43175 .27845 .41361 .249 .37072 .25663 .38951 .28559 Metetra
.646 .773 .94 r
.47431 .27089 .45682 .24085 .41361 .249 .43175 .27845 Metetra
.653 .773 .937 r
.51719 .26268 .50036 .23195 .45682 .24085 .47431 .27089 Metetra
.664 .774 .931 r
.56038 .25347 .54421 .22191 .50036 .23195 .51719 .26268 Metetra
.679 .777 .925 r
.60385 .24269 .58835 .21017 .54421 .22191 .56038 .25347 Metetra
.7 .783 .915 r
.64754 .22943 .63271 .19589 .58835 .21017 .60385 .24269 Metetra
.73 .794 .903 r
.69136 .21224 .67721 .17777 .63271 .19589 .64754 .22943 Metetra
.771 .814 .886 r
.73512 .18889 .72167 .1539 .67721 .17777 .69136 .21224 Metetra
.825 .843 .862 r
.7785 .15619 .76581 .12157 .72167 .1539 .73512 .18889 Metetra
.88 .875 .827 r
.82113 .1117 .8093 .07857 .76581 .12157 .7785 .15619 Metetra
.86 .876 .849 r
.86381 .07285 .85281 .04042 .8093 .07857 .82113 .1117 Metetra
.632 .775 .949 r
.07976 .30401 .05599 .27622 .01512 .28283 .03947 .31038 Metetra
.633 .775 .949 r
.12036 .29758 .09718 .26953 .05599 .27622 .07976 .30401 Metetra
.633 .775 .948 r
.16128 .29107 .1387 .26276 .09718 .26953 .12036 .29758 Metetra
.634 .774 .948 r
.20252 .28447 .18055 .25588 .1387 .26276 .16128 .29107 Metetra
.635 .774 .947 r
.24408 .27777 .22273 .24886 .18055 .25588 .20252 .28447 Metetra
.636 .774 .947 r
.28596 .27093 .26524 .24168 .22273 .24886 .24408 .27777 Metetra
.638 .774 .945 r
.32818 .2639 .3081 .23426 .26524 .24168 .28596 .27093 Metetra
.641 .773 .944 r
.37072 .25663 .3513 .22654 .3081 .23426 .32818 .2639 Metetra
.645 .773 .942 r
.41361 .249 .39485 .21839 .3513 .22654 .37072 .25663 Metetra
.65 .774 .939 r
.45682 .24085 .43874 .20964 .39485 .21839 .41361 .249 Metetra
.658 .774 .935 r
.50036 .23195 .48296 .20003 .43874 .20964 .45682 .24085 Metetra
.669 .776 .93 r
.54421 .22191 .5275 .18919 .48296 .20003 .50036 .23195 Metetra
.685 .78 .923 r
.58835 .21017 .57233 .17657 .5275 .18919 .54421 .22191 Metetra
.706 .787 .914 r
.63271 .19589 .61739 .16138 .57233 .17657 .58835 .21017 Metetra
.735 .798 .903 r
.67721 .17777 .66259 .14245 .61739 .16138 .63271 .19589 Metetra
.773 .817 .887 r
.72167 .1539 .70778 .11812 .66259 .14245 .67721 .17777 Metetra
.821 .843 .865 r
.76581 .12157 .75272 .08611 .70778 .11812 .72167 .1539 Metetra
.872 .873 .834 r
.8093 .07857 .79707 .04438 .75272 .08611 .76581 .12157 Metetra
.854 .874 .853 r
.85281 .04042 .84143 .00686 .79707 .04438 .8093 .07857 Metetra
0 g
.25 Mabswid
.97863 .407 m
1 .66631 L
s
1 .66631 m
.85971 .30581 L
s
.85971 .30581 m
.84101 0 L
s
.84101 0 m
.97863 .407 L
s
.84101 0 m
.02952 .14094 L
s
.02952 .14094 m
0 .4317 L
s
0 .4317 m
.85971 .30581 L
s
.85971 .30581 m
.84101 0 L
s
.84101 0 m
.02952 .14094 L
s
.65992 .03145 m
.66009 .03822 L
s
[(5)] .6596 .01792 .02404 1 Mshowa
.44155 .06938 m
.44142 .07614 L
s
[(10)] .44183 .05585 -0.02009 1 Mshowa
.23158 .10585 m
.23116 .1126 L
s
[(15)] .23241 .09234 -0.06189 1 Mshowa
.02952 .14094 m
.02884 .14767 L
s
[(20)] .03089 .12747 -0.10154 1 Mshowa
.125 Mabswid
.61555 .03916 m
.61562 .04322 L
s
.57154 .0468 m
.57156 .05086 L
s
.52787 .05439 m
.52786 .05845 L
s
.48454 .06191 m
.48449 .06597 L
s
.3989 .07679 m
.39879 .08084 L
s
.35658 .08414 m
.35643 .08819 L
s
.31459 .09143 m
.31441 .09548 L
s
.27292 .09867 m
.27271 .10272 L
s
.19055 .11297 m
.19026 .11702 L
s
.14983 .12004 m
.14952 .12409 L
s
.10942 .12706 m
.10908 .13111 L
s
.06932 .13403 m
.06894 .13807 L
s
.70465 .02368 m
.70479 .02774 L
s
.74974 .01585 m
.74991 .01991 L
s
.79519 .00796 m
.7954 .01201 L
s
gsave
.42216 -0.00809 -65.8782 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.25 Mabswid
.30719 .74476 m
0 .4317 L
s
.23823 .67448 m
.24495 .67367 L
s
[(5)] .2248 .6761 1 -0.12052 Mshowa
.14001 .57439 m
.14672 .57351 L
s
[(10)] .12659 .57615 1 -0.13106 Mshowa
.0253 .45748 m
.03199 .45652 L
s
[(15)] .0119 .4594 1 -0.14362 Mshowa
.125 Mabswid
.21974 .65563 m
.22377 .65514 L
s
.20069 .63622 m
.20472 .63572 L
s
.18107 .61623 m
.1851 .61572 L
s
.16086 .59563 m
.16488 .59511 L
s
.11852 .55248 m
.12254 .55194 L
s
.09633 .52987 m
.10035 .52932 L
s
.07342 .50652 m
.07744 .50597 L
s
.04976 .48241 m
.05378 .48184 L
s
.25621 .6928 m
.26024 .69232 L
s
.27368 .71061 m
.27771 .71013 L
s
.29067 .72792 m
.2947 .72745 L
s
gsave
.09049 .6163 -119 -9.47906 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(zeta) show
93.000000 12.812500 moveto
(x) show
105.000000 12.812500 moveto
(10) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{288, 214.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eQ000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00TGoo0P00SGoo002@Ool01000Oomoo`00
S7oo002@Ool00`00Oomoo`2=Ool008moo`@008eoo`00T7oo00<007ooOol0SGoo003oOolQOol00<]o
o`03001oogoo059oo`00bWoo00<007oo0000Dgoo003<Ool00`00Oomoo`1AOol00<Yoo`8005Aoo`00
bWoo00<007ooOol0:Goo0`009goo003:Ool3000SOol60002Ool00`00Oomoo`0UOol00>Yoo`H000Mo
o`<002Ioo`00i7oo1P000goo00<007ooOol01Goo0P0000=[NP0000009Woo003NOol6000@Ool01000
JgY[NV]j0P009Woo002BOol50002Ool00`00Oomoo`0kOol70004Ool00`00Oomoo`0>Ool00`00JgY[
NP02JgX3000UOol009Aoo`07001oogooOol007oo0000>7oo1@006Woo00<006]jJgX00f]j00<006]j
00009Goo002DOol01`00Oomoogoo001oo`00035oo`L001ioo`03001[NV]j00A[NP03001[NP0002Eo
o`00U7oo00L007ooOomoo`00Ool0000/Ool6000ROol20007JgX01000JgX0000097oo002DOol01`00
Oomoogoo001oo`0002Ioo`H000Eoo`03001oogoo01moo`03001[NV]j00M[NP04001[NV]j000TOol0
09=oo`8000Aoo`03001oogoo01moo`L002]oo`03001[NV]j00U[NP03001[NP0002Aoo`00]Woo1@00
<Goo0P002f]j10008goo002`Ool7000dOol01000KgY_NP002F]j0P000Vmj00<007ooOol08Goo002Z
Ool6000jOol01@00KgY_NVmj000026]j00<006mj00000Vmj00<007ooOol08Goo001OOol50002Ool0
0`00Oomoo`0kOol60002Ool00`00Oomoo`0jOol00`00KgY_NP02KgX00`00JgY[NP05JgX01000KgY_
NP000Vmj0P008Woo001QOol01`00Oomoogoo001oo`0003Ioo`H004Aoo`03001_NVmj00A_NP03001[
NV]j00=[NP05001_NVmjKgX00002KgX2000ROol0065oo`03001oogoo00=oo`03001oogoo02ioo`H0
00=oo`03001oogoo04=oo`03001_NVmj00E_NP03001[NV]j009[NP03001_NVmj009_NP05001_NVmj
KgX0000ROol0065oo`04001oogooOol2000/Ool5001>Ool00`00KgY_NP06KgX00`00JgY[NP020005
KgX01000KgY_NVmj0P008Goo001QOol01@00Oomoogoo00009Woo1`0017oo00<007ooOol0Bgoo00<0
06mjKgX026mj0P001fmj00<006mjKgX00`008Goo001POol20003Ool3000OOol6001GOol00`00KgY_
NP09KgX00`00KgY_NP06KgX00`00KgX00002KgX00`00Oomoo`0OOol0085oo`H005aoo`03001_NVmj
00U_NP8000Q_NP8000=_NP80021oo`00Ngoo1P0000=oo`00Ool0GWoo00<006mjKgX02Fmj00@006mi
KgT000M_NP03001_NVmj00=_NP03001oogoo01ioo`00MGoo1P00IGoo0P0000=WF`00KgX026mj00D0
06miKgU_N@0000I_NP8000E_NP03001oogoo01ioo`00;goo0`000goo00<007ooOol0>7oo1@000goo
00<007ooOol0I7oo00D006MKIe]WF`0000Q_NP03001_NFmi00=_N@03001_NVmj009_NP03001_NP00
00E_NP8001moo`00;goo00<007ooOol00Woo00<007oo0000<goo1P00KGoo0P001FMK00<006mjKgX0
16mj00<006miKgT016mi00D006mjKgY_NP00009_NP03001_NVmj00A_NP03001oogoo01eoo`00<7oo
00L007ooOomoo`00Ool0000]Ool60004Ool00`00Oomoo`1ZOol20007Ie/00`00KgY_NP03KgX00`00
KgU_N@05KgT01000KgY_NP000fmj00<006mjKgX016mj00<007ooOol07Goo000`Ool01`00Oomoogoo
001oo`0002Moo`L007Eoo`03001WFfMK00QWF`05001_NVmjKgX00009KgT20004KgX00`00KgY_NP03
KgX3000NOol002moo`03001oo`00009oo`03001oo`00025oo`H000Ioo`03001oogoo075oo`8000]W
F`04001_NVmj000:KgT00`00KgY_NP03KgX00`00KgY_NP02KgX01000KgY_NP007Woo000`Ool00`00
Oomoo`02Ool00`00Oomoo`0KOol50002Ool00`00Oomoo`1jOol00`00Ie]WF`0<Ie/2000:KgT20006
KgX01000KgY_NP000fmj00<007ooOol077oo001=Ool60022Ool3000>Ie/00`00KgU_N@08KgT01000
KgU_N@001Fmj00<006mj000016mj0P007Goo0017Ool60003Ool00`00Oomoo`20Ool20003Hc/00`00
Ie]WF`09Ie/30009KgT01@00KgU_NFmi00001Fmj0P001Fmj0P007Goo0011Ool6002:Ool20005Hc/0
0`00Ie]WF`08Ie/01@00Ie]WFfMK00001fmi00<006miKgT00fmi00<006mjKgX00Vmj00<006mjKgX0
1Fmj00<007ooOol06goo000kOol60005Ool00`00Oomoo`26Ool20008Hc/00`00Ie]WF`06Ie/00`00
Ie]WF`02Ie/00`00KgU_N@04KgT00`00KgU_N@04KgT01000KgY_NVmj0P001fmj0P0077oo000eOol6
00000goo001oo`2?Ool2000:Hc/00`00Ie]WF`04Ie/20005Ie/00`00KgU_N@04KgT00`00KgU_N@04
KgT01P00KgY_NP00KgX000I_NP<001aoo`00<Woo0`00UWoo0P003F<k00<006MKIe/00VMK00<006MK
Ie/01VMK00<006miKgT00Vmi00<006miKgT01Vmi0P000Vmj00<006mjKgX00fmj00@006mjKgX001ao
o`00;7oo00<007ooOol00goo0`00U7oo0P0000=O?000Hc/036<k00D006MKIe]WF`0000UWF`05001_
NFmiKgT00009KgT01@00KgY_NVmj000016mj00@006mjKgY_NP8001]oo`00:goo00<007oo000017oo
0`00TWoo0P0015ll00<006<kHc/02f<k0`002VMK00@006miKgT000U_N@8000=_NP05001_NVmjKgX0
0005KgX00`00Oomoo`0IOol002]oo`03001oo`0000Aoo`03001oo`00091oo`8000IO?003001S>f<k
00]S>`03001WFfMK00]WF`8000U_N@04001cNG=i0002KgX01000KgY_NP001Vmj00<007ooOol06Goo
000[Ool00`00Ool00004Ool01000Oomoo`00SGoo0P002Ell00<006<kHc/026<k0`003FMK00<006mi
KgT01fmi00D007=iLgUcN@00009_NP03001_NP0000M_NP8001Yoo`00:goo00<007oo000017oo0P00
0Woo00<007ooOol0Qgoo0`002ell00<006<kHc/01V<k0P000f<k00<006MKIe/026MK0`0026mi00<0
07=iLgT00W=i00<006mjKgX00P002Fmj00<007ooOol067oo000/Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`23Ool30002Fa`00`00GcaO?00:Gc`00`00Hc]S>`03Hc/20005Hc/00`00Ie]W
F`07Ie/01@00JeY[FV]J00001Vmi00<007=iLgT00g=i00@006mjKgX000Y_NP03001oogoo01Qoo`00
<Goo00<007ooOol017oo00<007ooOol0P7oo0P001E/L00<005llGc`02Ull00@006<kHc]S>`8000MS
>`03001WFfMK00IWF`03001[FV]J009[FP03001_NFmi00A_N@03001cNG=i00AcN@<000U_NP<001Uo
o`00<Goo0`001Goo00<007ooOol0O7oo0`0025/L00<005llGc`02Ull0`002V<k00<006MKIe/00fMK
0P001V]J00<006miKgT00Vmi00<007=iLgT01G=i00<006mj000026mj00@006nIKiT001Uoo`00<Goo
00<007ooOol01Goo00<007ooOol0NGoo0`002e/L00<005llGc`02Ell0P0036<k00<006MKIe/00VMK
00<006]JJeX01V]J00D006miKgU_N@0000McN@800003KgX006mj00I_NP05001_VFnIKiT0000IOol0
035oo`03001oogoo00Ioo`03001oogoo07Eoo`<0009G7@03001K75/L00YK7003001O?5ll00EO?0<0
0003Fc`006<k00]S>`05001WFfMKIe/00009JeX01000KgU_N@001g=i00<007=iLgT00P001Vmj00<0
06nIKiT00VnI0P0067oo000aOol20008Ool00`00Oomoo`1`Ool40005Ead00`00FaaK700:Fa`00`00
GcaO?003Gc`20005Fc`00`00Hc]S>`0:Hc/3000;JeX20008LgT00`00LgUcN@020005KgX00`00KiU_
V@04KiT00`00Oomoo`0FOol0035oo`03001oogoo00Qoo`03001oogoo06]oo`@000YG7@03001K75/L
00YK7003001O?000008000MK?003001S>f<k00US>`8000e[FP03001cNG=i00IcN@03001cNG=i009c
N@03001_NVmj009_NP03001_VFnI00E_V@03001oogoo01Ioo`00<Goo00<007ooOol02Goo00<007oo
Ool0I7oo1P000e<M00<005LMEad025LM00<005/LFa`02E/L0`002e/l00<006<kHc/01V<k0P0000=S
>`00JeX02V]J0`001g=i00<007=iLgT00g=i0P000Vmj00<006nIKiT01FnI0`005goo000aOol2000:
Ool00`00Oomoo`1POol40009Dad00`00EaeG7@09Ead00`00FaaK7005Fa`30002Ea`00`00FcaK?009
Fc`00`00Hc]S>`04Hc/20004Hc/00`00JeY[FP07JeX01@00JeY[FV]J00001G=i00<007=iLgT017=i
0P0000=_NP00KiT01VnI00@007>ILiT001Moo`00<Goo00<007ooOol02Woo00<007ooOol0Fgoo1000
0U<M00<005<MDad02E<M00<005LMEad025LM00<005/LFa`00e/L0P001ELL00<005/lFc`02E/l00<0
06<kHc/00V<k0P001V<k00<006]JJeX01V]J00<006]JJeX00V]J00<007=iLgT00g=i00<007=iLgT0
1G=i0P0026nI00@007>ILiT001Moo`00<7oo00<007ooOol037oo00<007ooOol0EWoo10001U<M00<0
05<MDad02E<M00<005LMEad02ELM00<005/L00000P0025LL00<005/lFc`02E/l00@006<k000000US
>`03001[FV]J00=[FP8000I[FP05001cNG=iLgT00008LgT00`00KiU_V@06KiT00`00LiUcV@02LiT0
0`00Oomoo`0DOol0021oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00eoo`03001oogoo055oo`@000]C7@03001C7E<M00UC7@03001G7ELM00MG7@<000]G7003001K?5/l
00QK?0<000]S>`03001[FV]J009[FP03001[FV]J00I[FP04001cNG=i0008LgT20007KiT00`00LiUc
V@03LiT00`00Oomoo`0DOol001moo`03001oo`0000Moo`03001oo`0000Aoo`<000ioo`03001oogoo
04Yoo`H000=C7@03001C7E<M00UC7@03001C7E<M00UC7@03001G7ELM00AG7@<0009G7@03001G75LL
00YG7003001K?5/l00EK?080009K?003001S>f<k00US>`05001[FV]JJeX00009JeX00`00LgT00008
LgT01000LgP000001FnI00<007>ILiT017>I0P005Goo000OOol00`00Ool00009Ool00`00Oomoo`02
Ool00`00Oomoo`0?Ool00`00Oomoo`14Ool50009Dad00`00DaeC7@0:Dad00`00DaeC7@09Dad00`00
Ead000030005Ead00`00EaaG700:Ea`00`00FcaK?002Fc`30004Fc`00`00Hc]S>`0:Hc/3000;JeX2
0007LgT00`00LgQcN0020004KiT00`00LiUcV@06LiT00`00Oomoo`0COol001moo`03001oo`0000Mo
o`8000Eoo`03001oogoo00moo`03001oogoo03moo`D000=C7@03001C7E<M00UC7@03001C7E<M00UC
7@03001C7E<M00MC7@@000YG7@03001G75LL00YG7004001K?0000008Fc`00`00Hc]S>`09Hc/00`00
JeY[FP0;JeX00`00LgUcN@06LgT01P00LgQcN000LgP0009_V@03001cVG>I00IcV@8001Eoo`007goo
00<007oo00001goo00<007ooOol017oo0P004Goo00<007ooOol0>Goo1@0025<M00<005<MDad02E<M
00<005<MDad02U<M00<005<MDad01P000e<M00<005LMEad025LM00<005LLEa`02ELL0`002U/l00<0
06<kHc/01f<k0`002f]J0`001g=i00L007=hLgQcN000LgP00002KiT00`00LiUcV@05LiT01000LiT0
000057oo000POol00`00Oomoo`06Ool30004Ool00`00Oomoo`0AOol00`00Oomoo`0bOol60003Dad0
0`00DaeC7@08Dad00`00DaeC7@09Dad00`00DaeC7@07Dad50009Dad00`00EaeG7@09Ead00`00EaaG
7005Ea`300000eLL001K?00;Fc`00`00Hc]S>`04Hc/20003Hc/00`00JeY[FP07JeX01@00JeY[FV]J
00001G=i00<007=hLgP00W=h00<007=hLgP00P001g>I00D007>ILiUcV@0001Aoo`00<7oo00<007oo
Ool04Woo00<007ooOol0:Woo1`002E<M00<005<MDad02E<M00<005<MDad025<M00@005<MDaeC7@H0
00=C7@03001C7E<M00UC7@03001G7ELM00QG7@03001G75LL00=G708000EG7003001K?5/l00UK?003
001S>f<k009S>`8000ES>`03001[FV]J00I[FP03001[FV]J009[FP03001cNG=i009cN@03001cN7=h
00=cN004001cN7=h0007LiT00`00LiUcV@02LiT00`00Oomoo`0BOol0031oo`8001Aoo`03001oogoo
025oo`P000E?7@03001C7E<M00UC7@03001C7E<M00UC7@03001C7E<M00IC7@D000UC7@03001C7E<M
00UC7@03001G7ELM00UG7@03001G7000008000MG7003001K?5/l00YK?004001S>`000008Hc/00`00
JeY[FP03JeX20005JeX01@00LgUcNG=i00001W=h00@007=h000000IcV@03001cVG>I00=cV@03001o
ogoo019oo`00<7oo00<007ooOol04goo00<007ooOol06goo1P000dlM00<004lMCad01dlM00<005<M
Dad02E<M00<005<MDad02E<M00@005<MDaeC7@D000=C7@03001C7E<M00UC7@03001C7E<M00UC7@03
001G7ELM00IG7@@000]G7003001K?5/l00QK?0<000YS>`03001[FV]J009[FP03001[FV]J00E[FP04
001cNG=i0007LgP20002MgP00`00LiUcV@03LiT00`00LiUcV@04LiT00`00Oomoo`0AOol002moo`03
001oogoo01Eoo`03001oogoo01Eoo`D000U?7@03001?7DlM00Q?7@03001C7E<M00UC7@03001C7E<M
00MC7@D000QC7@03001C7E<M00UC7@03001C7E<M00UC7@04001G7ELMEad50003Ead00`00EaaG7009
Ea`00`00FcaK?005Fc`300000e/L001S>`0:Hc/01@00JeY[FV]J00002F]J00<007=i00001g=h0P00
0WMh00<007>ILiT00W>I00<007>ILiT01G>I00<007ooOol04Goo000_Ool00`00Oomoo`0FOol00`00
Oomoo`0?Ool50003Cad00`00Cae?7@09Cad00`00Cae?7@08Cad00`00DaeC7@08Dad01000DaeC7E<M
1P000e<M00<005<MDad025<M00<005<MDad02E<M00<005<MDad025<M100025LM00<005LLEa`02ELL
00<005/lFc`00e/l0P001E/L00<006<kHc/02F<k0`002V]J0P0027=h00D007MhMgQgN00000=cV@03
001cVG>I00EcV@8001=oo`00;goo0`005goo00<007ooOol02Goo1@002DlM00<004lMCad02DlM00<0
04lMCad024lM00<005<MDad01U<M1@002E<M00<005<MDad02E<M00<005<MDad025<M00<005<MDad0
15<M100000=C7@00Ead02ULM00<005LLEa`02ELL00<005/l00000P001e/L00<006<kHc/02F<k00<0
06]JJeX02V]J00<007=hLgP01W=h0P000gMh00@007>ILiT000McV@04001cVG>I000BOol002moo`03
001oogoo01Qoo`03001oogoo00=oo`D000=?7@03001?7DlM00U?7@03001?7DlM00Q?7@03001?7DlM
00Q?7@04001C7E<MDad50003Cad00`00DaeC7@09Dad00`00DaeC7@08Dad00`00DaeC7@09Dad00`00
Dad000030006Dad00`00EaeG7@08Ead00`00EaaG7008Ea`3000:Fa`00`00Hc]S>`07Hc/3000;JeX2
0007LgP00`00MgP00004MgP20007LiT01@00LiUcVG>I00004Woo000_Ool00`00Oomoo`0GOol70009
Cad00`00Cae?7@08Cad00`00Cae?7@09Cad00`00Cae?7@06Cad50008Cad00`00DaeC7@09Dad00`00
DaeC7@09Dad00`00DaeC7@06Dad4000:Dad00`00EaeG7@09Ead00`00EaaG7004Ea`30002Ea`00`00
FaaK7009Fa`00`00Hc]S>`04Hc/20003Gc/00`00JeY[FP06JeX20002JeX00`00LgQcN004LgP00`00
MgP00004MgP00`00LiUcV@05LiT00`00LiUcV@02LiT00`00Oomoo`0@Ool002moo`80011oo`P000E?
7@03001?7DlM00U?7@03001?7DlM00Q?7@03001?7DlM00Q?7@04001?7DlMCad50003Cad00`00Cae?
7@08Cad00`00DaeC7@09Dad00`00DaeC7@08Dad01000DaeC7E<M1@000e<M00<005<MDad02E<M00<0
05LMEad025LM00<005LLEa`010001ELL00<005/LFa`02E/L00<006<kHc/00f<k00<005lkGc/00elk
00<006]JJeX01F]J00<006]JJeX00V]J00<007=hLgP00g=h00D007MhMgQgN000009gN08000IcV@03
001cVG>I00AcV@03001oogoo00moo`00;goo00<007ooOol02Woo1@000dlM00<004lMCad024lM00<0
04lMCad024lM00<004lMCad02DlM00<004lMCad014lM1`0024lM00<004lMCad02DlM00<005<MDad0
25<M00<005<MDad015<M200025<M00<005<MDad02E<M00<005LMEad025LM0`002ULL00<005/LFa`0
25/L00@006<kHc]S>`8000MO>`03001[FV]J00=[FP03001[FV]J00A[FP05001cN7=hLgP00004MgP0
1P00MgQgN000MiL000EcV@03001cVG>I00AcV@03001oogoo00moo`00;goo00<007ooOol00goo1`00
2DlM00<004lMCad024lM00<004lMCad024lM00<004lMCad01dlM20001DlM00<004lMCad024lM00<0
04lMCad02DlM00<005<MDad01U<M20001U<M00<005<MDad025<M00<005<MDad025<M00<005LMEad0
15LM100000=C7@00Ea`02ULL00<005/LFa`02E/L0`002Elk00<006]JJeX00V]J00<006]JJeX01F]J
00@007=hLgP000EgN003001gN000009gU`03001cVG>I009cV@03001cVG>I00AcV@80015oo`009goo
1@000goo1P001DlM00<004lMCad02DlM00<004lMCad024lM00<004lMCad024lM00@004lMCae?7@D0
00=?7@03001?7DlM00Q?7@03001?7DlM00Q?7@03001?7DlM00Q?7@04001C7E<MDad50003Cad00`00
DaeC7@08Dad00`00DaeC7@08Dad00`00DaeC7@09Dad00`00Ead000030006Dad00`00EaaG7009Ea`0
0`00FaaK7007Fa`2000;Gc/00`00JeY[FP020008JeX01000LgQcN0001GMh0P000gNG00D007>ILiUc
V@0000IcV@04001cV7>H000@Ool000=oo`8000Moo`03001oogoo00Ioo`03001oogoo015oo`03001o
ogoo00=oo`8000Y?7@03001?7DlM00Q?7@03001?7DlM00U?7@03001?7DlM00A?7@L000Q?7@03001?
7DlM00U?7@03001?7DlM00Q?7@03001?7DlM00I?7@D000Q?7@03001C7E<M00UC7@03001C7E<M00QC
7@03001C7E<M00IC7@@000YC7@03001G75LL00UG7003001K75/L00AK70<00003Fa`005lk00]O>`80
00][FP8000IgN08000=gU`04001cVG>I0007LiT01000LiQcV00047oo0004Ool00`00Oomoo`04Ool0
0`00Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool01000Oomoo`002TlM00<004lMCad024lM
00<004lMCad01dlM20001DlM00<004lMCad024lM00<004lMCad024lM00<004lMCad024lM00@004lM
Cae?7@D000=?7@03001?7DlM00Q?7@03001C7E<M00QC7@03001C7E<M00QC7@04001C7E<MDad50003
Dad00`00DaeC7@09Dad00`00EaaG7009Ea`00`00Fa`000030005Fa`00`00Gc]O>`09Gc/00`00JeY[
FP0:JeX00`00MgQgN005MgP00`00MiMgU`03MiL20007LiT01@00LiQcV7>H000047oo0004Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool01@00Oomoogoo
00002DlM00<004lMCad02DlM00@004lMCae?7@D000=?7@03001?7DlM00M?7@03001?7DlM00U?7@03
001?7DlM00Q?7@03001?7DlM00A?7@L000Q?7@03001?7DlM00U?7@03001C7E<M00QC7@03001C7E<M
00IC7@D000QC7@03001C7E<M00UC7@03001G75LL00QG70<000UK7003001O>elk00MO>`<000][FP80
00IgN08000EgU`03001cVG>I00EcV@03001cV7>H00=cV003001oogoo00eoo`000goo00<007oo0000
17oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00moo`03001oogoo009oo`<00003Ool0
04lM00U?7@03001?7DlM00M?7@D000Q?7@03001?7DlM00Q?7@03001?7DlM00U?7@03001?7DlM00I?
7@P000E?7@03001?7DlM00Q?7@03001?7DlM00U?7@03001C7E<M00MC7@04001C7E<MDad50003Dad0
0`00DaeC7@08Dad00`00DaeC7@08Dad00`00EaaG7004Ea`400000eLL001K700:Fa`00`00Gc]O>`04
Gc/20003Gc/00`00JeY[FP06JeX20002JeX00`00MgQgN003MgP20004MiL00`00MiL00005LiT00`00
LiQcV004LiP00`00Oomoo`0=Ool000=oo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo00ioo`8000Aoo`03001oogoo009oo`03001?7DlM00Q?7@04001?7DlMCad50003Cad0
0`00Cae?7@08Cad00`00Cae?7@08Cad00`00Cae?7@08Cad01000Cae?7DlM1@000dlM00<004lMCad0
1dlM00<004lMCad024lM00<004lMCad02DlM00<005<MDad015<M1`0025<M00<005<MDad025<M00<0
05<MDad02E<M00<005LL00000`001ULL00<005/LFa`025/L00<005lkGc/00Ulk0P001Elk00<006]J
JeX01F]J00<006]JJeX00V]J00<007MhMgP00WMh00<007NG000017NG00<007NG000017>I00<007>H
LiP017>H0P003goo0002Ool200000goo00000003Ool01000Oomoogoo10001Goo00<007ooOol057oo
00<007ooOol00goo00<004lMCad014lM1`0024lM00<004lMCad02DlM00<004lMCad024lM00<004lM
Cad01TlM1@0024lM00<004lMCad024lM00<004lMCad024lM00<004lMCad01dlM20001DlM00<005<M
Dad025<M00<005<MDad025<M00<005<MDad01U<M10002ULL00<005/LFa`02E/L00@005lk000000QO
>`03001[FV]J00=[FP03001[FV]J00A[FP03001gN7Mh00@000=gU`05001gUgNGMiL00002LiT00`00
LiQcV004LiP01000LiQcV0003Woo000;Ool01@00Oomoogoo00001Woo00<007ooOol05Goo0P001Goo
1P001DlM00<004lMCad024lM00<004lMCad02DlM00<004lMCad01dlM00@004lMCae?7@D000=?7@03
001?7DlM00Q?7@03001?7DlM00Q?7@03001?7DlM00M?7@04001?7DlMCad60003Cad00`00Cae?7@07
Cad00`00DaeC7@08Dad00`00DaeC7@08Dad01000DaeC7E<M1@000e<M00<005LLEa`02ELL00<005/L
Fa`01e/L0`002Ulk00<006]JJeX00V]J00@006]JJeY[FPP0009gU`04001gUgNG0004MiL01000LiUc
V@001W>H00@007>HLiP000ioo`0037oo00<007ooOol01Woo00<007ooOol05Woo00<007ooOol01Goo
00<004lMCad024lM00<004lMCad024lM00<004lMCad024lM00<004lMCad014lM1`0024lM00<004lM
Cad024lM00<004lMCad024lM00<004lMCad014lM1`002DlM00<004lMCad024lM00<005<MDad025<M
00<005<MDad01U<M1@0025<M00<005LLEa`02ELL00<005/LFa`01E/L0P0000=G7000Gc/02Ulk00<0
06]JJeX01P0016]J00<007Mh000017NG00<007NG00001GNG0P001W>H00D007>HLiQcV00000ioo`00
;Woo00<007ooOol01Woo00<004lMCad024lM00<004lMCad024lM00<004lMCad01TlM20001DlM00<0
04lMCad024lM00<004lMCad024lM00<004lMCad01TlM20001DlM00<004lMCad02DlM00<004lMCad0
24lM00<005<MDad01e<M00@005<MDaeC7@D000=C7@03001C7E<M00QC7@03001G75LL00QG7003001K
75/L009K70<000AG7003001O>elk00AO>`L000][FP8000AgU`8000IgU`03001cV7>H00AcV003001c
V7>H00=cV003001oogoo00]oo`00;Woo00<007ooOol01goo00<004lMCad01dlM00<004lMCad024lM
00@004lMCae?7@D000=?7@03001?7DlM00Q?7@03001?7DlM00Q?7@03001?7DlM00M?7@04001?7DlM
Cad50003Cad00`00Cae?7@08Cad00`00Cae?7@08Cad00`00Cae?7@08Cad00`00DaeC7@04Dad70008
Dad00`00DaeC7@08Dad00`00EaaG7009Ea`01000Fa`000001eLL1`001Elk00<006]JJeX02V]J00<0
07NGMiL00gNG0P001GNG0P001G>H00<007>HLiP017>H00<007ooOol02goo000^Ool20008Ool00`00
Cae?7@08Cad00`00Cae?7@04Cad70008Cad00`00Cae?7@09Cad00`00Cae?7@08Cad00`00Cae?7@05
Cad50008Cad00`00Cae?7@09Cad00`00Cae?7@08Cad00`00Cae?7@06Cad80005Cad00`00DaeC7@08
Dad00`00DaeC7@08Dad00`00EaaG7006Ea`40002Ea`700000eLL001O>`07Gc/3000;JeX20005MiL2
0005MiL00`00NgH00004LiP00`00LiQcV003LiP2000=Ool002eoo`03001oogoo00Uoo`03001?7DlM
00I?7@P000E?7@03001?7DlM00Q?7@03001?7DlM00Q?7@03001?7DlM00Q?7@04001?7DlMCad40003
Cad00`00Cae?7@08Cad00`00Cae?7@08Cad00`00Cae?7@08Cad01000Cae?7DlM1@000dlM00<004lM
Cad01dlM00<005<MDad025<M00<005<MDad025<M00@005LLEaaG70/000QG7003001O>elk00AO>`80
00=O6`03001[FV]J00I[FP80009[F@07001gUgNGMiL007NG000017NG00@007]fNgH000=cV003001c
V7>H00=cV004001gV7NH000<Ool002eoo`03001oogoo00Yoo`04001?7DlMCad40003Cad00`00Cae?
7@08Cad00`00Cae?7@08Cad00`00Cae?7@08Cad00`00Cae?7@04Cad70008Cad00`00Cae?7@08Cad0
0`00Cae?7@08Cad00`00Cae?7@04Cad70008Cad00`00Cae?7@08Cad00`00DaeC7@08Dad00`00DaeC
7@06Dad:0003Dad00`00EaaG7008Ea`00`00Gc]O>`02Gc/20005Ga/00`00JeY[FP05JeX00`00JeU[
F@02JeT01@00MiMgUgNG00000WNG00D007NGMiMgU`00009kMP04001cV7>H0006LiP01000MiQgV000
37oo000]Ool3000;Ool30008Cad00`00Cae?7@08Cad00`00Cae?7@08Cad00`00Cae?7@06Cad80005
Cad00`00Cae?7@08Cad00`00Cae?7@08Cad00`00Cae?7@06Cad80005Cad00`00Cae?7@08Cad00`00
Cae?7@08Cad00`00DaeC7@07Dad01000DaeC7E<M20002U<M00<005LLEa`02ELL00@005lk000000QO
6`03001[FV]J00=[FP03001[FF]I00=[F@04001gUgNG0003MiL01000MiMgU`000g]f00<007>H0000
1W>H00D007NHMiQgV00000aoo`00;Goo00<007ooOol037oo00<004lMCad024lM00<004lMCad01dlM
00<004lMCad024lM00@004lMCae?7@D000=?7@03001?7DlM00M?7@03001?7DlM00Q?7@03001?7DlM
00Q?7@04001?7DlMCad50003Cad00`00Cae?7@07Cad00`00Cae?7@08Cad00`00Cae?7@08Cad00`00
DaeC7@04Dad80007Dad00`00DaeC7@08Dad00`00EaaG7007Ea`3000:Ga/00`00JeY[FP02JeX00`00
JeU[F@04JeT00`00MiL00005MiL00`00MiL00004NgH20005LiP00`00MiQgV003MiP00`00Oomoo`09
Ool002eoo`03001oogoo00eoo`03001?7DlM00Q?7@03001?7DlM00M?7@03001?7DlM00A?7@L000U?
7@03001?7DlM00M?7@03001?7DlM00Q?7@03001?7DlM00A?7@L000Q?7@03001?7DlM00Q?7@03001?
7DlM00Q?7@03001?7DlM00I?7@T000A?7@03001C7E<M00MC7@03001C7E<M00QC7@03001G75LL00AG
70<00003E_`005lK00YO6`03001[FV]J008000Q[F@8000EgU`8000EkMP03001cV7>H00=cV003001g
V7NH00AgV003001oogoo00Uoo`006goo1@000Woo00<007ooOol00Woo00<007ooOol00goo00<007oo
00003Woo00<004lMCad024lM00<004lMCad00dlM2P001DlM00<004lMCad02DlM00<004lMCad01dlM
00<004lMCad01TlM20001DlM00<004lMCad024lM00<004lMCad024lM00<004lMCad01dlM00@004lM
Cae?7@P000Y?7@03001C7E<M00QC7@03001C7E<M00QC7@03001G700000<000EFo003001O6elK00UO
6`8000Y[F@03001gUgNG00AgU`03001kMW]f00=kMP8000EcV003001gV7NH00=gV08000]oo`007Goo
00<007ooOol01Woo00<007oo000017oo0P003goo00<004lMCad01dlM1`001DlM00<004lMCad024lM
00<004lMCad024lM00<004lMCad01dlM00@004lMCae?7@D000=?7@03001?7DlM00M?7@03001?7DlM
00Q?7@03001?7DlM00Q?7@03001?7DlM00A?7@P000M?7@03001?7DlM00Q?7@03001C7E<M00MC7@03
001C7E<M00IC7@@000UFo003001O6elK00UO6`03001[FF]I00Q[F@8000IgU`8000AkMP03001kM@00
00=cV003001gV7NH00=gV004001gUgNG000:Ool001eoo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo00moo`04001?7DlMCad50003Cad00`00Cae?7@07Cad00`00Cae?7@08Cad00`00Cae?7@08
Cad00`00Cae?7@03Cad70008Cad00`00Cae?7@08Cad00`00Cae?7@08Cad00`00Cae?7@06Cad90004
Cad00`00Cae?7@07Cad00`00Cae?7@08Cad00`00DaeC7@08Dad00`00DaeC7@050002C_d00`00E_aF
o009E_`00`00Ga]O6`06Ga/30009JeT01000JeU[F@0017NG00<007]f00000g]f00@007]eNgD0009c
V003001gV7NH00AgV004001gUgNG000:Ool001eoo`03001oogoo00Ioo`8000Eoo`03001oogoo011o
o`<000Q?7@03001?7DlM00Q?7@03001?7DlM00M?7@03001?7DlM00M?7@L000E?7@03001?7DlM00Q?
7@03001?7DlM00Q?7@03001?7DlM00M?7@04001?7DlMCad700000dlM001?7@08Cad00`00Cae?7@08
Cad00`00Cae?7@08Cad00`00DaeC7@03Dad70008C_d00`00E_aFo008E_`00`00Ga]O6`04Ga/20003
Fa/00`00JeU[F@05JeT01@00JeU[FF]I000017NG00@007]fNgH0009kMP06001kMG]e001cV0001WNH
00@007NGMiMgU`8000Uoo`007Goo00<007ooOol01Woo00<007ooOol017oo0P004Woo00<004lMCad0
24lM00<004lMCad01dlM00<004lMCad024lM00@004lMCae?7@D000=?7@03001?7DlM00M?7@03001?
7DlM00M?7@03001?7DlM00Q?7@03001?7DlM00A?7@P000M?7@03001?7DlM00Q?7@03001?7DlM00M?
7@03001?7DlM00I?7@P000E?7@03001>oDkm00M>o@03001Fo5Kl00QFo003001O6elK009O6`8000EK
6`03001[FF]I00A[F@03001[FF]I00=[F@04001gUgNG0003NgH00`00NgH00004NgD20005MiP00`00
MiMgU`03MiL00`00Oomoo`07Ool001aoo`8000Qoo`<000=oo`03001oogoo01=oo`03001?7DlM00Q?
7@03001?7DlM00M?7@03001?7DlM00A?7@L000Q?7@03001?7DlM00Q?7@03001?7DlM00M?7@03001?
7DlM00I?7@T000A?7@03001?7DlM00Q?7@03001?7DlM00M?7@03001?7DlM00Q?7@03001?7DlM00D0
00=?7@03001?7DlM00M?7@03001>oDkm00Q>o@03001Fo5Kl00QFo004001O6`000008Fa/00`00JeU[
F@02JeT00`00JeU[F@04JeT01000MiMgU`000g]f00<007]f000017]e00<007NHMiP00gNH00<007NG
MiL00gNG0P002Goo000/Ool00`00Oomoo`0DOol00`00Cae?7@08Cad00`00Cae?7@05Cad80005Cad0
0`00Cae?7@08Cad00`00Cae?7@07Cad00`00Cae?7@07Cad01000Cae?7DlM1`0000=?7@00Cad024lM
00<004lMCad02DlM00<004lMCad01dlM00<004lMCad00dlM1`0024lM00<004lMCad024lM00<004km
C_d01dkm00<005KlE_`01UKl10002U/K00D006]IJeU[F@0000M[F@03001gU`0000EkMP03001kMG]e
00=kM@03001gV7NH00=gV003001gUgNG00=gU`<000Qoo`00;7oo00<007oo00005Goo00<004lMCad0
1dlM00@004lMCae?7@@000=?7@03001?7DlM00Q?7@03001?7DlM00Q?7@03001?7DlM00M?7@03001?
7DlM00=?7@P000M?7@03001?7DlM00Q?7@03001?7DlM00Q?7@03001?7DlM00=?7@X000E?7@03001?
7DlM00Q?7@03001?7DlM00M?7@03001>oDkm00Q>o@03001Fo5Kl00D0009Bo003001K6e/K00UK6`04
001[FF]I0009JeT20005NgH00`00NgEkM@02NgD00`00NgD00003MiP00`00MiMgU`03MiL01000MiMg
U`0027oo000/Ool2000GOol00`00Cae?7@03Cad70008Cad00`00Cae?7@08Cad00`00Cae?7@07Cad0
0`00Cae?7@04Cad:0004Cad00`00Cae?7@08Cad00`00Cae?7@08Cad00`00Cae?7@06Cad70005Cad0
0`00Cae?7@07Cad00`00Cae?7@08Cad00`00Cae?7@08Cad00`00C_e>o@03C_d70008D_`00`00Fa]K
6`09Fa/2000:JeT00`00NgIkMP03NgH00`00NgD00003NgD00`00NgD00002MiP00`00MiMgU`03MiL0
1@00MiMgUgNG000027oo000/Ool00`00Oomoo`0GOol50005Cad00`00Cae?7@08Cad00`00Cae?7@07
Cad00`00Cae?7@06Cad;0002Cad00`00Cae?7@07Cad00`00Cae?7@08Cad00`00Cae?7@07Cad01000
Cae?7DlM1@000dlM00<004lMCad01TlM00<004lMCad024lM00<004lMCad024lM00<004lMCad00dlM
2P0014km00<005;lD_`025;l00<005/KFa/025/K0P002V]I0P001G]f00<007]e00000W]e00H007]e
NgD007NH0006MiL01000MiMgUgNG0P001goo000/Ool00`00Oomoo`0HOol00`00Cae?7@07Cad00`00
Cae?7@07Cad00`00Cae?7@08Cad01000Cae?7DlM20002DlM00<004lMCad024lM00<004lMCad01dlM
00<004lMCad014lM1`0024lM00<004lMCad01dlM00<004lMCad024lM00<004lMCad01DlM20001Dkm
00<004kmC_d01dkm00<005;lD_`025;l00<005/KFa/01E/K0P0000=Jn`00JeT026]I00@006mIKeT0
00=kMP04001kMG]e0002NgD01000NgEkMG]e0P001GNG00<007NGMiL00gNG00<007ooOol01Goo000/
Ool2000JOol00`00Cae?7@07Cad00`00Cae?7@07Cad00`00Cae?7@04Cad90006Cad00`00Cae?7@07
Cad00`00Cae?7@07Cad00`00Cae?7@06Cad80005Cad00`00Cae?7@08Cad00`00Cae?7@07Cad00`00
Cae?7@07Cad01000Cae?7DlM10000dlM00<004kmC_d01dkm00<004kmC_d01dkm00<005;lD_`025;l
00<005/KFa/00U/K0`0015[k00<006]IJeT01F]I00D006mIKeU_F@0000=kMP04001kMG]eNgD20004
NgD00`00MiMgU`03MiL00`00MiMgU`03MiL20007Ool002aoo`03001oogoo01Yoo`03001?7DlM00I?
7@03001?7DlM00I?7@X000=?7@03001?7DlM00Q?7@03001?7DlM00M?7@03001?7DlM00M?7@04001?
7DlMCad40003Cad00`00Cae?7@07Cad00`00Cae?7@08Cad00`00Cae?7@07Cad00`00Cae?7@04Cad7
0007Cad00`00C_e>o@08C_d00`00C_e>o@07C_d00`00D_aBo008D_`01000Fa/000001e[k00<006]I
JeT016]I00<006mIKeT00VmI00@007]fNgH000AkM@8000AkM@03001gUgNG00=gU`03001gUgNG00=g
U`8000Moo`00;7oo00<007ooOol06Woo00<004lMCad01dlM00@004lMCae?7@P000U?7@03001?7DlM
00Q?7@03001?7DlM00M?7@03001?7DlM00A?7@L000M?7@03001?7DlM00Q?7@03001?7DlM00Q?7@03
001?7DlM00=?7@X000E?7@03001?7DlM00M?7@03001>oDkm00M>o@03001>oDkm00M>o@03001Bo5;l
00IBo0@000UJn`03001[FF]I00=[F@03001_FFmI00=_F@04001kMW]f0005NgD01`00NgEkMG]e001k
M00000=gU`03001gUgNG00=gU`04001gUgNG0006Ool002aoo`03001oogoo01]oo`03001?7DlM00=?
7@L000Q?7@03001?7DlM00M?7@03001?7DlM00Q?7@03001?7DlM00=?7@X000E?7@03001?7DlM00M?
7@03001?7DlM00Q?7@03001?7DlM00E?7@P000E?7@03001?7DlM00M?7@03001?7DlM00Q?7@03001>
oDkm00M>o@03001>oDkm00M>o@03001Bo5;l00D0009:g003001Jne[k00UJn`03001[FF]I009[F@03
001_FFmI00A_F@8000EkM@8000=kM@03001kM00000=gU`03001gUgNG009gU`05001gUgNGMiL00006
Ool002]oo`<001aoo`L000A?7@03001?7DlM00Q?7@03001?7DlM00M?7@03001?7DlM00I?7@L000E?
7@03001?7DlM00Q?7@03001?7DlM00M?7@03001?7DlM00M?7@04001?7DlMCad40003Cad00`00Cae?
7@07Cad00`00Cae?7@08Cad00`00Cae?7@07Cad00`00C_e>o@03C_dA0008B]`00`00F_]Jn`08F_/0
1@00JeU[FF]I00001fmI0P001G]e0P000W]e00@007]dNg@0009gU`03001gUgNG00=gU`05001gUgNG
MiL00006Ool002]oo`03001oogoo01Eoo`L0009oo`03001?7DlM00M?7@03001?7DlM00M?7@03001?
7DlM00M?7@04001?7DlMCad50003Cad00`00Cae?7@07Cad00`00Cae?7@07Cad00`00Cae?7@07Cad0
0`00Cae?7@04Cad70007Cad00`00Cae?7@08Cad00`00Cae?7@07Cad00`00Cae?7@04Cad90005B_h0
0`00A]e6g@07A]d00`00B]a:g007B]`00`00F_]Jn`08F_/01000JeU[F@0026mI00<007]eNgD00g]e
00H007]eNgD007]e0002Ng@00`00MiL00005MiL01000MiMgUgNG0P001Woo000[Ool00`00Oomoo`0>
Ool7000:Ool00`00Cae?7@07Cad00`00Cae?7@07Cad00`00Cae?7@03Cad70008Cad00`00Cae?7@08
Cad00`00Cae?7@07Cad00`00Cae?7@03Cad:0005Cad00`00Cae?7@07Cad00`00Cae?7@08Cad00`00
Cae?7@05Cad80005Cah00`00B_i:oP06B_h00`00A]e6g@07A]d00`00B]a:g008B]`00`00F_]Jn`08
F_/20008KeT20005NgD01P00NgEkM@00NgD000=kM08000AgU`03001gUgNG009gU`8000Ioo`0097oo
0`0017oo0`0027oo1P004Woo00<004lMCad01dlM00<004lMCad00dlM2@001DlM00<004lMCad024lM
00<004lMCad01dlM00<004lMCad01TlM1`001DlM00<004lMCad024lM00<004lMCad01dlM00<004lM
Cad01dlM00@004lMCae?7@@000=?7P03001?7TlN00M?7P03001:oT[n00M:oP030016gDKM00M6g@03
001:g4[L00M:g003001Jne[k00MJn`8000Q_F@04001_F6mH0004NgD01@00NgEkMG]e000017]d00<0
07NGMiL00gNG00L007NGMiMgU`00Ool00006Ool002Aoo`03001oogoo00Aoo`04001oogooOol7000H
Ool00`00Cae?7@06Cad70005Cad00`00Cae?7@07Cad00`00Cae?7@08Cad00`00Cae?7@07Cad01000
Cae?7DlM10000dlM00<004lMCad01TlM00<004lMCad024lM00<004lMCad01dlM00<004lMCad014lM
1`001dlN00<004lNCah024lN00<004[nB_h01T[n00<004KMA]d01dKM00<004[LB]`01d[L00<005[k
F_/015[k0`0000=Ff`00KeT01VmI00D006mHKeQ_F00000=kM@03001kMG]e009kM@03001kM7]d009k
M003001gUgNG009gU`03001gUgNG009gU`03001oo`0000Ioo`009Goo00<007ooOol00goo100087oo
00@004lMCae?7@@000=?7@03001?7DlM00M?7@03001?7DlM00M?7@03001?7DlM00M?7@03001?7DlM
00A?7@L000M?7@03001?7DlM00M?7@03001?7DlM00Q?7@03001?7DlM00=?7@X000E?7@03001?7TlN
00M?7P03001?7TlN00M?7P03001:oT[n00M:oP030016gDKM00M6g@03001:g4[L00M:g003001Jn`00
00<000EFf`03001_FFmI00=_F@03001_F6mH00=_F004001kMG]e0004NgD01`00NgAkM7]d001oL`00
00=gU`05001gUgNGMiL00003Ool00`00Oomoo`03Ool002Eoo`03001oogoo00Aoo`03001oogoo025o
o`<000Q?7@03001?7DlM00M?7@03001?7DlM00M?7@03001?7DlM00=?7@X000E?7@03001?7DlM00M?
7@03001?7DlM00M?7@03001?7DlM00I?7@L000E?7@03001?7DlM00M?7@03001?7TlN00M?7P03001?
7TlN00Q?7P03001:oT[n009:oQX000UFf`03001_FFmI009_F@03001_F6mH00A_F003001kM@0000Ak
M@03001kM000009kM003001oL`00009gU`03001gUgNG009gU`05001oogooOol00005Ool002Aoo`03
001oo`0000Ioo`03001oogoo025oo`03001?7DlM00Q?7@03001?7DlM00I?7@03001?7DlM00I?7@L0
00E?7@03001?7DlM00Q?7@03001?7DlM00M?7@03001?7DlM00I?7@04001?7DlMCad50003Cad00`00
Cae?7@06Cad00`00Cae?7@08Cad00`00Cai?7P07Cah00`00Cai?7P03Cah90005Aah00`00@[e2_@07
@[d00`00AYa6W006AY`00`00E]]Ff`08E]/00`00KeU_F@02KeT00`00KeQ_F004KeP00`00NgD00004
NgD00`00Ng@00002Ng@01@00Og<007NG000017NG00<007ooOol00Woo00<007ooOol00goo000UOol0
0`00Oomoo`06Ool00`00Oomoo`0QOol00`00Cae?7@07Cad00`00Cae?7@07Cad01000Cae?7DlM1000
0dlM00<004lMCad01dlM00<004lMCad01dlM00<004lMCad01dlM00<004lMCad00dlM1`0024lM00<0
04lMCad01dlM00<004lMCad01dlM00<004lNCah00dlN2P001Dln00<004LNAah01TLN00<004:m@[d0
1d:m00<004JLAY`01dJL00<005KKE]/01eKK00D006mIKeU_F@0000Q_F003001kMG]e009kM@04001k
M7]dNg@20003Og<20004MiL00`00Oomoo`02Ool00`00Oomoo`03Ool002moo`03001oogoo025oo`03
001?7DlM00M?7@03001?7DlM00=?7@L000M?7@03001?7DlM00Q?7@03001?7DlM00M?7@03001?7DlM
00=?7@T000E?7@03001?7DlM00Q?7@03001?7DlM00M?7@03001?7DlM00E?7@L000EC?P03001??Tln
00Q??P0300177TLN00I77P030012_D:m00M2_@030016W4JL00I6W003001FfeKK00QFf`03001_F@00
00U_F003001kMG]e009kM@04001kM7]dNg@20003Og<00`00MiMgU`02MiL00`00Oomoo`03Ool00`00
Oomoo`03Ool002Aoo`D0009oo`03001oogoo009oo`03001oogoo025oo`03001?7DlM00=?7@T000E?
7@03001?7DlM00M?7@03001?7DlM00Q?7@03001?7DlM00=?7@T000E?7@03001?7DlM00M?7@03001?
7DlM00M?7@03001?7DlM00M?7@04001?7DlMCad40003Dad00`00DciC?P07Dch00`00Cci??P07Cch0
0`00Aai77P06Aah00`00@[e2_@07@[d00`00AYa6W007AY`00`00E]]Ff`07E]/20009KeP20004NgD0
1000NgAkM7]d0P000gmc00<007NGMiL00WNG00<007ooOol00goo00<007ooOol00goo000VOol01`00
Oomoogoo001oo`0000Aoo`<0025oo`D000E?7@03001?7DlM00M?7@03001?7DlM00M?7@03001?7DlM
00I?7@L000E?7@03001?7DlM00M?7@03001?7DlM00I?7@03001?7DlM00Q?7@03001?7DlM00=?7@L0
00MC7@03001C?U<n00MC?P03001??Tln00I??Q0000E2_@030016W4JL00I6W003001FfeKK00EFf`<0
00U_F004001_>6lh0002NgD00`00NgAkM003Ng@01P00Og=oL`00Og80009gU`03001oogoo00Aoo`03
001oogoo00=oo`009Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol08Goo00<004lMCad0
1dlM00<004lMCad01TlM00<004lMCad01dlM00@004lMCae?7@D000=?7@03001?7DlM00I?7@03001?
7DlM00M?7@03001?7DlM00M?7@03001?7DlM00=?7@X000E?7@03001C7E<M00MC7@03001C?U<n00MC
?P04001??TlnCch40003Deh00`00@am37`06@al01000=YdfWCJM2P001DJL00<005KKE]/010000U:k
00<006mHKeP01fmH00@006lhKcP0009kM@03001kM7]d009kM080009oL`03001oLP00009gU`03001o
ogoo00Aoo`03001oogoo00=oo`009Woo00@007ooOomoo`8000Moo`03001oogoo025oo`03001?7DlM
00I?7@03001?7DlM00M?7@03001?7DlM00=?7@L000Q?7@03001?7DlM00M?7@03001?7DlM00M?7@03
001?7DlM00=?7@T000E?7@03001?7DlM00M?7@03001C7E<M00MC7@03001C?U<n00IC?PD000MCGP03
00137d<O00M37`03000fWCJM00HfW@04000jG3YL>U`80007D[/00`00KeQ_F005KeP01@00KcQ_>6lh
00000W]e00<007]dNg@00W]d00T007mc001oL`00Og8007NG00001goo00<007ooOol00goo000VOol0
1@00Oomoogoo00002Goo00<007ooOol08Goo00<004lMCad01TlM00<004lMCad00dlM2@001DlM00<0
04lMCad024lM00<004lMCad01dlM00<004lMCad01DlM1`001DlM00<004lMCad01dlM00<004lMCad0
1dlM00<005<MDad01e<M00<005<nDch01@000eLm00<005=NDeh01e=N00<004<O@al01T<O00<003JM
=Yd01SJM00<003YL>U`01SYL00<005:kD[/01e:k00<006mHKeP016mH00<006lhKcP00Vlh00<007]e
00001G]d00D007mc001oL`00009oLP8000Moo`03001oogoo00=oo`009Goo0P000goo0`0027oo00<0
07ooOol087oo00<004lMCad01TlM1P001DlM00<004lMCad01dlM00<004lMCad024lM00<004lMCad0
1TlM00@004lMCae?7@@000=?7@03001?7DlM00I?7@03001?7DlM00M?7@03001?7DlM00M?7@03001C
7E<M00=C7@L000QG?@03001CGU=N00MCGP0300137d<O00=37`L000HfW@03000jG3YL00HjG003001B
^e:k00IB^`03001_F6mH00=_F003001_>6lh00A_>08000AkM003001oLgmc008000=oLP03001oogoo
00Moo`03001oogoo009oo`00=Woo00<007ooOol087oo00@004lMCae?7@@0009?7@03001?7DlM00M?
7@03001?7DlM00M?7@03001?7DlM00M?7@03001?7DlM00=?7@L000M?7@03001?7DlM00M?7@03001?
7DlM00M?7@03001?7DlM00=?7@T000EC7@03001G?ELm00QG?@03001CGU=N00ECGPL000Do?`03000N
?@0000@00003=Yd003YL00LjG003001B^e:k00MB^`05001_F6mHKeP00007KcP00`00NgAkM003Ng@0
1@00Og=oLgmc00000gmb00<007ooOol01goo00<007ooOol00Woo000gOol2000QOol30007Cad00`00
Cae?7@07Cad00`00Cae?7@07Cad00`00Cae?7@03Cad90005Cad00`00Cae?7@07Cad00`00Cae?7@07
Cad00`00Cae?7@05Cad70005Cad00`00DaeC7@06Dad00`00EceG?@08Ecd01000DeiCGU=N10000e^N
00<003lo?cl01clo00<001hm7Sd00ahm10001SYL00<005:kD[/01e:k00@006mHKeP000Q_>003001k
M7]d00=kM005001oLgmcOg<00003Og800`00Oomoo`07Ool00`00Oomoo`02Ool003Qoo`03001oogoo
021oo`03001?7DlM00M?7@03001?7DlM00M?7@03001?7DlM00=?7@T000E?7@03001?7DlM00M?7@03
001?7DlM00M?7@03001?7DlM00I?7@04001?7DlMCad40003Cad00`00Cae?7@06Cad00`00DaeC7@07
Dad00`00EceG?@06Ecd50008Fih00`00?clo?`03?cl600057Sd010009O/0000013YL00<005:kD[/0
1e:k00@006mHKeP000M_>08000AkM003001oLgmc009oL`800003Og8007oo00Uoo`03001oogoo009o
o`00>Goo00<007ooOol087oo00<004lMCad01TlM00<004lMCad01TlM1`001DlM00<004lMCad01dlM
00<004lMCad01TlM00<004lMCad01dlM00<004lMCad00dlM1`001dlM00<004lMCad01dlM00<005<M
Dad01U<M00@005LmEceG?@D000=KG@03001KWU^N00MKWPH000@_G0@000@N?@03000UnbGk008000<j
G003001B^e:k00MB^`8000M_>004001c=g<g0003Ng@02@00Og=oLgmc001oLP00Og80000:Ool00`00
Oomoo`02Ool003Yoo`03001oogoo01moo`03001?7DlM00M?7@04001?7DlMCad40003Cad00`00Cae?
7@07Cad00`00Cae?7@06Cad00`00Cae?7@07Cad00`00Cae?7@03Cad90005Cad00`00Cae?7@07Cad0
0`00Cae?7@06Cad00`00DaeC7@05Dad50009Fed00`00FiiKWP03Fih30002Im`01000;e`_G2mL1000
0goo0`000Qhm00<002Gk9O/00RGk0P0000<jG000D[/015:k1@0026lh00@007<gLcL000=kM009001o
LgmcOg<007mb001oLP0000Yoo`03001oogoo009oo`00>goo00<007ooOol07goo00<004lMCad00dlM
1`0024lM00<004lMCad01TlM00<004lMCad01dlM00<004lMCad00dlM2@001DlM00<004lMCad01TlM
00<004lMCad01dlM00<004lMCad01dlM00<005<MDad010000eLL00<005]MFed025]M00<005^NFih0
0`001VOL100027oo0`0000<N?@009O/012Gk1`0014ZK00<006lhKcP01Flh00D007<gLcMc=`0000=k
M005001oLgmcOg<00002Og82000:Ool00`00Oomoo`02Ool003aoo`03001oogoo01moo`D000E?7@03
001?7DlM00M?7@03001?7DlM00M?7@03001?7DlM00=?7@T000E?7@03001?7DlM00I?7@03001?7DlM
00M?7@03001?7DlM00M?7@03001?7DlM009?7@L000MG7003001KGE]M00QKG@<000QWg003001ceG?E
008000Uoo`040001>00000069O/00`00BY]:V`07BY/00`00KcQ_>004KcP00`00LcMc=`03LcL00`00
Ng@00003Og<01@00Og9oLWmb00002goo00<007ooOol00Woo000mOol2000POol00`00Cae?7@07Cad0
0`00Cae?7@07Cad00`00Cae?7@03Cad90005Cad00`00Cae?7@06Cad00`00Cae?7@07Cad00`00Cae?
7@06Cad00`00Cae?7@03Cad90005C]d00`00EaaG7007Ea`00`00FeeKG@05Fed200000fMK001Wg006
Im`20002LmD00`00Jd/0000:Ool200000`4h000000059O/00`00BY]:V`07BY/00`00KcQ_>002KcP0
0`00LcMc=`04LcL00`00Ng@00003Og<01@00Og9oLWmb00002goo00<007ooOol00Woo000nOol00`00
Oomoo`0OOol00`00Cae?7@06Cad00`00Cae?7@06Cad70005Cad00`00Cae?7@07Cad00`00Cae?7@06
Cad00`00Cae?7@06Cad00`00Cae?7@03Cad90005B_d00`00C]e>g@06C]d00`00EaaG7008Ea`00`00
FeeKG@02Fed20004Ie/00`00ImaWg003Im`01`00LmEceG?E001[B`0000eoo`030001>000008000<U
n`03001:VdZK00M:V`03001_>6lh009_>003001c=g<g00Ac=`03001kM00000=oL`04001oLWmbOg82
000:Ool00`00Oomoo`02Ool003moo`03001oogoo01moo`03001?7DlM00I?7@04001?7DlMCad40003
Cad00`00Cae?7@07Cad00`00Cae?7@06Cad00`00Cae?7@06Cad00`00Cae?7@03Cad90005Bah00`00
B_e:o@07B_d00`00C]e>g@06C]d00`00EaaG7007Ea`00`00FeeKG@020006Ie/00`00ImaWg002Im`0
0`00LmEce@02LmD00`00Jd/0000>Ool200022CP01@009O/UnbGk000024ZK00D006lhKcQ_>00000Qc
=`03001oLgmc009oL`04001oLWmbOg82000:Ool00`00Oomoo`02Ool0041oo`03001oogoo01moo`03
001?7DlM00=?7@H000Q?7@03001?7DlM00I?7@03001?7DlM00M?7@03001?7DlM00=?7@P000E??P03
001;7T/N00M;7P03001:oD[m00I:o@03001>gDkM00M>g@03001G75LL00EG70@000QWF`03001Wg6OL
008000Ace@04001[Bf];000@Ool00`002CP9>00200000bGk001:V`07BY/01000KcQ_>0002G<g00D0
07mcOg=oL`0000=oLP04001oogoo000:Ool00`00Oomoo`01Ool0045oo`03001oogoo01moo`D000A?
7@03001?7DlM00M?7@03001?7DlM00M?7@03001?7DlM00=?7@T000AC?@03001??Tln00M??P03001;
7T/N00M;7P03001:oD[m00I:o@03001>gDkM00I>g@04001G75LLEa`40002E]/00`00Ie]WF`08Ie/2
0005LmD01@00Jd][Bf];00004Goo00@000Th2CP9>0<000Q:V`8000Uc=`8000=oL`05001oLWmbOg80
0002Ool00`00Oomoo`08Ool00`00Oomoo`01Ool0049oo`03001oo`0001moo`03001?7DlM00I?7@03
001?7DlM00M?7@03001?7DlM00=?7@T000EC7@03001C?E<m00IC?@03001??Tln00M??P03001;7T/N
00=;7QT000MFf`03001WFfMK00MWF`03001ceG?E00Ace@04001[Bf];000COol00`002CP9>0022CP5
0004BY/20009LcL20003Og<01@00Og9oLWmb00000Woo00<007ooOol027oo00<007ooOol00Goo0013
Ool00`00Oomoo`0OOol00`00Cae?7@06Cad00`00Cae?7@06Cad60005Cad00`00DaeC7@06Dad00`00
DceC?@07Dcd00`00Cci??P03Cch90005@al00`00>[dj_@06>[d00`00@Ya2W005@Y`00`00E]]Ff`07
E]/00`00Ie]WF`06Ie/00`00KeP00004LmD01@00Jd][Bf];000057oo00D000Th2CP9>00000A2FPD0
00Uc=`04001c=g<g0002Og<01@00Og9oLWmb00000goo00<007ooOol01goo00<007ooOol00Goo0014
Ool00`00Oomoo`0NOol00`00Cae?7@07Cad01000Cae?7DlM10000TlM00<004lMCad01dlM00<005<M
Dad01U<M00<005<mDcd01E<m1`001E=n00<004<O@al01d<O00<003Zm>[d01CZm00<004:L@Y`01T:L
00<005KKE]/01eKK00<006MKIe/00fMK0P000VmH00<007?ELmD00W?E00D006];Jd][B`0001Eoo`05
0009>0Th2CP00007@UX00`00LcMc=`06LcL01`00LcMc=g<g001oL`0000=oLP03001oogoo009oo`03
001oogoo00Moo`03001oogoo005oo`00AGoo00<007ooOol07Woo00<004lMCad00dlM1`001dlM00<0
04lMCad01TlM00<005<MDad01U<M00@005<mDceC?@@000=GG@03001COU=n00MCOP0300137d<O00I3
7`03000j_CZm00Hj_@030012W4:L00E2W003001FfeKK00MFf`03001WFfMK009WF`03001_F6mH00=_
F004001ceG?E0003Jd/00`00Oomoo`0DOol200022CP00`00@UY2FP06@UX00`00LcMc=`05LcL01`00
LcMc=g<g001oL`0000=oLP03001oogoo00=oo`03001oogoo00Ioo`03001oogoo005oo`00AWoo00<0
07ooOol07Woo1@001DlM00<004lMCad01TlM00<004lMCad01dlM00<005<MDad00e<M1P0025MM00<0
05=nDgh01U=n3@001CZm00<004:L@Y`01T:L00<005KKE]/01UKK00D006MKIe]WF`0000I_F003001c
e@0000A[B`03001oogoo01Eoo`040009>0Th0008@UX00`00LcMc=`04LcL00`00LcMc=`02LcL00`00
Og<00003Og800`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`01Ool004Moo`03001oogoo01io
o`03001?7DlM00M?7@03001?7DlM00I?7@03001?7DlM00=?7@T000AG7@03001GGEMM00MGG@03001C
OU=n00ACOP8000=Gn@8000Qoo`@0008j_@030012W4:L00E2W003001FfeKK00MFf`<000Q_F08000A[
B`03001oogoo01Ioo`030009>00000Q2FP03001c=g<g00=c=`03001c=g<g00Ac=`8000=oLP03001o
ogoo00=oo`03001oogoo00Ioo`03001oogoo005oo`00B7oo0P007goo00<004lMCad01dlM00<004lM
Cad00dlM20001Dkm00<005LMEad01ULM00<005MMEed01eMM00<005=nDgh00`0015Oi00<007ooOol0
2Woo2@0014:L00<005KKE]/00UKK1@002VmH00<006];Jd/00f];00<007ooOol05Woo0P0000<9>000
@UX01d9J00D007<gLcMc=`0000Mc=`05001oLWmbOg800007Ool00`00Oomoo`05Ool00`00Oomoo`01
Ool004Uoo`03001oogoo01ioo`03001?7DlM00=?7@T000A:o@03001>oDkm00I>o@03001G7ELM00IG
7@03001GGEMM00IGG@@000EGn@<000ioo`040001>04h0003;KT90004DWT00`00KeQ_F007KeP20004
Jd/00`00Oomoo`0HOol30008@UX01@00LcMc=g<g00001g<g00D007mbOg9oLP0000Moo`03001oogoo
00Eoo`03001oogoo005oo`00BWoo00<007ooOol07Woo1@001D/N00<004[mB_d01D[m00<004kmC_d0
1dkm00<005LMEad01ULM00@005MMEeeGG@@000=[N`03001GnEOi009Gn@0400000@01000?Ool00`00
0CP00007;KT00`00DWUBN@07DWT00`00KeQ_F006KeP00`00McD00003Jd/00`00Oomoo`0HOol01000
03<000001d9J00@007<gLcL000Mc=`8000=oLP03001oogoo00Ioo`03001oogoo00Eoo`40005oo`5o
o`00Bgoo00<007ooOol07Woo00<004/NBah01d/N00<004[mB_d01D[m00<004kmC_d01dkm00<005LM
Ead01ELM100026]k00@005Oi000000800@03001oogoo00moo`<000L]^@03001BNE9i00IBN@03001_
F6mH00E_F004001g=GLe0003Jd/00`00Oomoo`0IOol2000013Wi00000000149J00<007<g000027<g
0P000gmb00<007ooOol01Woo00<007ooOol01Goo0@000Goo0Goo001<Ool00`00Oomoo`0NOol00`00
Bai;7P06Bah00`00B_e:o@06B_d00`00C_e>o@06C_d01000EaeG7ELM100000=JfP00Jg/02V]k00<0
000100400P0100<007ooOol04Goo00<002fi;KT01Bfi00<0059iDWT01U9i00<006mHKeP016mH00D0
07LeMcEg=@00009[B`03001oogoo01Yoo`030000<`0000<in@@00003@UX0000000Mc=`06001g=WLf
001oLP002Goo00<007ooOol01Goo0@000Goo0Goo0010Ool50002Ool00`00Oomoo`03Ool3000MOol0
0`00Bai;7P07Bah00`00B_e:o@05B_d00`00C_e>o@03C_d70006F]X00`00Jg][N`07Jg/00`00Ne@0
000300400`00Oomoo`0BOol00`00;KT]^@04;KT00`00DWUBN@06DWT00`00KeQ_F003KeP00`00McEg
=@03McD00`00Jd/0000MOol20007>OT20008LcL01P00McIg=P00Og8000Yoo`03001oogoo00Aoo`40
005oo`5oo`00@Woo00L007ooOomoo`00Ool00005Ool00`00Oomoo`0MOol00`00Bai;7P03BahA0004
@UX00`00F]YJfP06F]X00`00Jg][N`06Jg/01000NeAkE7]D0`005Woo00<002fi;KT00bfi00<0059i
DWT01e9i00<006mHKeP00VmH00<007LeMcD00gLe00<006];00007Goo0`001cWi00<007<gLcL01G<g
00L007LfMcIg=P00Og80000:Ool00`00Oomoo`04Ool10001Ool1Ool0049oo`07001oogooOol007oo
00001Woo00<007ooOol07Goo2@0000<RgP0000001RXl00<0049J@UX01T9J00<005[JF]X01U[J00<0
06]kJg/016]k00<007]DNe@017]D00<007ooOol05Goo0P0012fi00<0059iDWT01U9i00D006mHKeQ_
F00000Ig=@03001[B`0001ioo`8000Pin@03001c=g<g00Ac=`07001g=WLfMcH007mb00002goo00<0
07ooOol00goo0@000Goo0Goo0012Ool01`00Oomoogoo001oo`0000Moo`03001oogoo02Eoo`D000@Z
?0030012FT9J00I2FP03001JfU[J00IJfP03001[Nf]k00=[N`03001kE7]D00EkE003001oogoo01Io
o`8000<]^@03001BNE9i00IBN@04001_F6mH0008McD00`00Oomoo`0MOol20008>OT00`00LcMc=`03
LcL00`00McIg=P03McH00`00Oomoo`0:Ool00`00Oomoo`03Ool10001Ool1Ool0049oo`07001oogoo
Ool007oo000027oo00<007ooOol097oo00<007ooOol00Woo0P000bXl00<0049J@UX01D9J00<005[J
F]X01e[J00D006]kJg][N`0000MkE003001oogoo01Moo`030004L`00008]^@03001BNE9i00IBN@03
001_F00000Ug=@03001oogoo01ioo`8000Lin@03001c=g<g00=c=`03001g=WLf00=g=P03001oogoo
00Yoo`03001oogoo00=oo`40005oo`5oo`00@Goo0P0017oo00<007ooOol01goo00<007oo000097oo
00<007ooOol017oo0P000RXl00<0049J@UX01D9J00<005[JF]X01U[J00@006]kJg/000QkE003001o
ogoo01Qoo`030004L`00008000UBN@8000Ug=@03001oogoo01ioo`8000Lin@03001c=g<g009c=`03
001g=WLf00Ag=P03001oogoo00]oo`03001oogoo009oo`40005oo`5oo`00DWoo00<007ooOol08goo
00<007ooOol01Woo0`001d9J00<005[JF]X01e[J0P002G]D00<007ooOol067oo00@000Ac17<4L`80
00ABN@D000Ug=@03001oogoo01moo`@000Hin@05001c=g<gLcL00006McH00`00Oomoo`0;Ool00`00
Oomoo`02Ool10001Ool1Ool005=oo`03001oogoo029oo`03001oogoo00Qoo`<000E2FP03001JfU[J
00EJfP<000UkE003001oogoo01Yoo`040004L`Ac17<50004CQH00`00McEg=@07McD00`00Oomoo`0P
Ool200000c6h00000004>OT01000LcMc=`001WLf00<007ooOol03Goo00D007ooOomoo`00009oo`00
E7oo00<007ooOol08Goo00<007ooOol02Goo00<002Td00000`000T9J00<005[JF]X010000UYF00<0
07]DNe@01g]D00<007ooOol06Woo00D000Ac17<4L`0000Q>5P03001g=GLe00Mg=@03001oogoo021o
o`8000<a^005000inCWi>OT00002LcL00`00McIg=P04McH00`00Oomoo`0=Ool00`00Oomoo`02Ool1
0001Ool005Eoo`03001oogoo021oo`03001oogoo00Yoo`03000Y=2Td008Y=0D000IJEP03001kE7]D
00MkE003001oogoo01Yoo`050004L`Ac17<00008CQH00`00McEg=@06McD00`00Oomoo`0ROol00`00
<KPa^002<KP2000013Wi001c=`001WLf00<007ooOol03Woo00<007ooOol00Woo0@000Goo000:Ool4
0002Ool20003Ool20002Ool4000;Ool01000Oomoo`001goo1@000Woo00<007ooOol06Goo00<007oo
00007goo00<007ooOol02Woo00<002Td:C@012Td00<005YFFUH01UYF00<007]DNe@01W]D00<007oo
Ool077oo00@000Ac17<000U>5P03001g=GLe00Eg=@03001oogoo029oo`8000Da^0@000Ig=P03001o
ogoo00moo`05001oogooOol00001Ool000]oo`05001oo`00Ool00004Ool01@00Oomoo`00Ool00`00
3Goo0P002Woo00L007ooOomoo`00Ool0000KOol00`00Oomoo`0NOol00`00Oomoo`0:Ool00`00:C@Y
=004:C@00`00FUIJEP07FUH00`00NeAkE005Ne@00`00Oomoo`0LOol01@0017<4L`Ac000024hF00<0
07LeMcD01GLe00<007ooOol08Woo0P001c6h00<007LfMcH017Lf00<007ooOol047oo00D007ooOomo
o`00005oo`002Woo00<007oo00000Woo0`000Woo00<007ooOol017oo00<007ooOol02goo0P002Woo
00L007ooOomoo`00Ool0000LOol00`00Oomoo`0LOol00`00Oomoo`0<Ool00`00:C@Y=003:C@00`00
FUIJEP07FUH00`00NeAkE005Ne@00`00Oomoo`0LOol01@0017<4L`Ac000024hF00<007LeMcD017Le
00<007ooOol097oo00<0036h<KP01C6h00<007LfMcH017Lf00<007ooOol04Goo00@007ooOol0005o
o`002Woo100000Eoo`00000007oo00@000=oo`8000aoo`04001oogoo0009Ool01`00Oomoogoo001o
o`0001eoo`03001oogoo01]oo`03001oogoo00aoo`03000Y=2Td00<Y=003001JEUYF00MJEP03001k
E7]D00AkE003001oogoo01ioo`040004L`Ac0008CQH00`00McEg=@04McD00`00Oomoo`0TOol00`00
<KPa^005<KP00`00McIg=P04McH00`00Oomoo`0AOol01000Oomoo`000Goo000DOol00`00Oomoo`0N
Ool01`00Oomoogoo001oo`0001ioo`03001oogoo01Yoo`03001oogoo00aoo`03000Y=2Td00@Y=003
001JEUYF00IJEP03001kE7]D00AkE003001oogoo01ioo`040004L`Ac0008CQH00`00McEg=@04McD0
0`00Oomoo`0UOol00`00<KPa^004<KP00`00McIg=P03McH00`00Oomoo`0BOol01000Oomoo`000Goo
000dOol20004Ool00`00Oomoo`0NOol3000IOol00`00Oomoo`0<Ool00`00:C@Y=004:C@00`00FUIJ
EP06FUH00`00NeAkE004Ne@00`00Oomoo`0OOol00`0017<00008CQH00`00McEg=@03McD00`00Oomo
o`0VOol00`00<KPa^005<KP00`00McIg=P02McH00`00Oomoo`0COol00`00Ool00001Ool005aoo`03
001oogoo01Qoo`03001oogoo00eoo`03000Y=2Td00<Y=003001JEUYF00IJEP03001kE7]D00=kE003
001oogoo021oo`030004L`0000Q>5P03001g=GLe00=g=@03001oogoo02Moo`03000a^36h00@a^005
001g=WLfMcH0000FOol00`00Ool00001Ool005eoo`03001oogoo01Moo`03001oogoo00eoo`03000Y
=2Td00<Y=003001JEUYF00IJEP03001kE7]D00=kE003001oogoo021oo`040004L`Ac0008CQH00`00
McEg=@02McD00`00Oomoo`0XOol00`00<KPa^003<KP01@00McIg=WLf00005goo0P000Goo001NOol0
0`00Oomoo`0FOol00`00Oomoo`0=Ool00`00:C@Y=003:C@00`00FUIJEP07FUH00`00NeAkE002Ne@0
0`00Oomoo`0QOol00`0017<00008CQH01@00McEg=GLe0000;7oo00<0036h<KP00S6h00D007LfMcIg
=P0001Moo`40005oo`400000Ggoo00<007ooOol05Goo00<007ooOol03Woo00<002Td:C@00RTd00<0
05YFFUH01eYF00D007]DNeAkE00002Aoo`030004L`0000Q>5P05001g=GLeMcD0000]Ool01@00<KPa
^36h00000WLf00<007ooOol05Woo0@000Goo0@00001POol3000DOol00`00Oomoo`0>Ool00`00:C@Y
=002:C@00`00FUIJEP07FUH01@00NeAkE7]D000097oo00<000Ac000024hF00D007LeMcEg=@0002io
o`04000a^36h0002McH00`00Oomoo`0GOol20000065oo`03001oogoo01=oo`03001oogoo00moo`05
000Y=2Td:C@00009FUH01@00NeAkE7]D00009Goo0P0024hF00@007LeMcD0031oo`03000a^36h0080
01Yoo`800000HWoo00<007ooOol04Woo00<007ooOol03goo00D002Td:C@Y=00000UJEP04001kE7]D
000VOol20008CQH01000McEg=@00<Goo00@0036h000001]oo`400000Hgoo00<007ooOol04Goo00<0
07ooOol047oo00D002Td:C@Y=00000QJEP04001kE7]D000WOol00`00CQI>5P06CQH01000McEg=@00
<Woo0P0067oo1@00001OOol00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool01@00:C@Y
=2Td000025YF00@007]DNe@002Moo`8000M>5P03001g=@0003Aoo`03001oogoo00eoo`T000Eoo`00
GWoo00<007oo000017oo0`003goo00<007ooOol047oo00D002Td:C@Y=00000QJEP03001kE00002Qo
o`8000Q>5P8003]oo`T000ioo`00H7oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol04Goo
00@002Td:C@000UJEP8002Uoo`03001>5ThF00I>5P80039oo`T001Moo`00GWoo0P001goo00<007oo
Ool03Goo00<007ooOol04Goo00@002Td:C@000UJEP8002Uoo`D000A>5P03001oogoo02Qoo`T0021o
o`00GWoo00<007ooOol01goo00<007ooOol037oo00<007ooOol04Woo00<002Td00002EYF00<007oo
Ool0;Goo1@008Woo2000:Goo001NOol30008Ool3000;Ool00`00Oomoo`0BOol00`00:C@00009FUH0
0`00Oomoo`1;Ool9000aOol006Yoo`03001oogoo00Yoo`03001oogoo019oo`03000Y=00000QJEP03
001oogoo04=oo`T003Yoo`00Jgoo00<007ooOol02Goo00<007ooOol04goo0P001UYF0P00?Goo2@00
@goo001/Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00:C@00004FUH00`00Oomoo`0dOol9001<
Ool006eoo`<000Ioo`03001oogoo01Eoo`8000=JEP03001oogoo02aoo`T005Eoo`00KWoo00<007oo
Ool01Goo00<007ooOol05Goo0P0000=JEP0000009Woo2@00GWoo001_Ool00`00Oomoo`04Ool00`00
Oomoo`0FOol2000OOol9001WOol0071oo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo01Eo
o`T0071oo`00LGoo00<007ooOol00Woo00<007ooOol09Woo2000NGoo001bOol20002Ool00`00Oomo
o`0MOol90021Ool007=oo`04001oogoo000FOol9002:Ool007Aoo`03001oo`0000eoo`T009=oo`00
MGoo0P0017oo2@00W7oo001fOol5002UOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo0030Ool2001NOol00<5oo`03001oogoo05aoo`00KGoo0`000goo0P000Woo0`000goo0P00
00=oo`0000000Woo00<007ooOol00`003Woo0P000Woo0`000goo0`000Woo0P000Woo0`003Goo0`00
0goo00@007ooOomoo`8000Aoo`8000=oo`800006Ool007oo001oo`00B7oo001]Ool00`00Ool00002
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001o
ogoo00Eoo`@0009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo00001Goo00<007oo
Ool037oo00<007oo00000Woo00<007oo000017oo00@007ooOol0009oo`03001oo`0000=oo`05001o
o`00Ool00018Ool006moo`03001oogoo00<0009oo`03001oogoo009oo`06001oogoo001oo`000Woo
00<007oo00000Woo00<007ooOol02goo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool0
00020003Ool00`00Oomoo`0>Ool01P00Oomoo`00Ool000=oo`05001oogooOol00004Ool300001Woo
001oo`00Ool004Qoo`00KWoo00@007ooOomoo`<0009oo`<000=oo`800003Ool00000008000=oo`<0
00eoo`05001oogoo001oo`040002Ool3000017oo000000000Woo10003Goo00<007ooOol00P0000=o
o`0000000Woo0P0000=oo`0000000P000Woo0`0000Eoo`00001oo`0004Uoo`00KGoo00<007oo0000
6Goo00<007ooOol02goo00@007ooOol000Uoo`03001oogoo01Aoo`03001oo`0000aoo`03001oogoo
05=oo`00KGoo0`0067oo0P003Woo0P002Goo0P005Woo0`00HWoo003oOolQOol00?moob5oo`00ogoo
8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {213.438, 0}} -> {-0.166383, 0.0545821, 
  0.00379775, 0.00379775}},
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "Here is a third\[Hyphen]order system. In the next few inputs, we will \
compute the step response for a few values of the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)], "InlineFormula",
    CellTags->"S0.0.4"],
  " defined as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = p/\((\[Zeta]\[Omega]\_n)\)\)], 
    "InlineFormula",
    CellTags->"S0.0.4"],
  " for the particular case of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta] = 1/2\)], "InlineFormula",
    CellTags->"S0.0.4"],
  ". "
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
s3[wn_, zeta_, p_]  = TransferFunction[s,
 wn^2 p/((s^2 + 2 zeta wn s + wn^2)(s+p))]\
\>", "Input",
  CellLabel->"In[39]:=",
  CellTags->"4.3"],

Cell[BoxData[
    \(TransferFunction[
      s, {{\(p\ wn\^2\)\/\(\((p + s)\)\ 
              \((s\^2 + wn\^2 + 2\ s\ wn\ zeta)\)\)}}]\)], "Output",
  CellLabel->"Out[39]=",
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = \[Infinity]\)], "InlineFormula",
    CellTags->"S0.0.4"],
  ", the system degenerates to the second\[Hyphen]order one. "
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["MapAt[Limit[#, p -> Infinity]&, %, 2]", "Input",
  CellLabel->"In[40]:=",
  CellTags->"4.3"],

Cell[BoxData[
    \(TransferFunction[s, {{wn\^2\/\(s\^2 + wn\^2 + 2\ s\ wn\ zeta\)}}]\)], 
  "Output",
  CellLabel->"Out[40]=",
  CellTags->"4.3"]
}, Open  ]],

Cell["This is its step response. ", "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
OutputResponse[% /. {wn -> 1, zeta -> 1/2},
 UnitStep[t], t]\
\>", "Input",
  CellLabel->"In[41]:=",
  CellTags->"4.3"],

Cell[BoxData[
    \({1\/6\ E\^\(\(-\(1\/2\)\)\ I\ \((\(-I\) + \@3)\)\ t\)\ 
        \((\(-3\) - I\ \@3 - 3\ E\^\(I\ \@3\ t\) + I\ \@3\ E\^\(I\ \@3\ t\) + 
            6\ E\^\(1\/2\ \((t + I\ \@3\ t)\)\))\)\ UnitStep[t]}\)], "Output",\

  CellLabel->"Out[41]=",
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "This is the step response for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 2\)], "InlineFormula",
    CellTags->"S0.0.4"],
  ". "
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["OutputResponse[s3[1, 1/2, 1], UnitStep[t], t]", "Input",
  CellLabel->"In[42]:=",
  CellTags->"4.3"],

Cell[BoxData[
    \({\((
          1 - E\^\(-t\) - 
            \(I\ E\^\(\(-\(1\/2\)\)\ I\ \((\(-I\) + \@3)\)\ t\)\)\/\@3 + 
            \(I\ E\^\(1\/2\ I\ \((I + \@3)\)\ t\)\)\/\@3)\)\ UnitStep[t]}\)], 
  "Output",
  CellLabel->"Out[42]=",
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "Finally, this is the step response for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 1\)], "InlineFormula",
    CellTags->"S0.0.4"],
  ". "
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["OutputResponse[s3[1, 1/2, 1/2], UnitStep[t], t]", "Input",
  CellLabel->"In[43]:= ",
  CellTags->"4.3"],

Cell[BoxData[
    \({1\/6\ E\^\(\(-\(1\/2\)\)\ I\ \((\(-I\) + \@3)\)\ t\)\ 
        \((1 - I\ \@3 - 8\ E\^\(1\/2\ I\ \@3\ t\) + E\^\(I\ \@3\ t\) + 
            I\ \@3\ E\^\(I\ \@3\ t\) + 6\ E\^\(1\/2\ \((1 + I\ \@3)\)\ t\))
          \)\ UnitStep[t]}\)], "Output",
  CellLabel->"Out[43]= ",
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "This combines the three previous results. The solid, dashed, and dashed\
\[Hyphen]dotted lines represent the respective curves for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 1\)], "InlineFormula",
    CellTags->"S0.0.4"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`2\)], "InlineFormula",
    CellTags->"S0.0.4"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Infinity]\)], "InlineFormula",
    CellTags->"S0.0.4"],
  ". "
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Join[%, %%, %%%]], {t, 0, 8},
 PlotStyle -> {
 Thickness[.005],
 Dashing[{.03}],
 Dashing[{.05, .02, .01, .02}]
 },
 PlotLabel -> \"Step Response\"
]\
\>", "Input",
  CellLabel->"In[44]:=",
  CellTags->"4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.506094 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11593 -18 -4.5 ]
[.01131 .11593 0 4.5 ]
[.01131 .21715 -18 -4.5 ]
[.01131 .21715 0 4.5 ]
[.01131 .31837 -18 -4.5 ]
[.01131 .31837 0 4.5 ]
[.01131 .41959 -18 -4.5 ]
[.01131 .41959 0 4.5 ]
[.01131 .52081 -6 -4.5 ]
[.01131 .52081 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .01472 m
.2619 .02097 L
s
[(2)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(4)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(6)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.20238 .01472 m
.20238 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.79762 .01472 m
.79762 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11593 m
.03006 .11593 L
s
[(0.2)] .01131 .11593 1 0 Mshowa
.02381 .21715 m
.03006 .21715 L
s
[(0.4)] .01131 .21715 1 0 Mshowa
.02381 .31837 m
.03006 .31837 L
s
[(0.6)] .01131 .31837 1 0 Mshowa
.02381 .41959 m
.03006 .41959 L
s
[(0.8)] .01131 .41959 1 0 Mshowa
.02381 .52081 m
.03006 .52081 L
s
[(1)] .01131 .52081 1 0 Mshowa
.125 Mabswid
.02381 .04002 m
.02756 .04002 L
s
.02381 .06532 m
.02756 .06532 L
s
.02381 .09063 m
.02756 .09063 L
s
.02381 .14124 m
.02756 .14124 L
s
.02381 .16654 m
.02756 .16654 L
s
.02381 .19185 m
.02756 .19185 L
s
.02381 .24246 m
.02756 .24246 L
s
.02381 .26776 m
.02756 .26776 L
s
.02381 .29307 m
.02756 .29307 L
s
.02381 .34368 m
.02756 .34368 L
s
.02381 .36898 m
.02756 .36898 L
s
.02381 .39429 m
.02756 .39429 L
s
.02381 .44489 m
.02756 .44489 L
s
.02381 .4702 m
.02756 .4702 L
s
.02381 .4955 m
.02756 .4955 L
s
.02381 .54611 m
.02756 .54611 L
s
.02381 .57142 m
.02756 .57142 L
s
.02381 .59672 m
.02756 .59672 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Step) show
93.000000 12.812500 moveto
(Response) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.005 w
.02554 .01472 m
.02605 .01472 L
.02721 .01472 L
.02846 .01472 L
.02955 .01472 L
.03071 .01472 L
.0317 .01473 L
.03279 .01473 L
.03406 .01474 L
.03523 .01475 L
.03786 .01478 L
.0403 .01482 L
.04262 .01487 L
.045 .01494 L
.04753 .01502 L
.0521 .01523 L
.05752 .01557 L
.06244 .01599 L
.07287 .01723 L
.07874 .01818 L
.08414 .01922 L
.09471 .02176 L
.10458 .02478 L
.1234 .03237 L
.14407 .04355 L
.18298 .07253 L
.22434 .11319 L
.26418 .15927 L
.30251 .20707 L
.34329 .25857 L
.38256 .30619 L
.42031 .34827 L
.46051 .38773 L
.4992 .41977 L
.54034 .44727 L
.57997 .46766 L
.61807 .48219 L
.63768 .48797 L
.65863 .49302 L
.67855 .49687 L
.70013 .50013 L
.72093 .50251 L
.74011 .50415 L
.75888 .50532 L
.76954 .50583 L
.77952 .50621 L
.78992 .50654 L
.7998 .50678 L
.80867 .50695 L
.81834 .50709 L
Mistroke
.82367 .50715 L
.82869 .5072 L
.83805 .50726 L
.84331 .50729 L
.84814 .50731 L
.85344 .50733 L
.85632 .50733 L
.85904 .50734 L
.86142 .50734 L
.86401 .50735 L
.86617 .50735 L
.86854 .50735 L
.87111 .50735 L
.87242 .50735 L
.87383 .50736 L
.87515 .50736 L
.87635 .50736 L
.8775 .50736 L
.87872 .50736 L
.87988 .50736 L
.88093 .50736 L
.88199 .50736 L
.88299 .50736 L
.88416 .50736 L
.88523 .50736 L
.88641 .50736 L
.88766 .50736 L
.88878 .50736 L
.88998 .50736 L
.89111 .50736 L
.89214 .50736 L
.89335 .50736 L
.89467 .50736 L
.89591 .50736 L
.89706 .50736 L
.89824 .50736 L
.89947 .50736 L
.90169 .50736 L
.90407 .50736 L
.90667 .50736 L
.90893 .50736 L
.91135 .50737 L
.9157 .50737 L
.92125 .50738 L
.92649 .50739 L
.93116 .5074 L
.9363 .50742 L
.946 .50747 L
.95629 .50753 L
.97473 .50769 L
Mistroke
.97619 .5077 L
Mfstroke
.5 Mabswid
[ .03 ] 0 setdash
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01473 L
.03163 .01474 L
.03279 .01475 L
.03395 .01477 L
.0352 .01479 L
.03746 .01484 L
.04016 .01492 L
.04262 .01502 L
.04514 .01516 L
.04748 .01531 L
.05278 .01579 L
.05746 .01637 L
.06244 .01716 L
.06791 .01827 L
.07382 .01976 L
.08454 .02334 L
.09498 .02796 L
.10458 .03327 L
.1234 .04666 L
.14407 .06587 L
.18449 .1157 L
.2234 .17522 L
.26476 .24503 L
.30461 .31291 L
.34294 .37428 L
.38372 .43177 L
.42298 .47737 L
.46074 .51136 L
.48171 .52608 L
.50094 .53709 L
.51978 .54569 L
.53963 .55257 L
.54917 .55514 L
.55937 .55739 L
.56892 .55906 L
.57773 .56025 L
.58261 .56077 L
.58798 .56123 L
.59337 .56159 L
.59632 .56174 L
.59908 .56185 L
.60168 .56193 L
.60297 .56196 L
.60416 .56199 L
Mistroke
.60532 .56201 L
.60638 .56202 L
.60755 .56203 L
.6088 .56204 L
.60945 .56204 L
.61014 .56204 L
.61138 .56203 L
.61207 .56203 L
.61271 .56202 L
.61417 .56201 L
.61545 .56199 L
.61662 .56197 L
.61923 .5619 L
.62153 .56183 L
.62405 .56173 L
.62917 .56148 L
.63835 .56086 L
.64908 .55988 L
.65913 .55874 L
.69787 .55287 L
.73906 .54512 L
.77874 .53737 L
.8169 .53043 L
.85751 .52417 L
.89661 .51949 L
.918 .51753 L
.93816 .51605 L
.95796 .51495 L
.97619 .5142 L
Mfstroke
[ .05 .02 .01 .02 ] 0 setdash
.02499 .01474 m
.02605 .0148 L
.02729 .01493 L
.02846 .0151 L
.03053 .01551 L
.03279 .01612 L
.03527 .01698 L
.0379 .01812 L
.04262 .0207 L
.05205 .02783 L
.06244 .0385 L
.0842 .06895 L
.10458 .10539 L
.14335 .18806 L
.18458 .28326 L
.22428 .37125 L
.26248 .44562 L
.30312 .50952 L
.34225 .55461 L
.36366 .57255 L
.38383 .58534 L
.3936 .59018 L
.40391 .5944 L
.41358 .59756 L
.42239 .5998 L
.43186 .60156 L
.43708 .60226 L
.43948 .60252 L
.44202 .60276 L
.44419 .60292 L
.44658 .60307 L
.44876 .60318 L
.45081 .60325 L
.45197 .60328 L
.4532 .6033 L
.45425 .60331 L
.4554 .60332 L
.45664 .60332 L
.45734 .60331 L
.45797 .6033 L
.4592 .60328 L
.46036 .60326 L
.46275 .60318 L
.46499 .60307 L
.46744 .60293 L
.47008 .60274 L
.47546 .60224 L
.48037 .60167 L
.48984 .60024 L
.49882 .59855 L
Mistroke
.53707 .58834 L
.57777 .57411 L
.61695 .55934 L
.65858 .54436 L
.6987 .53182 L
.7373 .52214 L
.75689 .51821 L
.77836 .51466 L
.79882 .51199 L
.8179 .5101 L
.82838 .50929 L
.83829 .50866 L
.84712 .50822 L
.85215 .50801 L
.85686 .50784 L
.86191 .50769 L
.86654 .50758 L
.87149 .50748 L
.87424 .50744 L
.87681 .50741 L
.87906 .50739 L
.8811 .50738 L
.88219 .50737 L
.88337 .50737 L
.88462 .50736 L
.88579 .50736 L
.88693 .50736 L
.88819 .50736 L
.88949 .50736 L
.89071 .50736 L
.89186 .50737 L
.8929 .50737 L
.89524 .50738 L
.89752 .5074 L
.90004 .50743 L
.90514 .5075 L
.90986 .50758 L
.9143 .50767 L
.93506 .50829 L
.95521 .50913 L
.97371 .51005 L
.97619 .51018 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001JOol3
000iOol3000gOol2000jOol00`00Oomoo`0AOol005Yoo`03001oogoo03Yoo`03001oogoo03Ioo`03
001oo`0003Qoo`03001oo`00019oo`00Fgoo00<007ooOol0=goo1000=goo00<007oo0000>7oo00<0
07oo00004Woo001KOol00`00Oomoo`0gOol00`00Ool0000hOol2000jOol00`00Oomoo`0AOol005Yo
o`03001oo`0003Uoo`8003Qoo`03001oogoo03Qoo`03001oo`00019oo`00Fgoo00<007ooOol0>Goo
00<007ooOol0=goo0P00>Goo00<007ooOol04Goo003oOolQOol0025oo`03001oogoo0?aoo`008Goo
00<007ooOol0o7oo000QOol00`00Oomoo`3lOol0025oo`03001oogoo0?aoo`006goon0003Goo000Q
Ool01@00Oomoogoo000027oo1P002Woo00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo
00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo
00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol02goo00<007ooOol04Goo000QOol00`00Oomoo`02Ool20008Ool01000Oomoogoo0P00
jWoo000QOol00`00Oomoo`04Ool00`00Oomoo`06Ool30002Ool2003XOol0025oo`03001oogoo00Eo
o`03001oogoo00Qoo`80009oo`800>Ioo`008Goo00<007ooOol01Woo00<007ooOol02Goo00@007oo
Oomoo`800>Aoo`008Goo0P006Goo0P00hWoo000QOol00`00Oomoo`0JOol2003POol0025oo`03001o
ogoo01aoo`03001oogoo0=eoo`008Goo00<007ooOol02Goo00<007ooOol04Goo0P00gGoo000QOol0
0`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`3JOol0025oo`03001oogoo
00]oo`03001oogoo00]oo`8000Eoo`03001oogoo0=Uoo`008Goo0P0077oo00<007ooOol00goo0P00
fGoo000QOol00`00Oomoo`0LOol00`00Oomoo`04Ool00`00Oomoo`3FOol0025oo`03001oogoo01ao
o`03001oogoo00Eoo`03001oogoo0=Eoo`008Goo00<007ooOol07Goo00<007ooOol01Goo00<007oo
Ool0e7oo000QOol00`00Oomoo`0=Ool00`00Oomoo`0FOol00`00Oomoo`3COol0025oo`03001oogoo
00ioo`03001oogoo01Ioo`03001oogoo0=9oo`008Goo0P003goo00<007ooOol05goo00<007ooOol0
dGoo000QOol00`00Oomoo`0?Ool00`00Oomoo`0GOol00`00Oomoo`3@Ool0025oo`03001oogoo011o
o`03001oogoo01Moo`03001oogoo0<moo`008Goo00<007ooOol047oo00<007ooOol03goo00<007oo
Ool01Woo00<007ooOol0cWoo000QOol00`00Oomoo`0AOol00`00Oomoo`0?Ool00`00Oomoo`06Ool0
0`00Oomoo`3=Ool0015oo`03001oogoo009oo`04001oogooOol30004Ool00`00Oomoo`0AOol00`00
Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`3<Ool0011oo`03001oo`0000Moo`03001oogoo00Ao
o`03001oogoo019oo`03001oogoo00moo`03001oogoo00Moo`03001oogoo0<]oo`0047oo00<007oo
000027oo00<007ooOol00goo0P004goo00<007ooOol047oo00<007ooOol01goo00<007ooOol0bWoo
000@Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`0@Ool00`00Oomo
o`07Ool00`00Oomoo`39Ool0011oo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo01=oo`03
001oogoo011oo`03001oogoo00Qoo`03001oogoo0<Qoo`004Goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol0<Woo00<007ooOol0agoo000QOol00`00Oomoo`0cOol00`00Oomoo`36Ool0025o
o`03001oogoo03=oo`03001oogoo0<Ioo`008Goo0P005Woo00<007ooOol077oo00<007ooOol0aGoo
000QOol00`00Oomoo`0FOol00`00Oomoo`0LOol00`00Oomoo`34Ool0025oo`03001oogoo01Ioo`03
001oogoo015oo`03001oogoo00Uoo`03001oogoo0<=oo`008Goo00<007ooOol0:goo00<007ooOol0
2Goo00<007ooOol0`Woo000QOol00`00Oomoo`0[Ool00`00Oomoo`0:Ool00`00Oomoo`31Ool0025o
o`03001oogoo02aoo`03001oogoo00Yoo`03001oogoo0<1oo`008Goo0P00;Woo00<007ooOol02Woo
00<007ooOol0_goo000QOol00`00Oomoo`0HOol00`00Oomoo`0BOol00`00Oomoo`0;Ool00`00Oomo
o`2nOol0025oo`03001oogoo01Qoo`03001oogoo01=oo`03001oogoo00Yoo`03001oogoo0;ioo`00
8Goo00<007ooOol06Goo00<007ooOol087oo00<007ooOol0_Goo000QOol00`00Oomoo`0IOol00`00
Oomoo`0QOol00`00Oomoo`2lOol0025oo`03001oogoo01Yoo`03001oogoo025oo`03001oogoo0;]o
o`008Goo0P006goo00<007ooOol08Woo00<007ooOol0^Woo000QOol00`00Oomoo`0KOol00`00Oomo
o`0ROol00`00Oomoo`2iOol0025oo`03001oogoo01]oo`03001oogoo029oo`03001oogoo0;Uoo`00
8Goo00<007ooOol077oo00<007ooOol04goo00<007ooOol037oo00<007ooOol0^7oo000QOol00`00
Oomoo`0LOol00`00Oomoo`0DOol00`00Oomoo`0<Ool00`00Oomoo`2gOol0015oo`03001oogoo009o
o`03001oogoo009oo`<000=oo`03001oogoo01eoo`03001oogoo01=oo`03001oogoo00eoo`03001o
ogoo0;Ioo`0047oo00<007oo00002Goo00<007ooOol00Woo00<007ooOol07Goo00<007ooOol057oo
00<007ooOol03Goo00<007ooOol0]Goo000@Ool00`00Ool00007Ool40003Ool2000fOol00`00Oomo
o`0<Ool00`00Oomoo`2eOol0011oo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo03Eoo`03
001oogoo00eoo`03001oogoo0;Aoo`0047oo00<007oo000027oo0P0017oo00<007ooOol0=Woo00<0
07ooOol03Goo00<007ooOol0/goo000AOol00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`17
Ool00`00Oomoo`2bOol0025oo`03001oogoo01moo`03001oogoo02Eoo`03001oogoo0;9oo`008Goo
00<007ooOol087oo00<007ooOol09Goo00<007ooOol0/Goo000QOol2000QOol00`00Oomoo`0VOol0
0`00Oomoo`2`Ool0025oo`03001oogoo04Yoo`03001oogoo0:moo`008Goo00<007ooOol0BWoo00<0
07ooOol0[goo000QOol00`00Oomoo`0iOol00`00Oomoo`0?Ool00`00Oomoo`2^Ool0025oo`03001o
ogoo029oo`03001oogoo01Eoo`03001oogoo00moo`03001oogoo0:eoo`008Goo00<007ooOol08goo
00<007ooOol057oo00<007ooOol047oo00<007ooOol0[7oo000QOol2000TOol00`00Oomoo`0EOol0
0`00Oomoo`0@Ool00`00Oomoo`2[Ool0025oo`03001oogoo02Aoo`03001oogoo01Eoo`03001oogoo
011oo`03001oogoo0:Yoo`008Goo00<007ooOol097oo00<007ooOol05Goo00<007ooOol047oo00<0
07ooOol0ZWoo000QOol00`00Oomoo`0UOol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`2Y
Ool0025oo`03001oogoo02Eoo`03001oogoo02Uoo`03001oogoo0:Qoo`008Goo00<007ooOol09Goo
00<007ooOol0:Woo00<007ooOol0Ygoo000QOol2000WOol00`00Oomoo`0ZOol00`00Oomoo`2VOol0
025oo`03001oogoo02Ioo`03001oogoo02]oo`03001oogoo0:Eoo`008Goo00<007ooOol09Woo00<0
07ooOol0:goo00<007ooOol0YGoo000QOol00`00Oomoo`0WOol00`00Oomoo`0GOol00`00Oomoo`0A
Ool00`00Oomoo`2TOol0025oo`03001oogoo02Moo`03001oogoo01Qoo`03001oogoo015oo`03001o
ogoo0:=oo`004Goo00<007ooOol00Woo00@007ooOomoo`8000Eoo`03001oogoo049oo`03001oogoo
019oo`03001oogoo0:9oo`0047oo00<007oo00001goo00<007oo000017oo00<007ooOol0@goo00<0
07ooOol04Woo00<007ooOol0XGoo000@Ool00`00Ool00007Ool00`00Ool00004Ool20014Ool00`00
Oomoo`0COol00`00Oomoo`2POol0011oo`03001oo`0000Moo`8000Eoo`03001oogoo02Uoo`03001o
ogoo01Qoo`03001oogoo01=oo`03001oogoo09moo`0047oo00<007oo00001goo00<007ooOol017oo
00<007ooOol0:Woo00<007ooOol05goo00<007ooOol057oo00<007ooOol0WWoo000AOol00`00Oomo
o`07Ool20004Ool00`00Oomoo`0ZOol00`00Oomoo`0HOol00`00Oomoo`0COol00`00Oomoo`2NOol0
025oo`03001oogoo05aoo`03001oogoo09eoo`008Goo00<007ooOol0GGoo00<007ooOol0W7oo000Q
Ool2001OOol00`00Oomoo`2KOol0025oo`03001oogoo05moo`03001oogoo09Yoo`008Goo00<007oo
Ool0;7oo00<007ooOol0<Goo00<007ooOol0VGoo000QOol00`00Oomoo`0/Ool00`00Oomoo`0JOol0
0`00Oomoo`0EOol00`00Oomoo`2HOol0025oo`03001oogoo02eoo`03001oogoo01Yoo`03001oogoo
01Eoo`03001oogoo09Moo`008Goo00<007ooOol0;Goo00<007ooOol06Woo00<007ooOol05Woo00<0
07ooOol0UWoo000QOol2000_Ool00`00Oomoo`0JOol00`00Oomoo`0FOol00`00Oomoo`2EOol0025o
o`03001oogoo02ioo`03001oogoo01Yoo`03001oogoo01Moo`03001oogoo09Aoo`008Goo00<007oo
Ool0;goo00<007ooOol06Woo00<007ooOol05goo00<007ooOol0Tgoo000QOol00`00Oomoo`0_Ool0
0`00Oomoo`0KOol00`00Oomoo`0GOol00`00Oomoo`2BOol0025oo`03001oogoo031oo`03001oogoo
03Eoo`03001oogoo095oo`008Goo00<007ooOol0<Goo00<007ooOol0=Goo00<007ooOol0T7oo000Q
Ool00`00Oomoo`0aOol00`00Oomoo`0fOol00`00Oomoo`2?Ool0025oo`8003=oo`03001oogoo03Io
o`03001oogoo08ioo`008Goo00<007ooOol0K7oo00<007ooOol0SGoo000QOol00`00Oomoo`1AOol0
0`00Oomoo`0IOol2002=Ool0025oo`03001oogoo059oo`03001oogoo01Yoo`03001oogoo08Yoo`00
4Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0=7oo00<007ooOol0
6goo00<007ooOol06goo00<007ooOol0RGoo000@Ool00`00Ool00007Ool00`00Ool00004Ool00`00
Oomoo`0dOol00`00Oomoo`0LOol00`00Oomoo`0KOol00`00Oomoo`28Ool0011oo`03001oo`0000Mo
o`03001oo`0000Aoo`8003Ioo`03001oogoo01aoo`03001oogoo01]oo`03001oogoo08Moo`0047oo
00<007oo000027oo00<007ooOol00goo00<007ooOol0=Goo00<007ooOol077oo00<007ooOol077oo
0P00Qgoo000@Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`1EOol00`00Oomoo`0MOol0
0`00Oomoo`24Ool0015oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo07Ioo`8008Aoo`00
8Goo00<007ooOol0N7oo0P00PWoo000QOol00`00Oomoo`0gOol00`00Oomoo`10Ool00`00Oomoo`1o
Ool0025oo`8003Uoo`03001oogoo041oo`8007moo`008Goo00<007ooOol0>Goo00<007ooOol0@Goo
00<007ooOol0O7oo000QOol00`00Oomoo`0iOol00`00Oomoo`0NOol00`00Oomoo`0QOol2001lOol0
025oo`03001oogoo03Yoo`03001oogoo01ioo`03001oogoo029oo`8007Yoo`008Goo00<007ooOol0
>Woo00<007ooOol07goo00<007ooOol08goo0P00N7oo000QOol00`00Oomoo`0kOol00`00Oomoo`0O
Ool00`00Oomoo`0TOol2001fOol0025oo`8003eoo`03001oogoo01ioo`03001oogoo02Ioo`8007Ao
o`008Goo00<007ooOol0?7oo00<007ooOol07goo00<007ooOol09goo0`00LGoo000QOol00`00Oomo
o`0mOol00`00Oomoo`0OOol00`00Oomoo`0YOol4001]Ool0025oo`03001oogoo03eoo`03001oogoo
04moo`<006Yoo`008Goo00<007ooOol0?Woo00<007ooOol0DGoo0P00J7oo000QOol00`00Oomoo`2D
Ool4001TOol0025oo`03001oogoo09Qoo`D005moo`008Goo0P00IGoo00<007ooOol0=Woo1@00FWoo
000QOol00`00Oomoo`10Ool00`00Oomoo`0ROol2000kOol:001@Ool0025oo`03001oogoo045oo`03
001oogoo02=oo`8004=ooc@001aoo`008Goo00<007ooOol0@Woo00<007ooOol097oo00<007ooOol0
Dgoo1P0017oo10002Woo1`000Woo2@004goo000IOol50003Ool00`00Oomoo`1ZOol00`00Oomoo`1;
Ool7000VOol4000COol001]oo`03001oogoo00=oo`03001oogoo0;5oo`<0029oo`P001ioo`006goo
00<007ooOol00goo0P00cWoo0P00;Goo000KOol00`00Oomoo`03Ool00`00Oomoo`15Ool00`00Oomo
o`1SOol2000JOol6000_Ool001]oo`03001oogoo00=oo`03001oogoo04Ioo`03001oogoo02Moo`03
001oogoo03Aoo`@001Aoo`8003]oo`006Woo0P001Goo00<007ooOol0Agoo00<007ooOol09goo0P00
<7oo100057oo1000?Goo000QOol00`00Oomoo`18Ool00`00Oomoo`0XOol00`00Oomoo`0ZOol3000E
Ool30011Ool0025oo`03001oogoo04Uoo`03001oogoo02Qoo`8002Eoo`03001oogoo019oo`8004Yo
o`008Goo0P00Bgoo00<007ooOol0:Goo0P008Goo0P004Woo0`00C7oo000QOol00`00Oomoo`1;Ool0
0`00Oomoo`1LOol3001?Ool0025oo`03001oogoo04aoo`03001oogoo02moo`8001=oo`8000]oo`@0
05Qoo`008Goo00<007ooOol0CGoo00<007ooOol0<7oo1P002Goo100027oo1@00G7oo000QOol00`00
Oomoo`1=Ool00`00Oomoo`0lOol9001WOol0025oo`03001oogoo08]oo`8006moo`008Goo0P00RWoo
0P00LGoo000QOol00`00Oomoo`1AOol00`00Oomoo`2XOol0025oo`03001oogoo059oo`80031oo`03
001oogoo07Eoo`008Goo00<007ooOol0PWoo0P00N7oo000QOol00`00Oomoo`1mOol00`00Oomoo`1l
Ool0025oo`03001oogoo05Moo`<0021oo`<007moo`008Goo00<007ooOol0FWoo0P006Goo1@00PWoo
000QOol2001MOol5000?Ool50027Ool0025oo`03001oogoo065oo`<000Aoo`@000Aoo`03001oogoo
08Uoo`008Goo00<007ooOol0o7oo000QOol00`00Oomoo`3lOol0025oo`03001oogoo0?aoo`008Goo
00<007ooOol0o7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Ogoo0`00
6goo0`00P7oo0020Ool00`00Oomoo`0KOol00`00Oomoo`1oOol0075oo`<000=oo`8000=oo`80009o
o`<000]oo`<00004Ool007ooOol20002Ool20003Ool30003Ool200000goo00000002Ool01000Ool0
000017oo0P00Jgoo001aOol00`00Ool00002Ool01P00Oomoo`00Ool000Aoo`04001oogoo000;Ool0
1P00Oomoo`00Ool000Ioo`04001oogoo0002Ool00`00Ool00002Ool00`00Ool00002Ool01@00Oomo
ogoo00000Woo00<007ooOol0Jgoo001cOol01000Oomoo`0017oo0`000Woo00@007ooOol000]oo`<0
009oo`<000=oo`05001oogooOol00002Ool00`00Ool00002Ool00`00Ool00002Ool01000Oomoo`00
0goo0`00Jgoo001bOol00`00Oomoo`040002Ool300000goo00000002000<Ool01@00Oomoo`00Ool0
0`000goo0P0000=oo`0000000P000goo0P0000=oo`0000000P000goo0P000Woo0`00Jgoo001aOol0
0`00Ool00002Ool00`00Oomoo`0FOol01000Oomoo`00SGoo001aOol3000JOol4002>Ool00?moob5o
o`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.13269, -0.0966087, 
  0.0339684, 0.00799035}},
  CellTags->"4.3"]
}, Open  ]],

Cell["\<\
This is the simulation of a ramp response of the \
third\[Hyphen]order system for a particular set of parameters. To visualize \
the steady\[Hyphen]state error, we include the dashed straight line. \
\>", 
  "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
SimulationPlot[s3[1., .5, 1.], t, {t, 0, 20},
 Epilog -> {
 Dashing[{0.025}], Line[{{0,0}, {20,20}}]
 },
 PlotLabel -> \"Ramp Response\"

]\
\>", "Input",
  CellLabel->"In[45]:=",
  CellTags->"4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.0336321 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .0988 -18 -4.5 ]
[.01131 .0988 0 4.5 ]
[.01131 .18288 -6 -4.5 ]
[.01131 .18288 0 4.5 ]
[.01131 .26696 -18 -4.5 ]
[.01131 .26696 0 4.5 ]
[.01131 .35104 -12 -4.5 ]
[.01131 .35104 0 4.5 ]
[.01131 .43512 -24 -4.5 ]
[.01131 .43512 0 4.5 ]
[.01131 .5192 -12 -4.5 ]
[.01131 .5192 0 4.5 ]
[.01131 .60328 -24 -4.5 ]
[.01131 .60328 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .0988 m
.03006 .0988 L
s
[(2.5)] .01131 .0988 1 0 Mshowa
.02381 .18288 m
.03006 .18288 L
s
[(5)] .01131 .18288 1 0 Mshowa
.02381 .26696 m
.03006 .26696 L
s
[(7.5)] .01131 .26696 1 0 Mshowa
.02381 .35104 m
.03006 .35104 L
s
[(10)] .01131 .35104 1 0 Mshowa
.02381 .43512 m
.03006 .43512 L
s
[(12.5)] .01131 .43512 1 0 Mshowa
.02381 .5192 m
.03006 .5192 L
s
[(15)] .01131 .5192 1 0 Mshowa
.02381 .60328 m
.03006 .60328 L
s
[(17.5)] .01131 .60328 1 0 Mshowa
.125 Mabswid
.02381 .03153 m
.02756 .03153 L
s
.02381 .04835 m
.02756 .04835 L
s
.02381 .06516 m
.02756 .06516 L
s
.02381 .08198 m
.02756 .08198 L
s
.02381 .11561 m
.02756 .11561 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .14924 m
.02756 .14924 L
s
.02381 .16606 m
.02756 .16606 L
s
.02381 .19969 m
.02756 .19969 L
s
.02381 .21651 m
.02756 .21651 L
s
.02381 .23332 m
.02756 .23332 L
s
.02381 .25014 m
.02756 .25014 L
s
.02381 .28377 m
.02756 .28377 L
s
.02381 .30059 m
.02756 .30059 L
s
.02381 .3174 m
.02756 .3174 L
s
.02381 .33422 m
.02756 .33422 L
s
.02381 .36785 m
.02756 .36785 L
s
.02381 .38467 m
.02756 .38467 L
s
.02381 .40148 m
.02756 .40148 L
s
.02381 .4183 m
.02756 .4183 L
s
.02381 .45193 m
.02756 .45193 L
s
.02381 .46875 m
.02756 .46875 L
s
.02381 .48556 m
.02756 .48556 L
s
.02381 .50238 m
.02756 .50238 L
s
.02381 .53601 m
.02756 .53601 L
s
.02381 .55283 m
.02756 .55283 L
s
.02381 .56964 m
.02756 .56964 L
s
.02381 .58646 m
.02756 .58646 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Ramp) show
93.000000 12.812500 moveto
(Response) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.07143 .01472 L
.11905 .01803 L
.16667 .03301 L
.21429 .06049 L
.2619 .09517 L
.30952 .13153 L
.35714 .16679 L
.40476 .20065 L
.45238 .23384 L
.5 .26704 L
.54762 .30049 L
.59524 .33414 L
.64286 .36785 L
.69048 .40154 L
.7381 .43519 L
.78571 .46881 L
.83333 .50243 L
.88095 .53605 L
.92857 .56968 L
.97619 .60332 L
s
[ .025 ] 0 setdash
.02381 .01472 m
0 0 rlineto s
.02381 .01472 m
.87804 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001NOol0
0`00Oomoo`0dOol50002Ool00`00Oomoo`0`Ool50002Ool00`00Oomoo`0bOol30003Ool00`00Oomo
o`0<Ool005eoo`03001oo`0003Moo`07001oogooOol007oo0000<goo00L007ooOomoo`00Ool0000c
Ool00`00Oomoo`02Ool00`00Ool0000=Ool005moo`03001oogoo03Eoo`07001oogooOol007oo0000
<goo00<007ooOol00goo00<007ooOol0<Woo00L007ooOomoo`00Ool0000=Ool005eoo`8003Qoo`07
001oogooOol007oo0000<goo00@007ooOomoo`8003Eoo`07001oogooOol007oo00003Goo001MOol0
0`00Oomoo`0gOol01`00Oomoogoo001oo`0003=oo`05001oogooOol0000eOol00`00Ool00002Ool0
0`00Ool0000=Ool005eoo`<003Ioo`8000Aoo`03001oogoo035oo`8000=oo`<003Aoo`03001oogoo
009oo`03001oogoo00aoo`00ogoo8Goo000TOol00`00Oomoo`3iOol002Aoo`03001oogoo0?Uoo`00
97oo00<007ooOol0nGoo000TOol00`00Oomoo`3iOol001ioooP000Yoo`0097oo0`002Goo00<007oo
Ool027oo00<007oo00000P001goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol03Woo000T
Ool00`00Oomoo`02000GOol3003MOol002Aoo`03001oogoo009oo`03001oogoo01Moo`<00=Yoo`00
97oo0P0087oo0P00f7oo000TOol00`00Oomoo`0QOol2003FOol002Aoo`03001oogoo02=oo`800=Ao
o`0097oo00<007ooOol01goo00<007ooOol06goo00<007ooOol0dGoo000TOol20009Ool2000LOol2
003AOol002Aoo`03001oogoo00Yoo`8001aoo`800<moo`0097oo00<007ooOol037oo00<007ooOol0
6goo0P00cGoo000TOol00`00Oomoo`0/Ool00`00Oomoo`3:Ool002Aoo`8002ioo`03001oogoo0<Uo
o`0097oo00<007ooOol0;Woo0P00bGoo000TOol00`00Oomoo`0AOol00`00Oomoo`0LOol00`00Oomo
o`36Ool002Aoo`03001oogoo019oo`03001oogoo01aoo`03001oogoo0<Eoo`0097oo0P0057oo0P00
7Goo0P00aGoo000TOol00`00Oomoo`0EOol00`00Oomoo`0LOol00`00Oomoo`32Ool001=oo`<000=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo01aoo`03001oogoo0<5o
o`004goo00<007ooOol01goo00<007oo000017oo00<007ooOol0=Woo0P00`Goo000DOol00`00Oomo
o`08Ool00`00Oomoo`02Ool2000iOol00`00Oomoo`2nOol001Aoo`03001oogoo00Ioo`8000Eoo`03
001oogoo01]oo`03001oogoo01]oo`03001oogoo0;eoo`004goo00<007oo00001goo00<007ooOol0
17oo00<007ooOol077oo00<007ooOol06goo0P00_Goo000DOol00`00Oomoo`06Ool30004Ool00`00
Oomoo`0MOol2000MOol00`00Oomoo`2jOol002Aoo`03001oogoo01moo`03001oogoo01]oo`03001o
ogoo0;Uoo`0097oo0P008Goo00<007ooOol06goo00<007ooOol0^7oo000TOol00`00Oomoo`0oOol0
0`00Oomoo`2gOol002Aoo`03001oogoo041oo`800;Moo`0097oo00<007ooOol09Goo00<007ooOol0
6Woo00<007ooOol0]7oo000TOol2000WOol00`00Oomoo`0JOol00`00Oomoo`2cOol002Aoo`03001o
ogoo02Moo`8001]oo`800;=oo`0097oo00<007ooOol0:Goo00<007ooOol06Woo00<007ooOol0/7oo
000TOol00`00Oomoo`0ZOol00`00Oomoo`0JOol2002`Ool002Aoo`8004Yoo`03001oogoo0:eoo`00
97oo00<007ooOol0BWoo0P00[Goo000TOol00`00Oomoo`0_Ool00`00Oomoo`0JOol00`00Oomoo`2Z
Ool002Aoo`03001oogoo031oo`03001oogoo01Yoo`800:Yoo`0097oo0P00<Woo0P0077oo00<007oo
Ool0Ygoo000TOol00`00Oomoo`0cOol00`00Oomoo`0JOol00`00Oomoo`2VOol001ioo`03001oogoo
00=oo`03001oogoo03Aoo`03001oogoo01Yoo`800:Ioo`007Goo00<007oo000017oo00<007ooOol0
Dgoo00<007ooOol0Xgoo000OOol00`00Oomoo`02Ool2001EOol00`00Oomoo`2ROol001eoo`8000Eo
o`03001oogoo03Uoo`03001oogoo01Uoo`800:9oo`007Goo00<007ooOol017oo00<007ooOol0>Woo
00<007ooOol06Woo00<007ooOol0Wgoo000MOol30004Ool00`00Oomoo`0kOol2000KOol00`00Oomo
o`2NOol002Aoo`8003ioo`03001oogoo01Uoo`8009ioo`0097oo00<007ooOol0?Woo00<007ooOol0
6Woo00<007ooOol0Vgoo000TOol00`00Oomoo`1LOol2002KOol002Aoo`03001oogoo05ioo`03001o
ogoo09Qoo`0097oo00<007ooOol0Ggoo0P00V7oo000TOol20014Ool00`00Oomoo`0KOol00`00Oomo
o`2EOol002Aoo`03001oogoo04Aoo`8001aoo`8009Eoo`0097oo00<007ooOol0AWoo0P0077oo00<0
07ooOol0TWoo000TOol00`00Oomoo`18Ool00`00Oomoo`0JOol2002BOol002Aoo`8006Qoo`03001o
ogoo08moo`0097oo00<007ooOol0J7oo0P00Sgoo000TOol00`00Oomoo`1ZOol00`00Oomoo`2<Ool0
02Aoo`03001oogoo04ioo`03001oogoo01Yoo`8008aoo`0097oo0P00D7oo0P0077oo00<007ooOol0
RGoo000TOol00`00Oomoo`1AOol2000KOol20029Ool001Aoo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo05=oo`03001oogoo01Yoo`03001oogoo08Ioo`0057oo00<007oo
Ool01Woo00<007oo000017oo00<007ooOol0LGoo0P00QWoo000DOol00`00Oomoo`08Ool00`00Oomo
o`02Ool2001dOol00`00Oomoo`23Ool001Eoo`03001oogoo00Eoo`8000Eoo`03001oogoo07Aoo`80
08=oo`004goo00<007oo00001goo00<007ooOol017oo00<007ooOol0F7oo00<007ooOol06goo00<0
07ooOol0P7oo000COol30007Ool30004Ool00`00Oomoo`1IOol2000LOol00`00Oomoo`1oOol002Ao
o`8005aoo`8001]oo`8007moo`0097oo00<007ooOol0GGoo00<007ooOol06Woo00<007ooOol0O7oo
000TOol00`00Oomoo`1kOol00`00Oomoo`1kOol002Aoo`03001oogoo07aoo`8007]oo`0097oo0P00
Ogoo00<007ooOol0N7oo000TOol00`00Oomoo`1ROol00`00Oomoo`0JOol00`00Oomoo`1gOol002Ao
o`03001oogoo06=oo`03001oogoo01Yoo`8007Moo`0097oo00<007ooOol0I7oo0P0077oo00<007oo
Ool0M7oo000TOol00`00Oomoo`1VOol00`00Oomoo`0JOol00`00Oomoo`1cOol002Aoo`8006Qoo`03
001oogoo01Yoo`8007=oo`0097oo00<007ooOol0QWoo00<007ooOol0L7oo000TOol00`00Oomoo`27
Ool00`00Oomoo`1_Ool002Aoo`03001oogoo06aoo`03001oogoo01Uoo`8006moo`0097oo0P00KWoo
00<007ooOol06Woo00<007ooOol0K7oo000TOol00`00Oomoo`1^Ool2000KOol2001/Ool001Moo`D0
009oo`03001oogoo00=oo`03001oogoo071oo`03001oogoo01Yoo`03001oogoo06Uoo`006Goo00L0
07ooOomoo`00Ool00004Ool00`00Oomoo`1aOol00`00Oomoo`0JOol2001YOol001Uoo`07001oogoo
Ool007oo000017oo0P00TGoo00<007ooOol0IWoo000IOol01`00Oomoogoo001oo`0000Aoo`03001o
ogoo095oo`8006Ioo`006Goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`1fOol00`00Oomoo`0J
Ool00`00Oomoo`1SOol001Qoo`8000Aoo`03001oogoo00=oo`03001oogoo07Moo`03001oogoo01Yo
o`8006=oo`0097oo0P00NGoo0P0077oo00<007ooOol0H7oo000TOol00`00Oomoo`1jOol00`00Oomo
o`0JOol2001POol002Aoo`03001oogoo07]oo`03001oogoo01]oo`03001oogoo05eoo`0097oo00<0
07ooOol0VWoo0P00GGoo000TOol2002MOol00`00Oomoo`1JOol002Aoo`03001oogoo081oo`03001o
ogoo01Yoo`8005Yoo`0097oo00<007ooOol0PGoo00<007ooOol06goo00<007ooOol0Egoo000TOol0
0`00Oomoo`22Ool2000LOol2001GOol002Aoo`8008Eoo`03001oogoo01]oo`03001oogoo05Aoo`00
97oo00<007ooOol0QGoo00<007ooOol06goo00<007ooOol0Dgoo000TOol00`00Oomoo`2TOol2001C
Ool002Aoo`03001oogoo0:Ioo`03001oogoo051oo`0097oo0P00Z7oo00<007ooOol0Cgoo000TOol0
0`00Oomoo`2:Ool00`00Oomoo`0KOol00`00Oomoo`1>Ool002Aoo`03001oogoo08]oo`8001aoo`03
001oogoo04eoo`003Goo1@0000Aoo`00000000=oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo08eoo`8001]oo`8004eoo`003goo00D007ooOomoo`0000Uoo`03001oo`0000Aoo`03001oogoo
08moo`03001oogoo01Yoo`03001oogoo04Yoo`003goo00<007ooOol00Woo00<007ooOol027oo00<0
07ooOol00Woo0P00[Woo00<007ooOol0BGoo000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20005
Ool00`00Oomoo`2^Ool20019Ool000moo`07001oogooOol007oo00001goo00<007ooOol017oo00<0
07ooOol0/7oo00<007ooOol0AWoo000>Ool20004Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`2D
Ool00`00Oomoo`0JOol20016Ool002Aoo`8009Ioo`8001aoo`03001oogoo04=oo`0097oo00<007oo
Ool0Ugoo0P006goo0P00@goo000TOol00`00Oomoo`2IOol00`00Oomoo`0JOol00`00Oomoo`10Ool0
02Aoo`03001oogoo0;Moo`80041oo`0097oo0P00^Woo00<007ooOol0?Goo000TOol00`00Oomoo`2j
Ool2000mOol002Aoo`03001oogoo09ioo`03001oogoo01]oo`03001oogoo03Yoo`0097oo00<007oo
Ool0Wgoo0P0077oo0P00>Woo000TOol2002ROol2000LOol00`00Oomoo`0gOol002Aoo`03001oogoo
0:=oo`03001oogoo01Yoo`8003Moo`0097oo00<007ooOol0`Woo00<007ooOol0=7oo000TOol00`00
Oomoo`33Ool2000dOol002Aoo`800<Ioo`03001oogoo035oo`0097oo00<007ooOol0Z7oo00<007oo
Ool06goo00<007ooOol0<7oo000GOol50002Ool00`00Oomoo`03Ool00`00Oomoo`2YOol00`00Oomo
o`0KOol2000`Ool001Uoo`07001oogooOol007oo000017oo00<007ooOol0ZWoo0P007Goo00<007oo
Ool0;Goo000IOol00`00Oomoo`03Ool00`00Oomoo`02Ool2002]Ool00`00Oomoo`0KOol00`00Oomo
o`0/Ool001Uoo`04001oogooOol20005Ool00`00Oomoo`2]Ool00`00Oomoo`0KOol2000/Ool001Uo
o`05001oogooOol00006Ool00`00Oomoo`3=Ool00`00Oomoo`0YOol001Qoo`8000=oo`<000Aoo`03
001oogoo0<ioo`03001oogoo02Qoo`0097oo00<007ooOol0/goo00<007ooOol06Goo0P00:7oo000T
Ool2002eOol00`00Oomoo`0JOol00`00Oomoo`0UOol002Aoo`03001oogoo0;Eoo`8001]oo`8002Eo
o`0097oo00<007ooOol0]goo00<007ooOol06Woo00<007ooOol08Woo000TOol00`00Oomoo`2hOol0
0`00Oomoo`0JOol2000ROol002Aoo`800=Qoo`03001oogoo01moo`0097oo00<007ooOol0f7oo0P00
7goo000TOol00`00Oomoo`2mOol00`00Oomoo`0JOol00`00Oomoo`0LOol002Aoo`03001oogoo0;io
o`03001oogoo01Yoo`8001aoo`0097oo0P00`7oo0P0077oo00<007ooOol06Goo000TOol00`00Oomo
o`31Ool00`00Oomoo`0JOol2000IOol002Aoo`03001oogoo0<9oo`03001oogoo01]oo`03001oogoo
01Ioo`0097oo00<007ooOol0hGoo00<007ooOol05Goo000TOol2003SOol2000EOol002Aoo`03001o
ogoo0<Moo`03001oogoo01Yoo`03001oogoo019oo`003Goo1@000Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol0b7oo00<007ooOol06Woo00<007ooOol04Goo000?Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool00004Ool00`00Oomoo`39Ool2000KOol2000AOol0
00moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`800<aoo`03001oogoo01Yoo`03
001oogoo00ioo`003goo00<007ooOol00goo00<007ooOol01Goo0P001Goo00<007ooOol0c7oo00<0
07ooOol0:Woo000?Ool01`00Oomoogoo001oo`0000Moo`03001oogoo00Aoo`03001oogoo0?Uoo`00
3Woo0P000goo0`001goo0`0017oo00<007ooOol0nGoo000TOol00`00Oomoo`3iOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0022Ool3000KOol3001mOol008=oo`03001oogoo
01]oo`03001oogoo07aoo`00Lgoo0`0000=oo`00Ool01@0000Eoo`00Ool007oo00<000]oo`<00004
Ool007ooOol20002Ool20003Ool30003Ool200000goo00000002Ool01000Ool0000017oo0P00J7oo
001dOol01@00Oomoo`00Ool00`0000Qoo`00Ool007oo001oo`000Woo00<007ooOol02Goo00H007oo
Ool007oo0006Ool01000Oomoo`000Woo00<007oo00000Woo00<007oo00000Woo00D007ooOomoo`00
009oo`03001oogoo06Qoo`00M7oo0`0017oo00T007oo001oo`00Ool007oo00000Woo00<007ooOol0
2Goo0`000Woo0`000goo00D007ooOomoo`00009oo`03001oo`00009oo`03001oo`00009oo`04001o
ogoo0003Ool3001XOol007Aoo`04001oogoo0002Ool200001Woo000007oo001oo`@000aoo`05001o
ogoo001oo`030003Ool200000goo000000020003Ool200000goo000000020003Ool20002Ool3001X
Ool007Aoo`04001oogoo000JOol01000Oomoo`00RWoo001cOol4000JOol4002;Ool00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.08175, -1.45376, 
  0.0849214, 0.120238}},
  CellTags->"4.3"]
}, Open  ]],

Cell["Now we consider a two\[Hyphen]input, second\[Hyphen]order system. ", 
  "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
(system =
 StateSpace[{{0, 2}, {-1, -1}},
 {{1, 1}, {1, 0}}, {{1, -2}}]
)//ReviewForm\
\>", "Input",
  CellLabel->"In[46]:=",
  CellTags->"4.3"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "2"},
                  {\(-1\), \(-1\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", "1"},
                  {"1", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", \(-2\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[46]//ReviewForm=",
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "This applies the impulse function to all inputs in turn and simplifies the \
result. Note that we have multiplied the Dirac function by 2 to inject the \
unit energy during the positive half of the impulse (from 0 to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)], "InlineFormula",
    CellTags->"S0.0.4"],
  " seconds, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta] \[Rule] 0\)], "InlineFormula",
    CellTags->"S0.0.4"],
  "). "
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
Map[OutputResponse[#, 2DiracDelta[t], t]&,
 Subsystem[%, #]& /@ Range[2]
]//Simplify\
\>", "Input",
  CellLabel->"In[47]:=",
  CellTags->"4.3"],

Cell[BoxData[
    \({{\(-\(1\/14\)\)\ I\ E\^\(\(-\(1\/2\)\)\ I\ \((\(-I\) + \@7)\)\ t\)\ 
          \((\(-7\)\ I - 11\ \@7 - 7\ I\ E\^\(I\ \@7\ t\) + 
              11\ \@7\ E\^\(I\ \@7\ t\))\)\ \((\(-1\) + 2\ UnitStep[t])\)}, {
        1\/14\ E\^\(\(-\(1\/2\)\)\ I\ \((\(-I\) + \@7)\)\ t\)\ 
          \((7 + 5\ I\ \@7 + 7\ E\^\(I\ \@7\ t\) - 
              5\ I\ \@7\ E\^\(I\ \@7\ t\))\)\ \((\(-1\) + 2\ UnitStep[t])\)}}
      \)], "Output",
  CellLabel->"Out[47]=",
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "In Mathematica version 4.0 and later this result can be obtained without \
multiplying ",
  StyleBox["DiracDelta[t]", "MR"],
  " by 2."
}], "Commentary"],

Cell["\<\
Here is the plot of the impulse responses. Note that we have joined \
the lists in the previous result to plot all curves in one graph. The impulse \
responses for the first and second inputs are shown as a solid and a dashed \
line, respectively. \
\>", "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Join @@ %], {t, 0, 10},
 PlotRange -> All,
 PlotStyle -> {Thickness[.005],
 Dashing[{.05, .02}]},
 PlotLabel -> \"Impulse Response\"
]\
\>", "Input",
  CellLabel->"In[48]:=",
  CellTags->"4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.192205 0.17749 [
[.21429 .17971 -3 -9 ]
[.21429 .17971 3 0 ]
[.40476 .17971 -3 -9 ]
[.40476 .17971 3 0 ]
[.59524 .17971 -3 -9 ]
[.59524 .17971 3 0 ]
[.78571 .17971 -3 -9 ]
[.78571 .17971 3 0 ]
[.97619 .17971 -6 -9 ]
[.97619 .17971 6 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .10346 -24 -4.5 ]
[.01131 .10346 0 4.5 ]
[.01131 .28095 -18 -4.5 ]
[.01131 .28095 0 4.5 ]
[.01131 .3697 -6 -4.5 ]
[.01131 .3697 0 4.5 ]
[.01131 .45844 -18 -4.5 ]
[.01131 .45844 0 4.5 ]
[.01131 .54719 -6 -4.5 ]
[.01131 .54719 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .19221 m
.21429 .19846 L
s
[(2)] .21429 .17971 0 1 Mshowa
.40476 .19221 m
.40476 .19846 L
s
[(4)] .40476 .17971 0 1 Mshowa
.59524 .19221 m
.59524 .19846 L
s
[(6)] .59524 .17971 0 1 Mshowa
.78571 .19221 m
.78571 .19846 L
s
[(8)] .78571 .17971 0 1 Mshowa
.97619 .19221 m
.97619 .19846 L
s
[(10)] .97619 .17971 0 1 Mshowa
.125 Mabswid
.07143 .19221 m
.07143 .19596 L
s
.11905 .19221 m
.11905 .19596 L
s
.16667 .19221 m
.16667 .19596 L
s
.2619 .19221 m
.2619 .19596 L
s
.30952 .19221 m
.30952 .19596 L
s
.35714 .19221 m
.35714 .19596 L
s
.45238 .19221 m
.45238 .19596 L
s
.5 .19221 m
.5 .19596 L
s
.54762 .19221 m
.54762 .19596 L
s
.64286 .19221 m
.64286 .19596 L
s
.69048 .19221 m
.69048 .19596 L
s
.7381 .19221 m
.7381 .19596 L
s
.83333 .19221 m
.83333 .19596 L
s
.88095 .19221 m
.88095 .19596 L
s
.92857 .19221 m
.92857 .19596 L
s
.25 Mabswid
0 .19221 m
1 .19221 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .10346 m
.03006 .10346 L
s
[(-0.5)] .01131 .10346 1 0 Mshowa
.02381 .28095 m
.03006 .28095 L
s
[(0.5)] .01131 .28095 1 0 Mshowa
.02381 .3697 m
.03006 .3697 L
s
[(1)] .01131 .3697 1 0 Mshowa
.02381 .45844 m
.03006 .45844 L
s
[(1.5)] .01131 .45844 1 0 Mshowa
.02381 .54719 m
.03006 .54719 L
s
[(2)] .01131 .54719 1 0 Mshowa
.125 Mabswid
.02381 .03246 m
.02756 .03246 L
s
.02381 .05021 m
.02756 .05021 L
s
.02381 .06796 m
.02756 .06796 L
s
.02381 .08571 m
.02756 .08571 L
s
.02381 .12121 m
.02756 .12121 L
s
.02381 .13896 m
.02756 .13896 L
s
.02381 .15671 m
.02756 .15671 L
s
.02381 .17446 m
.02756 .17446 L
s
.02381 .20995 m
.02756 .20995 L
s
.02381 .2277 m
.02756 .2277 L
s
.02381 .24545 m
.02756 .24545 L
s
.02381 .2632 m
.02756 .2632 L
s
.02381 .2987 m
.02756 .2987 L
s
.02381 .31645 m
.02756 .31645 L
s
.02381 .3342 m
.02756 .3342 L
s
.02381 .35195 m
.02756 .35195 L
s
.02381 .38744 m
.02756 .38744 L
s
.02381 .40519 m
.02756 .40519 L
s
.02381 .42294 m
.02756 .42294 L
s
.02381 .44069 m
.02756 .44069 L
s
.02381 .47619 m
.02756 .47619 L
s
.02381 .49394 m
.02756 .49394 L
s
.02381 .51169 m
.02756 .51169 L
s
.02381 .52944 m
.02756 .52944 L
s
.02381 .56494 m
.02756 .56494 L
s
.02381 .58268 m
.02756 .58268 L
s
.02381 .60043 m
.02756 .60043 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Impulse) show
111.000000 12.812500 moveto
(Response) show
159.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.005 w
.02381 .01472 m
.04262 .20953 L
.06244 .37568 L
.07216 .44065 L
.08255 .49773 L
.08852 .52473 L
.09396 .54566 L
.09911 .56239 L
.10458 .57686 L
.10932 .58676 L
.11183 .59103 L
.11454 .5949 L
.11701 .59778 L
.11928 .59988 L
.12037 .6007 L
.12156 .60148 L
.1226 .60204 L
.12373 .60253 L
.12446 .60279 L
.12514 .60298 L
.12578 .60312 L
.12646 .60323 L
.12764 .60332 L
.12894 .60327 L
.12967 .60318 L
.13033 .60305 L
.1311 .60286 L
.13182 .60263 L
.1331 .6021 L
.1345 .60138 L
.13702 .59965 L
.1397 .59725 L
.14451 .59154 L
.1494 .58398 L
.15388 .57562 L
.16398 .55225 L
.18226 .49722 L
.22188 .34947 L
.25999 .21348 L
.2796 .15763 L
.30055 .11238 L
.3108 .09602 L
.31619 .08893 L
.3219 .08254 L
.32689 .07789 L
.33238 .07376 L
.33738 .07086 L
.34205 .06888 L
.34464 .06807 L
.34703 .06751 L
Mistroke
.34841 .06726 L
.34966 .06708 L
.35035 .067 L
.3511 .06693 L
.35181 .06688 L
.35246 .06685 L
.35365 .06681 L
.35475 .06682 L
.35597 .06686 L
.35727 .06695 L
.35792 .06702 L
.35863 .0671 L
.35992 .06728 L
.36234 .06773 L
.36456 .06828 L
.36701 .06903 L
.37197 .07096 L
.38088 .07577 L
.39099 .08306 L
.40026 .09114 L
.42113 .11287 L
.46081 .15897 L
.49897 .19726 L
.51862 .21178 L
.52961 .21807 L
.53958 .22263 L
.54959 .22611 L
.5588 .22838 L
.56362 .22923 L
.56639 .22961 L
.56892 .22989 L
.57159 .23013 L
.57296 .23022 L
.57445 .23031 L
.57583 .23037 L
.5771 .23041 L
.57832 .23044 L
.57962 .23045 L
.58075 .23045 L
.58199 .23044 L
.58329 .23041 L
.58449 .23038 L
.58563 .23033 L
.58666 .23028 L
.58897 .23014 L
.59146 .22994 L
.59416 .22967 L
.59906 .22906 L
.60856 .22742 L
.61733 .22545 L
Mistroke
.6567 .21312 L
.69456 .19977 L
.71561 .19324 L
.73487 .18832 L
.74438 .18631 L
.75476 .18448 L
.76449 .18308 L
.77366 .18206 L
.77862 .18162 L
.78399 .18123 L
.78886 .18096 L
.79335 .18077 L
.79586 .18069 L
.79821 .18063 L
.79954 .1806 L
.80079 .18058 L
.80223 .18056 L
.80355 .18055 L
.80485 .18054 L
.80551 .18054 L
.80623 .18054 L
.80751 .18054 L
.80871 .18055 L
.8094 .18055 L
.81012 .18056 L
.81141 .18057 L
.8128 .18059 L
.81432 .18062 L
.81686 .18068 L
.81962 .18075 L
.82461 .18094 L
.83395 .18142 L
.84486 .18217 L
.85491 .18301 L
.89433 .18708 L
.93224 .19103 L
.9726 .19412 L
.97619 .19432 L
Mfstroke
.5 Mabswid
[ .05 .02 ] 0 setdash
.02381 .3697 m
.03279 .4 L
.04262 .42604 L
.04758 .43639 L
.05288 .44546 L
.05789 .45216 L
.06244 .45675 L
.06507 .45875 L
.06785 .46038 L
.07022 .46137 L
.07157 .46178 L
.07283 .46206 L
.07353 .46217 L
.07428 .46226 L
.075 .46231 L
.07567 .46233 L
.07692 .4623 L
.07763 .46224 L
.07826 .46216 L
.07901 .46204 L
.07971 .46189 L
.08127 .46147 L
.08265 .46099 L
.0841 .46036 L
.08915 .45731 L
.09387 .45329 L
.10458 .44036 L
.11503 .42336 L
.12493 .40401 L
.14349 .36174 L
.18182 .26572 L
.2012 .22057 L
.2226 .17802 L
.23235 .16181 L
.24285 .14678 L
.2527 .13507 L
.26187 .12624 L
.27144 .11913 L
.2765 .11621 L
.28191 .11373 L
.28464 .11272 L
.28759 .11179 L
.2902 .11113 L
.29296 .11058 L
.29545 .11021 L
.29686 .11006 L
.29819 .10995 L
.2994 .10988 L
.30051 .10983 L
.30179 .10981 L
Mistroke
.30301 .10982 L
.30426 .10986 L
.30496 .10989 L
.30561 .10993 L
.3068 .11002 L
.30805 .11014 L
.31023 .11041 L
.31262 .1108 L
.31791 .11198 L
.32285 .11346 L
.33174 .11695 L
.34125 .12173 L
.38266 .15035 L
.42256 .18028 L
.44082 .19203 L
.46094 .2026 L
.48076 .21024 L
.49161 .21321 L
.49647 .21427 L
.50178 .21524 L
.50655 .21595 L
.51164 .21653 L
.51445 .21679 L
.51701 .21698 L
.51958 .21712 L
.52073 .21718 L
.522 .21723 L
.52309 .21726 L
.52425 .21729 L
.52548 .21731 L
.52663 .21733 L
.52777 .21734 L
.52886 .21733 L
.52983 .21733 L
.53089 .21732 L
.53204 .21729 L
.53331 .21726 L
.53589 .21718 L
.53828 .21706 L
.54052 .21693 L
.5452 .21658 L
.55033 .21609 L
.56068 .21477 L
.57917 .21154 L
.6197 .20241 L
.65871 .19381 L
.68004 .19007 L
.68982 .18867 L
.70018 .1874 L
.70969 .18645 L
Mistroke
.72017 .18563 L
.72476 .18535 L
.72969 .1851 L
.73401 .18491 L
.73861 .18476 L
.74137 .18469 L
.74386 .18464 L
.74637 .1846 L
.74873 .18457 L
.75007 .18456 L
.75081 .18455 L
.75149 .18455 L
.7527 .18454 L
.75334 .18454 L
.75403 .18454 L
.75477 .18454 L
.75557 .18454 L
.75633 .18454 L
.75703 .18455 L
.75766 .18455 L
.75836 .18455 L
.75976 .18456 L
.76237 .18459 L
.76475 .18463 L
.77013 .18474 L
.77487 .18487 L
.77986 .18504 L
.79962 .18597 L
.81799 .18712 L
.85705 .18989 L
.87698 .19123 L
.89857 .19248 L
.91939 .19342 L
.9293 .19377 L
.93857 .19403 L
.94721 .19423 L
.95649 .19438 L
.96177 .19445 L
.96438 .19447 L
.96679 .19449 L
.96915 .19451 L
.97129 .19452 L
.97366 .19453 L
.97497 .19453 L
.97619 .19454 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[48]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001Ioo`D000=oo`03001oogoo0?moo`0067oo00<007ooOol00goo
00<007ooOol0ogoo000BOol30003Ool00`00Oomoo`03Ool3003oOol001Qoo`03001oogoo00=oo`03
001oogoo0?moo`0067oo00<007ooOol00goo00<007ooOol0ogoo000GOol20005Ool00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo0P00ogoo0Goo000NOol2003oOol1Ool001ioo`800?moo`5o
o`007Woo0P00ogoo0Goo000NOol2003oOol1Ool001ioo`800?moo`5oo`007Woo0P00ogoo0Goo000N
Ool2003oOol1Ool001ioo`800?moo`5oo`007Woo0P00DGoo1`00Z7oo000NOol2001>Ool30007Ool2
002VOol001ioo`03001oo`0004aoo`03001oogoo00Yoo`800:Aoo`007Woo00<007oo0000Bgoo00<0
07ooOol03Goo00<007ooOol0XGoo000NOol3001:Ool00`00Oomoo`0?Ool00`00Oomoo`2POol001io
o`03001oo`0004Uoo`03001oogoo015oo`800:1oo`007Woo00<007oo0000B7oo00<007ooOol057oo
00<007ooOol0WGoo000>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Ool0
0017Ool00`00Oomoo`0FOol00`00Oomoo`2LOol000eoo`03001oo`0000Moo`03001oo`0000Aoo`03
001oo`0004Ioo`03001oogoo01Qoo`03001oogoo09]oo`0027oo0`000Woo00<007oo00002Goo00<0
07ooOol00Woo0`00AWoo00<007ooOol06Goo00<007ooOol0VWoo000=Ool00`00Ool00007Ool20005
Ool00`00Ool00015Ool00`00Oomoo`0JOol00`00Oomoo`2JOol000eoo`03001oo`0000Moo`03001o
ogoo00Aoo`03001oo`00045oo`T001Uoo`03001oogoo09Uoo`003Woo00<007ooOol01Woo0`0017oo
00@007ooOol003ioo`<0009oo`03001oogoo00=oo`8001Qoo`03001oogoo09Qoo`007Woo00@007oo
Ool003aoo`8000Eoo`03001oogoo00Eoo`8001Moo`03001oogoo09Moo`007Woo0P0000=oo`00Ool0
>Woo00<007ooOol017oo00<007ooOol027oo0`005Goo00<007ooOol0UWoo000NOol01000Oomoo`00
>Woo00<007ooOol01Goo00<007ooOol08Goo00<007ooOol0UGoo000NOol01000Oomoo`00@Goo00<0
07ooOol08Woo00<007ooOol0UGoo000NOol01000Oomoo`00@Goo00<007ooOol03goo00<007ooOol0
4Goo00<007ooOol0U7oo000NOol200000goo001oo`0eOol00`00Oomoo`07Ool00`00Oomoo`0AOol2
000BOol00`00Oomoo`2COol001ioo`04001oogoo000eOol00`00Oomoo`08Ool00`00Oomoo`0COol0
0`00Oomoo`0@Ool00`00Oomoo`2BOol001ioo`04001oogoo000eOol00`00Oomoo`07Ool00`00Oomo
o`0EOol2000AOol00`00Oomoo`2AOol001ioo`04001oogoo000/Ool30005Ool00`00Oomoo`08Ool0
0`00Oomoo`0GOol00`00Oomoo`02Ool3000:Ool00`00Oomoo`0QOol2000`Ool00`00Oomoo`0ZOol5
0002Ool00`00Oomoo`06Ool001ioo`05001oogooOol0000[Ool00`00Oomoo`04Ool00`00Oomoo`08
Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0QOol00`00Ool0000^
Ool00`00Ool0000]Ool01`00Oomoogoo001oo`0000Moo`007Woo0P000Woo00<007ooOol0:Woo00<0
07ooOol00goo00<007ooOol027oo00<007ooOol06Woo1P002goo00<007ooOol087oo00<007oo0000
;Woo00<007oo0000;Goo00L007ooOomoo`00Ool00007Ool001ioo`05001oogooOol0000/Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0LOol00`00Ool0000=Ool00`00Oomoo`0OOol2000`
Ool00`00Oomoo`0/Ool01`00Oomoogoo001oo`0000Moo`007Woo00D007ooOomoo`0002]oo`03001o
o`00009oo`03001oogoo00Uoo`03001oogoo01ioo`8000ioo`03001oogoo01ioo`03001oogoo02io
o`03001oo`0002eoo`07001oogooOol007oo00001goo000NOol01@00Oomoogoo0000;7oo00D007oo
Oomoo`0000]oo`03001oogoo01moo`03001oogoo00eoo`03001oogoo01ioo`8002moo`03001oogoo
02]oo`8000Aoo`03001oogoo00Ioo`007Woo00D007ooOomoo`0002moo`03001oogoo00Yoo`03001o
ogoo031oo`03001oogoo08]oo`007Woo0P000Woo00<007ooOol0;Goo00<007ooOol02Goo00<007oo
Ool08goo00<007ooOol037oo00<007ooOol0RWoo000NOol01@00Oomoogoo0000;Woo00<007ooOol0
2Woo00<007ooOol097oo00<007ooOol037oo0P00C7oo4000;Woo000NOol01@00Oomoogoo0000>goo
00<007ooOol09Goo0P003Woo00<007ooOol0>Goo4`003Goo2@009Goo000NOol01@00Oomoogoo0000
>Woo00<007ooOol0:7oo0P003Goo00<007ooOol0;goo2@000goo1P002Woo2@001Goo0P001Woo2P00
6goo000HOooo00050004Ool001ioo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`8000Yoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Moo`<000]oo`8000]oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oo`00
008000Moo`03001oogoo00<000Ioo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Uoo`h000Yoo`007Woo00<007ooOol00Woo00<007ooOol0:Goo00<007ooOol02Woo00<0
07ooOol08Woo00<007ooOol02Goo0P002goo00<007ooOol05Goo00<007ooOol01goo1@002Woo0`00
5Woo00<007ooOol0;Woo00<007ooOol027oo000NOol00`00Oomoo`02Ool00`00Oomoo`0XOol00`00
Oomoo`0;Ool00`00Oomoo`0`Ool00`00Oomoo`09Ool2000JOol5000=Ool2001EOol001ioo`03001o
ogoo009oo`03001oogoo02Qoo`03001oogoo00]oo`03001oogoo03ioo`03001oogoo015oo`8001=o
o`<005Moo`007Woo0P000goo00<007ooOol09goo00<007ooOol02goo00<007ooOol0=Woo0P0027oo
00<007ooOol02goo1@004goo0P00FWoo000NOol00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomo
o`0;Ool00`00Oomoo`0hOol800000goo00000005Ool6000EOol3001LOol001ioo`03001oogoo009o
o`03001oogoo02Ioo`03001oogoo00aoo`03001oogoo03moo`H001]oo`<005moo`007Woo00<007oo
Ool00Woo00<007ooOol09Woo00<007ooOol02goo00<007ooOol0AWoo0P005Goo1000HWoo000NOol2
0003Ool00`00Oomoo`0UOol00`00Oomoo`0<Ool00`00Oomoo`18Ool3000=Ool5001VOol001ioo`03
001oogoo00=oo`03001oogoo02Aoo`03001oogoo00aoo`03001oogoo04]oo`d006]oo`007Woo00<0
07ooOol00goo00<007ooOol08goo00<007ooOol03Goo00<007ooOol0`goo000NOol00`00Oomoo`03
Ool00`00Oomoo`0SOol00`00Oomoo`0<Ool00`00Oomoo`34Ool001ioo`03001oogoo00=oo`03001o
ogoo029oo`03001oogoo00eoo`03001oogoo0<Aoo`007Woo0P0017oo00<007ooOol08Woo00<007oo
Ool03Goo00<007ooOol0a7oo000NOol00`00Oomoo`03Ool00`00Oomoo`0aOol00`00Oomoo`35Ool0
01ioo`03001oogoo00=oo`03001oogoo035oo`03001oogoo0<Eoo`007Woo00<007ooOol00goo00<0
07ooOol0<Goo00<007ooOol0aGoo000NOol00`00Oomoo`04Ool00`00Oomoo`0OOol00`00Oomoo`0>
Ool00`00Oomoo`35Ool001ioo`8000Eoo`03001oogoo01moo`03001oogoo00eoo`03001oogoo0<Io
o`007Woo00<007ooOol017oo00<007ooOol07goo00<007ooOol03Goo00<007ooOol0aWoo000>Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0NOol0
0`00Oomoo`0>Ool00`00Oomoo`36Ool000eoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo
00Aoo`03001oogoo01ioo`03001oogoo00eoo`03001oogoo0<Moo`003Goo00<007oo00002Goo00<0
07ooOol00Woo0`0017oo00<007ooOol07Goo00<007ooOol03Woo00<007ooOol0agoo000=Ool00`00
Ool00007Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`0MOol00`00Oomoo`0>Ool00`00Oomoo`37
Ool000eoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo01aoo`03001o
ogoo00moo`03001oogoo0<Moo`003Woo00<007ooOol01Woo0`0017oo00<007ooOol017oo00<007oo
Ool077oo00<007ooOol03Woo00<007ooOol0b7oo000NOol00`00Oomoo`05Ool00`00Oomoo`0JOol0
0`00Oomoo`0?Ool00`00Oomoo`38Ool001ioo`8000Ioo`03001oogoo01Yoo`03001oogoo00moo`03
001oogoo0<Qoo`007Woo00<007ooOol01Goo00<007ooOol06Goo00<007ooOol03goo00<007ooOol0
bGoo000NOol00`00Oomoo`05Ool00`00Oomoo`0IOol00`00Oomoo`0?Ool00`00Oomoo`39Ool001io
o`03001oogoo00Eoo`03001oogoo02]oo`03001oogoo0<Uoo`007Woo0P001Woo00<007ooOol0:goo
00<007ooOol0bGoo000NOol00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Oomoo`3:Ool001ioo`03
001oogoo00Eoo`03001oogoo02Yoo`03001oogoo0<Yoo`007Woo00<007ooOol01Goo00<007ooOol0
67oo00<007ooOol03goo00<007ooOol0bWoo000NOol00`00Oomoo`06Ool00`00Oomoo`0GOol00`00
Oomoo`0>Ool00`00Oomoo`3;Ool001ioo`8000Moo`03001oogoo01Ioo`03001oogoo00moo`03001o
ogoo0<]oo`007Woo00<007ooOol01Woo00<007ooOol05Woo00<007ooOol03goo00<007ooOol0bgoo
000NOol00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`3;Ool001ioo`03
001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00moo`03001oogoo0<aoo`007Woo00<007ooOol0
1Woo00<007ooOol057oo00<007ooOol047oo00<007ooOol0c7oo000NOol20007Ool00`00Oomoo`0D
Ool00`00Oomoo`0@Ool00`00Oomoo`3<Ool001ioo`03001oogoo00Ioo`03001oogoo01=oo`03001o
ogoo011oo`03001oogoo0<eoo`005Woo1@000goo00<007ooOol01goo00<007ooOol04Woo00<007oo
Ool047oo00<007ooOol0cGoo000HOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0BOol0
0`00Oomoo`0@Ool00`00Oomoo`3=Ool001Qoo`03001oogoo00=oo`<000Moo`03001oogoo015oo`03
001oogoo015oo`03001oogoo0<eoo`0067oo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
4Goo00<007ooOol047oo00<007ooOol0cWoo000HOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`0TOol00`00Oomoo`3>Ool001Moo`8000Eoo`03001oogoo00Moo`03001oogoo02Aoo`03001o
ogoo0<ioo`007Woo0P0027oo00<007ooOol097oo00<007ooOol0cWoo000NOol20008Ool00`00Oomo
o`0SOol00`00Oomoo`3?Ool001ioo`03001oo`0000Moo`03001oogoo00moo`03001oogoo015oo`03
001oogoo0<moo`007Woo00<007oo000027oo00<007ooOol03Goo00<007ooOol04Woo00<007ooOol0
cgoo000NOol00`00Ool00008Ool00`00Oomoo`0=Ool00`00Oomoo`0BOol00`00Oomoo`3?Ool001io
o`<000Qoo`03001oogoo00aoo`03001oogoo019oo`03001oogoo0=1oo`007Woo00@007ooOol000Mo
o`03001oogoo00aoo`03001oogoo019oo`03001oogoo0=1oo`007Woo00@007ooOol000Moo`03001o
ogoo00]oo`03001oogoo01=oo`03001oogoo0=1oo`007Woo00D007ooOomoo`0000Ioo`03001oogoo
00]oo`03001oogoo01=oo`03001oogoo0=1oo`007Woo00D007ooOomoo`0000Ioo`03001oogoo00Yo
o`03001oogoo01=oo`03001oogoo0=5oo`007Woo0P000goo00<007ooOol00goo00<007ooOol02Woo
00<007ooOol04goo00<007ooOol0dGoo000NOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomo
o`08Ool00`00Oomoo`0DOol00`00Oomoo`3AOol001ioo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo00Qoo`03001oogoo01=oo`03001oogoo0=9oo`007Woo00<007ooOol02Goo00<007ooOol0
1goo00<007ooOol057oo00<007ooOol0dWoo000NOol00`00Oomoo`09Ool00`00Oomoo`0NOol00`00
Oomoo`3BOol001ioo`8000Yoo`03001oogoo01ioo`03001oogoo0=9oo`007Woo00<007ooOol01Goo
00D007ooOomoo`0001moo`03001oogoo0==oo`0037oo1@000Woo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol01Woo00@007ooOol001moo`03001oogoo0==oo`003Woo00<007ooOol01Woo00<0
07oo000017oo00<007ooOol01Woo00D007ooOomoo`0000Aoo`03001oogoo01Moo`03001oogoo0==o
o`003Woo00<007ooOol027oo00<007ooOol00Woo0`001goo0P0000=oo`00Ool00Woo00<007ooOol0
67oo00<007ooOol0dgoo000>Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`08Ool6000JOol00`00
Oomoo`3DOol000ioo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo01]o
o`03001oogoo0=Aoo`003Goo0P0027oo0`0017oo00<007ooOol02goo00<007ooOol06Woo00<007oo
Ool0e7oo000NOol00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`3DOol001ioo`8000aoo`03
001oogoo01Uoo`03001oogoo0=Eoo`007Woo00<007ooOol02goo00<007ooOol06Goo00<007ooOol0
eGoo000NOol00`00Oomoo`0;Ool00`00Oomoo`0IOol00`00Oomoo`3EOol001ioo`03001oogoo00ao
o`03001oogoo01Qoo`03001oogoo0=Eoo`007Woo0P003Goo00<007ooOol05goo00<007ooOol0eWoo
000NOol00`00Oomoo`0<Ool00`00Oomoo`0GOol00`00Oomoo`3FOol001ioo`03001oogoo00aoo`03
001oogoo01Moo`03001oogoo0=Ioo`007Woo00<007ooOol03Goo00<007ooOol05Goo00<007ooOol0
egoo000NOol00`00Oomoo`0=Ool00`00Oomoo`0EOol00`00Oomoo`3GOol001ioo`8000ioo`03001o
ogoo01Eoo`03001oogoo0=Moo`007Woo00<007ooOol03Goo00<007ooOol057oo00<007ooOol0f7oo
000NOol00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomoo`3HOol001ioo`03001oogoo00ioo`03
001oogoo01=oo`03001oogoo0=Qoo`007Woo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol0
fGoo000NOol2000?Ool00`00Oomoo`0BOol00`00Oomoo`3IOol001ioo`03001oogoo00moo`03001o
ogoo015oo`03001oogoo0=Uoo`005goo0`0017oo00<007ooOol03goo00<007ooOol047oo00<007oo
Ool0fWoo000GOol00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`3JOol0
01Qoo`03001oogoo00=oo`<000moo`03001oogoo011oo`03001oogoo0=Yoo`0067oo00<007ooOol0
0goo00<007ooOol03goo00<007ooOol03goo00<007ooOol0fgoo000GOol00`00Ool00004Ool00`00
Oomoo`0@Ool00`00Oomoo`0>Ool00`00Oomoo`3KOol001Qoo`03001oogoo00=oo`03001oogoo011o
o`03001oogoo00ioo`03001oogoo0=]oo`007Woo00<007ooOol047oo00<007ooOol03Goo00<007oo
Ool0g7oo000NOol2000BOol00`00Oomoo`0<Ool00`00Oomoo`3LOol001ioo`03001oogoo015oo`03
001oogoo00aoo`03001oogoo0=aoo`007Woo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol0
gGoo000NOol00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`3MOol001ioo`03001oogoo019o
o`03001oogoo00Uoo`03001oogoo0=ioo`007Woo0P0057oo00<007ooOol027oo00<007ooOol0gWoo
000NOol00`00Oomoo`0COol00`00Oomoo`07Ool00`00Oomoo`3OOol001ioo`03001oogoo01Aoo`03
001oogoo00Eoo`03001oogoo0>1oo`007Woo00<007ooOol057oo0P001Goo00<007ooOol0hGoo000N
Ool2000GOol01@00Oomoogoo0000i7oo000NOol00`00Oomoo`0GOol3003UOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol007Aoo`<0039oo`<007Aoo`00MGoo00<0
07ooOol0<Woo00<007ooOol0Lgoo001[Ool300001goo001oo`00Ool007oo00<000=oo`<00004Ool0
00000002Ool20004Ool2000>Ool3000017oo001oogoo0P000Woo0P000goo0`000goo0P0000=oo`00
00000Woo00@007oo000000Aoo`8005moo`00K7oo00X007ooOol007oo001oo`00Ool0009oo`03001o
o`00009oo`04001oogoo0005Ool01000Oomoo`004Goo00H007ooOol007oo0006Ool01000Oomoo`00
0Woo00<007oo00000Woo00<007oo00000Woo00D007ooOomoo`00009oo`03001oogoo05moo`00K7oo
00X007ooOol007oo001oo`00Ool0009oo`03001oo`00009oo`04001oogoo0004Ool01000Oomoogoo
0`003goo0`000Woo0`000goo00D007ooOomoo`00009oo`03001oo`00009oo`03001oo`00009oo`04
001oogoo0003Ool3001OOol006aoo`03001oogoo00800003Ool007oo00@00004Ool00000Ool20002
Ool00`00Oomoo`02Ool20002Ool3000?Ool01@00Oomoo`00Ool00`000goo0P0000=oo`0000000P00
0goo0P0000=oo`0000000P000goo0P000Woo0`00Ggoo001/Ool00`00Oomoo`0AOol00`00Oomoo`0H
Ool01000Oomoo`00PGoo001[Ool3000AOol2000IOol40022Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.22985, -1.09771, 
  0.0404452, 0.0217022}},
  CellTags->"4.3"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[48]=",
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "This is the ",
  StyleBox["simulated", "TI"],
  " (rather than computed symbolically) impulse response for the first input. \
Note that, for a continuous\[Hyphen]time system, the impulse response is \
represented as a decay of some initial state conditions in the absence of the \
input signal. The initial conditions are determined by the components of the \
matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.4"],
  ". "
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
SimulationPlot[#, 0, {t, 10},
 InitialConditions -> Flatten[#[[2]]],
 Sampled -> Period[.5],
 PlotLabel -> \"Simulated Impulse Response\" ]& @
 Subsystem[system, 1]\
\>", "Input",
  CellLabel->"In[49]:=",
  CellTags->"4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.193308 0.178593 [
[.21429 .18081 -3 -9 ]
[.21429 .18081 3 0 ]
[.40476 .18081 -3 -9 ]
[.40476 .18081 3 0 ]
[.59524 .18081 -3 -9 ]
[.59524 .18081 3 0 ]
[.78571 .18081 -3 -9 ]
[.78571 .18081 3 0 ]
[.97619 .18081 -6 -9 ]
[.97619 .18081 6 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .10401 -24 -4.5 ]
[.01131 .10401 0 4.5 ]
[.01131 .2826 -18 -4.5 ]
[.01131 .2826 0 4.5 ]
[.01131 .3719 -6 -4.5 ]
[.01131 .3719 0 4.5 ]
[.01131 .4612 -18 -4.5 ]
[.01131 .4612 0 4.5 ]
[.01131 .55049 -6 -4.5 ]
[.01131 .55049 0 4.5 ]
[.5 .63053 -80 0 ]
[.5 .63053 80 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .19331 m
.21429 .19956 L
s
[(2)] .21429 .18081 0 1 Mshowa
.40476 .19331 m
.40476 .19956 L
s
[(4)] .40476 .18081 0 1 Mshowa
.59524 .19331 m
.59524 .19956 L
s
[(6)] .59524 .18081 0 1 Mshowa
.78571 .19331 m
.78571 .19956 L
s
[(8)] .78571 .18081 0 1 Mshowa
.97619 .19331 m
.97619 .19956 L
s
[(10)] .97619 .18081 0 1 Mshowa
.125 Mabswid
.07143 .19331 m
.07143 .19706 L
s
.11905 .19331 m
.11905 .19706 L
s
.16667 .19331 m
.16667 .19706 L
s
.2619 .19331 m
.2619 .19706 L
s
.30952 .19331 m
.30952 .19706 L
s
.35714 .19331 m
.35714 .19706 L
s
.45238 .19331 m
.45238 .19706 L
s
.5 .19331 m
.5 .19706 L
s
.54762 .19331 m
.54762 .19706 L
s
.64286 .19331 m
.64286 .19706 L
s
.69048 .19331 m
.69048 .19706 L
s
.7381 .19331 m
.7381 .19706 L
s
.83333 .19331 m
.83333 .19706 L
s
.88095 .19331 m
.88095 .19706 L
s
.92857 .19331 m
.92857 .19706 L
s
.25 Mabswid
0 .19331 m
1 .19331 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .10401 m
.03006 .10401 L
s
[(-0.5)] .01131 .10401 1 0 Mshowa
.02381 .2826 m
.03006 .2826 L
s
[(0.5)] .01131 .2826 1 0 Mshowa
.02381 .3719 m
.03006 .3719 L
s
[(1)] .01131 .3719 1 0 Mshowa
.02381 .4612 m
.03006 .4612 L
s
[(1.5)] .01131 .4612 1 0 Mshowa
.02381 .55049 m
.03006 .55049 L
s
[(2)] .01131 .55049 1 0 Mshowa
.125 Mabswid
.02381 .03257 m
.02756 .03257 L
s
.02381 .05043 m
.02756 .05043 L
s
.02381 .06829 m
.02756 .06829 L
s
.02381 .08615 m
.02756 .08615 L
s
.02381 .12187 m
.02756 .12187 L
s
.02381 .13973 m
.02756 .13973 L
s
.02381 .15759 m
.02756 .15759 L
s
.02381 .17545 m
.02756 .17545 L
s
.02381 .21117 m
.02756 .21117 L
s
.02381 .22903 m
.02756 .22903 L
s
.02381 .24689 m
.02756 .24689 L
s
.02381 .26475 m
.02756 .26475 L
s
.02381 .30046 m
.02756 .30046 L
s
.02381 .31832 m
.02756 .31832 L
s
.02381 .33618 m
.02756 .33618 L
s
.02381 .35404 m
.02756 .35404 L
s
.02381 .38976 m
.02756 .38976 L
s
.02381 .40762 m
.02756 .40762 L
s
.02381 .42548 m
.02756 .42548 L
s
.02381 .44334 m
.02756 .44334 L
s
.02381 .47906 m
.02756 .47906 L
s
.02381 .49692 m
.02756 .49692 L
s
.02381 .51478 m
.02756 .51478 L
s
.02381 .53264 m
.02756 .53264 L
s
.02381 .56835 m
.02756 .56835 L
s
.02381 .58621 m
.02756 .58621 L
s
.02381 .60407 m
.02756 .60407 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Simulated) show
123.000000 12.812500 moveto
(Impulse) show
171.000000 12.812500 moveto
(Response) show
219.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.07143 .43876 L
.11905 .60332 L
.16667 .54839 L
.21429 .38106 L
.2619 .20871 L
.30952 .09836 L
.35714 .06727 L
.40476 .09598 L
.45238 .15012 L
.5 .19926 L
.54762 .22682 L
.59524 .23089 L
.64286 .21917 L
.69048 .2023 L
.7381 .18868 L
.78571 .18216 L
.83333 .18242 L
.88095 .18668 L
.92857 .19177 L
.97619 .19544 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[49]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001Ioo`D000=oo`03001oogoo0?moo`0067oo00<007ooOol00goo
00<007ooOol0ogoo000BOol30003Ool00`00Oomoo`03Ool3003oOol001Qoo`03001oogoo00=oo`03
001oogoo0?moo`0067oo00<007ooOol00goo00<007ooOol0ogoo000GOol20005Ool00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo0P00ogoo0Goo000NOol2003oOol1Ool001ioo`800?moo`5o
o`007Woo0P00ogoo0Goo000NOol2003oOol1Ool001ioo`800?moo`5oo`007Woo0P00ogoo0Goo000N
Ool2003oOol1Ool001ioo`800?moo`5oo`007Woo0`00Dgoo00<007ooOol0ZGoo000NOol00`00Ool0
001AOol200000goo0000002YOol001ioo`03001oo`00051oo`03001oogoo00=oo`800:Moo`007Woo
00<007oo0000CWoo0P0027oo0P00YGoo000NOol00`00Ool0001=Ool00`00Oomoo`0:Ool2002SOol0
01ioo`<004]oo`8000moo`800:5oo`007Woo00<007oo0000BWoo00<007ooOol04Goo0P00Wgoo000>
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Ool00018Ool2000FOol00`00
Oomoo`2LOol000eoo`03001oo`0000Moo`03001oo`0000Aoo`03001oo`0004Moo`03001oogoo01Mo
o`03001oogoo09]oo`0027oo0`000Woo00<007oo00002Goo00<007ooOol00Woo1000AWoo00<007oo
Ool067oo00<007ooOol0VWoo000=Ool00`00Ool00007Ool20005Ool01000Oomoo`00AGoo00<007oo
Ool06Woo00<007ooOol0VGoo000=Ool00`00Ool00007Ool00`00Oomoo`04Ool01000Oomoo`00AGoo
00<007ooOol06Woo00<007ooOol0VGoo000>Ool00`00Oomoo`06Ool30004Ool01000Oomoo`00A7oo
00<007ooOol077oo00<007ooOol0V7oo000NOol01000Oomoo`00A7oo00<007ooOol07Goo00<007oo
Ool0Ugoo000NOol200000goo001oo`12Ool00`00Oomoo`0OOol00`00Oomoo`2FOol001ioo`04001o
ogoo0013Ool00`00Oomoo`0POol00`00Oomoo`2EOol001ioo`04001oogoo0013Ool00`00Oomoo`0Q
Ool00`00Oomoo`2DOol001ioo`04001oogoo0012Ool00`00Oomoo`0SOol00`00Oomoo`2COol001io
o`04001oogoo0012Ool00`00Oomoo`0SOol00`00Oomoo`2COol001ioo`80009oo`03001oogoo03io
o`03001oogoo02Eoo`03001oogoo099oo`007Woo00D007ooOomoo`00041oo`03001oogoo02Ioo`03
001oogoo095oo`007Woo00D007ooOomoo`0002]oo`<0015oo`03001oogoo01]oo`<000Yoo`03001o
ogoo025oo`80031oo`03001oogoo02Yoo`D0009oo`03001oogoo00Ioo`007Woo00D007ooOomoo`00
02]oo`03001oogoo015oo`03001oogoo01aoo`03001oogoo00Yoo`03001oogoo021oo`03001oo`00
02ioo`03001oo`0002eoo`07001oogooOol007oo00001goo000NOol20002Ool00`00Oomoo`0ZOol0
0`00Oomoo`0@Ool00`00Oomoo`0JOol4000<Ool00`00Oomoo`0OOol00`00Ool0000^Ool00`00Ool0
000]Ool01`00Oomoogoo001oo`0000Moo`007Woo00D007ooOomoo`0002aoo`03001oogoo00moo`03
001oogoo01]oo`03001oo`0000ioo`03001oogoo01ioo`80031oo`03001oogoo02aoo`07001oogoo
Ool007oo00001goo000NOol01@00Oomoogoo0000:goo00<007oo000047oo00<007ooOol077oo0P00
3goo00<007ooOol07Goo00<007ooOol0;Woo00<007oo0000;Goo00L007ooOomoo`00Ool00007Ool0
01ioo`05001oogooOol0000/Ool00`00Oomoo`0>Ool00`00Oomoo`0NOol00`00Oomoo`0>Ool00`00
Oomoo`0MOol2000_Ool00`00Oomoo`0[Ool20004Ool00`00Oomoo`06Ool001ioo`05001oogooOol0
000mOol00`00Oomoo`0`Ool00`00Oomoo`2:Ool001ioo`8000=oo`03001oogoo03Uoo`03001oogoo
039oo`03001oogoo08Uoo`007Woo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol0<goo00<0
07ooOol0R7oo000NOol00`00Oomoo`02Ool00`00Oomoo`0iOol00`00Oomoo`0dOol00`00Oomoo`15
OolH000ZOol001ioo`03001oogoo009oo`03001oogoo03Qoo`03001oogoo03Ioo`03001oogoo03ao
o`P001Qoo`d001eoo`0067ooo`001@0017oo000NOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool2000:Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool2000;Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`02Ool30004Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool7000:Ool001ioo`03001oogoo009o
o`03001oogoo02Uoo`03001oogoo00]oo`03001oogoo025oo`03001oogoo01Ioo`03001oogoo01Eo
o`03001oogoo01Qoo`<001Aoo`03001oogoo02ioo`03001oogoo00Qoo`007Woo00<007ooOol00Woo
00<007ooOol0=Woo00<007ooOol0?7oo0P00;Goo0`00Dgoo000NOol00`00Oomoo`02Ool00`00Oomo
o`0fOol00`00Oomoo`0nOol2000XOol3001FOol001ioo`8000Aoo`03001oogoo03Eoo`03001oogoo
041oo`03001oogoo029oo`<005Uoo`007Woo00<007ooOol00goo00<007ooOol0=7oo00<007ooOol0
@Woo0P007goo0`00G7oo000NOol00`00Oomoo`03Ool00`00Oomoo`0dOol00`00Oomoo`14Ool2000I
Ool4001OOol001ioo`03001oogoo00=oo`03001oogoo03Aoo`03001oogoo04Ioo`8001=oo`@006=o
o`007Woo00<007ooOol00goo00<007ooOol0=7oo00<007ooOol0B7oo1P002Goo1000Igoo000NOol2
0004Ool00`00Oomoo`0cOol00`00Oomoo`1?Ool9001[Ool001ioo`03001oogoo00=oo`03001oogoo
03=oo`03001oogoo0<=oo`007Woo00<007ooOol00goo00<007ooOol0<goo00<007ooOol0`goo000N
Ool00`00Oomoo`03Ool00`00Oomoo`0bOol00`00Oomoo`34Ool001ioo`8000Eoo`03001oogoo035o
o`03001oogoo0<Aoo`007Woo00<007ooOol017oo00<007ooOol0<Goo00<007ooOol0a7oo000NOol0
0`00Oomoo`04Ool00`00Oomoo`0aOol00`00Oomoo`34Ool001ioo`03001oogoo00Aoo`03001oogoo
031oo`03001oogoo0<Eoo`007Woo00<007ooOol017oo00<007ooOol0<7oo00<007ooOol0aGoo000N
Ool20005Ool00`00Oomoo`0`Ool00`00Oomoo`35Ool001ioo`03001oogoo00Aoo`03001oogoo02mo
o`03001oogoo0<Ioo`007Woo00<007ooOol017oo00<007ooOol0;goo00<007ooOol0aWoo000>Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0_Ool0
0`00Oomoo`36Ool000eoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo00Eoo`03001oogoo
02ioo`03001oogoo0<Ioo`003Goo00<007oo00002Goo00<007ooOol00Woo0`001Goo00<007ooOol0
;Goo00<007ooOol0agoo000=Ool00`00Ool00007Ool20005Ool00`00Oomoo`05Ool00`00Oomoo`0]
Ool00`00Oomoo`37Ool000eoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo02eoo`03001oogoo0<Moo`003Woo00<007ooOol01Woo0`0017oo00<007ooOol01Goo00<007oo
Ool0;7oo00<007ooOol0b7oo000NOol20006Ool00`00Oomoo`0/Ool00`00Oomoo`38Ool001ioo`03
001oogoo00Eoo`03001oogoo02aoo`03001oogoo0<Qoo`007Woo00<007ooOol01Goo00<007ooOol0
:goo00<007ooOol0bGoo000NOol00`00Oomoo`05Ool00`00Oomoo`0[Ool00`00Oomoo`39Ool001io
o`03001oogoo00Ioo`03001oogoo02Yoo`03001oogoo0<Uoo`007Woo0P001goo00<007ooOol0:Woo
00<007ooOol0bGoo000NOol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`3:Ool001ioo`03
001oogoo00Ioo`03001oogoo02Uoo`03001oogoo0<Yoo`007Woo00<007ooOol01Woo00<007ooOol0
:Goo00<007ooOol0bWoo000NOol00`00Oomoo`06Ool00`00Oomoo`0XOol00`00Oomoo`3;Ool001io
o`8000Moo`03001oogoo02Qoo`03001oogoo0<]oo`007Woo00<007ooOol01Woo00<007ooOol0:7oo
00<007ooOol0bgoo000NOol00`00Oomoo`06Ool00`00Oomoo`0XOol00`00Oomoo`3;Ool001ioo`03
001oogoo00Ioo`03001oogoo02Moo`03001oogoo0<aoo`007Woo0P0027oo00<007ooOol09Woo00<0
07ooOol0c7oo000NOol00`00Oomoo`07Ool00`00Oomoo`0VOol00`00Oomoo`3<Ool001ioo`03001o
ogoo00Moo`03001oogoo02Eoo`03001oogoo0<eoo`005Woo1@000goo00<007ooOol01goo00<007oo
Ool09Goo00<007ooOol0cGoo000HOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0UOol0
0`00Oomoo`3=Ool001Qoo`03001oogoo00=oo`<000Moo`03001oogoo02Eoo`03001oogoo0<eoo`00
67oo00<007ooOol00goo00<007ooOol01goo00<007ooOol097oo00<007ooOol0cWoo000HOol00`00
Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0TOol00`00Oomoo`3>Ool001Moo`8000Eoo`03001o
ogoo00Moo`03001oogoo02Aoo`03001oogoo0<ioo`007Woo0P002Goo00<007ooOol08Woo00<007oo
Ool0cgoo000NOol00`00Oomoo`08Ool00`00Oomoo`0ROol00`00Oomoo`3?Ool001ioo`03001oogoo
00Qoo`03001oogoo029oo`03001oogoo0<moo`007Woo00<007ooOol027oo00<007ooOol08Woo00<0
07ooOol0cgoo000NOol00`00Oomoo`08Ool00`00Oomoo`0QOol00`00Oomoo`3@Ool001ioo`8000Uo
o`03001oogoo025oo`03001oogoo0=1oo`007Woo00<007ooOol027oo00<007ooOol08Goo00<007oo
Ool0d7oo000NOol00`00Oomoo`08Ool00`00Oomoo`0QOol00`00Oomoo`3@Ool001ioo`03001oogoo
00Qoo`03001oogoo021oo`03001oogoo0=5oo`007Woo00<007ooOol02Goo00<007ooOol07goo00<0
07ooOol0dGoo000NOol2000:Ool00`00Oomoo`0OOol00`00Oomoo`3AOol001ioo`03001oogoo00Uo
o`03001oogoo01ioo`03001oogoo0=9oo`007Woo00<007ooOol02Goo00<007ooOol07Woo00<007oo
Ool0dWoo000NOol00`00Oomoo`09Ool00`00Oomoo`0NOol00`00Oomoo`3BOol001ioo`8000Yoo`03
001oogoo01ioo`03001oogoo0=9oo`007Woo00<007ooOol02Woo00<007ooOol077oo00<007ooOol0
dgoo000NOol00`00Oomoo`0:Ool00`00Oomoo`0LOol00`00Oomoo`3COol000aoo`D0009oo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo01aoo`03001oogoo0==oo`003Woo
00<007ooOol01Woo00<007oo000017oo00<007ooOol02goo00<007ooOol06goo00<007ooOol0dgoo
000>Ool00`00Oomoo`08Ool00`00Oomoo`02Ool3000;Ool00`00Oomoo`0JOol00`00Oomoo`3DOol0
00ioo`03001oogoo00Ioo`8000Eoo`03001oogoo00]oo`03001oogoo01Yoo`03001oogoo0=Aoo`00
3Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol06Woo00<007ooOol0
e7oo000=Ool20008Ool30004Ool00`00Oomoo`0<Ool00`00Oomoo`0HOol00`00Oomoo`3EOol001io
o`03001oogoo00aoo`03001oogoo01Qoo`03001oogoo0=Eoo`007Woo0P003Goo00<007ooOol067oo
00<007ooOol0eGoo000NOol00`00Oomoo`0=Ool00`00Oomoo`0GOol00`00Oomoo`3EOol001ioo`03
001oogoo00eoo`03001oogoo01Ioo`03001oogoo0=Ioo`007Woo00<007ooOol03Goo00<007ooOol0
5Woo00<007ooOol0eWoo000NOol2000?Ool00`00Oomoo`0EOol00`00Oomoo`3FOol001ioo`03001o
ogoo00ioo`03001oogoo01Eoo`03001oogoo0=Ioo`007Woo00<007ooOol03Woo00<007ooOol057oo
00<007ooOol0egoo000NOol00`00Oomoo`0>Ool00`00Oomoo`0DOol00`00Oomoo`3GOol001ioo`03
001oogoo00moo`03001oogoo01=oo`03001oogoo0=Moo`007Woo0P0047oo00<007ooOol04Woo00<0
07ooOol0f7oo000NOol00`00Oomoo`0?Ool00`00Oomoo`0BOol00`00Oomoo`3HOol001ioo`03001o
ogoo011oo`03001oogoo015oo`03001oogoo0=Qoo`007Woo00<007ooOol047oo00<007ooOol04Goo
00<007ooOol0f7oo000NOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`3IOol001ioo`80
019oo`03001oogoo00moo`03001oogoo0=Uoo`007Woo00<007ooOol04Goo00<007ooOol03goo00<0
07ooOol0fGoo000GOol30004Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool00`00Oomoo`3IOol001Mo
o`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00ioo`03001oogoo0=Yoo`0067oo00<007oo
Ool00goo0`004Woo00<007ooOol03Goo00<007ooOol0fWoo000HOol00`00Oomoo`03Ool00`00Oomo
o`0BOol00`00Oomoo`0<Ool00`00Oomoo`3KOol001Moo`03001oo`0000Aoo`03001oogoo019oo`03
001oogoo00]oo`03001oogoo0=aoo`0067oo00<007ooOol00goo00<007ooOol04goo00<007ooOol0
2Goo00<007ooOol0gGoo000NOol00`00Oomoo`0COol00`00Oomoo`09Ool00`00Oomoo`3MOol001io
o`8001Aoo`03001oogoo00Qoo`03001oogoo0=ioo`007Woo00<007ooOol057oo00<007ooOol01Woo
00<007ooOol0ggoo000NOol00`00Oomoo`0DOol00`00Oomoo`05Ool00`00Oomoo`3POol001ioo`03
001oogoo01Aoo`03001oogoo00Aoo`03001oogoo0>5oo`007Woo0P005Goo00<007ooOol00goo00<0
07ooOol0hWoo000NOol00`00Oomoo`0EOol01@00Oomoogoo0000iGoo000NOol00`00Oomoo`0EOol0
1@00Oomoogoo0000iGoo000NOol00`00Oomoo`0EOol01000Oomoo`00iWoo000NOol00`00Oomoo`0F
Ool2003WOol001ioo`8001Moo`03001oogoo0>Ioo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00TWoo0`00<Woo0`00EWoo002COol00`00Oomoo`0bOol00`00Oomo
o`1EOol004eoo`<0009oo`<00006Ool007oo001oo`000Woo0`0000Aoo`000000009oo`@0009oo`80
00=oo`8000=oo`<0011oo`<00007Ool007oo001oo`00Ool00`000goo0`0000Aoo`000000009oo`80
00Aoo`8000ioo`<00004Ool007ooOol20002Ool20003Ool30003Ool200000goo00000002Ool01000
Ool0000017oo0P00@Goo001=Ool00`00Ool00003Ool02P00Oomoo`00Ool007oo001oo`000Woo00@0
07ooOol000=oo`<0009oo`06001oogoo001oo`0017oo00@007ooOol0015oo`0:001oogoo001oo`00
Ool007oo0002Ool00`00Ool00002Ool01000Oomoo`001Goo00@007ooOol0015oo`06001oogoo001o
o`001Woo00@007ooOol0009oo`03001oo`00009oo`03001oo`00009oo`05001oogooOol00002Ool0
0`00Oomoo`11Ool004moo`05001oogooOol00002Ool01`00Ool007oo001oo`00009oo`04001oogoo
0005Ool01000Oomoo`0017oo0`000Woo00@007ooOol0015oo`0:001oogoo001oo`00Ool007oo0002
Ool00`00Ool00002Ool01000Oomoo`0017oo00@007ooOomoo`<000moo`<0009oo`<000=oo`05001o
ogooOol00002Ool00`00Ool00002Ool00`00Ool00002Ool01000Oomoo`000goo0`00@Goo001>Ool0
1000Oomoogoo0P000Woo0P0000=oo`00Ool00P0000=oo`0000000Woo00<007ooOol00Woo0P0000=o
o`0000000P000Woo0`000goo0`004Goo00<007ooOol00P0000=oo`00Ool0100000Aoo`00001oo`80
009oo`03001oogoo009oo`80009oo`<000moo`05001oogoo001oo`030003Ool200000goo00000002
0003Ool200000goo000000020003Ool20002Ool30011Ool004eoo`03001oo`00019oo`03001oogoo
00Ioo`03001oogoo00Yoo`03001oogoo00moo`03001oogoo015oo`03001oogoo01Qoo`04001oogoo
001SOol004eoo`<000=oo`03001oogoo00]oo`8001Aoo`80011oo`<0015oo`8001Uoo`@006Aoo`00
ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.22975, -1.09704, 
  0.0404445, 0.0215678}},
  CellTags->"4.3"]
}, Open  ]],

Cell[TextData[{
  "This is another way to apply an input signal, in this case the ramp \
function, to all inputs in turn. These two simulation plots are generated \
within ",
  StyleBox["Block", "MR"],
  " with the local value ",
  StyleBox["$DisplayFunction", "MR"],
  " set to ",
  StyleBox["Identity", "MR"],
  " to prevent the plots from being output immediately. Instead, they are \
plotted outside ",
  StyleBox["Block", "MR"],
  " in one graph. The line with finer dashing corresponds to the first input. \
"
}], "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{

Cell["\<\
Show @@ Block[{$DisplayFunction = Identity},
 MapIndexed[
 SimulationPlot[#, t, {t, 10},
 PlotStyle -> Dashing[(#2)/100],
 PlotLabel -> \"Ramp Response\"
 ]&,
 Subsystem[system, #]& /@ Range[2]
 ]
]\
\>", "Input",
  CellLabel->"In[50]:=",
  CellTags->"4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.0266425 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .14793 -6 -4.5 ]
[.01131 .14793 0 4.5 ]
[.01131 .28114 -12 -4.5 ]
[.01131 .28114 0 4.5 ]
[.01131 .41435 -12 -4.5 ]
[.01131 .41435 0 4.5 ]
[.01131 .54757 -12 -4.5 ]
[.01131 .54757 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14793 m
.03006 .14793 L
s
[(5)] .01131 .14793 1 0 Mshowa
.02381 .28114 m
.03006 .28114 L
s
[(10)] .01131 .28114 1 0 Mshowa
.02381 .41435 m
.03006 .41435 L
s
[(15)] .01131 .41435 1 0 Mshowa
.02381 .54757 m
.03006 .54757 L
s
[(20)] .01131 .54757 1 0 Mshowa
.125 Mabswid
.02381 .04136 m
.02756 .04136 L
s
.02381 .068 m
.02756 .068 L
s
.02381 .09464 m
.02756 .09464 L
s
.02381 .12129 m
.02756 .12129 L
s
.02381 .17457 m
.02756 .17457 L
s
.02381 .20121 m
.02756 .20121 L
s
.02381 .22786 m
.02756 .22786 L
s
.02381 .2545 m
.02756 .2545 L
s
.02381 .30778 m
.02756 .30778 L
s
.02381 .33443 m
.02756 .33443 L
s
.02381 .36107 m
.02756 .36107 L
s
.02381 .38771 m
.02756 .38771 L
s
.02381 .441 m
.02756 .441 L
s
.02381 .46764 m
.02756 .46764 L
s
.02381 .49428 m
.02756 .49428 L
s
.02381 .52092 m
.02756 .52092 L
s
.02381 .57421 m
.02756 .57421 L
s
.02381 .60085 m
.02756 .60085 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Ramp) show
93.000000 12.812500 moveto
(Response) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01472 m
.11905 .01472 L
.21429 .04476 L
.30952 .12499 L
.40476 .2091 L
.5 .27591 L
.59524 .33613 L
.69048 .40077 L
.78571 .46913 L
.88095 .53699 L
.97619 .60332 L
s
[ .02 ] 0 setdash
.02381 .01472 m
.11905 .01472 L
.21429 .05169 L
.30952 .10547 L
.40476 .15064 L
.5 .18708 L
.59524 .22407 L
.69048 .26445 L
.78571 .30563 L
.88095 .3458 L
.97619 .38538 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001;Ool3
000]Ool3000/Ool2000^Ool00`00Oomoo`0WOol50002Ool00`00Oomoo`0BOol004]oo`03001oogoo
02ioo`03001oogoo02]oo`03001oo`0002aoo`03001oo`0002Yoo`07001oogooOol007oo00004goo
001<Ool00`00Oomoo`0[Ool4000/Ool00`00Ool0000/Ool00`00Ool0000ZOol01`00Oomoogoo001o
o`0001=oo`00C7oo00<007ooOol0:goo00<007oo0000;Goo0P00;Woo00<007ooOol0:Goo00L007oo
Oomoo`00Ool0000COol004]oo`03001oo`0002eoo`8002eoo`03001oogoo02aoo`03001oo`0002Yo
o`07001oogooOol007oo00004goo001<Ool00`00Oomoo`0]Ool00`00Oomoo`0/Ool2000]Ool00`00
Oomoo`0XOol20004Ool00`00Oomoo`0BOol00?moob5oo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000HOooh000@Ool001ioo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo008000Moo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo01Aoo`007Woo00<007ooOol06Woo1000hGoo000NOol00`00Oomoo`0LOol200000goo
001oo`3NOol001ioo`03001oogoo01ioo`@00=eoo`007Woo00<007ooOol08goo1000f7oo000NOol2
000VOol200000goo0000003EOol001ioo`03001oogoo02Moo`800003Ool000000==oo`007Woo00<0
07ooOol0;Goo00<007ooOol0cgoo000NOol00`00Oomoo`0/Ool01000Ool00000cgoo000NOol00`00
Oomoo`0]Ool2003@Ool001ioo`03001oogoo02moo`<00<eoo`007Woo00<007ooOol0<Goo0P00c7oo
000NOol2000cOol00`00Oomoo`3:Ool001ioo`03001oogoo03Aoo`800<Uoo`007Woo00<007ooOol0
=Goo0`00agoo000NOol00`00Oomoo`0fOol01000Ool00000aGoo000NOol00`00Oomoo`0hOol00`00
Oomoo`34Ool001ioo`03001oogoo03Uoo`03001oogoo0<=oo`007Woo0P00>goo00D007ooOomoo`00
0<1oo`007Woo00<007ooOol0?goo0P00_Woo000NOol00`00Oomoo`0lOol00`00Oomoo`02Ool2002l
Ool001ioo`03001oogoo03eoo`800<1oo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`10Ool0
0`00Oomoo`03Ool2002gOol001ioo`03001oogoo045oo`8000Eoo`800;Eoo`007Woo0P00Bgoo0P00
/goo000NOol00`00Oomoo`13Ool00`00Oomoo`2iOol001ioo`03001oogoo04Aoo`03001oogoo00Qo
o`800:ioo`007Woo00<007ooOol0AGoo00<007ooOol02Goo0P00[7oo000NOol00`00Oomoo`17Ool0
0`00Oomoo`09Ool2002ZOol001Qoo`03001oogoo00=oo`03001oogoo04Qoo`03001oogoo0;Aoo`00
5goo00<007oo000017oo00<007ooOol0BGoo00<007ooOol037oo0P00YGoo000IOol00`00Oomoo`02
Ool2001KOol2002SOol001Moo`8000Eoo`03001oogoo04]oo`03001oogoo00ioo`800:5oo`005goo
00<007ooOol017oo00<007ooOol0C7oo0P00/Goo000GOol30004Ool00`00Oomoo`1QOol2002LOol0
01ioo`03001oogoo04moo`03001oogoo015oo`8009Yoo`007Woo00<007ooOol0D7oo00<007ooOol0
4Woo0P00V7oo000NOol2001/Ool00`00Oomoo`2AOol001ioo`03001oogoo059oo`03001oogoo01Mo
o`80095oo`007Woo00<007ooOol0Dgoo00<007ooOol067oo0P00Sgoo000NOol00`00Oomoo`1DOol0
0`00Oomoo`2XOol001ioo`03001oogoo05Ioo`03001oogoo01]oo`03001oogoo08Qoo`007Woo00<0
07ooOol0Egoo00<007ooOol06goo0P00R7oo000NOol00`00Oomoo`1HOol00`00Oomoo`0LOol20026
Ool001ioo`8007ioo`80081oo`007Woo00<007ooOol0FWoo00<007ooOol08Woo0P00OWoo000NOol0
0`00Oomoo`1KOol2000TOol2001lOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0GWoo00<0
07ooOol09Goo0P00Mgoo000NOol00`00Oomoo`1OOol2000WOol3001dOol001ioo`8006=oo`03001o
ogoo02Ioo`03001oogoo075oo`007Woo00<007ooOol0Hgoo00<007ooOol0VGoo000NOol00`00Oomo
o`1TOol00`00Oomoo`0XOol2001^Ool001ioo`03001oogoo06Ioo`03001oogoo02Qoo`8006aoo`00
7Woo00<007ooOol0Igoo00<007ooOol0:Goo0P00JWoo000NOol00`00Oomoo`1XOol00`00Oomoo`2D
Ool001ioo`03001oogoo06Yoo`03001oogoo02aoo`03001oogoo06=oo`007Woo0P00K7oo00<007oo
Ool0;7oo0P00Hgoo000NOol00`00Oomoo`1/Ool00`00Oomoo`0]Ool2001QOol001ioo`03001oogoo
06ioo`03001oogoo035oo`03001oogoo05Yoo`007Woo00<007ooOol0Kgoo0P00<Woo0P00FWoo000N
Ool00`00Oomoo`2UOol2001HOol0015oo`D0009oo`03001oogoo00=oo`03001oogoo079oo`8008]o
o`004goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`1dOol00`00Oomoo`0dOol00`00Oomoo`1A
Ool001=oo`07001oogooOol007oo000017oo0P00[Goo0P00DGoo000COol01`00Oomoogoo001oo`00
00Aoo`03001oogoo07Ioo`03001oogoo03Eoo`8004moo`004goo00L007ooOomoo`00Ool00004Ool0
0`00Oomoo`1gOol20026Ool0019oo`8000Aoo`03001oogoo00=oo`03001oogoo07Yoo`03001oogoo
03Moo`03001oogoo04Qoo`007Woo00<007ooOol0Ngoo0P00>7oo0P00B7oo000NOol00`00Oomoo`2g
Ool20016Ool001ioo`8007moo`8007moo`007Woo00<007ooOol0P7oo0P00>goo00<007ooOol0?goo
000NOol00`00Oomoo`23Ool00`00Oomoo`0hOol2000oOol001ioo`03001oogoo08Aoo`03001oogoo
03Uoo`8003eoo`007Woo00<007ooOol0QGoo00<007ooOol0Mgoo000NOol00`00Oomoo`27Ool00`00
Oomoo`0lOol2000gOol001ioo`03001oogoo08Qoo`8003ioo`8003Eoo`007Woo0P00bgoo0P00<goo
000NOol00`00Oomoo`2;Ool00`00Oomoo`1aOol001ioo`03001oogoo08aoo`80045oo`03001oogoo
02eoo`007Woo00<007ooOol0d7oo0`00;7oo000NOol00`00Oomoo`2?Ool00`00Oomoo`11Ool2000Z
Ool001ioo`03001oogoo091oo`8006eoo`007Woo0P00U7oo00<007ooOol0@Woo0P009Goo000NOol0
0`00Oomoo`2DOol00`00Oomoo`13Ool2000SOol001ioo`03001oogoo09Eoo`03001oogoo04Aoo`80
025oo`007Woo00<007ooOol0Ugoo00<007ooOol0Agoo0P0077oo000NOol00`00Oomoo`2HOol20019
Ool2000JOol001ioo`03001oogoo0>Eoo`8001Qoo`007Woo00<007ooOol0Vgoo00<007ooOol0HGoo
000NOol2002MOol2001QOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0Wgoo00<007ooOol0
GGoo000NOol00`00Oomoo`2POol2001MOol0015oo`D0009oo`03001oogoo00=oo`03001oogoo0:=o
o`03001oogoo05Uoo`004goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`2TOol00`00Oomoo`1H
Ool001=oo`03001oogoo00=oo`03001oogoo009oo`800:Ioo`03001oogoo05Moo`004goo00@007oo
Oomoo`8000Eoo`03001oogoo0:Moo`03001oogoo05Eoo`004goo00D007ooOomoo`0000Ioo`03001o
ogoo0:Qoo`03001oogoo05Aoo`004Woo0P000goo0`0017oo00<007ooOol0ZGoo00<007ooOol0Dgoo
000NOol00`00Oomoo`2/Ool00`00Oomoo`1@Ool001ioo`03001oogoo0:eoo`03001oogoo04moo`00
7Woo00<007ooOol0[Woo00<007ooOol0CWoo000NOol2002aOol00`00Oomoo`1<Ool001ioo`03001o
ogoo0;5oo`03001oogoo04]oo`007Woo00<007ooOol0/Woo00<007ooOol0BWoo000NOol00`00Oomo
o`2dOol00`00Oomoo`18Ool001ioo`03001oogoo0;Eoo`8004Qoo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`2hOol00`00Oomoo`14Ool001ioo`800;Yoo`8004Aoo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`2lOol00`00Oomoo`10Ool001ioo`03001oogoo0;eoo`80041oo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`30Ool00`00Oomoo`0lOol001ioo`800<9oo`8003aoo`007Woo
00<007ooOol0a7oo00<007ooOol0>7oo000NOol00`00Oomoo`35Ool00`00Oomoo`0gOol001ioo`03
001oogoo0<Ioo`03001oogoo03Ioo`007Woo00<007ooOol0b7oo00<007ooOol0=7oo000NOol00`00
Oomoo`39Ool00`00Oomoo`0cOol001ioo`03001oogoo0<Yoo`03001oogoo039oo`007Woo0P00cGoo
00<007ooOol0<7oo000NOol00`00Oomoo`3=Ool00`00Oomoo`0_Ool001ioo`03001oogoo0<ioo`03
001oogoo02ioo`007Woo00<007ooOol0d7oo00<007ooOol0;7oo000BOol30003Ool00`00Oomoo`03
Ool00`00Oomoo`3AOol00`00Oomoo`0[Ool0019oo`03001oogoo009oo`03001oo`0000Aoo`03001o
ogoo0=9oo`03001oogoo02Yoo`004goo00L007ooOomoo`00Ool00004Ool2003EOol00`00Oomoo`0X
Ool001=oo`07001oogooOol007oo000017oo00<007ooOol0eGoo0P00:7oo000BOol00`00Ool00002
Ool00`00Ool00004Ool00`00Oomoo`3oOol001=oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo0=Qoo`03001oogoo02Aoo`007Woo00<007ooOol0fGoo0P0097oo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0=aoo`03001oogoo021oo`007Woo0P00gWoo0P0087oo000NOol00`00Oomoo`3P
Ool00`00Oomoo`0LOol001ioo`03001oogoo0>5oo`03001oogoo01]oo`007Woo00<007ooOol0hWoo
00<007ooOol06Woo000NOol00`00Oomoo`3TOol00`00Oomoo`0HOol001ioo`03001oogoo0>Eoo`03
001oogoo01Moo`007Woo00<007ooOol0iWoo00<007ooOol05Woo000NOol2003YOol00`00Oomoo`0D
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol007aoo`<001]o
o`<008=oo`00OGoo00<007ooOol06goo00<007ooOol0PWoo001]Ool300000goo001oo`0500001Goo
001oo`00Ool00`002goo0`0000Aoo`00Oomoo`80009oo`8000=oo`<000=oo`800003Ool00000009o
o`04001oo`000004Ool2001^Ool006ioo`05001oogoo001oo`03000027oo001oo`00Ool007oo0002
Ool00`00Oomoo`09Ool01P00Oomoo`00Ool000Ioo`04001oogoo0002Ool00`00Ool00002Ool00`00
Ool00002Ool01@00Oomoogoo00000Woo00<007ooOol0KWoo001^Ool30004Ool02@00Ool007oo001o
o`00Ool00002Ool00`00Oomoo`09Ool30002Ool30003Ool01@00Oomoogoo00000Woo00<007oo0000
0Woo00<007oo00000Woo00@007ooOol000=oo`<006ioo`00KWoo00@007ooOol0009oo`800006Ool0
0000Ool007oo100037oo00D007ooOol007oo00<000=oo`800003Ool00000008000=oo`800003Ool0
0000008000=oo`80009oo`<006ioo`00KWoo00@007ooOol001Yoo`04001oogoo002@Ool006eoo`@0
01Yoo`@0095oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.28611, -1.83515, 
  0.0424606, 0.151783}},
  CellTags->"4.3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
ScreenStyleEnvironment->"Working",
WindowSize->{484, 284},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> "Manual.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@:o@00000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "4.0"->{
    Cell[1731, 51, 69, 1, 56, "Section",
      CellTags->"4.0"],
    Cell[1803, 54, 898, 19, 124, "Text",
      CellTags->"4.0"]},
  "4.1"->{
    Cell[2726, 77, 62, 1, 44, "Subsection",
      CellTags->"4.1"],
    Cell[2791, 80, 74, 1, 26, "Text",
      CellTags->"4.1"],
    Cell[2868, 83, 408, 14, 26, "DisplayFormula",
      CellTags->"4.1"],
    Cell[3279, 99, 335, 11, 26, "Text",
      CellTags->"4.1"],
    Cell[3617, 112, 660, 20, 41, "DisplayFormula",
      CellTags->"4.1"],
    Cell[4280, 134, 776, 22, 68, "Text",
      CellTags->"4.1"],
    Cell[5059, 158, 393, 13, 26, "DisplayFormula",
      CellTags->"4.1"],
    Cell[5455, 173, 973, 32, 75, "Text",
      CellTags->"4.1"],
    Cell[6431, 207, 379, 13, 26, "DisplayFormula",
      CellTags->"4.1"],
    Cell[6813, 222, 60, 1, 26, "Text",
      CellTags->"4.1"],
    Cell[6876, 225, 540, 17, 36, "DisplayFormula",
      CellTags->"4.1"],
    Cell[7419, 244, 71, 1, 26, "Text",
      CellTags->"4.1"],
    Cell[7493, 247, 375, 13, 26, "DisplayFormula",
      CellTags->"4.1"],
    Cell[7871, 262, 700, 27, 26, "Text",
      CellTags->"4.1"],
    Cell[8574, 291, 648, 23, 28, "TopSpanBox",
      CellTags->"4.1"],
    Cell[9225, 316, 3077, 83, 24, "MiddleBox",
      CellTags->"4.1"],
    Cell[12305, 401, 652, 23, 12, "MiddleSpanBox",
      CellTags->"4.1"],
    Cell[12960, 426, 3078, 83, 24, "MiddleBox",
      CellTags->"4.1"],
    Cell[16041, 511, 762, 27, 12, "MiddleSpanBox",
      CellTags->"4.1"],
    Cell[16806, 540, 3164, 83, 35, "MiddleBox",
      CellTags->"4.1"],
    Cell[19973, 625, 1878, 55, 20, "BottomBox",
      CellTags->"4.1"],
    Cell[21854, 682, 87, 1, 18, "Caption",
      CellTags->"4.1"],
    Cell[21944, 685, 777, 21, 82, "Text",
      CellTags->"4.1"],
    Cell[22724, 708, 64, 1, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[22791, 711, 77, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[22871, 715, 91, 1, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[22987, 720, 88, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[23078, 724, 114, 3, 28, "Output",
      CellTags->"4.1"],
    Cell[23207, 730, 366, 8, 47, "MathCaption",
      CellTags->"4.1"],
    Cell[23598, 742, 91, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[23692, 746, 159, 4, 29, "Output",
      CellTags->"4.1"],
    Cell[23866, 753, 201, 7, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[24092, 764, 79, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[24174, 768, 62587, 1381, 185, 11237, 741, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.1"],
    Cell[86776, 2152, 1853, 58, 173, "Text",
      CellTags->"4.1"],
    Cell[88632, 2212, 1093, 35, 81, "DefinitionBox3Col",
      CellTags->"4.1"],
    Cell[89728, 2249, 203, 7, 18, "Caption",
      CellTags->"4.1"],
    Cell[89934, 2258, 183, 5, 40, "Text",
      CellTags->"4.1"],
    Cell[90120, 2265, 1318, 44, 38, "DisplayFormula",
      CellTags->"4.1"],
    Cell[91441, 2311, 966, 29, 74, "Text",
      CellTags->"4.1"],
    Cell[92410, 2342, 206944, 3625, 133, 194895, 3471, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"4.1"],
    Cell[299357, 5969, 153, 5, 18, "Caption",
      CellTags->"4.1"],
    Cell[299513, 5976, 94, 1, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[299632, 5981, 109, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[299744, 5985, 141, 4, 22, "Output",
      CellTags->"4.1"],
    Cell[299900, 5992, 649, 21, 40, "Text",
      CellTags->"4.1"],
    Cell[300552, 6015, 323, 9, 37, "MathCaption",
      CellTags->"4.1"],
    Cell[300900, 6028, 157, 6, 40, "Input",
      CellTags->"4.1"],
    Cell[301060, 6036, 439, 10, 33, "Output",
      CellTags->"4.1"],
    Cell[301514, 6049, 570, 16, 58, "MathCaption",
      CellTags->"4.1"],
    Cell[302109, 6069, 229, 11, 90, "Input",
      CellTags->"4.1"],
    Cell[302341, 6082, 14698, 527, 185, 6620, 421, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.1"],
    Cell[317054, 6612, 182, 5, 40, "Text",
      CellTags->"4.1"],
    Cell[317239, 6619, 88, 1, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[317352, 6624, 173, 8, 60, "Input",
      CellTags->"4.1"],
    Cell[317528, 6634, 179, 4, 43, "Output",
      CellTags->"4.1"],
    Cell[317722, 6641, 294, 8, 36, "MathCaption",
      CellTags->"4.1"],
    Cell[318041, 6653, 81, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[318125, 6657, 92, 3, 22, "Output",
      CellTags->"4.1"],
    Cell[318232, 6663, 125, 4, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[318382, 6671, 144, 6, 40, "Input",
      CellTags->"4.1"],
    Cell[318529, 6679, 858, 15, 79, "Output",
      CellTags->"4.1"],
    Cell[319402, 6697, 131, 4, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[319558, 6705, 99, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[319660, 6709, 534, 11, 44, "Output",
      CellTags->"4.1"],
    Cell[320209, 6723, 84, 1, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[320318, 6728, 145, 6, 40, "Input",
      CellTags->"4.1"],
    Cell[320466, 6736, 534, 11, 44, "Output",
      CellTags->"4.1"],
    Cell[321015, 6750, 934, 20, 124, "Text",
      CellTags->"4.1"],
    Cell[321952, 6772, 78, 1, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[322055, 6777, 105, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[322163, 6781, 133, 3, 28, "Output",
      CellTags->"4.1"],
    Cell[322311, 6787, 175, 5, 36, "MathCaption",
      CellTags->"4.1"],
    Cell[322511, 6796, 118, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[322632, 6800, 268, 6, 28, "Output",
      CellTags->"4.1"],
    Cell[322915, 6809, 74, 1, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[323014, 6814, 95, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[323112, 6818, 17204, 588, 185, 6613, 451, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.1"],
    Cell[340331, 7409, 230, 6, 36, "MathCaption",
      CellTags->"4.1"],
    Cell[340586, 7419, 80, 2, 22, "Input",
      CellTags->"4.1"],
    Cell[340669, 7423, 272, 6, 48, "Output",
      CellTags->"4.1"],
    Cell[340956, 7432, 70, 1, 26, "MathCaption",
      CellTags->"4.1"],
    Cell[341051, 7437, 90, 3, 22, "Input",
      CellTags->"4.1"],
    Cell[341144, 7442, 192, 5, 28, "Output",
      CellTags->"4.1"]},
  "4.2"->{
    Cell[341385, 7453, 71, 1, 44, "Subsection",
      CellTags->"4.2"],
    Cell[341459, 7456, 1795, 42, 194, "Text",
      CellTags->"4.2"],
    Cell[343257, 7500, 511, 18, 28, "TopSpanBox",
      CellTags->"4.2"],
    Cell[343771, 7520, 1959, 53, 24, "MiddleBox",
      CellTags->"4.2"],
    Cell[345733, 7575, 533, 19, 12, "MiddleSpanBox",
      CellTags->"4.2"],
    Cell[346269, 7596, 1491, 41, 12, "MiddleBox",
      CellTags->"4.2"],
    Cell[347763, 7639, 762, 27, 12, "MiddleSpanBox",
      CellTags->"4.2"],
    Cell[348528, 7668, 3417, 92, 35, "MiddleBox",
      CellTags->"4.2"],
    Cell[351948, 7762, 2019, 59, 20, "BottomBox",
      CellTags->"4.2"],
    Cell[353970, 7823, 89, 1, 18, "Caption",
      CellTags->"4.2"],
    Cell[354062, 7826, 386, 9, 54, "Text",
      CellTags->"4.2"],
    Cell[354451, 7837, 431, 14, 47, "MathCaption",
      CellTags->"4.2"],
    Cell[354885, 7853, 178, 9, 70, "Input",
      CellTags->"4.2"],
    Cell[355066, 7864, 160, 5, 26, "MathCaption",
      CellTags->"4.2"],
    Cell[355251, 7873, 90, 2, 22, "Input",
      CellTags->"4.2"],
    Cell[355344, 7877, 122, 3, 22, "Output",
      CellTags->"4.2"],
    Cell[355481, 7883, 149, 4, 26, "MathCaption",
      CellTags->"4.2"],
    Cell[355633, 7889, 58422, 1143, 96, 53247, 1074, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"4.2"],
    Cell[414058, 9034, 125, 5, 18, "Caption",
      CellTags->"4.2"],
    Cell[414208, 9043, 171, 7, 50, "Input",
      CellTags->"4.2"],
    Cell[414382, 9052, 223, 6, 31, "Output",
      CellTags->"4.2"],
    Cell[414620, 9061, 114, 4, 26, "MathCaption",
      CellTags->"4.2"],
    Cell[414759, 9069, 94, 2, 22, "Input",
      CellTags->"4.2"],
    Cell[414856, 9073, 197, 5, 29, "Output",
      CellTags->"4.2"],
    Cell[415068, 9081, 500, 9, 69, "MathCaption",
      CellTags->"4.2"],
    Cell[415593, 9094, 136, 5, 30, "Input",
      CellTags->"4.2"],
    Cell[415732, 9101, 760, 13, 54, "Output",
      CellTags->"4.2"],
    Cell[416507, 9117, 355, 10, 47, "MathCaption",
      CellTags->"4.2"],
    Cell[416887, 9131, 101, 2, 22, "Input",
      CellTags->"4.2"],
    Cell[416991, 9135, 21641, 478, 185, 3462, 248, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.2"],
    Cell[438647, 9616, 161, 4, 36, "MathCaption",
      CellTags->"4.2"],
    Cell[438833, 9624, 161, 7, 50, "Input",
      CellTags->"4.2"],
    Cell[438997, 9633, 20353, 463, 185, 3494, 249, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.2"],
    Cell[459365, 10099, 198, 7, 26, "MathCaption",
      CellTags->"4.2"],
    Cell[459588, 10110, 72, 2, 22, "Input",
      CellTags->"4.2"],
    Cell[459663, 10114, 27610, 574, 185, 3870, 275, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.2"],
    Cell[487288, 10691, 2648, 64, 343, "Text",
      CellTags->"4.2"],
    Cell[489939, 10757, 1566, 46, 28, "TopBox",
      CellTags->"4.2"],
    Cell[491508, 10805, 533, 19, 12, "MiddleSpanBox",
      CellTags->"4.2"],
    Cell[492044, 10826, 2139, 58, 24, "MiddleBox",
      CellTags->"4.2"],
    Cell[494186, 10886, 1002, 33, 12, "MiddleSpanBox",
      CellTags->"4.2"],
    Cell[495191, 10921, 2771, 75, 32, "BottomBox",
      CellTags->"4.2"],
    Cell[497965, 10998, 72, 1, 18, "Caption",
      CellTags->"4.2"],
    Cell[498040, 11001, 682, 16, 96, "Text",
      CellTags->"4.2"],
    Cell[498725, 11019, 190, 6, 36, "MathCaption",
      CellTags->"4.2"],
    Cell[498940, 11029, 168, 8, 60, "Input",
      CellTags->"4.2"],
    Cell[499111, 11039, 20647, 481, 185, 3679, 266, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.2"],
    Cell[519773, 11523, 68, 1, 26, "MathCaption",
      CellTags->"4.2"],
    Cell[519866, 11528, 89, 2, 22, "Input",
      CellTags->"4.2"],
    Cell[519958, 11532, 312, 9, 22, "Output",
      CellTags->"4.2"],
    Cell[520285, 11544, 212, 5, 36, "MathCaption",
      CellTags->"4.2"],
    Cell[520522, 11553, 182, 9, 70, "Input",
      CellTags->"4.2"],
    Cell[520707, 11564, 15647, 444, 185, 4269, 298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.2"],
    Cell[536369, 12011, 131, 4, 26, "MathCaption",
      CellTags->"4.2"],
    Cell[536525, 12019, 146, 5, 30, "Input",
      CellTags->"4.2"],
    Cell[536674, 12026, 559, 14, 29, "Output",
      CellTags->"4.2"],
    Cell[537248, 12043, 257, 6, 47, "MathCaption",
      CellTags->"4.2"],
    Cell[537530, 12053, 107, 2, 22, "Input",
      CellTags->"4.2"],
    Cell[537640, 12057, 56862, 960, 185, 4520, 308, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.2"],
    Cell[594517, 13020, 2565, 77, 180, "Text",
      CellTags->"4.2"],
    Cell[597085, 13099, 177737, 2931, 123, 165075, 2769, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"4.2"],
    Cell[774825, 16032, 135, 5, 18, "Caption",
      CellTags->"4.2"],
    Cell[774963, 16039, 103, 2, 26, "MathCaption",
      CellTags->"4.2"],
    Cell[775091, 16045, 173, 7, 50, "Input",
      CellTags->"4.2"],
    Cell[775267, 16054, 2204, 60, 96, "Output",
      CellTags->"4.2"],
    Cell[777486, 16117, 303, 9, 36, "MathCaption",
      CellTags->"4.2"],
    Cell[777814, 16130, 116, 2, 22, "Input",
      CellTags->"4.2"],
    Cell[777933, 16134, 2746, 76, 137, "Output",
      CellTags->"4.2"],
    Cell[780694, 16213, 111, 2, 26, "MathCaption",
      CellTags->"4.2"],
    Cell[780830, 16219, 100, 2, 22, "Input",
      CellTags->"4.2"],
    Cell[780933, 16223, 880, 20, 66, "Output",
      CellTags->"4.2"],
    Cell[781828, 16246, 208, 6, 36, "MathCaption",
      CellTags->"4.2"],
    Cell[782061, 16256, 158, 5, 30, "Input",
      CellTags->"4.2"],
    Cell[782222, 16263, 22006, 748, 185, 8954, 581, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.2"]},
  "4.3"->{
    Cell[804277, 17017, 79, 1, 44, "Subsection",
      CellTags->"4.3"],
    Cell[804359, 17020, 255, 6, 54, "Text",
      CellTags->"4.3"],
    Cell[804617, 17028, 218, 8, 36, "MathCaption",
      CellTags->"4.3"],
    Cell[804860, 17040, 140, 5, 30, "Input",
      CellTags->"4.3"],
    Cell[805003, 17047, 146, 4, 29, "Output",
      CellTags->"4.3"],
    Cell[805164, 17054, 131, 4, 26, "MathCaption",
      CellTags->"4.3"],
    Cell[805320, 17062, 102, 2, 22, "Input",
      CellTags->"4.3"],
    Cell[805425, 17066, 154, 4, 22, "Output",
      CellTags->"4.3"],
    Cell[805594, 17073, 254, 6, 36, "MathCaption",
      CellTags->"4.3"],
    Cell[805873, 17083, 186, 6, 40, "Input",
      CellTags->"4.3"],
    Cell[806062, 17091, 21759, 585, 185, 6281, 388, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.3"],
    Cell[827836, 17679, 465, 17, 47, "MathCaption",
      CellTags->"4.3"],
    Cell[828326, 17700, 296, 12, 100, "Input",
      CellTags->"4.3"],
    Cell[828625, 17714, 81756, 1889, 222, 36417, 1323, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.3"],
    Cell[910396, 19606, 575, 17, 47, "MathCaption",
      CellTags->"4.3"],
    Cell[910996, 19627, 153, 5, 30, "Input",
      CellTags->"4.3"],
    Cell[911152, 19634, 191, 5, 31, "Output",
      CellTags->"4.3"],
    Cell[911358, 19642, 235, 7, 26, "MathCaption",
      CellTags->"4.3"],
    Cell[911618, 19653, 98, 2, 22, "Input",
      CellTags->"4.3"],
    Cell[911719, 19657, 146, 4, 29, "Output",
      CellTags->"4.3"],
    Cell[911880, 19664, 69, 1, 26, "MathCaption",
      CellTags->"4.3"],
    Cell[911974, 19669, 129, 5, 30, "Input",
      CellTags->"4.3"],
    Cell[912106, 19676, 279, 6, 28, "Output",
      CellTags->"4.3"],
    Cell[912400, 19685, 195, 7, 26, "MathCaption",
      CellTags->"4.3"],
    Cell[912620, 19696, 106, 2, 22, "Input",
      CellTags->"4.3"],
    Cell[912729, 19700, 260, 7, 36, "Output",
      CellTags->"4.3"],
    Cell[913004, 19710, 204, 7, 26, "MathCaption",
      CellTags->"4.3"],
    Cell[913233, 19721, 109, 2, 22, "Input",
      CellTags->"4.3"],
    Cell[913345, 19725, 309, 6, 43, "Output",
      CellTags->"4.3"],
    Cell[913669, 19734, 504, 16, 36, "MathCaption",
      CellTags->"4.3"],
    Cell[914198, 19754, 232, 11, 90, "Input",
      CellTags->"4.3"],
    Cell[914433, 19767, 19261, 666, 185, 8421, 526, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.3"],
    Cell[933709, 20436, 251, 6, 47, "MathCaption",
      CellTags->"4.3"],
    Cell[933985, 20446, 208, 10, 117, "Input",
      CellTags->"4.3"],
    Cell[934196, 20458, 14896, 453, 186, 5117, 326, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.3"],
    Cell[949107, 20914, 111, 2, 28, "MathCaption",
      CellTags->"4.3"],
    Cell[949243, 20920, 154, 7, 72, "Input",
      CellTags->"4.3"],
    Cell[949400, 20929, 1376, 44, 113, "Output",
      CellTags->"4.3"],
    Cell[950791, 20976, 508, 13, 56, "MathCaption",
      CellTags->"4.3"],
    Cell[951324, 20993, 153, 6, 57, "Input",
      CellTags->"4.3"],
    Cell[951480, 21001, 487, 9, 168, "Output",
      CellTags->"4.3"],
    Cell[952157, 21020, 298, 6, 56, "MathCaption",
      CellTags->"4.3"],
    Cell[952480, 21030, 217, 9, 102, "Input",
      CellTags->"4.3"],
    Cell[952700, 21041, 21721, 743, 186, 9204, 583, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.3"],
    Cell[974424, 21786, 174, 5, 26, "Output",
      CellTags->"4.3"],
    Cell[974613, 21794, 572, 15, 72, "MathCaption",
      CellTags->"4.3"],
    Cell[975210, 21813, 233, 8, 87, "Input",
      CellTags->"4.3"],
    Cell[975446, 21823, 16673, 466, 186, 5018, 316, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.3"],
    Cell[992134, 22292, 553, 15, 69, "MathCaption",
      CellTags->"4.3"],
    Cell[992712, 22311, 267, 12, 100, "Input",
      CellTags->"4.3"],
    Cell[992982, 22325, 12757, 387, 186, 4489, 279, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"4.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"4.0", 1006684, 22741},
  {"4.1", 1006826, 22746},
  {"4.2", 1012943, 22920},
  {"4.3", 1018784, 23080}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 69, 1, 56, "Section",
  CellTags->"4.0"],
Cell[1803, 54, 898, 19, 124, "Text",
  CellTags->"4.0"],

Cell[CellGroupData[{
Cell[2726, 77, 62, 1, 44, "Subsection",
  CellTags->"4.1"],
Cell[2791, 80, 74, 1, 26, "Text",
  CellTags->"4.1"],
Cell[2868, 83, 408, 14, 26, "DisplayFormula",
  CellTags->"4.1"],
Cell[3279, 99, 335, 11, 26, "Text",
  CellTags->"4.1"],
Cell[3617, 112, 660, 20, 41, "DisplayFormula",
  CellTags->"4.1"],
Cell[4280, 134, 776, 22, 68, "Text",
  CellTags->"4.1"],
Cell[5059, 158, 393, 13, 26, "DisplayFormula",
  CellTags->"4.1"],
Cell[5455, 173, 973, 32, 75, "Text",
  CellTags->"4.1"],
Cell[6431, 207, 379, 13, 26, "DisplayFormula",
  CellTags->"4.1"],
Cell[6813, 222, 60, 1, 26, "Text",
  CellTags->"4.1"],
Cell[6876, 225, 540, 17, 36, "DisplayFormula",
  CellTags->"4.1"],
Cell[7419, 244, 71, 1, 26, "Text",
  CellTags->"4.1"],
Cell[7493, 247, 375, 13, 26, "DisplayFormula",
  CellTags->"4.1"],
Cell[7871, 262, 700, 27, 26, "Text",
  CellTags->"4.1"],
Cell[8574, 291, 648, 23, 28, "TopSpanBox",
  CellTags->"4.1"],
Cell[9225, 316, 3077, 83, 24, "MiddleBox",
  CellTags->"4.1"],
Cell[12305, 401, 652, 23, 12, "MiddleSpanBox",
  CellTags->"4.1"],
Cell[12960, 426, 3078, 83, 24, "MiddleBox",
  CellTags->"4.1"],
Cell[16041, 511, 762, 27, 12, "MiddleSpanBox",
  CellTags->"4.1"],
Cell[16806, 540, 3164, 83, 35, "MiddleBox",
  CellTags->"4.1"],
Cell[19973, 625, 1878, 55, 20, "BottomBox",
  CellTags->"4.1"],
Cell[21854, 682, 87, 1, 18, "Caption",
  CellTags->"4.1"],
Cell[21944, 685, 777, 21, 82, "Text",
  CellTags->"4.1"],
Cell[22724, 708, 64, 1, 26, "MathCaption",
  CellTags->"4.1"],
Cell[22791, 711, 77, 2, 22, "Input",
  CellTags->"4.1"],
Cell[22871, 715, 91, 1, 26, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[22987, 720, 88, 2, 22, "Input",
  CellTags->"4.1"],
Cell[23078, 724, 114, 3, 28, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[23207, 730, 366, 8, 47, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[23598, 742, 91, 2, 22, "Input",
  CellTags->"4.1"],
Cell[23692, 746, 159, 4, 29, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[23866, 753, 201, 7, 26, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[24092, 764, 79, 2, 22, "Input",
  CellTags->"4.1"],
Cell[24174, 768, 62587, 1381, 185, 11237, 741, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.1"]
}, Open  ]],
Cell[86776, 2152, 1853, 58, 173, "Text",
  CellTags->"4.1"],
Cell[88632, 2212, 1093, 35, 81, "DefinitionBox3Col",
  CellTags->"4.1"],
Cell[89728, 2249, 203, 7, 18, "Caption",
  CellTags->"4.1"],
Cell[89934, 2258, 183, 5, 40, "Text",
  CellTags->"4.1"],
Cell[90120, 2265, 1318, 44, 38, "DisplayFormula",
  CellTags->"4.1"],
Cell[91441, 2311, 966, 29, 74, "Text",
  CellTags->"4.1"],
Cell[92410, 2342, 206944, 3625, 133, 194895, 3471, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"4.1"],
Cell[299357, 5969, 153, 5, 18, "Caption",
  CellTags->"4.1"],
Cell[299513, 5976, 94, 1, 26, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[299632, 5981, 109, 2, 22, "Input",
  CellTags->"4.1"],
Cell[299744, 5985, 141, 4, 22, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[299900, 5992, 649, 21, 40, "Text",
  CellTags->"4.1"],
Cell[300552, 6015, 323, 9, 37, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[300900, 6028, 157, 6, 40, "Input",
  CellTags->"4.1"],
Cell[301060, 6036, 439, 10, 33, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[301514, 6049, 570, 16, 58, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[302109, 6069, 229, 11, 90, "Input",
  CellTags->"4.1"],
Cell[302341, 6082, 14698, 527, 185, 6620, 421, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.1"]
}, Open  ]],
Cell[317054, 6612, 182, 5, 40, "Text",
  CellTags->"4.1"],
Cell[317239, 6619, 88, 1, 26, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[317352, 6624, 173, 8, 60, "Input",
  CellTags->"4.1"],
Cell[317528, 6634, 179, 4, 43, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[317722, 6641, 294, 8, 36, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[318041, 6653, 81, 2, 22, "Input",
  CellTags->"4.1"],
Cell[318125, 6657, 92, 3, 22, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[318232, 6663, 125, 4, 26, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[318382, 6671, 144, 6, 40, "Input",
  CellTags->"4.1"],
Cell[318529, 6679, 858, 15, 79, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[319402, 6697, 131, 4, 26, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[319558, 6705, 99, 2, 22, "Input",
  CellTags->"4.1"],
Cell[319660, 6709, 534, 11, 44, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[320209, 6723, 84, 1, 26, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[320318, 6728, 145, 6, 40, "Input",
  CellTags->"4.1"],
Cell[320466, 6736, 534, 11, 44, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[321015, 6750, 934, 20, 124, "Text",
  CellTags->"4.1"],
Cell[321952, 6772, 78, 1, 26, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[322055, 6777, 105, 2, 22, "Input",
  CellTags->"4.1"],
Cell[322163, 6781, 133, 3, 28, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[322311, 6787, 175, 5, 36, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[322511, 6796, 118, 2, 22, "Input",
  CellTags->"4.1"],
Cell[322632, 6800, 268, 6, 28, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[322915, 6809, 74, 1, 26, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[323014, 6814, 95, 2, 22, "Input",
  CellTags->"4.1"],
Cell[323112, 6818, 17204, 588, 185, 6613, 451, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.1"]
}, Open  ]],
Cell[340331, 7409, 230, 6, 36, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[340586, 7419, 80, 2, 22, "Input",
  CellTags->"4.1"],
Cell[340669, 7423, 272, 6, 48, "Output",
  CellTags->"4.1"]
}, Open  ]],
Cell[340956, 7432, 70, 1, 26, "MathCaption",
  CellTags->"4.1"],

Cell[CellGroupData[{
Cell[341051, 7437, 90, 3, 22, "Input",
  CellTags->"4.1"],
Cell[341144, 7442, 192, 5, 28, "Output",
  CellTags->"4.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[341385, 7453, 71, 1, 44, "Subsection",
  CellTags->"4.2"],
Cell[341459, 7456, 1795, 42, 194, "Text",
  CellTags->"4.2"],
Cell[343257, 7500, 511, 18, 28, "TopSpanBox",
  CellTags->"4.2"],
Cell[343771, 7520, 1959, 53, 24, "MiddleBox",
  CellTags->"4.2"],
Cell[345733, 7575, 533, 19, 12, "MiddleSpanBox",
  CellTags->"4.2"],
Cell[346269, 7596, 1491, 41, 12, "MiddleBox",
  CellTags->"4.2"],
Cell[347763, 7639, 762, 27, 12, "MiddleSpanBox",
  CellTags->"4.2"],
Cell[348528, 7668, 3417, 92, 35, "MiddleBox",
  CellTags->"4.2"],
Cell[351948, 7762, 2019, 59, 20, "BottomBox",
  CellTags->"4.2"],
Cell[353970, 7823, 89, 1, 18, "Caption",
  CellTags->"4.2"],
Cell[354062, 7826, 386, 9, 54, "Text",
  CellTags->"4.2"],
Cell[354451, 7837, 431, 14, 47, "MathCaption",
  CellTags->"4.2"],
Cell[354885, 7853, 178, 9, 70, "Input",
  CellTags->"4.2"],
Cell[355066, 7864, 160, 5, 26, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[355251, 7873, 90, 2, 22, "Input",
  CellTags->"4.2"],
Cell[355344, 7877, 122, 3, 22, "Output",
  CellTags->"4.2"]
}, Open  ]],
Cell[355481, 7883, 149, 4, 26, "MathCaption",
  CellTags->"4.2"],
Cell[355633, 7889, 58422, 1143, 96, 53247, 1074, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"4.2"],
Cell[414058, 9034, 125, 5, 18, "Caption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[414208, 9043, 171, 7, 50, "Input",
  CellTags->"4.2"],
Cell[414382, 9052, 223, 6, 31, "Output",
  CellTags->"4.2"]
}, Open  ]],
Cell[414620, 9061, 114, 4, 26, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[414759, 9069, 94, 2, 22, "Input",
  CellTags->"4.2"],
Cell[414856, 9073, 197, 5, 29, "Output",
  CellTags->"4.2"]
}, Open  ]],
Cell[415068, 9081, 500, 9, 69, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[415593, 9094, 136, 5, 30, "Input",
  CellTags->"4.2"],
Cell[415732, 9101, 760, 13, 54, "Output",
  CellTags->"4.2"]
}, Open  ]],
Cell[416507, 9117, 355, 10, 47, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[416887, 9131, 101, 2, 22, "Input",
  CellTags->"4.2"],
Cell[416991, 9135, 21641, 478, 185, 3462, 248, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.2"]
}, Open  ]],
Cell[438647, 9616, 161, 4, 36, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[438833, 9624, 161, 7, 50, "Input",
  CellTags->"4.2"],
Cell[438997, 9633, 20353, 463, 185, 3494, 249, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.2"]
}, Open  ]],
Cell[459365, 10099, 198, 7, 26, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[459588, 10110, 72, 2, 22, "Input",
  CellTags->"4.2"],
Cell[459663, 10114, 27610, 574, 185, 3870, 275, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.2"]
}, Open  ]],
Cell[487288, 10691, 2648, 64, 343, "Text",
  CellTags->"4.2"],
Cell[489939, 10757, 1566, 46, 28, "TopBox",
  CellTags->"4.2"],
Cell[491508, 10805, 533, 19, 12, "MiddleSpanBox",
  CellTags->"4.2"],
Cell[492044, 10826, 2139, 58, 24, "MiddleBox",
  CellTags->"4.2"],
Cell[494186, 10886, 1002, 33, 12, "MiddleSpanBox",
  CellTags->"4.2"],
Cell[495191, 10921, 2771, 75, 32, "BottomBox",
  CellTags->"4.2"],
Cell[497965, 10998, 72, 1, 18, "Caption",
  CellTags->"4.2"],
Cell[498040, 11001, 682, 16, 96, "Text",
  CellTags->"4.2"],
Cell[498725, 11019, 190, 6, 36, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[498940, 11029, 168, 8, 60, "Input",
  CellTags->"4.2"],
Cell[499111, 11039, 20647, 481, 185, 3679, 266, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.2"]
}, Open  ]],
Cell[519773, 11523, 68, 1, 26, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[519866, 11528, 89, 2, 22, "Input",
  CellTags->"4.2"],
Cell[519958, 11532, 312, 9, 22, "Output",
  CellTags->"4.2"]
}, Open  ]],
Cell[520285, 11544, 212, 5, 36, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[520522, 11553, 182, 9, 70, "Input",
  CellTags->"4.2"],
Cell[520707, 11564, 15647, 444, 185, 4269, 298, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.2"]
}, Open  ]],
Cell[536369, 12011, 131, 4, 26, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[536525, 12019, 146, 5, 30, "Input",
  CellTags->"4.2"],
Cell[536674, 12026, 559, 14, 29, "Output",
  CellTags->"4.2"]
}, Open  ]],
Cell[537248, 12043, 257, 6, 47, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[537530, 12053, 107, 2, 22, "Input",
  CellTags->"4.2"],
Cell[537640, 12057, 56862, 960, 185, 4520, 308, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.2"]
}, Open  ]],
Cell[594517, 13020, 2565, 77, 180, "Text",
  CellTags->"4.2"],
Cell[597085, 13099, 177737, 2931, 123, 165075, 2769, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"4.2"],
Cell[774825, 16032, 135, 5, 18, "Caption",
  CellTags->"4.2"],
Cell[774963, 16039, 103, 2, 26, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[775091, 16045, 173, 7, 50, "Input",
  CellTags->"4.2"],
Cell[775267, 16054, 2204, 60, 96, "Output",
  CellTags->"4.2"]
}, Open  ]],
Cell[777486, 16117, 303, 9, 36, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[777814, 16130, 116, 2, 22, "Input",
  CellTags->"4.2"],
Cell[777933, 16134, 2746, 76, 137, "Output",
  CellTags->"4.2"]
}, Open  ]],
Cell[780694, 16213, 111, 2, 26, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[780830, 16219, 100, 2, 22, "Input",
  CellTags->"4.2"],
Cell[780933, 16223, 880, 20, 66, "Output",
  CellTags->"4.2"]
}, Open  ]],
Cell[781828, 16246, 208, 6, 36, "MathCaption",
  CellTags->"4.2"],

Cell[CellGroupData[{
Cell[782061, 16256, 158, 5, 30, "Input",
  CellTags->"4.2"],
Cell[782222, 16263, 22006, 748, 185, 8954, 581, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[804277, 17017, 79, 1, 44, "Subsection",
  CellTags->"4.3"],
Cell[804359, 17020, 255, 6, 54, "Text",
  CellTags->"4.3"],
Cell[804617, 17028, 218, 8, 36, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[804860, 17040, 140, 5, 30, "Input",
  CellTags->"4.3"],
Cell[805003, 17047, 146, 4, 29, "Output",
  CellTags->"4.3"]
}, Open  ]],
Cell[805164, 17054, 131, 4, 26, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[805320, 17062, 102, 2, 22, "Input",
  CellTags->"4.3"],
Cell[805425, 17066, 154, 4, 22, "Output",
  CellTags->"4.3"]
}, Open  ]],
Cell[805594, 17073, 254, 6, 36, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[805873, 17083, 186, 6, 40, "Input",
  CellTags->"4.3"],
Cell[806062, 17091, 21759, 585, 185, 6281, 388, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.3"]
}, Open  ]],
Cell[827836, 17679, 465, 17, 47, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[828326, 17700, 296, 12, 100, "Input",
  CellTags->"4.3"],
Cell[828625, 17714, 81756, 1889, 222, 36417, 1323, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.3"]
}, Open  ]],
Cell[910396, 19606, 575, 17, 47, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[910996, 19627, 153, 5, 30, "Input",
  CellTags->"4.3"],
Cell[911152, 19634, 191, 5, 31, "Output",
  CellTags->"4.3"]
}, Open  ]],
Cell[911358, 19642, 235, 7, 26, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[911618, 19653, 98, 2, 22, "Input",
  CellTags->"4.3"],
Cell[911719, 19657, 146, 4, 29, "Output",
  CellTags->"4.3"]
}, Open  ]],
Cell[911880, 19664, 69, 1, 26, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[911974, 19669, 129, 5, 30, "Input",
  CellTags->"4.3"],
Cell[912106, 19676, 279, 6, 28, "Output",
  CellTags->"4.3"]
}, Open  ]],
Cell[912400, 19685, 195, 7, 26, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[912620, 19696, 106, 2, 22, "Input",
  CellTags->"4.3"],
Cell[912729, 19700, 260, 7, 36, "Output",
  CellTags->"4.3"]
}, Open  ]],
Cell[913004, 19710, 204, 7, 26, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[913233, 19721, 109, 2, 22, "Input",
  CellTags->"4.3"],
Cell[913345, 19725, 309, 6, 43, "Output",
  CellTags->"4.3"]
}, Open  ]],
Cell[913669, 19734, 504, 16, 36, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[914198, 19754, 232, 11, 90, "Input",
  CellTags->"4.3"],
Cell[914433, 19767, 19261, 666, 185, 8421, 526, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.3"]
}, Open  ]],
Cell[933709, 20436, 251, 6, 47, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[933985, 20446, 208, 10, 117, "Input",
  CellTags->"4.3"],
Cell[934196, 20458, 14896, 453, 186, 5117, 326, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.3"]
}, Open  ]],
Cell[949107, 20914, 111, 2, 28, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[949243, 20920, 154, 7, 72, "Input",
  CellTags->"4.3"],
Cell[949400, 20929, 1376, 44, 113, "Output",
  CellTags->"4.3"]
}, Open  ]],
Cell[950791, 20976, 508, 13, 56, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[951324, 20993, 153, 6, 57, "Input",
  CellTags->"4.3"],
Cell[951480, 21001, 487, 9, 168, "Output",
  CellTags->"4.3"]
}, Open  ]],
Cell[951982, 21013, 172, 5, 50, "Commentary"],
Cell[952157, 21020, 298, 6, 56, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[952480, 21030, 217, 9, 102, "Input",
  CellTags->"4.3"],
Cell[952700, 21041, 21721, 743, 186, 9204, 583, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.3"],
Cell[974424, 21786, 174, 5, 26, "Output",
  CellTags->"4.3"]
}, Open  ]],
Cell[974613, 21794, 572, 15, 72, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[975210, 21813, 233, 8, 87, "Input",
  CellTags->"4.3"],
Cell[975446, 21823, 16673, 466, 186, 5018, 316, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.3"]
}, Open  ]],
Cell[992134, 22292, 553, 15, 69, "MathCaption",
  CellTags->"4.3"],

Cell[CellGroupData[{
Cell[992712, 22311, 267, 12, 100, "Input",
  CellTags->"4.3"],
Cell[992982, 22325, 12757, 387, 186, 4489, 279, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"4.3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

