(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    277345,       5986]*)
(*NotebookOutlinePosition[    284209,       6186]*)
(*  CellTagsIndexPosition[    284085,       6178]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["11. Nonlinear Control Systems", "Section",
  CellTags->"11.0"],

Cell["\<\
Although systematic treatment of nonlinear control problems is \
beyond the scope of the present revision, this application package does \
provide the linearization tools that may allow construction of a linear model \
describing the behavior of the nonlinear system in the vicinity of some \
operating point. For reasonably smooth nonlinearities, this approach may \
provide a useful insight into the properties of the system, if not a suitable \
approximation. \
\>", "Text",
  CellTags->"11.0"],

Cell[CellGroupData[{

Cell["11.1 Local Linearization of Nonlinear Systems", "Subsection",
  CellTags->"11.1"],

Cell["For a nonlinear state\[Hyphen]space system of the form ", "Text",
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  StyleBox["\<\"x\"\>",
                    "TB"], "."], "=", 
                StyleBox["\<\"f\"\>",
                  "TB"], 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["\<\"x\"\>",
                      "TB"], ",", 
                    StyleBox["\<\"u\"\>",
                      "TB"]}], ")"}]}],
              "DisplayFormula"]},
          {
            StyleBox[
              RowBox[{
                StyleBox["\<\"y\"\>",
                  "TB"], "=", 
                StyleBox["\<\"h\"\>",
                  "TB"], 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["\<\"x\"\>",
                      "TB"], ",", 
                    StyleBox["\<\"u\"\>",
                      "TB"]}], ")"}]}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DisplayFormula",
  CellTags->"11.1"],

Cell["the locally linearized model is given by ", "Text",
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  OverscriptBox[
                    StyleBox["\<\"x\"\>",
                      "TB"], "~"], "."], "=", 
                RowBox[{
                  StyleBox["\<\"A\"\>",
                    "TB"], 
                  OverscriptBox[
                    StyleBox["\<\"x\"\>",
                      "TB"], "~"]}], "+", 
                RowBox[{
                  StyleBox["\<\"B\"\>",
                    "TB"], 
                  OverscriptBox[
                    StyleBox["\<\"u\"\>",
                      "TB"], "~"]}]}],
              "DisplayFormula"]},
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  StyleBox["\<\"y\"\>",
                    "TB"], "~"], "=", 
                RowBox[{
                  StyleBox["\<\"C\"\>",
                    "TB"], 
                  OverscriptBox[
                    StyleBox["\<\"x\"\>",
                      "TB"], "~"]}], "+", 
                RowBox[{
                  StyleBox["\<\"D\"\>",
                    "TB"], 
                  OverscriptBox[
                    StyleBox["\<\"u\"\>",
                      "TB"], "~"]}]}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DisplayFormula",
  CellTags->"11.1"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["\<\"x\"\>",
            "TB"], "~"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["\<\"y\"\>",
            "TB"], "~"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", and ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["\<\"u\"\>",
            "TB"], "~"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " are small deviations, "
}], "Text",
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  StyleBox["\<\"x\"\>",
                    "TB"], "~"], \((t)\), "=", 
                StyleBox["\<\"x\"\>",
                  "TB"], \((t)\), "-", 
                SubscriptBox[
                  StyleBox["\<\"x\"\>",
                    "TB"], "n"], \((t)\)}],
              "DisplayFormula"]},
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  StyleBox["\<\"y\"\>",
                    "TB"], "~"], \((t)\), "=", 
                StyleBox["\<\"y\"\>",
                  "TB"], \((t)\), "-", 
                SubscriptBox[
                  StyleBox["\<\"y\"\>",
                    "TB"], "n"], \((t)\)}],
              "DisplayFormula"]},
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  StyleBox["\<\"u\"\>",
                    "TB"], "~"], \((t)\), "=", 
                StyleBox["\<\"u\"\>",
                  "TB"], \((t)\), "-", 
                SubscriptBox[
                  StyleBox["\<\"u\"\>",
                    "TB"], "n"], \((t)\)}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DisplayFormula",
  CellTags->"11.1"],

Cell[TextData[{
  "from some known solution ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"x\"\>",
            "TB"], "n"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"y\"\>",
            "TB"], "n"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"u\"\>",
            "TB"], "n"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " to the original nonlinear equation, which we refer to as the nominal \
solution. The coefficients ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " are the Jacobian matrices evaluated on the nominal solution:  "
}], "Text",
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["\<\"A\"\>",
                "TB"], 
              StyleBox["=",
                "DisplayFormula"], 
              StyleBox[
                SubscriptBox[
                  RowBox[{
                    StyleBox["\[AutoLeftMatch]",
                      "DisplayFormula"], 
                    FractionBox[
                      RowBox[{"\[PartialD]", 
                        StyleBox["\<\"f\"\>",
                          "TB"]}], 
                      RowBox[{"\[PartialD]", 
                        StyleBox["\<\"x\"\>",
                          "TB"]}]], "\[RightBracketingBar]"}], "n"],
                "DisplayFormula"]}]},
          {
            RowBox[{
              StyleBox["\<\"B\"\>",
                "TB"], 
              StyleBox["=",
                "DisplayFormula"], 
              StyleBox[
                SubscriptBox[
                  RowBox[{"\[AutoLeftMatch]", 
                    FractionBox[
                      RowBox[{"\[PartialD]", 
                        StyleBox["\<\"f\"\>",
                          "TB"]}], 
                      RowBox[{"\[PartialD]", 
                        StyleBox["\<\"u\"\>",
                          "TB"]}]], "\[RightBracketingBar]"}], "n"],
                "DisplayFormula"]}]},
          {
            RowBox[{
              StyleBox["\<\"C\"\>",
                "TB"], 
              StyleBox["=",
                "DisplayFormula"], 
              StyleBox[
                SubscriptBox[
                  RowBox[{"\[AutoLeftMatch]", 
                    FractionBox[
                      RowBox[{"\[PartialD]", 
                        StyleBox["\<\"h\"\>",
                          "TB"]}], 
                      RowBox[{"\[PartialD]", 
                        StyleBox["\<\"x\"\>",
                          "TB"]}]], "\[RightBracketingBar]"}], "n"],
                "DisplayFormula"]}]},
          {
            RowBox[{
              StyleBox["\<\"D\"\>",
                "TB"], 
              StyleBox["=",
                "DisplayFormula"], 
              StyleBox[
                SubscriptBox[
                  RowBox[{"\[AutoLeftMatch]", 
                    FractionBox[
                      RowBox[{"\[PartialD]", 
                        StyleBox["\<\"h\"\>",
                          "TB"]}], 
                      RowBox[{"\[PartialD]", 
                        StyleBox["\<\"u\"\>",
                          "TB"]}]], "\[RightBracketingBar]"}], "n"],
                "DisplayFormula"]}]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DisplayFormula",
  CellTags->"11.1"],

Cell[TextData[{
  "where the Jacobian ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[PartialD]", 
          StyleBox["\<\"g\"\>",
            "TB"], "/", "\[PartialD]", 
          StyleBox["\<\"t\"\>",
            "TB"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " for a vector of functions "
}], "Text",
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"g\"\>",
          "TB"], 
        RowBox[{"(", 
          StyleBox["\<\"t\"\>",
            "TB"], ")"}], "=", 
        RowBox[{"[", GridBox[{
              {
                StyleBox[\(\(g\_1\)(t\_1, t\_2, \[Ellipsis], t\_n)\),
                  "DisplayFormula"]},
              {
                StyleBox[\(\(g\_2\)(t\_1, t\_2, \[Ellipsis], t\_n)\),
                  "DisplayFormula"]},
              {
                StyleBox["\[VerticalEllipsis]",
                  "DisplayFormula"]},
              {
                StyleBox[\(\(g\_m\)(t\_1, t\_2, \[Ellipsis], t\_n)\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Center}], "]"}]}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"11.1"],

Cell[TextData[{
  "in variables ",
  Cell[BoxData[
      \(TraditionalForm\`t\_1, t\_2, \[Ellipsis], t\_n\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " is "
}], "Text",
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[PartialD]", 
            StyleBox["\<\"g\"\>",
              "TB"]}], 
          RowBox[{"\[PartialD]", 
            StyleBox["\<\"t\"\>",
              "TB"]}]], "=", 
        RowBox[{"[", GridBox[{
              {
                StyleBox[\(\[PartialD]g\_1\/\[PartialD]t\_1\),
                  "DisplayFormula"], 
                StyleBox[\(\[PartialD]g\_1\/\[PartialD]t\_2\),
                  "DisplayFormula"], 
                StyleBox["\[CenterEllipsis]",
                  "DisplayFormula"], 
                StyleBox[\(\[PartialD]g\_1\/\[PartialD]t\_n\),
                  "DisplayFormula"]},
              {
                StyleBox[\(\[PartialD]g\_2\/\[PartialD]t\_1\),
                  "DisplayFormula"], 
                StyleBox[\(\[PartialD]g\_2\/\[PartialD]t\_2\),
                  "DisplayFormula"], 
                StyleBox["\[CenterEllipsis]",
                  "DisplayFormula"], 
                StyleBox[\(\[PartialD]g\_2\/\[PartialD]t\_n\),
                  "DisplayFormula"]},
              {
                StyleBox["\[VerticalEllipsis]",
                  "DisplayFormula"], 
                StyleBox["\[VerticalEllipsis]",
                  "DisplayFormula"], 
                StyleBox["\[VerticalEllipsis]",
                  "DisplayFormula"], 
                StyleBox["\[VerticalEllipsis]",
                  "DisplayFormula"]},
              {
                StyleBox[\(\[PartialD]g\_m\/\[PartialD]t\_1\),
                  "DisplayFormula"], 
                StyleBox[\(\[PartialD]g\_m\/\[PartialD]t\_2\),
                  "DisplayFormula"], 
                StyleBox["\[CenterEllipsis]",
                  "DisplayFormula"], 
                StyleBox[\(\[PartialD]g\_m\/\[PartialD]t\_n\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Center}], "]"}]}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"11.1"],

Cell[TextData[{
  "The function ",
  StyleBox["Linearize", "MR"],
  " attempts to find such an approximation. "
}], "Text",
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Linearize",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["f",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{"x", 
                        StyleBox[",",
                          "MR"], " ", \(x\_n\)}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{"u", 
                        StyleBox[",",
                          "MR"], " ", \(u\_n\)}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            StyleBox[
              RowBox[{
                
                StyleBox[
                  \(find\ a\ linearized\ state - 
                    space\ approximation\ to\ the\ function\ f\ in\ the\ state
                      \ variable\ x\ and\ input\ variable\ u\ in\ the\ 
                      vicinity\ of\ the\ operating\ point\ \),
                  SingleLetterItalics->False], 
                FormBox[
                  RowBox[{
                    FormBox[\(x\_n\),
                      "TraditionalForm"], ",", " ", \(u\_n\)}],
                  "TraditionalForm"]}],
              "Text"]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Linearize",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["f",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{
                        RowBox[{
                          StyleBox["{",
                            "MR"], 
                          RowBox[{\(x\_1\), 
                            StyleBox[",",
                              "MR"], " ", \(x\_\(1 n\)\)}], 
                          StyleBox["}",
                            "MR"]}], 
                        StyleBox[",",
                          "MR"], " ", 
                        RowBox[{
                          StyleBox["{",
                            "MR"], 
                          RowBox[{\(x\_2\), 
                            StyleBox[",",
                              "MR"], " ", \(x\_\(2 n\)\)}], 
                          StyleBox["}",
                            "MR"]}], 
                        StyleBox[",",
                          "MR"], " ", "\[Ellipsis]"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{
                        RowBox[{
                          StyleBox["{",
                            "MR"], 
                          RowBox[{\(u\_1\), 
                            StyleBox[",",
                              "MR"], " ", \(u\_\(1 n\)\)}], 
                          StyleBox["}",
                            "MR"]}], 
                        StyleBox[",",
                          "MR"], " ", 
                        RowBox[{
                          StyleBox["{",
                            "MR"], 
                          RowBox[{\(u\_2\), 
                            StyleBox[",",
                              "MR"], " ", \(u\_\(2 n\)\)}], 
                          StyleBox["}",
                            "MR"]}], 
                        StyleBox[",",
                          "MR"], " ", "\[Ellipsis]"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            StyleBox[
              RowBox[{
                
                StyleBox[
                  \(find\ a\ linearized\ state - 
                    space\ approximation\ to\ a\ vector\ of\ functions\ f\ in
                      \ the\ state\ variables\ \),
                  SingleLetterItalics->False], 
                FormBox[\(x\_i\),
                  "TraditionalForm"], 
                StyleBox[\(\ and\ input\ variables\ \),
                  SingleLetterItalics->False], 
                FormBox[\(u\_i\),
                  "TraditionalForm"], 
                
                StyleBox[\(\ in\ the\ vicinity\ of\ the\ operating\ point\ 
                  \),
                  SingleLetterItalics->False], 
                FormBox[
                  RowBox[{
                    FormBox[\(x\_in\),
                      "TraditionalForm"], ",", " ", \(u\_in\)}],
                  "TraditionalForm"]}],
              "Text"]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Linearize",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["f",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["h",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{
                        RowBox[{
                          StyleBox["{",
                            "MR"], 
                          RowBox[{\(x\_1\), 
                            StyleBox[",",
                              "MR"], " ", \(x\_\(1 n\)\)}], 
                          StyleBox["}",
                            "MR"]}], 
                        StyleBox[",",
                          "MR"], " ", 
                        RowBox[{
                          StyleBox["{",
                            "MR"], 
                          RowBox[{\(x\_2\), 
                            StyleBox[",",
                              "MR"], " ", \(x\_\(2 n\)\)}], 
                          StyleBox["}",
                            "MR"]}], 
                        StyleBox[",",
                          "MR"], " ", "\[Ellipsis]"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{
                        RowBox[{
                          StyleBox["{",
                            "MR"], 
                          RowBox[{\(u\_1\), 
                            StyleBox[",",
                              "MR"], " ", \(u\_\(1 n\)\)}], 
                          StyleBox["}",
                            "MR"]}], 
                        StyleBox[",",
                          "MR"], " ", 
                        RowBox[{
                          StyleBox["{",
                            "MR"], 
                          RowBox[{\(u\_2\), 
                            StyleBox[",",
                              "MR"], " ", \(u\_\(2 n\)\)}], 
                          StyleBox["}",
                            "MR"]}], 
                        StyleBox[",",
                          "MR"], " ", "\[Ellipsis]"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"11.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(find\ a\ linearized\ state - 
                space\ approximation\ to\ the\ vectors\ f\ and\ h\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"11.1"],

Cell["Local linearization. ", "Caption",
  CellTags->"11.1"],

Cell[TextData[{
  StyleBox["Linearize", "MR"],
  " accepts one or both of the function vectors ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"f\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"h\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " and returns, respectively, the short (containing just matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ") or full (containing all four matrices) state\[Hyphen]space description. \
Desired options for the resulting state\[Hyphen]space object may be supplied \
to ",
  StyleBox["Linearize", "MR"],
  " or inserted later. \nAs an example, we consider the linearization of the \
one\[Hyphen]dimensional magnetic ball suspension system shown in Figure\
\[NonBreakingSpace]11.1 (after Kuo (1991)).  The system attempts to control \
the vertical position ",
  Cell[BoxData[
      \(TraditionalForm\`l(t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " of the steel ball through input voltage ",
  Cell[BoxData[
      \(TraditionalForm\`e(t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ". The state variables are chosen as ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t) = l(t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(t) = \(l\& . \)(t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_3\)(t) = i(t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ". The only input variable is ",
  Cell[BoxData[
      \(TraditionalForm\`u(t) = e(t)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ".  \n",
  Cell["", "Message",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    CellTags->"S0.0.2"],
  "   "
}], "Text",
  CellTags->"11.1"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 304 196
%%HiResBoundingBox: 47 4 304 196
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (10:53:12 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 200 translate 1 -1 scale
gsave
47 196 translate
257 -192 scale
1 string
1021 763 1 [1021 0 0 763 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFFFFFF0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF1FFFFFFFFF07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF9FFFFFFFFF0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FCFFFFFFFFF07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF8FFFFFFFFE0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF1FFFFFFFFE07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3EF83EE3FFFFFFFFE0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7C7C7F07FFFFFFFFC07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E7E3F3FFFFFFFFFE07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7C3C3F3FFFFFFFFFC07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBC3E3F8FFFFFFFFFE03FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3C5E1F11FFFFFFFFC03FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBCEF3F3CFFFFFFFFC03FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9C671F3C7FFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F79F3E7FFFFFFF803FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDC731F1C7FFFFFFF801FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FB8FBE3FFFFFFF803FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD8FD8FCC7FFFFFFF801FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8FE8FFBFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FE47FFFFFFFFFF000FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8FF0FFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FF07FFFFFFFFFF000FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FF87FFFFFFFFFF000FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFC3FFFFFFFFFF0007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBFFEBFFFFFFFFFE000FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0001FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4001FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8C009FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9C00DFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9C00DFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBC00EFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7C00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF400017F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA000000B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000
5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA000000000
0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0000000000
01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000000000
003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000
001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000000000
0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000400400
0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800002FC00FA0
00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000155C005D5
00001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0000FFFC00FFF
A0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005555400555
500007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FFFFC00FFF
FE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00055D5D400D5D
5D00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8002FFFFFC00FFF
FFE0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000555555400555
5550001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFC00FFF
FFFA000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8001D5D5D5C005D5
D5D50007FFFFFFFFFFFDD7FD7F5FF5FD5FFF5FF7DD5D5FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFC00FFF
FFFF8003FFFFFFFFFFFC29FC3E0FE0F83FFCAFE18E3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0005555555400555
55554001FFFFFFFFFFFC7C7C5047C07C7FF8F1C7163E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFC00FFF
FFFFE001FFFFFFFFFFF9FE78F8FB8FBEFFF8FB8F9E3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC005D5D5D5D400D5D
5D5D50007FFFFFFFFFFDFC78F1FD1FDC7FF9F9CF1F3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFC00FFF
FFFFF8007FFFFFFFFFFBFE38F3FFBFFEFFF8F8EF9E3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00155555555400555
555554003FFFFFFFFFFFFC78F3FF1FFC7FF9FCE71F3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFC00FFF
FFFFFF003FFFFFFFFFFFF878F3FFBFFEFFF8F8FB9E3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC005D5D5D5D5C005D5
D5D5D5001FFFFFFFFFFFF078F155155C7FF9F8FD1F3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFC00FFF
FFFFFF800FFFFFFFFFFFE0F8FAA3AA3EFFF8F8EF9E3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001555555555400555
5555554007FFFFFFFFFF01F8F3E31F1C7FF8F1C71F3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFC00FFF
FFFFFFE003FFFFFFFFFE0FF8FBE3BE3EFFF8F3EFBE3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001D5D5D5D5D400D5D
5D5D5D5001FFFFFFFFFC1FF05D47C47C7FF901E71F3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFC00FFF
FFFFFFF803FFFFFFFFFC3FF8BEBFFAFEFFF8EFFAFE3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC005555555555400555
5555555401FFFFFFFFFC7F7CFFFFFFFC7FF9FFFFFF3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFC00FFF
FFFFFFFE00FFFFFFFFFCFFFEFFFFFFFEFFF8FFFFFE3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801D5D5D5D5D5C005D5
D5D5D5D4007FFFFFFFFCFE7FFFFFFFFC7FF9FFFFFF3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFC00FFF
FFFFFFFE007FFFFFFFFEFEFFFFFFFFFEFFF8FFFFFE3E3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0015555555555400555
55555555007FFFFFFFFE507FFFFFFFF47FF1FFFFFC3C3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFC00FFF
FFFFFFFF803FFFFFFFFFAFFFFFFFFFFEFFFAFFFFFFBFBFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055D5D5D5D5D400D5D
5D5D5D5D001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFC00FFF
FFFFFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0055555555555400555
55555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFFFFFFFFFFC00FFF
FFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC015D5D5D5D5D5C005D5
D5D5D5D5C00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFC00FFF
FFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80155555555555400555
555555555007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFC00FFF
FFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D400D5D
5D5D5D5D5007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF807FFFFFFFFFFFC00FFF
FFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555400555
555555555403FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFC00FFF
FFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5C005D5
D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFC00FFF
FFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00555555555555400555
555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFFFFFFFFFFFC00FFF
FFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC015D5D5D5D5D5D400D5D
5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFFFFFFFFFFFC00FFF
FFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01555555555555400555
555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFF0003FF
FFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01D5D5D5D5D5D40001D5
D5D5D5D5D500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFC0001FF
FFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01555555555550000055
555555555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFF80000FF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC015D5D5D5D5D5000005D
5D5D5D5D5D00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFE000003F
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01555555555540000015
5555555555007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFE000003F
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01D5D5D5D5D5C0000015
D5D5D5D5D500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFEAAAAAAAAAAAAAAAAAAAAAABFFFFC03FFFFFFFFFFE000003F
FFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFC00000000000000000000001FFFFC01555555555540000015
555555555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFEAAAAAAAAAAAAAAAAAAAAAABFFFFC03FFFFFFFFFFE000003F
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFC015D5D5D5D5D5000005D
5D5D5D5D5D00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFF800007F
FFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFC01555555555550000055
555555555400FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFF80000FF
FFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFC01D5D5D5D5D5D40001D5
D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFE01FFFFFFFFFFFE0003FF
FFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFC01555555555555000555
555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFF800FFF
FFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFE005D5D5D5D5D5D001D5D
5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFF800FFF
FFFFFFFFFC03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFF00555555555555400555
555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF800FFF
FFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFF0055D5D5D5D5D58015D5
D5D5D5D5D003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFF807FFFFFFFFFFF800FFF
FFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFF00555555555555400555
555555555007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFF800FFF
FFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFC01D5D5D5D5D5D001D5D
5D5D5D5D5007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFF800FFF
FFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFC0155555555555400555
55555555400FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFF800FFF
FFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFC005D5D5D5D5D58015D5
D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFF800FFF
FFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFF0055555555555400555
55555555003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFF800FFF
FFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFF8015D5D5D5D5D001D5D
5D5D5D5D007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFF800FFF
FFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFC005555555555400555
55555554007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFF800FFF
FFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFE0055D5D5D5D58015D5
D5D5D5D001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF827FFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFF800FFF
FFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF337FFFFFFFFFFFFFFFFFFFFFF001555555555400555
5555554003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3BFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFF800FFF
FFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF73FFFFFFFFFFFFFFFFFFFFFFFC0055D5D5D5D001D5D
5D5D5D4007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFF800FFF
FFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF73FFFFFFFFFFFFFFFFFFFFFFFE00155555555400555
555555001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFF800FFF
FFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFF00055D5D5D58015D5
D5D5D4007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFF8007FFFFFFF800FFF
FFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFC0015555555400555
55555000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFF800FFF
FFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFF00055D5D5D001D5D
5D5D0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFF800FFF
FFFE000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFC000555555400555
5554000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFE0003FFFFF800FFF
FFF8003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFF00015D5D58015D5
D5C0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFC000FFFFF800FFF
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFC00015555400555
540001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFF8000BFFF800FFF
F80003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFC000155D001D5D
400007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFE00003FF800FFE
80003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000015400550
00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFE000002800A00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000
000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000
007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0000000000
02FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE800000000
BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000005
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA0002BF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFC5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01F7F
FFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB800EFF
FFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBC01EFF
FFFFFF47FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB800EFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDC01DFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC8008FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4011FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0001FF
FFFFFE000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0001FF
FFFFFD555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0001FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FF
FFFFFF87FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FF
FFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFF
FFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFF
FFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF
FFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFF
FFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFF
FFFFFFE755FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFF
FFFFFFE780FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFF
FFFFFFF7007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFF
FFFFFFE3FFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFF
FFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF73FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFF
FFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFF
FFFFFFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF73FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFF
FFFFFFF1FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFB3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFF
FFFFFFFBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF107FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFF
FFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFF
FFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFD43FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F557FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAAAEAFE3FE3FEBAFF8BEAEAEAEB9
F006AEAF8FFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF05471F007C07C507E7DF1F1E1850
40071F1E01E07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FF39F8F78FB8F8FE7EF9F3E38E3
EBFF9F3E3BE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FF31F1FB1FB8F8FC7C71F1F31F1
F7FF1F1C7CE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFB9E3FF3FF8F8F8FE79F3E38F3
FBFF9F38FEE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFF1E7FF1FF8F8F8FE71F1F3C71
F01F1F18FFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFF9E3FE3FF8F8F8FE39F3E3E73
F39F9F39FFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FDF1E7FF3FF8F8F9FC71F1F3F91
E3CF1F19FFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FDF9E0033FF8F8F8FE79F3E3FE3
E7CF9F3800E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFF00000000000000000000000
00000000000000001FFFFFFFFFFFFFFF051F1F7E71F78F8FCFC71F1F3CF1
C7C71F1DF0E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000000000000
00000000000000003FFFFFFFFFFFFFFF8A1F9FBE7BE38F8FEFCF9F3E38F3
E78F8F3EF9E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFF00000000000000000000000
00000000000000001FFFFFFFFFFFFFFF1FDF1F9C7DE78F00C79D14047CF3
F387143E71E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFAAAAAAAAAAAAAAAAAAAAABFE00000000000000000000000
00000000000000003FFFFFFFFFFFFFFF9FFF9FE8FEAF0388FA3F9878FEAF
FA3F98FFA380FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFF0000000000000000000001FF00000000000000000000000
00000000000000001FFFFFFFFFFFFFFF1FFF1FF7FF5F0FFDFD7FFD7DFF5F
FD7FFDFFDFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFAAAAAAAAAAAAAAAAAAAAABFE00000000000000000000000
00000000000000003FFFFFFFFFFFFFFF9FFF9FFFFFFFEFFFFFFFFFFFFFFF
FFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000
00000000000000001FFFFFFFFFFFFFFF1FF71FFFFFFFCFFFFFFFFFFFFFFF
FFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000000000000
00000000000000003FFFFFFFFFFFFFFF9FFF9FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFF1FC71FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFE000F9FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEABFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00007FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80A803FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FF01FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFF81FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFC0FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFE0FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFF07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFF83FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF83FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00AAAAAAAAAAAAAAAAA2AAA
AAAAAAAAAAAAAAA00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA8FFFFF83FFFFFFAAABFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF400000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000007FFFFC3FFFFFF5555FFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFFFC3FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000007FFFFC1FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000AAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAA00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA0FFFFFC3FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFC3FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE02E00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFF83FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF807F00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF87FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFF87FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFF07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFE0FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFC0FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FF81FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007C01FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800007FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0000FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF00D5D5D5D5D5D5D5D5D5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF00555555555555555555555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF005D5D5D5D5D5D5D5D5D5D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFF00D5D5D5D5D5D5D5D5D5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFF00555555555555555555555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFF005D5D5D5D5D5D5D5D5D5D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF807F00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE02E00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA000FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF400555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE00BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
5555555555555540007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE02803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03F80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFF87FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF17FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9BFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9C7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC71FFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7BFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF11FFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D45555
D5D5D5D5D5D5D5C01FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07C1FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFEA
FFFFFFFFFFFFFFE03FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FE3FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FA3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545554
01555555555555401F007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7C7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FF3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
802BFFFFFFFFFFE03E03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFBFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
4000155D5D5D5D401003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7C7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FDFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFEFFFF
F80000BFFFEEAA80000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE78FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
5000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC70FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFBA2AA2
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE39FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5150000000000
000000000000000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE31FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00AAAAA8000000000000000
0000000000002AA03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE23FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000000000000
00000044555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0000000000000000000022AA
A0003FFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3E3FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000011555C5D5D
40015D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F1FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000002AAAAEFFFFFFFFFEFFFE
80BFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000555555555555555545554
05555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0F0FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00E00FFFFFFFFFFFFFFFFE7FE2
BFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01F005D5D5D5D5D5D5D5D45515
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F1FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E3FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFF00555555555555555555555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFF00D5D5D5D5D5D5D5D5D5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFF00555555555555555555555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFF005D5D5D5D5D5D5D5D5D5D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FFFFFE3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFC1FFFFF1
FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFC0FFFFF0
FFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFFFC07FFFF0
7FFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFFF80FFFFE0
7FFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFF807FFFE0
7FFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFF807FFFE0
3FFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFF00555555555555555555555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFF007FFFC0
3FFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF77FFFFFC1FFFFFFD1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFC30FFFF803FFFE0
3FFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF27FFFFFE1FFFFFF81
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFF00D5D5D5D5D5D5D5D5D5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFC307FFF003FFFC0
1FFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFF40FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFF838FFFF083FFFC0
3FFFE10FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFE20FFFFFE00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFF00555555555555555555555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFF8707FFF041FFFC0
1FFFC107FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFC007FFFFC00
7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFF8387FFE0E3FFF82
1FFFE387FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF020FFFFC383FFFFE18
3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFF005D5D5D5D5D5D5D5D5D5D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFF0787FFE1C1FFF86
1FFFC187FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF060FFFF81C1FFFFC18
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFE00FFFFFFFFFFFFFFFFEFFFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFF8F83FFE1E1FFF86
0FFFC383FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0F0FFFF83C1FFFF83C
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0003FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFF07C3FFC1C1FFF07
0FFFC3C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1F07FFF07C1FFFF07C
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00001FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFF0F83FFE3E0FFF8F
0FFF83E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83F83FFF8FE0FFFF87E
0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00A00FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFF0FC1FFC1F0FFF07
07FF87C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83F83FFF07F0FFFF07E
0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FC07FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FE3FFC3E0FFF0F
8FFF87E1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FC3FFF0FF0FFFF0FE
0FFFFFFFFFFFFFFFFFFFFFFFFFAFFFF80FFF03FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FC1FFC3F07FF0F
07FF07E0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FC1FFF0FF07FFF0FF
07FFFFFFFFFFFFFFFFFFFFFFF07FFFF01FFF01FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FE1FF83F0FFE0F
87FF0FE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFE3FFE0FF8FFFE0FF
0FFFFFFFFFFFFFFFFFFFFFFFA3FFFFF03FFFE3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01F005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FE1FF87F07FE1F
87FF07F07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FC1FFF1FF07FFE1FF
07FFFFFFFFFFFFFFFFFFFFF007FFFFF07FFFC1FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80A00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FE0FF87F87FE1F
83FE0FF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFE3FFE0FF8FFFE0FF
0FFFFFFFFFFFFFFFFFFFFF800FFFFFE0FFFFE0FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF40000555555555555555545555
555555555555554000000000000000000000000001FFC1FE0FF07F07FC1F
C3FE0FF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFC1FFE1FF07FFE1FF
07FFFFFFFFFFFFFFFFFFF0001FFFFFE0FFFFF07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE000000000000000000000000002FFC3FF0FF8FF83FE3F
C3FE0FF8000000000000000000000000003FFFFFF0FFE1FFE0FF8FFFE1FF
0FFFFFFFFFFFFFFFFFFF80003FFFFFE1FFFFF0FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D40000000000000000000000000007FC3FF07F07FC3FC1F
C1FC1FF8000000000000000000000000003FFFFFF0FFC1FFF1FF07FFE1FF
07FFFFFFC00000000000000000000001FFFFF07FFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE800FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE0000000000000000000000000003F83FF8FF0FFC3FC3F
E3FE1FF8000000000000000000000000003FFFFFF0FFE3FFE0FF8FFFE0FF
0FFFFFFFE00000000000000000000003FFFFF8FFFFFFFFBFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFF83F87FF07F0FFC1FC3F
C1FC1FFC000000000000000000000000001FFFFFF07FC1FFF0FF07FFE1FF
0FFFFFFF000000000000000000000001FFFFF07FFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFF83F87FF87E0FFE3F83F
E1FE3FFEFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFF0FFE3FFF0FF0FFFE0FE
0FFFFFFF000000000000000000000003FFFFF8FFFFFFFFBFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFC1F07FF87E1FFC1F87F
E1FC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFF07FC1FFF07F0FFFF0FE
1FFFFFFF055555555000000015555541FFFFF07FFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFE1F8FFF83E1FFE1F87F
E0F83FFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFF87FC3FFF8FE0FFFF0FE
1FFFFFFF0FFFFFFFFFA000003FFFFFE1FFFFF0FFFFFFFFBFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFC1F07FFC3C1FFE1F07F
F0783FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFF07FC3FFF07E0FFFF07C
1FFFFFFF0FFFFFFFFFFD000007FFFFE0FFFFF07FFFFFE0007FFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFE0F0FFFC3E3FFE0F0FF
F0F83FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFF83F83FFF83E1FFFF87E
3FFFFFFE0FFFFFFFFFFFFA8003FFFFE0FFFFE0FFFFFFEAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFF0F0FFFC1C1FFF0F07F
F0787FFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFC1F07FFF81C1FFFF078
1FFFFFFE1FFFFFFFFFFFFFF4017FFFF07FFFC1FFFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFF0E0FFFE3C3FFF0F0FF
F8F87FFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFC1F87FFFC3C3FFFF838
3FFFFFFE1FFFFFFFFFFFFFFFE83FFFF83FFFC1FFFFFFFFBFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFF061FFFC1C3FFF060FF
F0707FFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFC1F07FFFC103FFFFC10
7FFFFFFC1FFFFFFFFFFFFFFFFF47FFF01FFF01FFFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFF861FFFE183FFF8E0FF
F830FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFE0E0FFFFE003FFFFE20
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFF80FFE03FFFFFFFFBFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFF841FFFE187FFF061FF
F870FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFF041FFFFF007FFFFC00
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFC01FC07FFFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFF823FFFE087FFF861FF
F820FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF803FFFFF80FFFFFE01
FFFFFFF07FFFFFFFFFFFFFFFFFFFFFFE00A00FFFFFFFFFBFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFC01FFFF007FFF841FF
FC20FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFF003FFFFF00FFFFFF01
FFFFFFC07FFFFFFFFFFFFFFFFFFFFFFF00001FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFC03FFFF00FFFF823FF
FC21FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE07FFFFF00FFFFFE03
FFFFFFA0FFFFFFFFFFFFFFFFFFFFFFFFE0007FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFC03FFFF007FFFC01FF
FC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFC01FFFFC001FFFF800
7FFFFF01FFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFE03FFFF80FFFFC03FF
FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFF800FFFF8080FFFE000
3FFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFE07FFFF00FFFFC03FF
FC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFC0001FF401C00550010
07FFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFE07FFFF80FFFFE03FF
FE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FE006002A003E000000F8
02FF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFF81FFFFC07FF
FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000001F0000007F000001FC
0000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFF81FFFFE07FF
FE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000003FE00003FFE0000FFF
800000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFC5FFFFE07FF
FF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF400007FF40017FFF4005FFF
C00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFE3FFF
FF0BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFABFFFFFFFFFFFF
FA00BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFF
FF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF97FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF8BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005D5D5D5D5D5D5D5D455D5
D5D5D5D5D5D5D5C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00D5D5D5D5D5D5D5D5C5D5D
5D5D5D5D5D5D5D401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555555555555545555
55555555555555401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFE7FFF
FFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000
00000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000000000000
00000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000
00000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000000000000
00000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000
00000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFEAAAAAAAAAAAAAAAAAAAAAAAAAAA00000000000000000000000
00000000000000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFE00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFE00000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFE00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFE00000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFE00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFE00000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFE00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFEAAAAAA2AAAAAAAAA0AAAAAAAAAA0AAAAAAAA82AAAAAAAAA0AA
AAAAAAAA0AAAAAAAAAA82AAAAAAAAA2AAAAAAAAAA0AAAAAFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFF07FFFFFFFFC3FF
FFFFFFFC1FFFFFFFFFF07FFFFFFFFC7FFFFFFFFFC3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFF8FFFFFFFFF87FFFFFFFFF83FFFFFFFF0FFFFFFFFF8FFF
FFFFFFF87FFFFFFFFFE3FFFFFFFFF0FFFFFFFFFF8FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFC1FFFFFFFFF1FFFFFFFFFF0FFFFFFFFC1FFFFFFFFF1FFF
FFFFFFF1FFFFFFFFFFC3FFFFFFFFC1FFFFFFFFFE1FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFF83FFFFFFFFE3FFFFFFFFFE3FFFFFFFF8FFFFFFFFFC3FFF
FFFFFFE3FFFFFFFFFF8FFFFFFFFF87FFFFFFFFFC3FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFF07FFFFFFFF07FFFFFFFFFC7FFFFFFFF07FFFFFFFF07FFF
FFFFFF07FFFFFFFFFE1FFFFFFFFF07FFFFFFFFF07FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFE3FFFFFFFFF0FFFFFFFFFF0FFFFFFFFE3FFFFFFFFE07FFF
FFFFFF0FFFFFFFFFFE3FFFFFFFFE3FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFF87FFFFFFFFC07FFF
FFFFFC1FFFFFFFFFF07FFFFFFFF87FFFFFFFFFC3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFF8FFFFFFFFF8FFFFFFFFFF87FFFFFFFF0FFFFFFFFF8E7FFF
FFFFF8FFFFFFFFFFE1FFFFFFFFF8FFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFC1FFFFFFFFF1FFFFFFFFFF07FFFFFFFC1FFFFFFFFE1C7FFF
FFFFF0FFFFFFFFFFC3FFFFFFFFC1FFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFF83FFFFFFFFE3FFFFFFFFFE3FFFFFFFF87FFFFFFFFE3E7FFF
FFFFE3FFFFFFFFFF8FFFFFFFFF83FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFF0FFFFFFFFF87FFFFFFFFFC7FFFFFFFF1FFFFFFFFF07C7FFF
FFFF87FFFFFFFFFF1FFFFFFFFF0FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFE3FFFFFFFFE0FFFFFFFFFF8FFFFFFFFE3FFFFFFFFE1FFFFFF
FFFE0FFFFFFFFFFC3FFFFFFFFE3FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFF07FFFFFFFFC3FFFFFF
FFFC1FFFFFFFFFF07FFFFFFFF47FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFF8FFFFFFFFF8FFFFFFFFFF83FFFFFFFF0FFFFFFFFF8FFFFFFF
FFF87FFFFFFFFFE3FFFFFFFFF0FFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFC1FFFFFFFFF1FFFFFFFFFF0FFFFFFFFC1FFFFFFFFE1FFFFFFF
FFF1FFFFFFFFFFC3FFFFFFFFC1FFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFF83FFFFFFFFE3FFFFFFFFFE3FFFFFFFF8FFFFFFFFFC3FFFFFFF
FFE3FFFFFFFFFF8FFFFFFFFF87FFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFF07FFFFFFFF07FFFFFFFFFC7FFFFFFFF07FFFFFFFF07FFFFFFF
FF07FFFFFFFFFE1FFFFFFFFF07FFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFE3FFFFFFFFF0FFFFFFFFFF0FFFFFFFFE3FFFFFFFFE3FFFFFFFF
FF0FFFFFFFFFFE3FFFFFFFFE3FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFF87FFFFFFFFC3FFFFFFFF
FC1FFFFFFFFFF07FFFFFFFF87FFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFF8FFFFFFFFF8FFFFFFFFFF87FFFFFFFF0FFFFFFFFF8FFFFE7FFF
F8FFFFFFFFFFE1FFFFFFFFF8FFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFC1FFFFFFFFF1FFFFFFFFFF07FFFFFFFC1FFFFFFFFE1FFFFC7FFF
F1FFFFFFFFFFC3FFFFFFFFC1FFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFF83FFFFFFFFE3FFFFFFFFFE3FFFFFFFF87FFFFFFFFE3FFFFFFFFF
E3FFFFFFFFFF8FFFFFFFFF87FFFFFFFFFA3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFF0FFFFFFFFF87FFFFFFFFF87FFFFFFFF1FFFFFFFFF07FFFFFFFFF
87FFFFFFFFFE1FFFFFFFFF0FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFE3FFFFFFFFE0FFFFFFFFFF8FFFFFFFFE3FFFFFFFFE1FFFFFFFFFE
0FFFFFFFFFFC3FFFFFFFFE3FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFF07FFFFFFFFC3FFFFFFFFFC
1FFFFFFFFFF07FFFFFFFF07FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFF0FFFFFFFFF8FFFFFFFFFF83FFFFFFFF0FFFFFFFFF8FFFFFFFFFF8
FFFFFFFFFFE3FFFFFFFFF0FFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFC1FFFFFFFFF1FFFFFFFFFF0FFFFFFFFC1FFFFFFFFC1FFFFFFFFFF1
FFFFFFFFFFC3FFFFFFFFC1FFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFF87FFFFFFFFE3FFFFFFFFFE3FFFFFFFF8FFFFFFFFFC3FFFFFFFFFE3
FFFFFFFFFF8FFFFFFFFF8FFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFF07FFFFFFFF07FFFFFFFFF47FFFFFFFF0FFFFFFFFF07FFFFFFFFF07
FFFFFFFFFE1FFFFFFFFF07FFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFE3FFFFFFFFE1FFFFFFFFFF0FFFFFFFFE3FFFFFFFFE3FFFFFFFFFF0F
FFFFFFFFFA3FFFFFFFFE3FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFF87FFFFFFFFC3FFFFFFFFFC1F
FFFFFFFFF07FFFFFFFF87FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFF8FFFFFFFFF8FFFFFFFFFF87FFFFFFFE0FFFFFFFFF8FFFFFFFFFF8FF
FFFFFFFFE3FFFFFFFFF0FFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFC1FFFFFFFFF1FFFFFFFFFF07FFFFFFFC1FFFFFFFFE1FFFFFFFFFF1FF
FFFFFFFFC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFF83FFFFFFFFE3FFFFFFFFFE3FFFFFFFF87FFFFFFFFA3FFFFFFFFFE3FF
FFFFFFFF8FFFFFFFFF87FFFFFFFFFA3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFF0FFFFFFFFF07FFFFFFFFF87FFFFFFFF1FFFFFFFFF07FFFFFFFFF07FF
FFFFFFFC1FFFFFFFFF1FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFE3FFFFFFFFE0FFFFFFFFFF8FFFFFFFFE3FFFFFFFFE3FFFFFFFFFE0FFF
FFFFFFFC3FFFFFFFFE3FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFF47FFFFFFFFC1FFFFFFFFFC1FFFFFFFF87FFFFFFFFC7FFFFFFFFFC1FFF
FFFFFFF07FFFFFFFF07FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFF0FFFFFFFFF8FFFFFFFFFF87FFFFFFFF8FFFFFFFFFEFFFFFFFFFFEFFFF
FFFFFFE3FFFFFFFFF0FFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFE1FFFFFFFFF1FFFFFFFFFF0FFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC3FFFFFFFFC1FFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFE7FFFFFFFFFBFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF8FFFFFFFFFCFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFF7FFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFDFFFFFFFFFC7FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{257, 192},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000410000`1000`40O003h00Oogoo0Woo003oOol2
Ool003Qoo`03HaQoogoo0<Ioo`00>7oo00<aS7ooOol0aWoo000hOol00c6<Oomoo`36Ool003Qoo`03
<Haoogoo0<Ioo`00>7oo00<aS7ooOol0aWoo000hOol00c6<Oomoo`36Ool003Qoo`03<Haoogoo0<Io
o`00>7oo00<aS7ooOol0aWoo000hOol00c6<Oomoo`36Ool003Qoo`03<Haoogoo0<Ioo`00>7oo00<a
S7ooOol0aWoo000gOol00ekg<Haoo`37Ool002aoo`9g_@Uoo`03=JdaS7oo0<Moo`00:goo00AJeWoo
@Q1_N`Qoo`038@PaS7oo0<Moo`009Woo00QF]GNmF]IW>D8@MkeBU48@27oo00=g_@00:DX0b7oo000V
Ool02E[FG_LaS6mk8@QoocW>E[Eg_@07Ool00fLi0008@P38Ool002Ioo`09IcUBU5:DDY@aS7Nm@Q1_
NcW>00Moo`04BU800000Kg_7Ool002Ioo`09MkdQ25kgMkdYBUJeMkeNmf]J00Moo`04=Jd00000BU;7
Ool002Moo`058@Qg_Goo>Li2400:Ool012U:000003W>agoo000WOol01FmkOomoogooKg/02Goo00Eg
_@00000002U:0<Moo`00=Goo00=_N`0000000P0000=g_GooOol0a7oo000eOol01U:D>Lh000006<IW
>LIoo`00=Goo00IF]Ekg0000048@Kg_6Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37
Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37Ool003Io
o`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L0
0000@Q37Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37
Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37Ool003Io
o`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L00000@Q37Ool003Ioo`04G_L0
0000@Q37Ool003Eoo`06Kg]6<@00000aS6mkaWoo000aOol017NmE[DYBQS61P0000@8@RU:BU9g_L9o
o`00;goo00=g_DYB48@0100000@8@P000008@PD00003>Lig_Goo0;moo`00;Woo00UNmaS6000000Q2
:DY:DU[FE[D00P0000DaS5kgBU8aS12400800003249BU7oo0;ioo`00;Goo00YBU000000@Q3W>HaQW
>F<HIcUBU0800007>LiS66LiHaQW>D8@48@00P0000<aS7NmOol0_7oo000/Ool02d8@00000248G_MS
66LiHaQW>F<HE[D00P0000PaS6LiHaQW>F<HIcUJeSW>0P0000<HaWNmOol02Woo00i245kgG_MoocW>
IcU:DU:DOom245:DOolicVmk0Woo00YBU5kgKg]BU6LiBU9BU6LiDYAW>IMoo`00:goo00aBU000000i
cVLiHaQW>F<HIcUS66LiDY@200002CW>HaQW>F<HIcUS66LiHaPicP0200000bU:Oomoo`08Ool2Kg/0
2Goo:DYNmd8@BU9W>GNmBU9Nm`02Mkd01T8@Oomoogoo<Haoo`924006Kg]245:DG_M245kgUgoo000Z
Ool03EJe000003W>IcUS66LiHaQW>F<HIcUS65Je0080000:<HaW>F<HIcUS66LiHaQW>F<H@Q020000
0e:DOomoo`08Ool03Fmk<H`icUkg@Q1:DUkg@Q1:DUJeBU9[FT8@00=oo`03:DYg_BU:009Nm`05@Q1B
U5kg@Q1Nm`2GOol002Uoo`0>MkdHaP008@QW>F<HIcUS66LiHaQW>F<HIcUBU080000;>LiS66LiHaQW
>F<HIcUS66LiHaPicP0200000fmkOomoo`07Ool03A24IcUg_Ekg<Ha_NekgDYAg_EkgBU9ood8@00=o
o`03:DYBU6Li00=W>@04DYANmd8@G_NGOol002Uoo`0>BU8000Q2G_MS66LiHaQW>F<HIcUS66LiHaQF
]@80000><HaW>F<HIcUS66LiHaQW>F<HIcUS61S6000YBPUoo`05BU9W>E:DOomg_@06Ool01WNm@Q1o
ogooMkdaS0Eoo`04@Q1NmcW>G_NGOol002Qoo`0?Mkd@Q000<HaS66LiHaQW>F<HIcUS66LiHaQW>E:D
0080000<>LiS66LiHaQW>F<HIcUS66LiHaQW>DYB0P0000=W>GooOol01Woo0WNm2Woo00Eg_GooOomo
ofmk00Ioo`03MkeoogNm09Moo`00:7oo00mJeP00249S66LiHaQW>F<HIcUS66LiHaQW>F<HE[D00P00
00laS6LiHaQW>F<HIcUS66LiHaQW>F<HIcTHaP00>Lh0^Goo000XOol03c6<000YBVLiHaQW>F<HIcUS
66LiHaQW>F<HIcUBU00200003cW>HaQW>F<HIcUS66LiHaQW>F<HIcUS64YB000@Q02iOol002Qoo`0?
5:D005JeJeYg_F]JMke[FWNmJeYg_F]JMke[FUkg0080000@=Jeg_F]JMke[FWNmJeYg_F]JMke[FWNm
G_L8@P00MkfhOol002Moo`0@Mkd00000F]IW>F<HIcUS66LiHaQW>F<HIcUS66LiDY@2000043W>HaQW
>F<HIcUS66LiHaQW>F<HIcUS66Li48@005Je^7oo000WOol046Li000@Q6LiHaQW>F<HIcUS66LiHaQW
>F<HIcUJeQS60P000108@UkgHaQW>F<HIcUS66LiHaQW>F<HIcUS61S6001:D[Qoo`009goo00mNm`00
48AS66LiHaQW>F<HIcUS66LiHaQW>F<H8@P0100000lQ26LiHaQW>F<HIcUS66LiHaQW>F<HIcTaS000
@Q00^7oo000;Ool00gNmKg]_N`04Kg/00gNmKg]_N`0>Kg/4Ool03Ukg000@Q6LiHaQW>F<HIcUS66Li
HaQW>F<HIcT600003V<HIcUS66LiHaQW>F<HIcUS66LiHaPYBP00>LjhOol000]oo`03IcUBU5:D00AB
U003@Q1BU5:D00iBU0Aoo`0?G_L00124HaQW>F<HIcUS66LiHaQW>F<HIcUS61S600@0000?48AW>F<H
IcUS66LiHaQW>F<HIcUS66Li:DX0048@0;Qoo`004Woo00=247ooOol04Woo00m_N`00249W>F<HIcUS
66LiHaQW>F<HIcUS66LiBU80100000mBU6<HIcUS66LiHaQW>F<HIcUS66LiHaP@Q000DY@0^7oo000A
Ool00gNm5:Eoo`0COol047Nm000004YBIcUS66LiHaQW>F<HIcUS66LiHaQW>C6<0P00011246<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>@Q2001W>KQoo`004Goo00=Nm`Q2Ool057oo00lYBP00>LiS66LiHaQW
>F<HIcUS66LiHaQW>F<H@Q000P0000dicVLiHaQW>F<HIcUS66LiHaQW>F<HIcU:DP0200000gNmOomo
o`2fOol0015oo`03DY@007Nm01Aoo`0?BU8001S6IcUS66LiHaQW>F<HIcUS66LiHaQW>CW>0080000?
@Q1S66LiHaQW>F<HIcUS66LiHaQW>F<H:DX002U:0;Uoo`004Goo00=24000G_L057oo00m_N`00001:
DVLiHaQW>F<HIcUS66LiHaQW>F<H@Q000P0000licVLiHaQW>F<HIcUS66LiHaQW>F<HG_L8@P00G_L0
^Goo000AOol00bU:001BU00EOol03SW>000@Q6<HIcUS66LiHaQW>F<HIcUS66Li>Lh200003T8@HaQW
>F<HIcUS66LiHaQW>F<HIcTaS0006<JjOol0015oo`036<H8@T8@01Eoo`0>Mkd00000<HaS66LiHaQW
>F<HIcUS66LiHaQ24080000;>LiW>F<HIcUS66LiHaQW>F<HIcU:DP0200000e:DOomoo`2hOol0015o
o`03IcTYBVmk01Ioo`0=DY@00000BU9S66LiHaQW>F<HIcUS66Li>Lh00P0000e246<HIcUS66LiHaQW
>F<HIcUJePQ2000Q202kOol0015oo`03MkdYBWoo01Moo`0<8@P000Q2BU9S66LiHaQW>F<HIcUS648@
0P0000dicVLiHaQW>F<HIcUS66LiF]H@Q0006<Ig_@2kOol0019oo`03:DYoogoo01Ioo`0<MkdHaP00
000icV<HIcUS66LiHaQW>CW>0P0000a246<HIcUS66LiHaQW>D8@48@00124Kg^lOol0019oo`03:DYo
ogoo01Moo`0;MkdQ2000000@Q5[FIcUS66LiHaQ2400200001cW>IcUS66LiHaQNmbU:008000036<I_
Ngoo0;aoo`004Woo00<YBWooOol067oo00=g_DYB00000P0000DQ24YBHaQW>CW>00800005@Q1S66Li
DY@YBP0300000bU:Mkeoo`2mOol0019oo`03:DYoogoo01Yoo`03IcTYBP0000<0008HaP80000348@H
aPQ200<0000348ABU7oo0;moo`004Woo00<YBWooOol077oo00=W>BU:2480200000<8@RU:G_L0`Woo
000BOol00bU:Oomoo`0OOol00fLiE[DYBP02000012U:DYAW>GNma7oo000BOol00bU:Oomoo`0QOol0
15:D000005:Dagoo000BOol00f]JOomoo`0QOol015:D000005:Dagoo000fOol015:D000005:Dagoo
000fOol015:D000005:Dagoo000@Ool00cW>Mkeoo`0SOol015:D000005:Dagoo000@Ool00dYBOomo
o`0SOol015:D000005:Dagoo000@Ool2E[DTOol015:D000005:Dagoo000AOol00d8@Oomoo`0ROol0
15:D000005:Dagoo000AOol00d8@Oomoo`0ROol015:D000005:D27oo00=F]GooOol0_7oo000fOol0
15:D000005:D27oo00<icWNmOol0_7oo000fOol015:D000005:D27oo00=:DWooOol0_7oo000fOol0
15:D000005:D27oo00=F]EkgOol0_7oo000BOol00cF]Oomoo`0POol01WNmDY@00000DYA_N`Qoo`03
@Q1oogoo0;]oo`004Woo00<YBWooOol087oo00IS64YB000004YBF]H7Ool00gNmIcUoo`2lOol0019o
o`03:DYoogoo021oo`06Kg/8@P000008@VLi1goo00AF]E:DDYAW>K]oo`004Woo00<YBWooOol08Goo
00D@Q000000007Nm0<Ioo`004Woo00<YBWooOol08Goo00@YBP00000Ha/Moo`004Woo00<YBWooOol0
8Goo00@e[@00000YBPQoo`03MkeNmgoo0;aoo`004Woo00<YBWooOol08Goo00AF]@00001240Qoo`03
IcUBU7oo0;aoo`004Woo00<YBWooOol08Goo00Ag_@00001F]@Uoo`04@Q1g_FmkMkfjOol0019oo`03
:DYoogoo029oo`035:D006mk00Uoo`04DYAW>C6<DYBjOol0015oo`03Kg/YBWNm02=oo`03=Jd8@Woo
00Uoo`04IcUg_FLiIcVjOol0015oo`03:DX8@U:D02=oo`03G_LYBWoo00Uoo`05MkeoogooDYAg_@2i
Ool0015oo`038@P005:D02Aoo`03@Q1oogoo00Yoo`03BU8HaWoo0;Uoo`004Goo00<aS000E[D097oo
00=F]GooOol0aWoo000AOol00dYB001W>@0TOol00d8@Oomoo`0nOol00fLiDYA_N`25Ool0015oo`03
DY@8@Woo02Aoo`03E[Eoogoo03ioo`04DYA_NekgMkf4Ool0015oo`03IcTDYGoo04Qoo`0ZIcTaS5kg
BU9JeT8@Kg/YBU:DKg/aS5JeKg/aS6Li8@QoodYBIcUBU6Li@Q1NmdYBDYA6<C6<CW<icU:D>Li246Li
@Q1NmdYBE[DaS5:DIcU247NmNgoo000AOol00gNm:DYoo`0TOol00ekgOomoo`0QOol01Fmk@Q1oogNm
IcT00T8@00A_NgooE[EF]@9oo`0:8@Qoob48OolYBWoo>LiW>D8@G_L2DY@045kg@Q1>Le:DG_M6<E:D
Kg]245kgDY@DYGooMkeNme:DO7oo000BOol00ekgOomoo`0@Ool00c6<8@PQ200@8@P00aS68@PQ200B
8@P00fmkOomoo`0<Ool02Vmk:DYF]E:DKg]246LiBU8YBVLi0U[F00]g_B48MkdHaVLi>LioocW>IcTi
cTic0092400@IcU:DUJeE[E247Nm8@Q_Nc6<CW=F]D8@E[DHaUkgDYAlOol000eoo`E24003BU92448@
00i2409oo`0348@0000002D00003Kg]oogoo00aoo`0LKg]247ooMke_Nd8@Oom_NfLiOom_NfLiKg/a
S7NmIcUNmgooE[Eg_GooKg]BU7ooG_MoofmkIcT2Ool01EJeMkeoofmkG_L00Woo00AW>FmkF]I247ao
o`009Goo014@Q000:DY:DT8@BU9244YB@Q1:DT8@BU9244YB@Q1:DT8@009:DP0F8@Q244YB@Q1:DT8@
BU9244YB@Q1:DT8@BU9244YB@Q1:DT8@BU88@P00Kg/>Ool01VLi@Q1Nme:DMke:DYmoo`009Goo02T@
Q000BU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQg_CW>IcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<H48@006mk0;=oo`009Goo02T@Q000@Q1W>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcU[FSW>HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li48@006mk0;=oo`00
9Goo02T@Q000BU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQg_D8@IcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<H48@006mk0;=oo`009Goo02T@Q000@Q1W>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcU[FSW>HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li48@006mk
0;=oo`009Goo02T@Q000BU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQg_CW>IcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H48@006mk0;=oo`009Goo02T@Q000@Q1W>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcU[FSW>HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
48@006mk0;=oo`009Goo02T@Q000BU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQg_D8@IcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H48@006mk0;=oo`009Goo02T@Q000@Q1W>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcU[FSW>HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66Li48@006mk0;=oo`009Goo02T@Q000BU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQg
_CW>IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H48@006mk08Qoo`05>Lh@Q124:DYW
>@0VOol002Eoo`0Y48@0048@IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiJeXicV<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>A24001_N`27Ool01c6<:DYNmfmkBU8005kg02Eoo`00
9Goo02T@Q000BU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQg_D8@IcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<H48@006mk08Ioo`03G_L8@Woo00=oo`03BU8HaWoo02Aoo`008goo
00ANmc6<0000010@Q088@Q8@Q003248000Q200d@Q0035:D@Q124028@Q003248@Q124028@Q0035:D@
Q124024@Q003248@Q12400T@Q003<Haoogoo009oo`03Mkd007Nm00Eoo`05Kg]NmekgG_Mg_@0JOol0
025oo`0]Kg/HaQS6>Lh8@P00@Q1BU5JeDYAF]E:DE[EBU5JeDYAF]E:DE[EBU5JeDYANmc6<E[EBU5Je
DYAF]E:DE[EBU5JeDYAF]E:DE[EBU5JeDYAF]E:D48@005Je00e_N`03Mke_Nfmk029_N`03JeY_Nfmk
029_N`03Mke_Nfmk025_N`03JeY_Nfmk00Q_N`03@Q0YBWoo00=oo`03Kg/8@Woo02Aoo`0087oo02i_
Na24BU9g_Goo48@0048@IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiJeXicV<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>A24001_NhIoo`03Mkd005kg00=oo`8aS2Eoo`007goo00=g
_AS6BU800goo02T@Q000BU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQg_D8@IcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H48@006mk08Moo`04DY@002U:@Q026<H00fmkOomoo`0S
Ool001moo`03F]H@Q7oo00=oo`0Y48@0048@IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiJeXi
cV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>A24001_N`28Ool017Nm@Q1244YB9goo
000OOol00c6<>Lioo`03Ool0:A24001:DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67NmDYAW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaP@Q000Kg/0/goo000OOol00bU:DYAoo`03
Ool0:A24001246LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F]JIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcT@Q000Kg/0/goo000OOol00bU:DYAoo`03Ool0:A24001:DV<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67NmBU9W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaP@Q000Kg/0/goo000OOol2>Lh4Ool0:A24001246LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F]J>LiS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT@Q000Kg/0/goo000OOol0
0ekg249g_@03Ool0:A24001:DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67NmDYAW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaP@Q000Kg/0/goo000POol00bU:<Haoo`02Ool0:A24
001246LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F]JIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcT@Q000Kg/0/goo000QOol0;AS6<Ha_Ngoo48@004YBHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HMke:DVLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS6124001_
N`2cOol0029oo`03<H`8@QS60080000W@Q1W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcU[FSW>
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li48@006mk0;=oo`008goo00Eg_D8@0000
04YB00m[FP03Lia246]J015[FP035:D007Nm0;=oo`009Goo02X@Q000BU9S66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQg_CW>IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H48@00248
BU:bOol002Eoo`0/48@0048@IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiJeY246<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>A24001:DQS6249W>K1oo`009Goo02d@Q000BU9S66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQg_CW>IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<H48@006mkOom:DQ24IcT0[goo000UOol0:A24001246LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F]J>LiS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT@Q000Kg/00Woo00=2
4124Ool0[Woo000UOol0:A24001:DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67Nm>LiW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaP@Q000Kg/00goo00<HaUJeOol0[Goo000UOol0
:A24001246LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F]J@Q1S66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcT@Q000Kg/00goo00=:DSW>Ool0S7oo00=g_EJeOol07Woo000UOol0:A24
001:DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67Nm>LiW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaP@Q000Kg/00goo00=BU2U:Ool0S7oo00=:DVmkIcT07Woo000UOol0:A240012
46LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F]J>LiS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT@Q000Kg/00goo00=:DS6<Ool0S7oo00=NmdHaE[D07Woo000UOol0:A24001:DV<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67Nm>LiW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaP@Q000Kg/00goo00<YBT8@Ool0SGoo0TYB00=_NgooOol06goo000UOol0:A24001246Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F]J@Q1S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcT@Q000Kg/00Woo00=_N`00Kg/0[Woo000UOol0;A24001:DV<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS67Nm>LiW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaP@Q000Kg]o
ogNm6<I2402_Ool002Eoo`0D48@0048@IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiJeXicP9S
600GDYA:DS6<BU9BU6LiHaQW>F<HIcUS66LiHaQW>F<HIcT@Q000Kg]JeQS6<Hag_@0OOol01GNm6<Io
oc6<IcT0=7oo00@icTHaE[E245=oo`009Goo01D@Q000BU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiF]I[FS6<E[D00U:D00=:DR4800000P0000D@Q1S6>LhaS3W>008aS0038@PYBR4800800003248@
Q4YB029oo`03<Ha_NbU:03Eoo`04IcU247ooMkeCOol002Aoo`07E[D8@P006<HYBR48:DX00R4800H@
Q1S648@8@Q24248600001@Q248@@Q12424800`0000@Q22U::DXYBP@aS092400448@005kgMkdSOol0
15:D<H`icWNm=7oo00=g_B48Ool0E7oo000ROol00e:D248HaP0200000b48>Li24003@Q02BU84DY@0
6e[FHaQS66<HMkdicVLiHaQBU36<:DXicU:DHaQW>F<HIcUS66LiHaQW>F<HIcUS6124001_N`0TOol0
16mk:DY_NbU:=Goo00<aS7NmOol0Dgoo000QOol0;CW>249F]Goo48@0048@IcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiJeXaS6<HF]IS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>A24001_
N`0TOol017Nm<Ha:DVLi=Goo00=:DUkgOol0Dgoo000POol00eJe249W>@02Ool0:A24001:DV<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67Nm<HaW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaP@Q000Kg/0/goo000POol00a24DYAoo`02Ool0:A24001246LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F]JBU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT@Q000Kg/0/goo
000OOol00fLi249oo`03Ool0:A24001:DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67NmHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaP@Q000Kg/0/goo000OOol00eJe8@Qoo`03
Ool0:A24001246LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F]JBU9S66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcT@Q000Kg/077oo0Vmk1Goo00=_NgNmOol0SGoo000OOol00eJe8@Qo
o`03Ool0:A24001:DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67Nm<HaW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaP@Q000Kg/077oo00=:DP00BU8017oo00<HaR48Ool00goo00=F
]AS6Ool00goo00=g_A24IcT0PGoo000OOol00fLi6<Ioo`03Ool0:A24001246LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F]JBU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT@Q000
Kg/077oo00<YBQ24:DX00goo00Ag_@00001g_@=oo`03>Lh006Li00=oo`03DY@003W>02Aoo`03G_M[
FWoo00Aoo`03Mke247oo00Eoo`03IcU:DWoo04]oo`007goo00=g_@Q2G_L00goo02T@Q000BU9S66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQg_F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<H48@006mk01aoo`03249JePQ200=oo`04E[D@Q1S6E[D3Ool00aS6249:DP03Ool00cW>:DX@
Q00SOol01248248DYGNm0goo00A_Nb4848A:DPAoo`04Mkd8@Q24BU8QOol00fmkMkeoo`0WOol0021o
o`03DY@HaWNm009oo`0Y48@0048@IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiJeY:DV<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>A24001_N`0KOol01FLi48Aoo`Q2IcT00Woo00@i
cTYB<H`icP9oo`04Mkd8@U:D:DX3Ool011S6E[DHaUJe8Goo00EBU1S6Kg/8@TYB00=oo`05>LhaS6Li
001g_@03Ool01D8@:DYNm`00Mkd07Woo00IJeQ242488@QS6IcTVOol0021oo`0^MkdQ21S6Mkeooa24
001:DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67Nm<HaW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaP@Q000Kg/KOol01DYB<Haooc6<BU800Woo00@HaUJeE[DHaP9oo`04E[DHaVmk
2482Ool01Fmk249oocW>5:D08Goo00DHaU[FOomF]AS600=oo`056<IF]Goo:DYF]@03Ool01AS6E[Eo
oa24E[D05Woo00Ag_E[FG_Mg_@=oo`03F]H005:D009oo`03@Q0@Q7Nm02Eoo`008Goo02eg_D8@000a
S0Q2001246LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F]J<HaS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcT@Q000>Lh0648@01aNmgooOolYBU:DOom:DRU:Oomg_@Q2Oom_N`00Mkeo
ocW>BU9ooa24IcUoodYB6<Ioofmk001>LaUNm`03Kg]oogoo00Aoo`05001g_GooJeX8@P03Ool01@Q2
Kg]ooc6<DY@00goo00D007NmOolQ25:D019oo`06MkeBU3W>48@005:D1Goo00<YBT8@Ool00goo00<Y
BT8@Ool097oo000SOol0:fLi@Q000000BU9S66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQg_C6<
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H48@003W>01Q2400;001W>Goo249_Ngoo
Kg/8@WooE[DHaP02Ool02bU:E[EooaS6E[Eooc6<BU9ooc6<BU800Woo6R4800<HaSW>Ool01Goo00D0
07NmOom[FQ2400=oo`056<IW>Goo:DYBU003Ool01@00Kg]ooaS6E[D01Woo00=:DP0000005@0000=_
NgooOol00Woo00=BU36<Ool01Woo00=NmfmkOol06goo000UOol0:A24001246LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F]J<HaS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT@Q000
Kg/067oo00@aS3W>IcT@Q0=oo`0448AW>CW>BU82Ool2>Lh02Fmk249oogooDY@Q27oo249F]@0LOol0
0e:D6<Ioo`05Ool01A24E[EoodYB6<H00goo00DaS48@Ool8@VLi00=oo`04:DYBU7Nm2487Ool00aS6
CW=_N`06Kg/01VLiE[DicRU:6<H@Q0800003>Li_Nfmk00=_N`036<IBU7oo00=oo`03>LhaS7oo00Eo
o`04F]I244YBG_LKOol002Eoo`0Y48@004YBHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HMkda
S6LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS6124001_N`0HOol016Li48A:DS6<0goo
00@aS4YB6<IF]@9oo`04IcTHaU:D6<H2Ool016mk249W>@Q27Woo00<8@VLiOol017oo00E:DQS6Mkd8
@TYB00=oo`04G_L8@SW>6<H4Ool015:D8@PYBS6<1Woo00=W>@Q2Ool03Goo00Eg_EkgDYA:DVLi00=o
o`03DY@8@VLi009oo`03F]H006Li00Moo`03G_M_Ngoo01]oo`009Goo02T@Q000@Q1W>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcU[FS6<HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
48@006mk01Uoo`8@Q007DYAoogooOomBU1S624800goo00Ag_@00<Ha:DP=oo`0348@aS2U:01ioo`03
BU88@VLi00Eoo`038@P8@RU:00Eoo`03:DX005Je00Aoo`04Mkd8@PQ2Mkd5Ool00fmk6<I2400GOol0
1SW>248Q22U:249BU0Qoo`03Kg]g_Goo01]oo`009Goo02T@Q000BU9S66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQg_C6<IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H48@006mk01Uo
o`03>Lh006mk00=oo`03Kg/001S600Aoo`03:DX005Je00=oo`03<H`004YB01moo`0G>Lh8@TYBKg]o
ogNmDY@HaQ24000icVLiKg]BU2U:24924000>Li:DU:DBU8@Q0036<H01e[FMkeoofmkBU88@S6<01Uo
o`04Kg]F]EkgMkdWOol002Eoo`0Y48@0048@IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiJeXa
S6<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>A24001_N`0IOol00fLi48Aoo`04Ool0
0bU:F]Ioo`03Ool00cW>6<Ioo`03Ool00e:D249Nm`0POol00ekg:DX8@P0200003B48DYAooekg<H`H
aQ248@Q246mkOomW>C6<008Q2006:DYF]GooMke:DQS60P0000<@Q36<E[D0AGoo000UOol0:A24001:
DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67Nm<HaW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaP@Q000Kg/06Woo00=:DWooOol03goo0WNm97oo00=g_GooOol0GWoo000UOol0:A24
001246LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F]J<HaS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcT@Q000Kg/06Woo00=g_GooOol0G7oo00=BU5kgOol0=goo000UOol0:A24001:
DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67Nm<HaW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaP@Q000Kg/0NGoo00=W>EJeOol0=goo000UOol0:A24001246LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F]J<HaS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT@Q000
Kg/0NGoo00=g_D8@Ool0=goo000UOol0:A24001:DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
67Nm<HaW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaP@Q000Kg/0NGoo00=g_FLiOol0
=goo000UOol0:ABU000e[EkgE[ENmeJeG_MF]EkgE[ENmeJeG_MF]EkgE[ENmf<H:DYF]EkgE[ENmeJe
G_MF]EkgE[ENmeJeG_MF]EkgE[ENmeJeG_L8@P00JeX0NWoo00<e[GooOol0=Woo000UOol0:A24001:
DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67Nm<HaW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaP@Q000Kg/0/goo000UOol0:A24001246LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F]J<HaS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT@Q000Kg/0/goo000UOol0
:A24001:DV<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS67Nm<HaW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaP@Q000Kg/0/goo000UOol00a24000HaP0@8@P00a248@PQ200@8@P00`Q2
001_N`2cOol000Uoo`03Kg]BU5:D00IBU003E[EBU5:D011BU0032480000002D00003@Q1BU5:D00]B
U003E[EBU5:D00iBU9Eoo`002Goo00=Nm`000000G`0000<@Q7ooOol0Tgoo0009Ool00fLi<H`aS003
<H`28@P00c6<=JdaS005<H`00bU:000aS008<H`00bU:000aS007<H`00a246<HaS006<H`012U:<H`8
@RU:2C6<00<8@R48<H`0236<00<Q20Q2<H`0236<00<@Q3F]<H`0236<00<@Q248<H`00c6<00<icWoo
Ool0Tgoo000>Ool2>Lh8Ool00fLi<Ha_N`08Ool00gNm<HaNm`07Ool00e:D<Hag_@07Ool00f]J<HaW
>@08Ool00fmk>LiNm`09Ool00ekg<Haoo`07Ool00fLi8@QW>@08Ool00gNm>LiBU02KOol000aoo`03
Kg/icVLi00Qoo`03DYA247Nm00Qoo`03DY@YBWNm00Ioo`03MkdicU:D00Qoo`03BU8e[BU:00Qoo`03
IcTaS6Li00Uoo`03>Li:DWoo00Moo`03CW<icWoo00Qoo`03Kg/aS6mk09aoo`002goo00=W>C6<Kg/0
1goo00=g_C6<DY@027oo00=g_DYBDY@01goo00=W>C6<Kg/01goo00Eg_C6<F]Iooe[F00Moo`03@Q0i
cWoo00Qoo`03Kg/aS6Li00Moo`03MkdicU:D00Uoo`03DYA:DWNm09eoo`002Woo0SW>27oo00=W>C6<
Mkd027oo00=g_C6<G_L01goo00=BU36<Mkd01goo00=NmbU:Mkd027oo00=_NcW>G_L02Goo00=Nmc6<
Ool01goo00=W>B48IcT027oo00=g_C6<DY@0Wgoo0008Ool00fmk>LiW>@08Ool00e:D@Q1g_@08Ool0
0e:D:DYg_@06Ool00gNm>LiBU008Ool2BU84Ool00e[FOomoo`02Ool00fLi>LiW>@09Ool00cW>BU9o
o`07Ool00dic>Lioo`08Ool00fmk<Ha_N`2POol000Moo`03IcTaS6mk00Moo`03IcTYBU:D00Qoo`03
Mke245:D00Moo`03IcTaS6mk00Moo`03MkdaS5[F00Uoo`03@Q0icWoo00Qoo`03Kg/YBVLi00Moo`03
Kg/icU[F00Uoo`03DYA247Nm0:5oo`001Woo0SW>27oo00=F]CW>Ool027oo00=_Nc6<G_L01goo00=B
U3W>Mkd01goo00=F]BU:Mkd027oo00=_NcW>IcT02Goo00=Nmc6<Ool01goo00=W>BU:IcT027oo00=g
_C6<DY@0Xgoo0004Ool00fmk>LiW>@08Ool00cW>DYAoo`08Ool00e:D:DYg_@06Ool00gNm<HaBU008
Ool2BU89Ool00fLi>LiW>@09Ool00cW>DYAoo`07Ool00dYB>Lioo`08Ool00eJe:DYg_@2TOol000=o
o`03G_LaS6mk00Moo`03IcTQ26Li00Qoo`03Mke245:D00Moo`03Kg/aS6mk00Moo`03MkdicU[F00Uo
o`8icPUoo`03Kg/Q26Li00Moo`03Kg/icUkg00Uoo`03>LiBU7oo0:Eoo`000Woo00=_NcW>Ool027oo
00=247ooOol027oo00=BU6LiOol01goo00=W>GNmOol027oo00=g_GooOol027oo00=g_GooOol01goo
00=g_C6<Ool027oo00<YBVLiOol027oo00<Q26LiOol0YWoo003oOol2Ool00?moo`9oo`00\
\>"],
  CellTags->"11.1"],

Cell[TextData[{
  StyleBox["Figure 11.1. ",
    FontWeight->"Bold"],
  "Magnetic ball levitation system."
}], "Caption",
  CellTags->"11.1"],

Cell["Load the application. ", "MathCaption",
  CellTags->"11.1"],

Cell["<<ControlSystems`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"11.1"],

Cell[TextData[{
  "This is the ",
  StyleBox["Mathematica", "TI"],
  " implementation of vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"f\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " corresponding to the nonlinear state equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          OverscriptBox[
            StyleBox["\<\"x\"\>",
              "TB"], "."], "=", 
          StyleBox["\<\"f\"\>",
            "TB"], 
          RowBox[{"(", 
            RowBox[{
              StyleBox["\<\"x\"\>",
                "TB"], ",", 
              StyleBox["\<\"u\"\>",
                "TB"]}], ")"}]}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ". "
}], "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["\<\
f = {
 x2,
 g - 1/M x3^2/x1,
 - R/L x3 + 1/L e
}\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    \({x2, g - x3\^2\/\(M\ x1\), e\/L - \(R\ x3\)\/L}\)], "Output",
  CellLabel->"Out[2]= ",
  CellTags->"11.1"]
}, Open  ]],

Cell[TextData[{
  "The output vector contains a single variable. ",
  StyleBox["Linearize", "MR"],
  " does not require additional list wrapping in such a case. "
}], "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["h = x1", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    \(x1\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"11.1"]
}, Open  ]],

Cell[TextData[{
  "This linearizes the state equation near some nominal point with the \
coordinates ",
  StyleBox["x10", "MR"],
  ", ",
  StyleBox["x20", "MR"],
  ", ",
  StyleBox["x30", "MR"],
  ", and ",
  StyleBox["e0", "MR"],
  ". Since only one vector (",
  StyleBox["f", "MR"],
  ") is supplied, the resulting state\[Hyphen]space object contains only two \
matrices, ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  ". "
}], "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["\<\
ball = Linearize[f,
 {{x1, x10}, {x2, x20}, {x3, x30}},
 {e, e0}
]\
\>", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    \(StateSpace[{{0, 1, 0}, {x30\^2\/\(M\ x10\^2\), 0, 
          \(-\(\(2\ x30\)\/\(M\ x10\)\)\)}, {0, 0, \(-\(R\/L\)\)}}, {{0}, {
          0}, {1\/L}}]\)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"11.1"]
}, Open  ]],

Cell["This finds the full (four\[Hyphen]matrix) state\[Hyphen]space \
description. ", "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["\<\
Linearize[f, h,
 {{x1, x10}, {x2, 0}, {x3, x30}},
 {e, e0}
]\
\>", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    \(StateSpace[{{0, 1, 0}, {x30\^2\/\(M\ x10\^2\), 0, 
          \(-\(\(2\ x30\)\/\(M\ x10\)\)\)}, {0, 0, \(-\(R\/L\)\)}}, {{0}, {
          0}, {1\/L}}, {{1, 0, 0}}, {{0}}]\)], "Output",
  CellLabel->"Out[5]= ",
  CellTags->"11.1"]
}, Open  ]],

Cell[TextData[{
  "As soon as linearized state\[Hyphen]space model is found, we may apply \
other ",
  StyleBox["Control System Professional", "TI"],
  " functions. For this experiment, let the nominal point be the equilibrium \
position of the ball at some coordinate ",
  StyleBox["l0", "MR"],
  ". "
}], "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["\<\
{
 x10 -> l0,
 x20 -> 0,
 x30 -> Sqrt[M g l0]
}\
\>", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    \({x10 \[Rule] l0, x20 \[Rule] 0, x30 \[Rule] \@\(g\ l0\ M\)}\)], "Output",\

  CellLabel->"Out[6]= ",
  CellTags->"11.1"]
}, Open  ]],

Cell["This is the state\[Hyphen]space description near the equilibrium. ", 
  "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["ball = ball /. %", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    \(StateSpace[{{0, 1, 0}, {g\/l0, 0, 
          \(-\(\(2\ \@\(g\ l0\ M\)\)\/\(l0\ M\)\)\)}, {0, 0, 
          \(-\(R\/L\)\)}}, {{0}, {0}, {1\/L}}]\)], "Output",
  CellLabel->"Out[7]= ",
  CellTags->"11.1"]
}, Open  ]],

Cell[TextData[{
  "This is the same result in ",
  StyleBox["ReviewForm", "MR"],
  ". "
}], "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["%//ReviewForm", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "1", "0"},
                  {\(g\/l0\), "0", 
                    \(-\(\(2\ \@\(g\ l0\ M\)\)\/\(l0\ M\)\)\)},
                  {"0", "0", \(-\(R\/L\)\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0"},
                  {"0"},
                  {\(1\/L\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[8]//ReviewForm= ",
  CellTags->"11.1"]
}, Open  ]],

Cell[TextData[{
  "We now find the state feedback gain matrix that places the poles of the \
system into some position ",
  StyleBox["p1", "MR"],
  ", ",
  StyleBox["p2", "MR"],
  ", ",
  StyleBox["p3", "MR"],
  ". "
}], "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["StateFeedbackGains[ball, {p1, p2, p3}]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    \({{\(L\ M\ \((g\ p1 + g\ p2 + g\ p3 + l0\ p1\ p2\ p3)\)\)\/\(2\ 
            \@\(g\ l0\ M\)\), 
        \(-\(\(L\ M\ \((g + l0\ p1\ p2 + l0\ p1\ p3 + l0\ p2\ p3)\)\)\/\(2\ 
                \@\(g\ l0\ M\)\)\)\), \(-L\)\ p1 - L\ p2 - L\ p3 - R}}\)], 
  "Output",
  CellLabel->"Out[9]= ",
  CellTags->"11.1"]
}, Open  ]],

Cell["This is the system after the feedback loop is closed. ", "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["StateFeedbackConnect[ball, %]", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    \(StateSpace[{{0, 1, 0}, {g\/l0, 0, 
          \(-\(\(2\ \@\(g\ l0\ M\)\)\/\(l0\ M\)\)\)}, {
          \(\(-\(\(L\ \@\(g\ l0\ M\)\ p1\)\/\(2\ l0\)\)\) - 
              \(L\ \@\(g\ l0\ M\)\ p2\)\/\(2\ l0\) - 
              \(L\ \@\(g\ l0\ M\)\ p3\)\/\(2\ l0\) - 
              \(L\ \@\(g\ l0\ M\)\ p1\ p2\ p3\)\/\(2\ g\)\)\/L, 
          \(\(L\ \@\(g\ l0\ M\)\)\/\(2\ l0\) + 
              \(L\ \@\(g\ l0\ M\)\ p1\ p2\)\/\(2\ g\) + 
              \(L\ \@\(g\ l0\ M\)\ p1\ p3\)\/\(2\ g\) + 
              \(L\ \@\(g\ l0\ M\)\ p2\ p3\)\/\(2\ g\)\)\/L, 
          \(-\(R\/L\)\) + \(L\ p1 + L\ p2 + L\ p3 + R\)\/L}}, {{0}, {0}, {
          1\/L}}]\)], "Output",
  CellLabel->"Out[10]= ",
  CellTags->"11.1"]
}, Open  ]],

Cell["\<\
To simulate the system, we assign some values and drop \
insignificant numerical errors. \
\>", "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["\<\
% /. {
 l0 -> .1, M -> 10 10^-3,
 L -> 10., R -> 100,
 g -> 9.8,
 p1 -> -1, p2 -> -1 - I, p3 -> -1 + I
}//Chop\
\>", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    \(StateSpace[{{0, 1, 0}, {98.0000000000000071`, 0, 
          \(-197.989898732233307`\)}, {1.49502576593727232`, 
          0.515177797721627683`, \(-3.`\)}}, {{0}, {0}, {0.1`}}]\)], "Output",\

  CellLabel->"Out[11]= ",
  CellTags->"11.1"]
}, Open  ]],

Cell[TextData[{
  "Let us investigate the dynamics of the state variables. One way to do this \
is to insert an identity matrix as matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.2"],
  " into the previous state\[Hyphen]space object to feed all states through \
to the outputs. "
}], "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["Insert[%, IdentityMatrix[3], -1]", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"11.1"],

Cell[BoxData[
    \(StateSpace[{{0, 1, 0}, {98.0000000000000071`, 0, 
          \(-197.989898732233307`\)}, {1.49502576593727232`, 
          0.515177797721627683`, \(-3.`\)}}, {{0}, {0}, {0.1`}}, {{1, 0, 0}, {
          0, 1, 0}, {0, 0, 1}}]\)], "Output",
  CellLabel->"Out[12]= ",
  CellTags->"11.1"]
}, Open  ]],

Cell[TextData[{
  "This gives the state response to a unit step function, that is, it shows \
how the state variables change if the input voltage applied to the \
electromagnet suddenly changes by some value (",
  Cell[BoxData[
      \(TraditionalForm\`\(-10\)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " mV in the plot). The coordinate and velocity of the ball are shown as a \
solid and dashed line, respectively, and the current in the magnet is shown \
as the dashed\[Hyphen]dotted line. "
}], "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{

Cell["\<\
SimulationPlot[%, -.01, {t, 5},
 Sampled -> Period[.1],
 PlotStyle -> {
 Thickness[.001],
 Dashing[{.04, .02}],
 Dashing[{.05, .01, .01, .01}]
 },
 PlotLabel -> \"Step Response\"
]\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"11.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0151371 5.97201 [
[.21429 .00264 -3 -9 ]
[.21429 .00264 3 0 ]
[.40476 .00264 -3 -9 ]
[.40476 .00264 3 0 ]
[.59524 .00264 -3 -9 ]
[.59524 .00264 3 0 ]
[.78571 .00264 -3 -9 ]
[.78571 .00264 3 0 ]
[.97619 .00264 -3 -9 ]
[.97619 .00264 3 0 ]
[.01131 .13458 -24 -4.5 ]
[.01131 .13458 0 4.5 ]
[.01131 .25402 -24 -4.5 ]
[.01131 .25402 0 4.5 ]
[.01131 .37346 -24 -4.5 ]
[.01131 .37346 0 4.5 ]
[.01131 .4929 -24 -4.5 ]
[.01131 .4929 0 4.5 ]
[.01131 .61234 -18 -4.5 ]
[.01131 .61234 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01514 m
.21429 .02139 L
s
[(1)] .21429 .00264 0 1 Mshowa
.40476 .01514 m
.40476 .02139 L
s
[(2)] .40476 .00264 0 1 Mshowa
.59524 .01514 m
.59524 .02139 L
s
[(3)] .59524 .00264 0 1 Mshowa
.78571 .01514 m
.78571 .02139 L
s
[(4)] .78571 .00264 0 1 Mshowa
.97619 .01514 m
.97619 .02139 L
s
[(5)] .97619 .00264 0 1 Mshowa
.125 Mabswid
.0619 .01514 m
.0619 .01889 L
s
.1 .01514 m
.1 .01889 L
s
.1381 .01514 m
.1381 .01889 L
s
.17619 .01514 m
.17619 .01889 L
s
.25238 .01514 m
.25238 .01889 L
s
.29048 .01514 m
.29048 .01889 L
s
.32857 .01514 m
.32857 .01889 L
s
.36667 .01514 m
.36667 .01889 L
s
.44286 .01514 m
.44286 .01889 L
s
.48095 .01514 m
.48095 .01889 L
s
.51905 .01514 m
.51905 .01889 L
s
.55714 .01514 m
.55714 .01889 L
s
.63333 .01514 m
.63333 .01889 L
s
.67143 .01514 m
.67143 .01889 L
s
.70952 .01514 m
.70952 .01889 L
s
.74762 .01514 m
.74762 .01889 L
s
.82381 .01514 m
.82381 .01889 L
s
.8619 .01514 m
.8619 .01889 L
s
.9 .01514 m
.9 .01889 L
s
.9381 .01514 m
.9381 .01889 L
s
.25 Mabswid
0 .01514 m
1 .01514 L
s
.02381 .13458 m
.03006 .13458 L
s
[(0.02)] .01131 .13458 1 0 Mshowa
.02381 .25402 m
.03006 .25402 L
s
[(0.04)] .01131 .25402 1 0 Mshowa
.02381 .37346 m
.03006 .37346 L
s
[(0.06)] .01131 .37346 1 0 Mshowa
.02381 .4929 m
.03006 .4929 L
s
[(0.08)] .01131 .4929 1 0 Mshowa
.02381 .61234 m
.03006 .61234 L
s
[(0.1)] .01131 .61234 1 0 Mshowa
.125 Mabswid
.02381 .045 m
.02756 .045 L
s
.02381 .07486 m
.02756 .07486 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .16444 m
.02756 .16444 L
s
.02381 .1943 m
.02756 .1943 L
s
.02381 .22416 m
.02756 .22416 L
s
.02381 .28388 m
.02756 .28388 L
s
.02381 .31374 m
.02756 .31374 L
s
.02381 .3436 m
.02756 .3436 L
s
.02381 .40332 m
.02756 .40332 L
s
.02381 .43318 m
.02756 .43318 L
s
.02381 .46304 m
.02756 .46304 L
s
.02381 .52276 m
.02756 .52276 L
s
.02381 .55262 m
.02756 .55262 L
s
.02381 .58248 m
.02756 .58248 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Step) show
93.000 13.000 moveto
(Response) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .01514 m
.04286 .01532 L
.0619 .01649 L
.08095 .01937 L
.1 .02444 L
.11905 .03195 L
.1381 .04201 L
.15714 .05459 L
.17619 .06957 L
.19524 .08674 L
.21429 .10586 L
.23333 .12663 L
.25238 .14876 L
.27143 .17195 L
.29048 .19587 L
.30952 .22025 L
.32857 .24482 L
.34762 .26931 L
.36667 .29351 L
.38571 .31722 L
.40476 .34027 L
.42381 .3625 L
.44286 .38381 L
.4619 .4041 L
.48095 .4233 L
.5 .44136 L
.51905 .45825 L
.5381 .47397 L
.55714 .48852 L
.57619 .50191 L
.59524 .51417 L
.61429 .52535 L
.63333 .53549 L
.65238 .54463 L
.67143 .55284 L
.69048 .56017 L
.70952 .56669 L
.72857 .57245 L
.74762 .57752 L
.76667 .58195 L
.78571 .5858 L
.80476 .58913 L
.82381 .59199 L
.84286 .59443 L
.8619 .5965 L
.88095 .59824 L
.9 .59969 L
.91905 .60089 L
.9381 .60188 L
.95714 .60268 L
Mistroke
.97619 .60332 L
Mfstroke
[ .04 .02 ] 0 setdash
.02381 .01514 m
.04286 .02048 L
.0619 .03443 L
.08095 .05426 L
.1 .0777 L
.11905 .10293 L
.1381 .12848 L
.15714 .15321 L
.17619 .17627 L
.19524 .19704 L
.21429 .2151 L
.23333 .23019 L
.25238 .24222 L
.27143 .25118 L
.29048 .25715 L
.30952 .2603 L
.32857 .26083 L
.34762 .25897 L
.36667 .25499 L
.38571 .24916 L
.40476 .24175 L
.42381 .23303 L
.44286 .22325 L
.4619 .21267 L
.48095 .2015 L
.5 .18995 L
.51905 .17821 L
.5381 .16644 L
.55714 .15479 L
.57619 .14337 L
.59524 .13228 L
.61429 .12162 L
.63333 .11145 L
.65238 .10181 L
.67143 .09275 L
.69048 .08428 L
.70952 .07642 L
.72857 .06916 L
.74762 .06251 L
.76667 .05645 L
.78571 .05095 L
.80476 .046 L
.82381 .04156 L
.84286 .03761 L
.8619 .03412 L
.88095 .03104 L
.9 .02836 L
.91905 .02602 L
.9381 .02402 L
.95714 .0223 L
Mistroke
.97619 .02084 L
Mfstroke
[ .05 .01 .01 .01 ] 0 setdash
.02381 .01514 m
.04286 .01472 L
.0619 .01493 L
.08095 .01612 L
.1 .0185 L
.11905 .02216 L
.1381 .02716 L
.15714 .03345 L
.17619 .04097 L
.19524 .04959 L
.21429 .0592 L
.23333 .06964 L
.25238 .08075 L
.27143 .09238 L
.29048 .10437 L
.30952 .11657 L
.32857 .12886 L
.34762 .1411 L
.36667 .15318 L
.38571 .165 L
.40476 .17648 L
.42381 .18754 L
.44286 .19814 L
.4619 .20821 L
.48095 .21774 L
.5 .2267 L
.51905 .23506 L
.5381 .24284 L
.55714 .25003 L
.57619 .25665 L
.59524 .2627 L
.61429 .26821 L
.63333 .2732 L
.65238 .2777 L
.67143 .28173 L
.69048 .28533 L
.70952 .28852 L
.72857 .29134 L
.74762 .29382 L
.76667 .29598 L
.78571 .29786 L
.80476 .29948 L
.82381 .30087 L
.84286 .30206 L
.8619 .30306 L
.88095 .3039 L
.9 .3046 L
.91905 .30518 L
.9381 .30565 L
.95714 .30603 L
Mistroke
.97619 .30634 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001;Ool3
000_Ool5000_Ool3000`Ool3000_Ool30007Ool004aoo`03001oogoo02moo`04001oogoo000^Ool0
1@00Oomoogoo0000<7oo00<007ooOol0;Goo00D007ooOomoo`0000Ioo`00C7oo00<007ooOol0<7oo
00<007ooOol0<Woo00<007ooOol0:goo1@00<Woo00<007ooOol017oo001<Ool00`00Oomoo`0aOol0
0`00Oomoo`0_Ool2000^Ool01000Oomoo`00<goo00<007ooOol017oo001<Ool00`00Oomoo`0^Ool0
1@00Oomoogoo0000<Woo00<007ooOol0;7oo00<007oo0000;goo10001goo001;Ool2000`Ool01@00
Oomoogoo0000;Woo00D007ooOomoo`0002moo`8002moo`03001oogoo00Qoo`00C7oo00<007ooOol0
;goo0`00<7oo0`00<Goo00<007ooOol0;Goo1@001Woo000KOol00`00Oomoo`3oOol3Ool001]oo`03
001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001Aoool0
00d000006goo00@007ooOomoo`<000=oo`04001oogooOol;0005Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`080007Ool001]oo`03001oogoo00Aoo`03001oogoo00Uoo`<000Eoo`<00<ioo`@000Aoo`8000mo
o`006goo00<007ooOol01Goo00<007ooOol02goo0`001Goo00<007oo00000P00a7oo1@006Goo000K
Ool00`00Oomoo`0FOol20008Ool2002hOol30005Ool2000NOol001]oo`03001oogoo01Qoo`<000Mo
o`<00;1oo`D002Qoo`006goo00<007ooOol02Goo00<007ooOol03goo0P0027oo0P00Zgoo0`00;Goo
000KOol2000;Ool00`00Oomoo`0@Ool20008Ool2002SOol2000dOol001]oo`03001oogoo00]oo`03
001oogoo015oo`03001oogoo00Moo`03001oogoo09eoo`<003Ioo`006goo00<007ooOol037oo00<0
07ooOol04Goo0P002Woo0P00Ugoo1000>Goo000KOol00`00Oomoo`0<Ool00`00Oomoo`0COol00`00
Oomoo`09Ool00`00Oomoo`2AOol3000mOol001]oo`03001oogoo00eoo`03001oogoo01=oo`03001o
ogoo00]oo`8008Uoo`8004Aoo`006goo00<007ooOol03Woo00<007ooOol04goo00<007ooOol037oo
0P00Q7oo0`00AWoo000KOol00`00Oomoo`0?Ool00`00Oomoo`0COol2000>Ool20020Ool20019Ool0
01]oo`80015oo`03001oogoo01Aoo`03001oogoo00eoo`8007]oo`<004]oo`006goo00<007ooOol0
:7oo00<007ooOol03Woo00<007ooOol0Mgoo00<007ooOol0C7oo000KOol00`00Oomoo`0YOol00`00
Oomoo`0>Ool20036Ool001]oo`03001oogoo02Yoo`03001oogoo00moo`03001oogoo06ioo`8005=o
o`006goo00<007ooOol04goo00<007ooOol05Goo00<007ooOol0O7oo0`00EGoo000KOol00`00Oomo
o`0DOol00`00Oomoo`0EOol00`00Oomoo`0?Ool3001WOol2001HOol001]oo`03001oogoo01Eoo`03
001oogoo01Eoo`03001oogoo015oo`03001oogoo069oo`8005Yoo`006goo00<007ooOol05Woo00<0
07ooOol05Goo00<007ooOol04Woo00<007ooOol0Ggoo00<007ooOol0FWoo000KOol2000GOol00`00
Oomoo`0FOol2000COol2002lOol001]oo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo019o
o`8005Qoo`03001oogoo05moo`006goo00<007ooOol067oo00<007ooOol05goo00<007ooOol04goo
00<007ooOol0Dgoo0P00HWoo000KOol00`00Oomoo`0HOol00`00Oomoo`0HOol00`00Oomoo`0COol2
001@Ool3001TOol001]oo`03001oogoo01Uoo`03001oogoo01Qoo`03001oogoo01Aoo`8004aoo`80
06Moo`000Woo0P0017oo00<007ooOol00goo0P000Woo1@0017oo00<007ooOol0=Goo00<007ooOol0
5Goo00<007ooOol0B7oo00<007ooOol0Igoo00001Goo001oogoo000027oo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`0eOol00`00Oomoo`0FOol00`00Oomoo`16Ool00`00Oomoo`1XOol0
0005Ool007ooOol00008Ool01000Oomoo`000goo00<007ooOol017oo0P00=goo00<007ooOol05goo
00<007ooOol0[goo00001Goo001oogoo000027oo00@007ooOol000Aoo`03001oogoo00=oo`03001o
ogoo01eoo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo03ioo`03001oogoo06eoo`0000Eo
o`00Oomoo`0000Qoo`06001oogoo001oo`000goo00<007ooOol00Woo00<007ooOol07Goo00<007oo
Ool067oo00<007ooOol05goo00<007ooOol0?7oo00<007ooOol0KWoo00001Goo001oogoo000027oo
00H007ooOol007oo0003Ool00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`0HOol00`00Oomo
o`0IOol2000hOol2001aOol0009oo`8000Yoo`8000=oo`<000Eoo`03001oogoo01moo`03001oogoo
01Qoo`03001oogoo01Yoo`03001oogoo039oo`<007=oo`006goo00<007ooOol087oo00<007ooOol0
5goo00<007ooOol06goo0P00<7oo0P00MWoo000KOol00`00Oomoo`0QOol00`00Oomoo`0GOol00`00
Oomoo`0LOol2000]Ool00`00Oomoo`1fOol001]oo`03001oogoo029oo`03001oogoo01Moo`03001o
ogoo01eoo`03001oogoo0:=oo`006goo0P0097oo00<007ooOol05goo00<007ooOol07Goo0P00Xgoo
000KOol00`00Oomoo`0nOol00`00Oomoo`0NOol00`00Oomoo`0QOol2001mOol001]oo`03001oogoo
03moo`03001oogoo01ioo`03001oogoo01moo`03001oogoo07eoo`006goo00<007ooOol0?goo00<0
07ooOol087oo0`006goo0P00P7oo000KOol00`00Oomoo`0WOol00`00Oomoo`0FOol00`00Oomoo`0R
Ool00`00Oomoo`0FOol20022Ool001]oo`03001oogoo02Moo`03001oogoo01Moo`03001oogoo02=o
o`8001=oo`8008Aoo`006goo00<007ooOol0:7oo00<007ooOol05goo00<007ooOol097oo0P0047oo
00<007ooOol0Q7oo000KOol2000ZOol00`00Oomoo`0GOol00`00Oomoo`0UOol00`00Oomoo`2DOol0
01]oo`03001oogoo02Yoo`8001Qoo`03001oogoo02Eoo`8009Aoo`006goo00<007ooOol0;7oo00<0
07ooOol05Goo00<007ooOol09goo0P001Goo0`00RWoo000KOol00`00Oomoo`0]Ool00`00Oomoo`0E
Ool00`00Oomoo`0XOol00`00Oomoo`02002=Ool001]oo`03001oogoo02ioo`03001oogoo01Eoo`03
001oogoo02Qoo`<008ioo`006goo00<007ooOol0Agoo00<007ooOol09Woo0P000goo00<007ooOol0
RWoo000KOol00`00Oomoo`18Ool00`00Oomoo`0TOol00`00Oomoo`04Ool2002:Ool001]oo`03001o
ogoo039oo`8001Eoo`03001oogoo029oo`03001oogoo095oo`006goo0P00=Goo00<007ooOol04Woo
00<007ooOol0;Woo1000Q7oo000KOol00`00Oomoo`0eOol2000COol00`00Oomoo`0KOol2000DOol3
0021Ool001]oo`03001oogoo03Moo`80019oo`03001oogoo01Qoo`8001Uoo`8007moo`006goo00<0
07ooOol0>Goo00<007ooOol047oo00<007ooOol057oo0`007Goo0`00O7oo0002Ool20004Ool00`00
Oomoo`03Ool20004Ool30004Ool00`00Oomoo`0jOol00`00Oomoo`0@Ool00`00Oomoo`0AOol2000S
Ool00`00Oomoo`1iOol00005Ool007ooOol00008Ool01000Oomoo`0017oo00<007ooOol00goo00<0
07ooOol0>goo00<007ooOol047oo00<007ooOol03Woo0P00:7oo0P00Mgoo00001Goo001oogoo0000
27oo00D007ooOol007oo00D000Aoo`03001oogoo04ioo`03001oogoo03Yoo`03001oogoo07Aoo`00
00Eoo`00Oomoo`0000Qoo`06001oogoo001oo`000Woo00<007ooOol00goo0P00@Goo0`0037oo00<0
07ooOol017oo1@00<goo0P00LWoo00001Goo001oogoo000027oo00@007ooOol0009oo`03001oo`00
00Eoo`03001oogoo04=oo`D000Qoo`03001oo`0000<003Yoo`@006ioo`0000Eoo`00Oomoo`0000Qo
o`04001oogoo0003Ool20005Ool00`00Oomoo`18Ool30005Ool20012Ool3001[Ool0009oo`8000Yo
o`8000Eoo`03001oogoo00=oo`03001oogoo059oo`03001oogoo049oo`<006Qoo`006goo00<007oo
Ool0Dgoo00<007ooOol0A7oo00<007ooOol00P00Hgoo000KOol00`00Oomoo`1COol00`00Oomoo`19
Ool00`00Oomoo`02001NOol001]oo`03001oogoo05Aoo`03001oogoo04eoo`@005Yoo`006goo0P00
EWoo00<007ooOol0D7oo1@00EGoo000KOol00`00Oomoo`1FOol00`00Oomoo`1DOol30002Ool00`00
Oomoo`1=Ool001]oo`03001oogoo05Moo`03001oogoo05Uoo`80009oo`D004Ioo`006goo00<007oo
Ool0F7oo00<007ooOol0HGoo2000?Woo000KOol00`00Oomoo`1HOol00`00Oomoo`1YOol00`00Oomo
o`030002Ool5000aOol001]oo`03001oogoo05Uoo`03001oogoo07Eoo`T0009oo`@00003Ool00000
008001eoo`006goo00<007ooOol0FWoo00<007ooOol0R7oo2`0000=oo`0000001P002Goo000KOol0
0`00Oomoo`1KOol00`00Oomoo`2TOol001]oo`8005eoo`03001oogoo0:=oo`006goo00<007ooOol0
GGoo00<007ooOol0XWoo000KOol00`00Oomoo`1NOol00`00Oomoo`2QOol001]oo`03001oogoo05mo
o`03001oogoo0:1oo`006goo00<007ooOol0H7oo00<007ooOol0Wgoo000KOol00`00Oomoo`1QOol0
0`00Oomoo`2NOol001]oo`03001oogoo069oo`03001oogoo09eoo`006goo0P00Hgoo00<007ooOol0
WGoo000KOol00`00Oomoo`1SOol00`00Oomoo`2LOol001]oo`03001oogoo06Aoo`03001oogoo09]o
o`006goo00<007ooOol0IGoo00<007ooOol0VWoo000KOol00`00Oomoo`1VOol00`00Oomoo`2IOol0
009oo`8000Aoo`03001oogoo00=oo`8000=oo`<000Eoo`03001oogoo06Moo`03001oogoo09Qoo`00
00Eoo`00Oomoo`0000Qoo`06001oogoo001oo`000goo00<007ooOol00Woo00<007ooOol0J7oo00<0
07ooOol0Ugoo00001Goo001oogoo000027oo00H007ooOol007oo0003Ool00`00Oomoo`02Ool00`00
Oomoo`1YOol00`00Oomoo`2FOol00005Ool007ooOol00008Ool01@00Oomoo`00Ool010001Goo0P00
Jgoo00<007ooOol0UGoo00001Goo001oogoo000027oo00H007ooOol007oo0008Ool00`00Oomoo`1[
Ool00`00Oomoo`2DOol00005Ool007ooOol00008Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol0K7oo00<007ooOol0Tgoo0002Ool2000:Ool20004Ool20005Ool00`00Oomoo`1]Ool00`00
Oomoo`2BOol001]oo`03001oogoo06ioo`03001oogoo095oo`006goo00<007ooOol0Kgoo00<007oo
Ool0T7oo000KOol00`00Oomoo`1`Ool00`00Oomoo`2?Ool001]oo`80079oo`03001oogoo08ioo`00
6goo00<007ooOol0LWoo00<007ooOol0SGoo000KOol00`00Oomoo`1cOol00`00Oomoo`2<Ool001]o
o`03001oogoo07Aoo`03001oogoo08]oo`006goo00<007ooOol0MGoo00<007ooOol0RWoo000KOol0
0`00Oomoo`1fOol00`00Oomoo`29Ool001]oo`03001oogoo07Moo`03001oogoo08Qoo`006goo0P00
NGoo00<007ooOol0Qgoo000KOol00`00Oomoo`1iOol00`00Oomoo`26Ool001]oo`03001oogoo07Yo
o`03001oogoo08Eoo`006goo00<007ooOol0Ngoo0P00QGoo000KOol00`00Oomoo`1mOol00`00Oomo
o`22Ool001]oo`03001oogoo07ioo`80089oo`006goo00<007ooOol0P7oo00<007ooOol0Ogoo000K
Ool00`00Oomoo`21Ool2001oOol001]oo`8008Aoo`03001oogoo07aoo`006goo00<007ooOol0Q7oo
00<007ooOol0Ngoo000KOol00`00Oomoo`25Ool00`00Oomoo`1jOol001]oo`03001oogoo08Ioo`80
07Yoo`006goo00<007ooOol0R7oo0P00N7oo0002Ool20004Ool00`00Oomoo`03Ool20003Ool30005
Ool00`00Oomoo`2:Ool00`00Oomoo`1eOol00005Ool007ooOol00008Ool01P00Oomoo`00Ool000=o
o`03001oogoo009oo`03001oogoo08]oo`8007Eoo`0000Eoo`00Oomoo`0000Qoo`06001oogoo001o
o`000goo00<007ooOol00Woo0P00SWoo00<007ooOol0LWoo00001Goo001oogoo000027oo00@007oo
Ool0009oo`<000Eoo`03001oogoo08ioo`03001oogoo075oo`0000Eoo`00Oomoo`0000Qoo`06001o
ogoo001oo`000goo00<007ooOol00Woo00<007ooOol0Sgoo00<007ooOol0L7oo00001Goo001oogoo
000027oo00H007ooOol007oo0003Ool00`00Oomoo`02Ool00`00Oomoo`2@Ool2001`Ool0009oo`80
00Yoo`8000=oo`<000Eoo`03001oogoo099oo`8006ioo`006goo00<007ooOol0U7oo00<007ooOol0
Jgoo000KOol00`00Oomoo`2EOol2001[Ool001]oo`03001oogoo09Moo`<006Qoo`006goo0P00Vgoo
0P00IWoo000KOol00`00Oomoo`2LOol2001TOol001]oo`03001oogoo09ioo`03001oogoo065oo`00
6goo00<007ooOol0Wgoo0P00HGoo000KOol00`00Oomoo`2QOol3001NOol001]oo`03001oogoo0:Ao
o`8005aoo`006goo00<007ooOol0YWoo0`00FGoo000KOol2002ZOol2001GOol001]oo`03001oogoo
0:]oo`<005Aoo`006goo00<007ooOol0[Woo0P00DWoo000KOol00`00Oomoo`2`Ool3001?Ool001]o
o`03001oogoo0;=oo`@004]oo`006goo00<007ooOol0]goo1@00AWoo000KOol00`00Oomoo`2lOol5
0011Ool001]oo`03001oogoo0<5oo`D003aoo`006goo0P00agoo1@00=goo000KOol00`00Oomoo`3;
Ool6000aOol001]oo`03001oogoo0=5oo`D002aoo`006goo00<007ooOol0eWoo3`007Goo0008Ool2
0004Ool00`00Oomoo`02Ool30005Ool00`00Oomoo`3UOol?000>Ool000Moo`04001oogoo0009Ool0
0`00Oomoo`04Ool00`00Oomoo`3dOol70007Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool0
0`00Oomoo`3oOol3Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool2003oOol4Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol3Ool000Moo`04001oogoo0008Ool2003o
Ool<Ool000Qoo`8000Yoo`03001oogoo0?moo`Yoo`00ogoo8Goo003oOolQOol008Aoo`<001]oo`<0
07]oo`00QGoo00<007ooOol06goo00<007ooOol0NWoo001cOol30004Ool20003Ool30003Ool30008
Ool30002Ool00`00Ool000020002Ool40003Ool30003Ool30002Ool300000goo000000040003Ool3
001ROol007=oo`04001oogoo0002Ool01P00Oomoo`00Ool000Ioo`04001oogoo0008Ool01P00Oomo
o`00Ool000Uoo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00goo
00<007oo0000IGoo001fOol01000Oomoo`0017oo1@000Woo00@007ooOol000Qoo`03001oo`00009o
o`D0009oo`<000=oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo00<0009oo`D0
065oo`00M7oo0P000goo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo0008Ool30002
Ool01`00Oomoogoo001oo`0000Ioo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oo`00
00Eoo`05001oogooOol0001QOol007=oo`03001oogoo009oo`@000=oo`<0009oo`@000Uoo`04001o
ogoo0002Ool30003Ool400000goo000000020003Ool30002Ool40003Ool40002Ool3001ROol007=o
o`04001oogoo0002Ool00`00Oomoo`0EOol01000Oomoo`00Rgoo001dOol30002Ool00`00Oomoo`0D
Ool4002<Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.539323, -0.00816133, 
  0.0197364, 0.000674244}},
  CellTags->"11.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["11.2 Rational Polynomial Approximations", "Subsection",
  CellTags->"11.2"],

Cell[TextData[{
  "Another approach to obtaining the linear time\[Hyphen]invariant (LTI)  \
approximation to a nonlinear system involves the approximation of a nonlinear \
transfer function by a polynomial ratio. Corresponding functions are provided \
with standard ",
  StyleBox["Mathematica", "TI"],
  " packages and represent Pad\[EAcute], economized rational, general \
rational, and minimax approximations. The first two are in the context ",
  StyleBox["Calculus`Pade`", "MR"],
  ", and the others are in ",
  StyleBox["NumericalMath`Approximations`", "MR"],
  ". Note that the built\[Hyphen]in function ",
  StyleBox["InterpolatingPolynomial", "MR"],
  " may be useful for some approximations, too.     "
}], "Text",
  CellTags->"11.2"],

Cell["\<\
Here is the transfer function describing some ideal heat exchanger. \
\
\>", "MathCaption",
  CellTags->"11.2"],

Cell[CellGroupData[{

Cell["h = 1/((10s+1)(50s+1))", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"11.2"],

Cell[BoxData[
    \(1\/\(\((1 + 10\ s)\)\ \((1 + 50\ s)\)\)\)], "Output",
  CellLabel->"Out[14]= ",
  CellTags->"11.2"]
}, Open  ]],

Cell[TextData[{
  "The temperature sensor for the exchanger is located so that its reading is \
delayed a few seconds, which introduces the ",
  StyleBox["delay", "MR"],
  " term. "
}], "MathCaption",
  CellTags->"11.2"],

Cell[CellGroupData[{

Cell["delay = Exp[-a s]", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"11.2"],

Cell[BoxData[
    \(E\^\(\(-a\)\ s\)\)], "Output",
  CellLabel->"Out[15]= ",
  CellTags->"11.2"]
}, Open  ]],

Cell["This loads the necessary package. ", "MathCaption",
  CellTags->"11.2"],

Cell["Needs[\"Calculus`Pade`\"]", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"11.2"],

Cell[TextData[{
  "We use the Pad\[EAcute] approximation to represent the delay as a \
polynomial ratio of the order ",
  Cell[BoxData[
      \(TraditionalForm\`2/2\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ". "
}], "MathCaption",
  CellTags->"11.2"],

Cell[CellGroupData[{

Cell["Pade[delay, {s, 0, 2, 2}]", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"11.2"],

Cell[BoxData[
    \(\(1 - \(a\ s\)\/2 + \(a\^2\ s\^2\)\/12\)\/\(1 + \(a\ s\)\/2 + 
        \(a\^2\ s\^2\)\/12\)\)], "Output",
  CellLabel->"Out[17]= ",
  CellTags->"11.2"]
}, Open  ]],

Cell[TextData[{
  "This generates an object suitable for analysis with ",
  StyleBox["Control System Professional", "TI"],
  ". "
}], "MathCaption",
  CellTags->"11.2"],

Cell[CellGroupData[{

Cell["TransferFunction[s, % h]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"11.2"],

Cell[BoxData[
    \(TransferFunction[
      s, {{\(1 - \(a\ s\)\/2 + \(a\^2\ s\^2\)\/12\)\/\(\((1 + 10\ s)\)\ 
              \((1 + 50\ s)\)\ \((1 + \(a\ s\)\/2 + \(a\^2\ s\^2\)\/12)\)\)}}]
      \)], "Output",
  CellLabel->"Out[18]= ",
  CellTags->"11.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
ScreenStyleEnvironment->"Working",
WindowSize->{500, 300},
WindowMargins->{{2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "Manual.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "11.0"->{
    Cell[1739, 51, 68, 1, 68, "Section",
      CellTags->"11.0"],
    Cell[1810, 54, 507, 9, 94, "Text",
      CellTags->"11.0"]},
  "11.1"->{
    Cell[2342, 67, 87, 1, 56, "Subsection",
      CellTags->"11.1"],
    Cell[2432, 70, 91, 1, 30, "Text",
      CellTags->"11.1"],
    Cell[2526, 73, 1060, 33, 45, "DisplayFormula",
      CellTags->"11.1"],
    Cell[3589, 108, 77, 1, 30, "Text",
      CellTags->"11.1"],
    Cell[3669, 111, 1420, 43, 53, "DisplayFormula",
      CellTags->"11.1"],
    Cell[5092, 156, 623, 24, 30, "Text",
      CellTags->"11.1"],
    Cell[5718, 182, 1345, 40, 69, "DisplayFormula",
      CellTags->"11.1"],
    Cell[7066, 224, 1368, 49, 62, "Text",
      CellTags->"11.1"],
    Cell[8437, 275, 2682, 74, 151, "DisplayFormula",
      CellTags->"11.1"],
    Cell[11122, 351, 353, 12, 30, "Text",
      CellTags->"11.1"],
    Cell[11478, 365, 806, 24, 79, "DisplayFormula",
      CellTags->"11.1"],
    Cell[12287, 391, 192, 7, 30, "Text",
      CellTags->"11.1"],
    Cell[12482, 400, 1978, 50, 135, "DisplayFormula",
      CellTags->"11.1"],
    Cell[14463, 452, 143, 5, 31, "Text",
      CellTags->"11.1"],
    Cell[14609, 459, 1346, 43, 38, "TopSpanBox",
      CellTags->"11.1"],
    Cell[15958, 504, 758, 20, 50, "MiddleBox",
      CellTags->"11.1"],
    Cell[16719, 526, 2843, 79, 43, "MiddleSpanBox",
      CellTags->"11.1"],
    Cell[19565, 607, 1088, 29, 62, "MiddleBox",
      CellTags->"11.1"],
    Cell[20656, 638, 2960, 83, 43, "MiddleSpanBox",
      CellTags->"11.1"],
    Cell[23619, 723, 334, 10, 36, "BottomBox",
      CellTags->"11.1"],
    Cell[23956, 735, 60, 1, 14, "Caption",
      CellTags->"11.1"],
    Cell[24019, 738, 2103, 64, 179, "Text",
      CellTags->"11.1"],
    Cell[26125, 804, 220528, 4104, 200, 199698, 3842, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"11.1"],
    Cell[246656, 4910, 140, 5, 15, "Caption",
      CellTags->"11.1"],
    Cell[246799, 4917, 65, 1, 28, "MathCaption",
      CellTags->"11.1"],
    Cell[246867, 4920, 78, 2, 27, "Input",
      CellTags->"11.1"],
    Cell[246948, 4924, 769, 27, 44, "MathCaption",
      CellTags->"11.1"],
    Cell[247742, 4955, 118, 8, 87, "Input",
      CellTags->"11.1"],
    Cell[247863, 4965, 126, 3, 45, "Output",
      CellTags->"11.1"],
    Cell[248004, 4971, 201, 5, 43, "MathCaption",
      CellTags->"11.1"],
    Cell[248230, 4980, 68, 2, 27, "Input",
      CellTags->"11.1"],
    Cell[248301, 4984, 81, 3, 26, "Output",
      CellTags->"11.1"],
    Cell[248397, 4990, 711, 27, 58, "MathCaption",
      CellTags->"11.1"],
    Cell[249133, 5021, 136, 7, 72, "Input",
      CellTags->"11.1"],
    Cell[249272, 5030, 228, 5, 79, "Output",
      CellTags->"11.1"],
    Cell[249515, 5038, 120, 2, 28, "MathCaption",
      CellTags->"11.1"],
    Cell[249660, 5044, 130, 7, 72, "Input",
      CellTags->"11.1"],
    Cell[249793, 5053, 248, 5, 79, "Output",
      CellTags->"11.1"],
    Cell[250056, 5061, 341, 9, 61, "MathCaption",
      CellTags->"11.1"],
    Cell[250422, 5074, 117, 8, 87, "Input",
      CellTags->"11.1"],
    Cell[250542, 5084, 140, 4, 32, "Output",
      CellTags->"11.1"],
    Cell[250697, 5091, 112, 2, 28, "MathCaption",
      CellTags->"11.1"],
    Cell[250834, 5097, 78, 2, 27, "Input",
      CellTags->"11.1"],
    Cell[250915, 5101, 222, 5, 82, "Output",
      CellTags->"11.1"],
    Cell[251152, 5109, 126, 5, 29, "MathCaption",
      CellTags->"11.1"],
    Cell[251303, 5118, 75, 2, 27, "Input",
      CellTags->"11.1"],
    Cell[251381, 5122, 1165, 36, 159, "Output",
      CellTags->"11.1"],
    Cell[252561, 5161, 255, 10, 43, "MathCaption",
      CellTags->"11.1"],
    Cell[252841, 5175, 100, 2, 27, "Input",
      CellTags->"11.1"],
    Cell[252944, 5179, 324, 7, 113, "Output",
      CellTags->"11.1"],
    Cell[253283, 5189, 97, 1, 28, "MathCaption",
      CellTags->"11.1"],
    Cell[253405, 5194, 92, 2, 27, "Input",
      CellTags->"11.1"],
    Cell[253500, 5198, 720, 14, 196, "Output",
      CellTags->"11.1"],
    Cell[254235, 5215, 140, 4, 42, "MathCaption",
      CellTags->"11.1"],
    Cell[254400, 5223, 181, 9, 114, "Input",
      CellTags->"11.1"],
    Cell[254584, 5234, 258, 6, 53, "Output",
      CellTags->"11.1"],
    Cell[254857, 5243, 414, 11, 68, "MathCaption",
      CellTags->"11.1"],
    Cell[255296, 5258, 95, 2, 39, "Input",
      CellTags->"11.1"],
    Cell[255394, 5262, 302, 6, 68, "Output",
      CellTags->"11.1"],
    Cell[255711, 5271, 538, 11, 84, "MathCaption",
      CellTags->"11.1"],
    Cell[256274, 5286, 251, 12, 147, "Input",
      CellTags->"11.1"],
    Cell[256528, 5300, 17823, 568, 186, 6554, 423, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"11.1"]},
  "11.2"->{
    Cell[274400, 5874, 81, 1, 68, "Subsection",
      CellTags->"11.2"],
    Cell[274484, 5877, 743, 15, 142, "Text",
      CellTags->"11.2"],
    Cell[275230, 5894, 121, 4, 40, "MathCaption",
      CellTags->"11.2"],
    Cell[275376, 5902, 85, 2, 39, "Input",
      CellTags->"11.2"],
    Cell[275464, 5906, 119, 3, 56, "Output",
      CellTags->"11.2"],
    Cell[275598, 5912, 220, 6, 55, "MathCaption",
      CellTags->"11.2"],
    Cell[275843, 5922, 80, 2, 39, "Input",
      CellTags->"11.2"],
    Cell[275926, 5926, 96, 3, 38, "Output",
      CellTags->"11.2"],
    Cell[276037, 5932, 77, 1, 41, "MathCaption",
      CellTags->"11.2"],
    Cell[276117, 5935, 88, 2, 39, "Input",
      CellTags->"11.2"],
    Cell[276208, 5939, 256, 8, 56, "MathCaption",
      CellTags->"11.2"],
    Cell[276489, 5951, 88, 2, 39, "Input",
      CellTags->"11.2"],
    Cell[276580, 5955, 171, 4, 76, "Output",
      CellTags->"11.2"],
    Cell[276766, 5962, 168, 5, 41, "MathCaption",
      CellTags->"11.2"],
    Cell[276959, 5971, 87, 2, 39, "Input",
      CellTags->"11.2"],
    Cell[277049, 5975, 256, 6, 76, "Output",
      CellTags->"11.2"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"11.0", 278201, 6008},
  {"11.1", 278344, 6013},
  {"11.2", 282923, 6141}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 68, 1, 68, "Section",
  CellTags->"11.0"],
Cell[1810, 54, 507, 9, 94, "Text",
  CellTags->"11.0"],

Cell[CellGroupData[{
Cell[2342, 67, 87, 1, 56, "Subsection",
  CellTags->"11.1"],
Cell[2432, 70, 91, 1, 30, "Text",
  CellTags->"11.1"],
Cell[2526, 73, 1060, 33, 45, "DisplayFormula",
  CellTags->"11.1"],
Cell[3589, 108, 77, 1, 30, "Text",
  CellTags->"11.1"],
Cell[3669, 111, 1420, 43, 53, "DisplayFormula",
  CellTags->"11.1"],
Cell[5092, 156, 623, 24, 30, "Text",
  CellTags->"11.1"],
Cell[5718, 182, 1345, 40, 69, "DisplayFormula",
  CellTags->"11.1"],
Cell[7066, 224, 1368, 49, 62, "Text",
  CellTags->"11.1"],
Cell[8437, 275, 2682, 74, 151, "DisplayFormula",
  CellTags->"11.1"],
Cell[11122, 351, 353, 12, 30, "Text",
  CellTags->"11.1"],
Cell[11478, 365, 806, 24, 79, "DisplayFormula",
  CellTags->"11.1"],
Cell[12287, 391, 192, 7, 30, "Text",
  CellTags->"11.1"],
Cell[12482, 400, 1978, 50, 135, "DisplayFormula",
  CellTags->"11.1"],
Cell[14463, 452, 143, 5, 31, "Text",
  CellTags->"11.1"],
Cell[14609, 459, 1346, 43, 38, "TopSpanBox",
  CellTags->"11.1"],
Cell[15958, 504, 758, 20, 50, "MiddleBox",
  CellTags->"11.1"],
Cell[16719, 526, 2843, 79, 43, "MiddleSpanBox",
  CellTags->"11.1"],
Cell[19565, 607, 1088, 29, 62, "MiddleBox",
  CellTags->"11.1"],
Cell[20656, 638, 2960, 83, 43, "MiddleSpanBox",
  CellTags->"11.1"],
Cell[23619, 723, 334, 10, 36, "BottomBox",
  CellTags->"11.1"],
Cell[23956, 735, 60, 1, 14, "Caption",
  CellTags->"11.1"],
Cell[24019, 738, 2103, 64, 179, "Text",
  CellTags->"11.1"],
Cell[26125, 804, 220528, 4104, 200, 199698, 3842, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"11.1"],
Cell[246656, 4910, 140, 5, 15, "Caption",
  CellTags->"11.1"],
Cell[246799, 4917, 65, 1, 28, "MathCaption",
  CellTags->"11.1"],
Cell[246867, 4920, 78, 2, 27, "Input",
  CellTags->"11.1"],
Cell[246948, 4924, 769, 27, 44, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[247742, 4955, 118, 8, 87, "Input",
  CellTags->"11.1"],
Cell[247863, 4965, 126, 3, 45, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[248004, 4971, 201, 5, 43, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[248230, 4980, 68, 2, 27, "Input",
  CellTags->"11.1"],
Cell[248301, 4984, 81, 3, 26, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[248397, 4990, 711, 27, 58, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[249133, 5021, 136, 7, 72, "Input",
  CellTags->"11.1"],
Cell[249272, 5030, 228, 5, 79, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[249515, 5038, 120, 2, 28, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[249660, 5044, 130, 7, 72, "Input",
  CellTags->"11.1"],
Cell[249793, 5053, 248, 5, 79, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[250056, 5061, 341, 9, 61, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[250422, 5074, 117, 8, 87, "Input",
  CellTags->"11.1"],
Cell[250542, 5084, 140, 4, 32, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[250697, 5091, 112, 2, 28, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[250834, 5097, 78, 2, 27, "Input",
  CellTags->"11.1"],
Cell[250915, 5101, 222, 5, 82, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[251152, 5109, 126, 5, 29, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[251303, 5118, 75, 2, 27, "Input",
  CellTags->"11.1"],
Cell[251381, 5122, 1165, 36, 159, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[252561, 5161, 255, 10, 43, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[252841, 5175, 100, 2, 27, "Input",
  CellTags->"11.1"],
Cell[252944, 5179, 324, 7, 113, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[253283, 5189, 97, 1, 28, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[253405, 5194, 92, 2, 27, "Input",
  CellTags->"11.1"],
Cell[253500, 5198, 720, 14, 196, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[254235, 5215, 140, 4, 42, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[254400, 5223, 181, 9, 114, "Input",
  CellTags->"11.1"],
Cell[254584, 5234, 258, 6, 53, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[254857, 5243, 414, 11, 68, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[255296, 5258, 95, 2, 39, "Input",
  CellTags->"11.1"],
Cell[255394, 5262, 302, 6, 68, "Output",
  CellTags->"11.1"]
}, Open  ]],
Cell[255711, 5271, 538, 11, 84, "MathCaption",
  CellTags->"11.1"],

Cell[CellGroupData[{
Cell[256274, 5286, 251, 12, 147, "Input",
  CellTags->"11.1"],
Cell[256528, 5300, 17823, 568, 186, 6554, 423, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"11.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[274400, 5874, 81, 1, 68, "Subsection",
  CellTags->"11.2"],
Cell[274484, 5877, 743, 15, 142, "Text",
  CellTags->"11.2"],
Cell[275230, 5894, 121, 4, 40, "MathCaption",
  CellTags->"11.2"],

Cell[CellGroupData[{
Cell[275376, 5902, 85, 2, 39, "Input",
  CellTags->"11.2"],
Cell[275464, 5906, 119, 3, 56, "Output",
  CellTags->"11.2"]
}, Open  ]],
Cell[275598, 5912, 220, 6, 55, "MathCaption",
  CellTags->"11.2"],

Cell[CellGroupData[{
Cell[275843, 5922, 80, 2, 39, "Input",
  CellTags->"11.2"],
Cell[275926, 5926, 96, 3, 38, "Output",
  CellTags->"11.2"]
}, Open  ]],
Cell[276037, 5932, 77, 1, 41, "MathCaption",
  CellTags->"11.2"],
Cell[276117, 5935, 88, 2, 39, "Input",
  CellTags->"11.2"],
Cell[276208, 5939, 256, 8, 56, "MathCaption",
  CellTags->"11.2"],

Cell[CellGroupData[{
Cell[276489, 5951, 88, 2, 39, "Input",
  CellTags->"11.2"],
Cell[276580, 5955, 171, 4, 76, "Output",
  CellTags->"11.2"]
}, Open  ]],
Cell[276766, 5962, 168, 5, 41, "MathCaption",
  CellTags->"11.2"],

Cell[CellGroupData[{
Cell[276959, 5971, 87, 2, 39, "Input",
  CellTags->"11.2"],
Cell[277049, 5975, 256, 6, 76, "Output",
  CellTags->"11.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

