(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    407640,      10422]*)
(*NotebookOutlinePosition[    417115,      10699]*)
(*  CellTagsIndexPosition[    416880,      10687]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["12. Miscellaneous", "Section",
  CellTags->"12.0"],

Cell[TextData[{
  "This chapter covers several mathematical and utility functions. The \
functions ",
  StyleBox["SchurDecompositionOrdered", "MR"],
  ", ",
  StyleBox["LyapunovSolve", "MR"],
  ", ",
  StyleBox["Rank", "MR"],
  ", and ",
  StyleBox["DisplayTogetherGraphicsArray", "MR"],
  " are included with ",
  StyleBox["Control System Professional", "TI"],
  " but are useful well outside its scope. Other utility functions include \
the means to determine the structure of systems (",
  StyleBox["CountInputs", "MR"],
  ", ",
  StyleBox["CountOutputs", "MR"],
  ", and ",
  StyleBox["CountStates", "MR"],
  ") and to check on the structural consistency (",
  StyleBox["ConsistentQ", "MR"],
  "). Also described is the function to create systems with random elements \
(",
  StyleBox["RandomSystem", "MR"],
  "). "
}], "Text",
  CellTags->"12.0"],

Cell[CellGroupData[{

Cell["12.1 Ordered Schur Decomposition", "Subsection",
  CellTags->"12.1"],

Cell[TextData[{
  "The function ",
  StyleBox["SchurDecompositionOrdered", "MR"],
  " is an extension to the built\[Hyphen]in function ",
  StyleBox["SchurDecomposition", "MR"],
  "; it shares the same syntax and accepts the same options, with certain \
extensions and exceptions. \nSimilar to the Schur decomposition, the purpose \
of the ordered Schur decomposition of matrix ",
  StyleBox["m", "MR"],
  " is to find a unitary matrix ",
  StyleBox["q", "MR"],
  " and triangular matrix ",
  StyleBox["t", "MR"],
  ", such that ",
  StyleBox["q.t.Conjugate[Transpose[q]]", "MR"],
  " gives ",
  StyleBox["m", "MR"],
  ", with matrix ",
  StyleBox["t", "MR"],
  " being such that the eigenvalues of ",
  StyleBox["m", "MR"],
  "  appear on the main diagonal of ",
  StyleBox["t", "MR"],
  ". In addition, the ordered Schur decomposition makes the eigenvalues \
appear on the diagonal in the prescribed order. The guidelines for selecting \
the ordering function in ",
  StyleBox["SchurDecompositionOrdered", "MR"],
  " are the same as those for the built\[Hyphen]in function ",
  StyleBox["Sort", "MR"],
  ". "
}], "Text",
  CellTags->"12.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["SchurDecompositionOrdered",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["m",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"12.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Schur",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["decomposition",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["which",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["eigenvalues",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["m",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["appear",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["on",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["diagonal",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["canonical",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["order",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"12.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["SchurDecompositionOrdered",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["m",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["pred",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"12.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["use",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["function",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["pred",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["determine",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["whether",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["pairs",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["eigenvalues",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["are",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["order",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"12.1"],

Cell["Ordered Schur decomposition. ", "Caption",
  CellTags->"12.1"],

Cell["Load the application. ", "MathCaption",
  CellTags->"12.1"],

Cell["<<ControlSystems`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"12.1"],

Cell[TextData[{
  "Here is a ",
  Cell[BoxData[
      \(TraditionalForm\`3\[Cross]3\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " matrix with random elements. "
}], "MathCaption",
  CellTags->"12.1"],

Cell[CellGroupData[{

Cell["m = Table[Random[], {3}, {3}]", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"12.1"],

Cell[BoxData[
    \({{0.786598577984162083`, 0.84833947833540968`, 0.612827312044955441`}, {
        0.398037596516517133`, 0.238011825115338071`, 
        0.517231567102455613`}, {0.238887398864559807`, 
        0.194398677011978158`, 0.893263035578304709`}}\)], "Output",
  CellLabel->"Out[2]= ",
  CellTags->"12.1"]
}, Open  ]],

Cell[TextData[{
  "This finds its Schur decomposition using the built\[Hyphen]in ",
  StyleBox["Mathematica", "TI"],
  " function. "
}], "MathCaption",
  CellTags->"12.1"],

Cell["{q, t} = SchurDecomposition[m];", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"12.1"],

Cell["\<\
The eigenvalues on the main diagonal do not follow any particular \
order. \
\>", "MathCaption",
  CellTags->"12.1"],

Cell[CellGroupData[{

Cell["t//MatrixForm", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"12.1"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1.54149636555318103`", "0.42521915053488879`", 
              "0.422634401187195685`"},
            {"0", \(-0.124460332496154002`\), "0.295622656971173505`"},
            {"0", "0", "0.500837405620777786`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[4]//MatrixForm= ",
  CellTags->"12.1"]
}, Open  ]],

Cell[TextData[{
  "This finds the ordered Schur decomposition of matrix ",
  StyleBox["m", "MR"],
  " using the ",
  StyleBox["Control System Professional", "TI"],
  " function. "
}], "MathCaption",
  CellTags->"12.1"],

Cell["{qo, to} = SchurDecompositionOrdered[m];", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"12.1"],

Cell["Now the diagonal elements appear in canonical order. ", "MathCaption",
  CellTags->"12.1"],

Cell[CellGroupData[{

Cell["to//Chop//MatrixForm", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"12.1"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(-0.124460332496154046`\), "0.343931464352355886`", 
              \(-0.309218875484861221`\)},
            {"0", "0.500837405620777964`", \(-0.482616569582407262`\)},
            {"0", "0", "1.5414963655531821`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[6]//MatrixForm= ",
  CellTags->"12.1"]
}, Open  ]],

Cell["The decomposition is still valid. ", "MathCaption",
  CellTags->"12.1"],

Cell[CellGroupData[{

Cell["qo.to.Conjugate[Transpose[qo]] - m //Chop//MatrixForm", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"12.1"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0"},
            {"0", "0", "0"},
            {"0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[7]//MatrixForm= ",
  CellTags->"12.1"]
}, Open  ]],

Cell["\<\
This is the ordered Schur decomposition in which the eigenvalues \
residing in the right half of the complex plane go first. \
\>", "MathCaption",\

  CellTags->"12.1"],

Cell["{qo, to} = SchurDecompositionOrdered[m, Re[#]>0&];", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"12.1"],

Cell[TextData[{
  "This is corresponding matrix ",
  StyleBox["t", "MR"],
  ". "
}], "MathCaption",
  CellTags->"12.1"],

Cell[CellGroupData[{

Cell["to//Chop//MatrixForm", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"12.1"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1.54149636555318103`", "0.5638293274931506`", 
              "0.203783346981772295`"},
            {"0", "0.500837405620777786`", \(-0.295622656971173505`\)},
            {"0", "0", \(-0.124460332496154002`\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[9]//MatrixForm= ",
  CellTags->"12.1"]
}, Open  ]],

Cell[TextData[{
  "As yet another example, this sorts the eigenvalues in descending order of \
their real parts. For this particular matrix ",
  StyleBox["m", "MR"],
  ", the result is the same as the previous one. "
}], "MathCaption",
  CellTags->"12.1"],

Cell["\<\
{qo, to} = SchurDecompositionOrdered[m,
 Re[#2]<Re[#1]&];\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"12.1"],

Cell[CellGroupData[{

Cell["to//Chop//MatrixForm", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"12.1"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1.54149636555318103`", "0.5638293274931506`", 
              "0.203783346981772295`"},
            {"0", "0.500837405620777786`", \(-0.295622656971173505`\)},
            {"0", "0", \(-0.124460332496154002`\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[11]//MatrixForm= ",
  CellTags->"12.1"]
}, Open  ]],

Cell[TextData[{
  "The function ",
  StyleBox["SchurDecompositionOrdered", "MR"],
  " accepts the option ",
  StyleBox["Pivoting", "MR"],
  ", just as ",
  StyleBox["SchurDecomposition", "MR"],
  " does. However, the option ",
  StyleBox["RealBlockForm", "MR"],
  " in ",
  StyleBox["SchurDecompositionOrdered", "MR"],
  " currently accepts only the default value ",
  StyleBox["False", "MR"],
  ". "
}], "Text",
  CellTags->"12.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["RealBlockForm",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["False",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(whether\ complex\ eigenvalues\ of\ the\ real\ input\ matrix\ 
                should\ be\ returned\ as\ real\ blocks\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.25, 0.23, 0.52},
  RowLines->{True, False}},
  CellTags->"12.1"],

Cell[TextData[{
  "Option value specific to ",
  StyleBox["SchurDecompositionOrdered", "MR"],
  ". "
}], "Caption",
  CellTags->"12.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["12.2 Lyapunov Equations", "Subsection",
  CellTags->"12.2"],

Cell[TextData[{
  "The function ",
  StyleBox["LyapunovSolve", "MR"],
  " attempts to find the solution ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"X\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " to the ",
  StyleBox["Lyapunov equation", "TI"],
  " "
}], "Text",
  CellTags->"12.2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"X\"\>",
          "TB"], 
        StyleBox["\<\"A\"\>",
          "TB"], "+", 
        StyleBox["\<\"B\"\>",
          "TB"], 
        StyleBox["\<\"X\"\>",
          "TB"], "=", 
        StyleBox["\<\"C\"\>",
          "TB"]}], TraditionalForm]], "DisplayFormula",
  CellTags->"12.2"],

Cell[TextData[{
  "a special class of linear matrix equations that occurs in many branches of \
control theory, such as stability analysis, optimal control, and response of \
a linear system to white noise (see, ",
  StyleBox["e.g.", "TI"],
  ", Brogan (1991)). Typically, ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " are square matrices with dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`m\[Cross]m\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Cross]n\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ". To be consistent, matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"X\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " should have dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Cross]m\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ". An important particular case of the Lyapunov equation, "
}], "Text",
  CellTags->"12.2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          StyleBox["\<\"A\"\>",
            "TB"], "T"], 
        StyleBox["\<\"X\"\>",
          "TB"], "+", 
        StyleBox["\<\"X\"\>",
          "TB"], 
        StyleBox["\<\"A\"\>",
          "TB"], "=", 
        StyleBox["\<\"C\"\>",
          "TB"]}], TraditionalForm]], "DisplayFormula",
  CellTags->"12.2"],

Cell[TextData[{
  "involves only matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", in which case all matrices are square with the same dimensions. \nFor \
discrete\[Hyphen]time systems, the ",
  StyleBox["discrete Lyapunov equation", "TI"],
  ", "
}], "Text",
  CellTags->"12.2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"X\"\>",
          "TB"], "=", 
        StyleBox["\<\"A\"\>",
          "TB"], 
        StyleBox["\<\"X\"\>",
          "TB"], 
        SuperscriptBox[
          StyleBox["\<\"A\"\>",
            "TB"], "T"], "+", 
        StyleBox["\<\"C\"\>",
          "TB"]}], TraditionalForm]], "DisplayFormula",
  CellTags->"12.2"],

Cell[TextData[{
  "arises (see, ",
  StyleBox["e.g.", "TI"],
  ", Franklin ",
  StyleBox["et al.", "TI"],
  " (1990)). The solution can be found with ",
  StyleBox["DiscreteLyapunovSolve", "MR"],
  ". "
}], "Text",
  CellTags->"12.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["LyapunovSolve",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["a",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["c",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], 
            
            StyleBox[
              \(solve\ the\ matrix\ Lyapunov\ equation\ x . a + 
                  Transpose[a] . x == c\ for\ matrix\ x\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "TopBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.35, 0.58}},
  CellTags->"12.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["LyapunovSolve",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["a",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["b",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["c",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[\(solve\ the\ Lyapunov\ equation\ x . a + b . x == c\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.35, 0.58}},
  CellTags->"12.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["DiscreteLyapunovSolve",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["a",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["c",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"12.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(solve\ the\ discrete\ Lyapunov\ equation\ x == 
                a . x . Transpose[a] + c\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.35, 0.58}},
  CellTags->"12.2"],

Cell["Functions for solving Lyapunov equations. ", "Caption",
  CellTags->"12.2"],

Cell[TextData[{
  "Here is some matrix ",
  StyleBox["a", "MR"],
  ". "
}], "MathCaption",
  CellTags->"12.2"],

Cell["a = {{1/2, 1}, {-1, -1}};", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"12.2"],

Cell[TextData[{
  "Here is matrix ",
  StyleBox["c", "MR"],
  ". "
}], "MathCaption",
  CellTags->"12.2"],

Cell["c = {{q1, 0}, {0, q2}};", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"12.2"],

Cell["\<\
This solves the discrete Lyapunov equation and simplifies the \
result. \
\>", "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{

Cell["DiscreteLyapunovSolve[a, c] //Simplify", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"12.2"],

Cell[BoxData[
    \({{2\ q1 + \(3\ q2\)\/2, \(-q1\) - \(5\ q2\)\/4}, {
        \(-q1\) - \(5\ q2\)\/4, \(3\ q1\)\/2 + \(19\ q2\)\/8}}\)], "Output",
  CellLabel->"Out[14]= ",
  CellTags->"12.2"]
}, Open  ]],

Cell["\<\
We may verify that the solution indeed satisfies the discrete \
Lyapunov equation. \
\>", "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{

Cell["a.%.Transpose[a] + c == % //Simplify", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"12.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[15]= ",
  CellTags->"12.2"]
}, Open  ]],

Cell[TextData[{
  "Consider now an example of design of a feedback controller that uses \
Lyapunov's method to approximate the minimum\[Hyphen]time response system for \
a given system (see Brogan (1991), Section\[NonBreakingSpace]10.8). The \
method is applicable to systems stable at least in Lyapunov's sense. To find \
the Lyapunov function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"V", 
          RowBox[{"(", 
            StyleBox["\<\"x\"\>",
              "TB"], ")"}], "="}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["\<\"x\"\>",
              "TB"], "T"], 
          StyleBox["\<\"P\"\>",
            "TB"], 
          StyleBox["\<\"x\"\>",
            "TB"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", we will first solve the Lyapunov equation, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["\<\"A\"\>",
              "TB"], "T"], 
          StyleBox["\<\"P\"\>",
            "TB"], "+", 
          StyleBox["\<\"P\"\>",
            "TB"], 
          StyleBox["\<\"A\"\>",
            "TB"], "=", "-", 
          StyleBox["\<\"Q\"\>",
            "TB"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", where ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"Q\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " is the identity matrix with proper dimensions. Knowing ",
  Cell[BoxData[
      FormBox[
        RowBox[{"V", 
          RowBox[{"(", 
            StyleBox["\<\"x\"\>",
              "TB"], ")"}]}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", one can find ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V\& . \), 
          RowBox[{"(", 
            StyleBox["\<\"x\"\>",
              "TB"], ")"}], "="}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            OverscriptBox[
              StyleBox["\<\"x\"\>",
                "TB"], "."], "T"], 
          StyleBox["\<\"P\"\>",
            "TB"], 
          StyleBox["\<\"x\"\>",
            "TB"], "+", 
          SuperscriptBox[
            StyleBox["\<\"x\"\>",
              "TB"], "T"], 
          StyleBox["\<\"P\"\>",
            "TB"], 
          OverscriptBox[
            StyleBox["\<\"x\"\>",
              "TB"], "."], "="}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          SuperscriptBox[
            StyleBox["\<\"x\"\>",
              "TB"], "T"], 
          StyleBox["\<\"x\"\>",
            "TB"], "+", "2", 
          SuperscriptBox[
            StyleBox["\<\"u\"\>",
              "TB"], "T"], 
          SuperscriptBox[
            StyleBox["\<\"B\"\>",
              "TB"], "T"], 
          StyleBox["\<\"P\"\>",
            "TB"], 
          StyleBox["\<\"x\"\>",
            "TB"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ". To make ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V\& . \), 
          RowBox[{"(", 
            StyleBox["\<\"x\"\>",
              "TB"], ")"}]}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " as negative as possible, and thereby obtain the fastest response, we will \
compute the input signal as    "
}], "Text",
  CellTags->"12.2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"u\"\>",
          "TB"], "=", 
        FractionBox[
          RowBox[{"-", 
            SuperscriptBox[
              StyleBox["\<\"B\"\>",
                "TB"], "T"], 
            StyleBox["\<\"P\"\>",
              "TB"], 
            StyleBox["\<\"x\"\>",
              "TB"], \((t)\)}], 
          RowBox[{"\[VerticalSeparator]", 
            SuperscriptBox[
              StyleBox["\<\"B\"\>",
                "TB"], "T"], 
            StyleBox["\<\"P\"\>",
              "TB"], 
            StyleBox["\<\"x\"\>",
              "TB"], \((t)\), "\[VerticalSeparator]"}]]}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"12.2"],

Cell[TextData[{
  "These are matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " for a state\[Hyphen]space system, which we assume to be continuous\
\[Hyphen]time. "
}], "MathCaption",
  CellTags->"12.2"],

Cell["a = {{-3, 2}, {-1, -1}};", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"12.2"],

Cell["b = {{1, -1}, {0, 1}};", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"12.2"],

Cell[TextData[{
  "This solves the Lyapunov equation. The matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"Q\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " is assumed to be the identity matrix ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Cross]2\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ". "
}], "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{

Cell["p = LyapunovSolve[a, -IdentityMatrix[2]]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"12.2"],

Cell[BoxData[
    \({{7\/40, \(-\(1\/40\)\)}, {\(-\(1\/40\)\), 9\/20}}\)], "Output",
  CellLabel->"Out[18]= ",
  CellTags->"12.2"]
}, Open  ]],

Cell["Here is how we compute the control law. ", "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{

Cell["\<\
(
 bpx = Transpose[b].p.{x1, x2};
 u = -bpx/Sqrt[bpx.bpx]//Simplify
)\
\>", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"12.2"],

Cell[BoxData[
    \({\(\(-7\)\ x1 + x2\)\/\@\(113\ x1\^2 - 318\ x1\ x2 + 362\ x2\^2\), 
      \(8\ x1 - 19\ x2\)\/\@\(113\ x1\^2 - 318\ x1\ x2 + 362\ x2\^2\)}\)], 
  "Output",
  CellLabel->"Out[19]= ",
  CellTags->"12.2"]
}, Open  ]],

Cell["\<\
Despite the fact that our system is linear, the minimum time \
response control is not. \
\>", "Text",
  CellTags->"12.2"],

Cell["\<\
This plot shows the first control signal as a function of the state \
variables. \
\>", "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[u[[1]], {x1, -2, 2}, {x2, -2, 2},
 PlotPoints -> 40,
 Boxed -> False,
 AxesLabel -> {\"x1\", \"x2\", \"u[[1]]\"},
 ViewPoint -> {3.076, 0.000, 1.080},
 PlotLabel -> \"Minimum time response control\"
];\
\>", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"12.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .60103 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 -0.162103 1 [
[.5 .61353 -89 0 ]
[.5 .61353 89 12.5625 ]
[.1162 .60103 -12 -4.5 ]
[.1162 .60103 0 4.5 ]
[.09066 .5534 -12 -4.5 ]
[.09066 .5534 0 4.5 ]
[.06136 .49873 -6 -4.5 ]
[.06136 .49873 0 4.5 ]
[.02737 .43534 -6 -4.5 ]
[.02737 .43534 0 4.5 ]
[-0.0125 .36096 -6 -4.5 ]
[-0.0125 .36096 0 4.5 ]
[-0.00114 .49873 -16 -6.28125 ]
[-0.00114 .49873 0 6.28125 ]
[.01889 -0.01173 -8.2114 -9 ]
[.01889 -0.01173 3.7886 0 ]
[.25934 -0.01229 -7.1057 -9 ]
[.25934 -0.01229 4.8943 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74066 -0.01229 -2.44715 -9 ]
[.74066 -0.01229 3.55285 0 ]
[.98111 -0.01173 -1.8943 -9 ]
[.98111 -0.01173 4.1057 0 ]
[.5 -0.075 -8 -12.5625 ]
[.5 -0.075 8 0 ]
[.01018 .0082 -12 -4.5 ]
[.01018 .0082 0 4.5 ]
[.00484 .09126 -24 -4.5 ]
[.00484 .09126 0 4.5 ]
[-0.00062 .17619 -6 -4.5 ]
[-0.00062 .17619 0 4.5 ]
[-0.00621 .26307 -18 -4.5 ]
[-0.00621 .26307 0 4.5 ]
[-0.01192 .35196 -6 -4.5 ]
[-0.01192 .35196 0 4.5 ]
[-0.06312 .17619 -40 -6.28125 ]
[-0.06312 .17619 0 6.28125 ]
[ 0 0 0 0 ]
[ 1 .60103 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .61353 -150 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Minimum) show
111.000000 12.812500 moveto
(time) show
141.000000 12.812500 moveto
(response) show
195.000000 12.812500 moveto
(control) show
237.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.25 Mabswid
.1287 .60103 m
0 .36096 L
s
.1287 .60103 m
.13495 .60103 L
s
[(-2)] .1162 .60103 1 0 Mshowa
.10316 .5534 m
.10941 .5534 L
s
[(-1)] .09066 .5534 1 0 Mshowa
.07386 .49873 m
.08011 .49873 L
s
[(0)] .06136 .49873 1 0 Mshowa
.03987 .43534 m
.04612 .43534 L
s
[(1)] .02737 .43534 1 0 Mshowa
0 .36096 m
.00625 .36096 L
s
[(2)] -0.0125 .36096 1 0 Mshowa
.125 Mabswid
.12386 .592 m
.12761 .592 L
s
.11889 .58274 m
.12264 .58274 L
s
.11379 .57322 m
.11754 .57322 L
s
.10855 .56344 m
.1123 .56344 L
s
.09763 .54308 m
.10138 .54308 L
s
.09194 .53246 m
.09569 .53246 L
s
.08608 .52154 m
.08983 .52154 L
s
.08006 .5103 m
.08381 .5103 L
s
.06747 .48681 m
.07122 .48681 L
s
.06088 .47453 m
.06463 .47453 L
s
.0541 .46187 m
.05785 .46187 L
s
.0471 .44881 m
.05085 .44881 L
s
.03242 .42143 m
.03617 .42143 L
s
.02471 .40706 m
.02846 .40706 L
s
.01675 .39221 m
.0205 .39221 L
s
.00852 .37685 m
.01227 .37685 L
s
gsave
-0.00114 .49873 -77 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x1) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.25 Mabswid
.02321 0 m
.97679 0 L
s
.02321 0 m
.02537 .00586 L
s
[(-2)] .01889 -0.01173 .36857 1 Mshowa
.26161 0 m
.26274 .00615 L
s
[(-1)] .25934 -0.01229 .18428 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.73839 0 m
.73726 .00615 L
s
[(1)] .74066 -0.01229 -0.18428 1 Mshowa
.97679 0 m
.97463 .00586 L
s
[(2)] .98111 -0.01173 -0.36857 1 Mshowa
.125 Mabswid
.07089 0 m
.07207 .00356 L
s
.11857 0 m
.11963 .0036 L
s
.16625 0 m
.16718 .00363 L
s
.21393 0 m
.21474 .00366 L
s
.30928 0 m
.30983 .00371 L
s
.35696 0 m
.35738 .00373 L
s
.40464 0 m
.40492 .00374 L
s
.45232 0 m
.45246 .00375 L
s
.54768 0 m
.54754 .00375 L
s
.59536 0 m
.59508 .00374 L
s
.64304 0 m
.64262 .00373 L
s
.69072 0 m
.69017 .00371 L
s
.78607 0 m
.78526 .00366 L
s
.83375 0 m
.83282 .00363 L
s
.88143 0 m
.88037 .0036 L
s
.92911 0 m
.92793 .00356 L
s
gsave
.5 -0.075 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x2) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.25 Mabswid
.02321 0 m
0 .36096 L
s
.02268 .0082 m
.02893 .0082 L
s
[(-1)] .01018 .0082 1 0 Mshowa
.01734 .09126 m
.02359 .09126 L
s
[(-0.5)] .00484 .09126 1 0 Mshowa
.01188 .17619 m
.01813 .17619 L
s
[(0)] -0.00062 .17619 1 0 Mshowa
.00629 .26307 m
.01254 .26307 L
s
[(0.5)] -0.00621 .26307 1 0 Mshowa
.00058 .35196 m
.00683 .35196 L
s
[(1)] -0.01192 .35196 1 0 Mshowa
.125 Mabswid
.02162 .02467 m
.02537 .02467 L
s
.02056 .0412 m
.02431 .0412 L
s
.01949 .05781 m
.02324 .05781 L
s
.01842 .0745 m
.02217 .0745 L
s
.01626 .10809 m
.02001 .10809 L
s
.01517 .125 m
.01892 .125 L
s
.01408 .14199 m
.01783 .14199 L
s
.01298 .15905 m
.01673 .15905 L
s
.01077 .19341 m
.01452 .19341 L
s
.00966 .21071 m
.01341 .21071 L
s
.00854 .22808 m
.01229 .22808 L
s
.00742 .24554 m
.01117 .24554 L
s
.00516 .28069 m
.00891 .28069 L
s
.00402 .29838 m
.00777 .29838 L
s
.00288 .31616 m
.00663 .31616 L
s
.00173 .33402 m
.00548 .33402 L
s
gsave
-0.06312 .17619 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
69.000000 12.812500 moveto
(@) show
75.000000 12.812500 moveto
(@) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 12.812500 moveto
(D) show
93.000000 12.812500 moveto
(D) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 .60103 L
0 .60103 L
closepath
clip
newpath
.5 Mabswid
.533 .681 .933 r
.13232 .52299 .15095 .52812 .14888 .51792 .13012 .51307 Metetra
.539 .687 .935 r
.13012 .51307 .14888 .51792 .14678 .50764 .1279 .50309 Metetra
.545 .693 .937 r
.1279 .50309 .14678 .50764 .14466 .49731 .12565 .49308 Metetra
.55 .7 .939 r
.12565 .49308 .14466 .49731 .1425 .48695 .12336 .48305 Metetra
.556 .707 .941 r
.12336 .48305 .1425 .48695 .14032 .47659 .12104 .47302 Metetra
.561 .714 .943 r
.12104 .47302 .14032 .47659 .1381 .46624 .11869 .463 Metetra
.567 .721 .945 r
.11869 .463 .1381 .46624 .13584 .45591 .1163 .453 Metetra
.571 .728 .948 r
.1163 .453 .13584 .45591 .13355 .44562 .11387 .44303 Metetra
.576 .734 .95 r
.11387 .44303 .13355 .44562 .13122 .43537 .1114 .43309 Metetra
.58 .741 .953 r
.1114 .43309 .13122 .43537 .12886 .42517 .1089 .42317 Metetra
.584 .747 .955 r
.1089 .42317 .12886 .42517 .12645 .41501 .10635 .41329 Metetra
.587 .754 .957 r
.10635 .41329 .12645 .41501 .12401 .4049 .10376 .40344 Metetra
.591 .759 .959 r
.10376 .40344 .12401 .4049 .12152 .39482 .10113 .39361 Metetra
.593 .765 .961 r
.10113 .39361 .12152 .39482 .119 .38479 .09845 .3838 Metetra
.596 .77 .963 r
.09845 .3838 .119 .38479 .11643 .37479 .09574 .37401 Metetra
.598 .775 .965 r
.09574 .37401 .11643 .37479 .11382 .36481 .09297 .36423 Metetra
.6 .78 .966 r
.09297 .36423 .11382 .36481 .11116 .35486 .09017 .35446 Metetra
.602 .784 .968 r
.09017 .35446 .11116 .35486 .10846 .34492 .08731 .34469 Metetra
.603 .788 .969 r
.08731 .34469 .10846 .34492 .10572 .33499 .08441 .33491 Metetra
.604 .791 .971 r
.08441 .33491 .10572 .33499 .10293 .32505 .08146 .32512 Metetra
.605 .795 .972 r
.08146 .32512 .10293 .32505 .10009 .31511 .07846 .31531 Metetra
.606 .798 .973 r
.07846 .31531 .10009 .31511 .09721 .30515 .07541 .30547 Metetra
.606 .801 .974 r
.07541 .30547 .09721 .30515 .09427 .29516 .07232 .2956 Metetra
.607 .803 .975 r
.07232 .2956 .09427 .29516 .09129 .28515 .06917 .28568 Metetra
.607 .806 .976 r
.06917 .28568 .09129 .28515 .08826 .27509 .06597 .27572 Metetra
.607 .808 .977 r
.06597 .27572 .08826 .27509 .08517 .26499 .06271 .26571 Metetra
.607 .81 .978 r
.06271 .26571 .08517 .26499 .08204 .25484 .0594 .25563 Metetra
.607 .812 .979 r
.0594 .25563 .08204 .25484 .07885 .24463 .05604 .24549 Metetra
.607 .814 .979 r
.05604 .24549 .07885 .24463 .07561 .23434 .05261 .23528 Metetra
.607 .815 .98 r
.05261 .23528 .07561 .23434 .07231 .22399 .04913 .22498 Metetra
.607 .817 .981 r
.04913 .22498 .07231 .22399 .06896 .21355 .0456 .2146 Metetra
.607 .818 .981 r
.0456 .2146 .06896 .21355 .06555 .20303 .042 .20413 Metetra
.606 .819 .982 r
.042 .20413 .06555 .20303 .06208 .19241 .03834 .19356 Metetra
.606 .821 .982 r
.03834 .19356 .06208 .19241 .05855 .18169 .03461 .18288 Metetra
.606 .822 .983 r
.03461 .18288 .05855 .18169 .05496 .17086 .03083 .17209 Metetra
.605 .823 .983 r
.03083 .17209 .05496 .17086 .0513 .15992 .02697 .16119 Metetra
.605 .823 .984 r
.02697 .16119 .0513 .15992 .04759 .14886 .02305 .15016 Metetra
.604 .824 .984 r
.02305 .15016 .04759 .14886 .0438 .13767 .01906 .139 Metetra
.604 .825 .984 r
.01906 .139 .0438 .13767 .03995 .12634 .015 .1277 Metetra
.526 .669 .927 r
.15095 .52812 .16958 .53385 .16763 .52338 .14888 .51792 Metetra
.532 .674 .929 r
.14888 .51792 .16763 .52338 .16566 .51278 .14678 .50764 Metetra
.538 .681 .93 r
.14678 .50764 .16566 .51278 .16366 .50211 .14466 .49731 Metetra
.545 .688 .932 r
.14466 .49731 .16366 .50211 .16164 .49139 .1425 .48695 Metetra
.551 .695 .935 r
.1425 .48695 .16164 .49139 .15958 .48066 .14032 .47659 Metetra
.557 .703 .937 r
.14032 .47659 .15958 .48066 .1575 .46993 .1381 .46624 Metetra
.563 .71 .94 r
.1381 .46624 .1575 .46993 .15538 .45924 .13584 .45591 Metetra
.569 .718 .943 r
.13584 .45591 .15538 .45924 .15323 .44858 .13355 .44562 Metetra
.574 .726 .945 r
.13355 .44562 .15323 .44858 .15104 .43798 .13122 .43537 Metetra
.579 .733 .948 r
.13122 .43537 .15104 .43798 .14882 .42745 .12886 .42517 Metetra
.583 .74 .951 r
.12886 .42517 .14882 .42745 .14656 .41697 .12645 .41501 Metetra
.587 .747 .953 r
.12645 .41501 .14656 .41697 .14426 .40656 .12401 .4049 Metetra
.591 .754 .956 r
.12401 .4049 .14426 .40656 .14192 .3962 .12152 .39482 Metetra
.594 .76 .958 r
.12152 .39482 .14192 .3962 .13954 .38591 .119 .38479 Metetra
.597 .766 .96 r
.119 .38479 .13954 .38591 .13712 .37566 .11643 .37479 Metetra
.6 .771 .962 r
.11643 .37479 .13712 .37566 .13466 .36547 .11382 .36481 Metetra
.602 .776 .964 r
.11382 .36481 .13466 .36547 .13216 .35531 .11116 .35486 Metetra
.604 .781 .966 r
.11116 .35486 .13216 .35531 .12961 .34518 .10846 .34492 Metetra
.605 .786 .967 r
.10846 .34492 .12961 .34518 .12703 .33507 .10572 .33499 Metetra
.607 .79 .969 r
.10572 .33499 .12703 .33507 .12439 .32497 .10293 .32505 Metetra
.608 .794 .97 r
.10293 .32505 .12439 .32497 .12172 .31488 .10009 .31511 Metetra
.609 .797 .972 r
.10009 .31511 .12172 .31488 .119 .30479 .09721 .30515 Metetra
.609 .8 .973 r
.09721 .30515 .119 .30479 .11623 .29468 .09427 .29516 Metetra
.61 .803 .974 r
.09427 .29516 .11623 .29468 .11341 .28456 .09129 .28515 Metetra
.61 .806 .975 r
.09129 .28515 .11341 .28456 .11055 .2744 .08826 .27509 Metetra
.61 .808 .976 r
.08826 .27509 .11055 .2744 .10764 .26421 .08517 .26499 Metetra
.61 .81 .977 r
.08517 .26499 .10764 .26421 .10468 .25397 .08204 .25484 Metetra
.61 .813 .978 r
.08204 .25484 .10468 .25397 .10166 .24368 .07885 .24463 Metetra
.61 .814 .979 r
.07885 .24463 .10166 .24368 .0986 .23333 .07561 .23434 Metetra
.61 .816 .979 r
.07561 .23434 .0986 .23333 .09549 .22291 .07231 .22399 Metetra
.61 .818 .98 r
.07231 .22399 .09549 .22291 .09232 .21242 .06896 .21355 Metetra
.61 .819 .981 r
.06896 .21355 .09232 .21242 .0891 .20184 .06555 .20303 Metetra
.609 .82 .981 r
.06555 .20303 .0891 .20184 .08582 .19117 .06208 .19241 Metetra
.609 .822 .982 r
.06208 .19241 .08582 .19117 .08248 .18041 .05855 .18169 Metetra
.608 .823 .982 r
.05855 .18169 .08248 .18041 .07909 .16954 .05496 .17086 Metetra
.608 .824 .983 r
.05496 .17086 .07909 .16954 .07563 .15856 .0513 .15992 Metetra
.607 .825 .983 r
.0513 .15992 .07563 .15856 .07212 .14746 .04759 .14886 Metetra
.607 .825 .984 r
.04759 .14886 .07212 .14746 .06854 .13624 .0438 .13767 Metetra
.606 .826 .984 r
.0438 .13767 .06854 .13624 .0649 .12489 .03995 .12634 Metetra
.518 .656 .922 r
.16958 .53385 .18821 .54024 .18638 .52951 .16763 .52338 Metetra
.524 .661 .922 r
.16763 .52338 .18638 .52951 .18453 .51861 .16566 .51278 Metetra
.531 .667 .924 r
.16566 .51278 .18453 .51861 .18266 .50758 .16366 .50211 Metetra
.538 .674 .926 r
.16366 .50211 .18266 .50758 .18077 .49647 .16164 .49139 Metetra
.545 .682 .928 r
.16164 .49139 .18077 .49647 .17885 .48533 .15958 .48066 Metetra
.552 .69 .931 r
.15958 .48066 .17885 .48533 .1769 .47418 .1575 .46993 Metetra
.559 .698 .934 r
.1575 .46993 .1769 .47418 .17491 .46306 .15538 .45924 Metetra
.565 .707 .937 r
.15538 .45924 .17491 .46306 .1729 .45199 .15323 .44858 Metetra
.571 .715 .94 r
.15323 .44858 .1729 .45199 .17086 .44099 .15104 .43798 Metetra
.577 .724 .943 r
.15104 .43798 .17086 .44099 .16878 .43006 .14882 .42745 Metetra
.582 .732 .946 r
.14882 .42745 .16878 .43006 .16666 .41922 .14656 .41697 Metetra
.587 .74 .949 r
.14656 .41697 .16666 .41922 .1645 .40845 .14426 .40656 Metetra
.591 .747 .951 r
.14426 .40656 .1645 .40845 .16231 .39778 .14192 .3962 Metetra
.595 .754 .954 r
.14192 .3962 .16231 .39778 .16008 .38718 .13954 .38591 Metetra
.598 .761 .957 r
.13954 .38591 .16008 .38718 .15781 .37666 .13712 .37566 Metetra
.601 .767 .959 r
.13712 .37566 .15781 .37666 .15551 .3662 .13466 .36547 Metetra
.604 .773 .961 r
.13466 .36547 .15551 .3662 .15316 .35581 .13216 .35531 Metetra
.606 .778 .963 r
.13216 .35531 .15316 .35581 .15077 .34546 .12961 .34518 Metetra
.608 .783 .965 r
.12961 .34518 .15077 .34546 .14834 .33516 .12703 .33507 Metetra
.609 .788 .967 r
.12703 .33507 .14834 .33516 .14586 .32488 .12439 .32497 Metetra
.611 .792 .968 r
.12439 .32497 .14586 .32488 .14335 .31463 .12172 .31488 Metetra
.612 .796 .97 r
.12172 .31488 .14335 .31463 .14079 .30439 .119 .30479 Metetra
.612 .8 .971 r
.119 .30479 .14079 .30439 .13818 .29415 .11623 .29468 Metetra
.613 .803 .973 r
.11623 .29468 .13818 .29415 .13553 .2839 .11341 .28456 Metetra
.613 .806 .974 r
.11341 .28456 .13553 .2839 .13284 .27364 .11055 .2744 Metetra
.614 .808 .975 r
.11055 .2744 .13284 .27364 .1301 .26334 .10764 .26421 Metetra
.614 .811 .976 r
.10764 .26421 .1301 .26334 .12731 .25302 .10468 .25397 Metetra
.614 .813 .977 r
.10468 .25397 .12731 .25302 .12448 .24264 .10166 .24368 Metetra
.613 .815 .978 r
.10166 .24368 .12448 .24264 .12159 .23222 .0986 .23333 Metetra
.613 .817 .979 r
.0986 .23333 .12159 .23222 .11866 .22173 .09549 .22291 Metetra
.613 .819 .979 r
.09549 .22291 .11866 .22173 .11568 .21118 .09232 .21242 Metetra
.613 .82 .98 r
.09232 .21242 .11568 .21118 .11264 .20055 .0891 .20184 Metetra
.612 .821 .981 r
.0891 .20184 .11264 .20055 .10955 .18983 .08582 .19117 Metetra
.612 .823 .981 r
.08582 .19117 .10955 .18983 .10641 .17902 .08248 .18041 Metetra
.611 .824 .982 r
.08248 .18041 .10641 .17902 .10321 .16811 .07909 .16954 Metetra
.611 .825 .982 r
.07909 .16954 .10321 .16811 .09996 .1571 .07563 .15856 Metetra
.61 .826 .983 r
.07563 .15856 .09996 .1571 .09665 .14597 .07212 .14746 Metetra
.609 .827 .983 r
.07212 .14746 .09665 .14597 .09328 .13471 .06854 .13624 Metetra
.609 .827 .984 r
.06854 .13624 .09328 .13471 .08985 .12334 .0649 .12489 Metetra
.509 .643 .916 r
.18821 .54024 .20684 .5473 .20513 .53638 .18638 .52951 Metetra
.516 .647 .916 r
.18638 .52951 .20513 .53638 .2034 .52519 .18453 .51861 Metetra
.523 .652 .917 r
.18453 .51861 .2034 .52519 .20166 .51381 .18266 .50758 Metetra
.53 .659 .918 r
.18266 .50758 .20166 .51381 .19989 .5023 .18077 .49647 Metetra
.538 .667 .921 r
.18077 .49647 .19989 .5023 .1981 .49071 .17885 .48533 Metetra
.545 .675 .923 r
.17885 .48533 .1981 .49071 .19629 .4791 .1769 .47418 Metetra
.553 .684 .926 r
.1769 .47418 .19629 .4791 .19445 .4675 .17491 .46306 Metetra
.56 .694 .93 r
.17491 .46306 .19445 .4675 .19257 .45595 .1729 .45199 Metetra
.567 .703 .933 r
.1729 .45199 .19257 .45595 .19067 .44447 .17086 .44099 Metetra
.574 .713 .937 r
.17086 .44099 .19067 .44447 .18873 .43309 .16878 .43006 Metetra
.58 .722 .94 r
.16878 .43006 .18873 .43309 .18676 .42182 .16666 .41922 Metetra
.586 .731 .943 r
.16666 .41922 .18676 .42182 .18475 .41065 .1645 .40845 Metetra
.591 .739 .947 r
.1645 .40845 .18475 .41065 .18271 .39959 .16231 .39778 Metetra
.595 .748 .95 r
.16231 .39778 .18271 .39959 .18062 .38864 .16008 .38718 Metetra
.599 .755 .953 r
.16008 .38718 .18062 .38864 .17851 .3778 .15781 .37666 Metetra
.603 .762 .955 r
.15781 .37666 .17851 .3778 .17635 .36705 .15551 .3662 Metetra
.606 .769 .958 r
.15551 .3662 .17635 .36705 .17415 .35638 .15316 .35581 Metetra
.608 .775 .96 r
.15316 .35581 .17415 .35638 .17192 .34579 .15077 .34546 Metetra
.611 .781 .962 r
.15077 .34546 .17192 .34579 .16964 .33526 .14834 .33516 Metetra
.612 .786 .964 r
.14834 .33516 .16964 .33526 .16733 .32479 .14586 .32488 Metetra
.614 .791 .966 r
.14586 .32488 .16733 .32479 .16497 .31435 .14335 .31463 Metetra
.615 .795 .968 r
.14335 .31463 .16497 .31435 .16258 .30394 .14079 .30439 Metetra
.616 .799 .97 r
.14079 .30439 .16258 .30394 .16014 .29356 .13818 .29415 Metetra
.616 .802 .971 r
.13818 .29415 .16014 .29356 .15765 .28318 .13553 .2839 Metetra
.617 .806 .972 r
.13553 .2839 .15765 .28318 .15513 .27279 .13284 .27364 Metetra
.617 .809 .974 r
.13284 .27364 .15513 .27279 .15256 .26239 .1301 .26334 Metetra
.617 .811 .975 r
.1301 .26334 .15256 .26239 .14995 .25196 .12731 .25302 Metetra
.617 .814 .976 r
.12731 .25302 .14995 .25196 .14729 .24151 .12448 .24264 Metetra
.617 .816 .977 r
.12448 .24264 .14729 .24151 .14458 .231 .12159 .23222 Metetra
.617 .818 .978 r
.12159 .23222 .14458 .231 .14183 .22045 .11866 .22173 Metetra
.616 .82 .978 r
.11866 .22173 .14183 .22045 .13903 .20983 .11568 .21118 Metetra
.616 .821 .979 r
.11568 .21118 .13903 .20983 .13618 .19914 .11264 .20055 Metetra
.615 .823 .98 r
.11264 .20055 .13618 .19914 .13329 .18837 .10955 .18983 Metetra
.615 .824 .981 r
.10955 .18983 .13329 .18837 .13034 .17752 .10641 .17902 Metetra
.614 .825 .981 r
.10641 .17902 .13034 .17752 .12734 .16657 .10321 .16811 Metetra
.614 .826 .982 r
.10321 .16811 .12734 .16657 .12428 .15552 .09996 .1571 Metetra
.613 .827 .982 r
.09996 .1571 .12428 .15552 .12118 .14435 .09665 .14597 Metetra
.612 .828 .983 r
.09665 .14597 .12118 .14435 .11801 .13307 .09328 .13471 Metetra
.612 .829 .983 r
.09328 .13471 .11801 .13307 .11479 .12167 .08985 .12334 Metetra
.501 .632 .911 r
.20684 .5473 .22549 .55499 .22389 .54399 .20513 .53638 Metetra
.506 .633 .909 r
.20513 .53638 .22389 .54399 .22228 .53261 .2034 .52519 Metetra
.513 .637 .909 r
.2034 .52519 .22228 .53261 .22066 .52092 .20166 .51381 Metetra
.52 .643 .91 r
.20166 .51381 .22066 .52092 .21902 .50901 .19989 .5023 Metetra
.528 .65 .912 r
.19989 .5023 .21902 .50901 .21736 .49696 .1981 .49071 Metetra
.537 .659 .915 r
.1981 .49071 .21736 .49696 .21568 .48483 .19629 .4791 Metetra
.545 .668 .918 r
.19629 .4791 .21568 .48483 .21397 .47268 .19445 .4675 Metetra
.554 .679 .922 r
.19445 .4675 .21397 .47268 .21224 .46058 .19257 .45595 Metetra
.562 .689 .925 r
.19257 .45595 .21224 .46058 .21047 .44856 .19067 .44447 Metetra
.57 .7 .929 r
.19067 .44447 .21047 .44856 .20868 .43665 .18873 .43309 Metetra
.577 .71 .933 r
.18873 .43309 .20868 .43665 .20685 .42486 .18676 .42182 Metetra
.584 .72 .937 r
.18676 .42182 .20685 .42486 .20499 .41321 .18475 .41065 Metetra
.59 .73 .941 r
.18475 .41065 .20499 .41321 .2031 .40171 .18271 .39959 Metetra
.595 .74 .945 r
.18271 .39959 .2031 .40171 .20116 .39034 .18062 .38864 Metetra
.6 .748 .948 r
.18062 .38864 .20116 .39034 .1992 .37912 .17851 .3778 Metetra
.604 .756 .951 r
.17851 .3778 .1992 .37912 .19719 .36802 .17635 .36705 Metetra
.608 .764 .954 r
.17635 .36705 .19719 .36802 .19515 .35704 .17415 .35638 Metetra
.611 .771 .957 r
.17415 .35638 .19515 .35704 .19307 .34616 .17192 .34579 Metetra
.613 .778 .959 r
.17192 .34579 .19307 .34616 .19095 .33538 .16964 .33526 Metetra
.616 .783 .962 r
.16964 .33526 .19095 .33538 .1888 .32467 .16733 .32479 Metetra
.617 .789 .964 r
.16733 .32479 .1888 .32467 .1866 .31403 .16497 .31435 Metetra
.619 .794 .966 r
.16497 .31435 .1866 .31403 .18437 .30344 .16258 .30394 Metetra
.62 .798 .968 r
.16258 .30394 .18437 .30344 .18209 .29289 .16014 .29356 Metetra
.62 .802 .969 r
.16014 .29356 .18209 .29289 .17978 .28236 .15765 .28318 Metetra
.621 .806 .971 r
.15765 .28318 .17978 .28236 .17742 .27184 .15513 .27279 Metetra
.621 .809 .972 r
.15513 .27279 .17742 .27184 .17502 .26133 .15256 .26239 Metetra
.621 .812 .973 r
.15256 .26239 .17502 .26133 .17258 .2508 .14995 .25196 Metetra
.621 .815 .975 r
.14995 .25196 .17258 .2508 .1701 .24025 .14729 .24151 Metetra
.621 .817 .976 r
.14729 .24151 .1701 .24025 .16757 .22966 .14458 .231 Metetra
.62 .819 .977 r
.14458 .231 .16757 .22966 .165 .21903 .14183 .22045 Metetra
.62 .821 .978 r
.14183 .22045 .165 .21903 .16239 .20835 .13903 .20983 Metetra
.619 .823 .978 r
.13903 .20983 .16239 .20835 .15973 .1976 .13618 .19914 Metetra
.619 .824 .979 r
.13618 .19914 .15973 .1976 .15702 .18678 .13329 .18837 Metetra
.618 .826 .98 r
.13329 .18837 .15702 .18678 .15426 .17588 .13034 .17752 Metetra
.617 .827 .981 r
.13034 .17752 .15426 .17588 .15146 .16489 .12734 .16657 Metetra
.617 .828 .981 r
.12734 .16657 .15146 .16489 .1486 .1538 .12428 .15552 Metetra
.616 .829 .982 r
.12428 .15552 .1486 .1538 .1457 .14261 .12118 .14435 Metetra
.615 .83 .982 r
.12118 .14435 .1457 .14261 .14274 .1313 .11801 .13307 Metetra
.614 .83 .983 r
.11801 .13307 .14274 .1313 .13973 .11987 .11479 .12167 Metetra
.493 .623 .908 r
.22549 .55499 .24416 .56318 .24266 .5523 .22389 .54399 Metetra
.497 .621 .904 r
.22389 .54399 .24266 .5523 .24116 .54087 .22228 .53261 Metetra
.503 .622 .902 r
.22228 .53261 .24116 .54087 .23966 .52897 .22066 .52092 Metetra
.51 .626 .902 r
.22066 .52092 .23966 .52897 .23814 .51672 .21902 .50901 Metetra
.518 .633 .903 r
.21902 .50901 .23814 .51672 .23661 .50421 .21736 .49696 Metetra
.527 .641 .905 r
.21736 .49696 .23661 .50421 .23506 .49154 .21568 .48483 Metetra
.536 .65 .908 r
.21568 .48483 .23506 .49154 .23349 .4788 .21397 .47268 Metetra
.545 .661 .912 r
.21397 .47268 .23349 .4788 .2319 .46606 .21224 .46058 Metetra
.555 .672 .916 r
.21224 .46058 .2319 .46606 .23027 .4534 .21047 .44856 Metetra
.564 .684 .921 r
.21047 .44856 .23027 .4534 .22862 .44086 .20868 .43665 Metetra
.572 .696 .925 r
.20868 .43665 .22862 .44086 .22694 .42846 .20685 .42486 Metetra
.58 .708 .93 r
.20685 .42486 .22694 .42846 .22523 .41624 .20499 .41321 Metetra
.588 .719 .934 r
.20499 .41321 .22523 .41624 .22348 .4042 .2031 .40171 Metetra
.594 .73 .939 r
.2031 .40171 .22348 .4042 .2217 .39234 .20116 .39034 Metetra
.6 .74 .943 r
.20116 .39034 .2217 .39234 .21989 .38066 .1992 .37912 Metetra
.605 .75 .946 r
.1992 .37912 .21989 .38066 .21803 .36915 .19719 .36802 Metetra
.61 .758 .95 r
.19719 .36802 .21803 .36915 .21615 .3578 .19515 .35704 Metetra
.613 .767 .953 r
.19515 .35704 .21615 .3578 .21422 .3466 .19307 .34616 Metetra
.616 .774 .956 r
.19307 .34616 .21422 .3466 .21226 .33552 .19095 .33538 Metetra
.619 .781 .959 r
.19095 .33538 .21226 .33552 .21026 .32455 .1888 .32467 Metetra
.621 .787 .961 r
.1888 .32467 .21026 .32455 .20823 .31367 .1866 .31403 Metetra
.623 .792 .963 r
.1866 .31403 .20823 .31367 .20616 .30287 .18437 .30344 Metetra
.624 .797 .966 r
.18437 .30344 .20616 .30287 .20404 .29214 .18209 .29289 Metetra
.625 .802 .967 r
.18209 .29289 .20404 .29214 .2019 .28144 .17978 .28236 Metetra
.625 .806 .969 r
.17978 .28236 .2019 .28144 .19971 .27078 .17742 .27184 Metetra
.625 .809 .971 r
.17742 .27184 .19971 .27078 .19748 .26014 .17502 .26133 Metetra
.625 .813 .972 r
.17502 .26133 .19748 .26014 .19521 .2495 .17258 .2508 Metetra
.625 .816 .973 r
.17258 .2508 .19521 .2495 .19291 .23885 .1701 .24025 Metetra
.625 .818 .975 r
.1701 .24025 .19291 .23885 .19056 .22818 .16757 .22966 Metetra
.625 .82 .976 r
.16757 .22966 .19056 .22818 .18817 .21747 .165 .21903 Metetra
.624 .822 .977 r
.165 .21903 .18817 .21747 .18574 .20672 .16239 .20835 Metetra
.623 .824 .978 r
.16239 .20835 .18574 .20672 .18326 .19592 .15973 .1976 Metetra
.623 .826 .978 r
.15973 .1976 .18326 .19592 .18074 .18504 .15702 .18678 Metetra
.622 .827 .979 r
.15702 .18678 .18074 .18504 .17818 .1741 .15426 .17588 Metetra
.621 .829 .98 r
.15426 .17588 .17818 .1741 .17557 .16307 .15146 .16489 Metetra
.62 .83 .981 r
.15146 .16489 .17557 .16307 .17292 .15195 .1486 .1538 Metetra
.619 .831 .981 r
.1486 .1538 .17292 .15195 .17022 .14072 .1457 .14261 Metetra
.619 .831 .982 r
.1457 .14261 .17022 .14072 .16747 .12939 .14274 .1313 Metetra
.618 .832 .982 r
.14274 .1313 .16747 .12939 .16466 .11794 .13973 .11987 Metetra
.487 .62 .908 r
.24416 .56318 .26286 .57157 .26146 .56109 .24266 .5523 Metetra
.489 .613 .901 r
.24266 .5523 .26146 .56109 .26007 .54986 .24116 .54087 Metetra
.493 .61 .897 r
.24116 .54087 .26007 .54986 .25867 .53796 .23966 .52897 Metetra
.499 .611 .894 r
.23966 .52897 .25867 .53796 .25727 .52551 .23814 .51672 Metetra
.506 .614 .894 r
.23814 .51672 .25727 .52551 .25586 .51261 .23661 .50421 Metetra
.515 .621 .895 r
.23661 .50421 .25586 .51261 .25444 .49942 .23506 .49154 Metetra
.524 .63 .898 r
.23506 .49154 .25444 .49942 .253 .48604 .23349 .4788 Metetra
.535 .641 .901 r
.23349 .4788 .253 .48604 .25155 .4726 .2319 .46606 Metetra
.545 .653 .906 r
.2319 .46606 .25155 .4726 .25007 .4592 .23027 .4534 Metetra
.556 .666 .911 r
.23027 .4534 .25007 .4592 .24857 .44591 .22862 .44086 Metetra
.566 .679 .916 r
.22862 .44086 .24857 .44591 .24703 .43279 .22694 .42846 Metetra
.576 .693 .921 r
.22694 .42846 .24703 .43279 .24547 .41987 .22523 .41624 Metetra
.584 .706 .926 r
.22523 .41624 .24547 .41987 .24387 .40717 .22348 .4042 Metetra
.593 .718 .931 r
.22348 .4042 .24387 .40717 .24224 .39472 .2217 .39234 Metetra
.6 .73 .936 r
.2217 .39234 .24224 .39472 .24057 .38249 .21989 .38066 Metetra
.606 .741 .941 r
.21989 .38066 .24057 .38249 .23888 .37049 .21803 .36915 Metetra
.611 .752 .945 r
.21803 .36915 .23888 .37049 .23714 .3587 .21615 .3578 Metetra
.616 .761 .949 r
.21615 .3578 .23714 .3587 .23537 .3471 .21422 .3466 Metetra
.62 .77 .952 r
.21422 .3466 .23537 .3471 .23357 .33567 .21226 .33552 Metetra
.623 .778 .955 r
.21226 .33552 .23357 .33567 .23173 .3244 .21026 .32455 Metetra
.625 .785 .958 r
.21026 .32455 .23173 .3244 .22986 .31325 .20823 .31367 Metetra
.627 .791 .961 r
.20823 .31367 .22986 .31325 .22794 .30222 .20616 .30287 Metetra
.628 .797 .963 r
.20616 .30287 .22794 .30222 .226 .29127 .20404 .29214 Metetra
.629 .802 .965 r
.20404 .29214 .226 .29127 .22401 .2804 .2019 .28144 Metetra
.63 .806 .967 r
.2019 .28144 .22401 .2804 .22199 .26958 .19971 .27078 Metetra
.63 .81 .969 r
.19971 .27078 .22199 .26958 .21994 .2588 .19748 .26014 Metetra
.63 .814 .971 r
.19748 .26014 .21994 .2588 .21784 .24804 .19521 .2495 Metetra
.63 .817 .972 r
.19521 .2495 .21784 .24804 .21571 .23729 .19291 .23885 Metetra
.63 .82 .973 r
.19291 .23885 .21571 .23729 .21354 .22653 .19056 .22818 Metetra
.629 .822 .975 r
.19056 .22818 .21354 .22653 .21133 .21574 .18817 .21747 Metetra
.628 .824 .976 r
.18817 .21747 .21133 .21574 .20908 .20492 .18574 .20672 Metetra
.628 .826 .977 r
.18574 .20672 .20908 .20492 .2068 .19406 .18326 .19592 Metetra
.627 .828 .978 r
.18326 .19592 .2068 .19406 .20447 .18314 .18074 .18504 Metetra
.626 .829 .979 r
.18074 .18504 .20447 .18314 .2021 .17215 .17818 .1741 Metetra
.625 .831 .979 r
.17818 .1741 .2021 .17215 .19968 .16108 .17557 .16307 Metetra
.624 .832 .98 r
.17557 .16307 .19968 .16108 .19723 .14993 .17292 .15195 Metetra
.623 .833 .981 r
.17292 .15195 .19723 .14993 .19473 .13867 .17022 .14072 Metetra
.622 .834 .981 r
.17022 .14072 .19473 .13867 .19218 .12732 .16747 .12939 Metetra
.621 .834 .982 r
.16747 .12939 .19218 .12732 .18959 .11584 .16466 .11794 Metetra
.485 .627 .914 r
.26286 .57157 .28161 .57963 .2803 .56993 .26146 .56109 Metetra
.484 .613 .903 r
.26146 .56109 .2803 .56993 .279 .55928 .26007 .54986 Metetra
.485 .603 .895 r
.26007 .54986 .279 .55928 .2777 .54773 .25867 .53796 Metetra
.489 .598 .889 r
.25867 .53796 .2777 .54773 .27641 .53534 .25727 .52551 Metetra
.494 .597 .886 r
.25727 .52551 .27641 .53534 .27512 .52227 .25586 .51261 Metetra
.502 .601 .885 r
.25586 .51261 .27512 .52227 .27382 .50865 .25444 .49942 Metetra
.511 .608 .886 r
.25444 .49942 .27382 .50865 .27252 .49466 .253 .48604 Metetra
.522 .618 .889 r
.253 .48604 .27252 .49466 .2712 .48047 .25155 .4726 Metetra
.533 .63 .893 r
.25155 .4726 .2712 .48047 .26986 .46623 .25007 .4592 Metetra
.545 .644 .898 r
.25007 .4592 .26986 .46623 .2685 .45206 .24857 .44591 Metetra
.557 .659 .904 r
.24857 .44591 .2685 .45206 .26711 .43805 .24703 .43279 Metetra
.569 .674 .91 r
.24703 .43279 .26711 .43805 .2657 .42428 .24547 .41987 Metetra
.579 .689 .917 r
.24547 .41987 .2657 .42428 .26425 .41079 .24387 .40717 Metetra
.589 .704 .923 r
.24387 .40717 .26425 .41079 .26277 .39759 .24224 .39472 Metetra
.598 .718 .928 r
.24224 .39472 .26277 .39759 .26126 .3847 .24057 .38249 Metetra
.606 .731 .934 r
.24057 .38249 .26126 .3847 .25972 .37209 .23888 .37049 Metetra
.613 .743 .939 r
.23888 .37049 .25972 .37209 .25814 .35977 .23714 .3587 Metetra
.618 .755 .943 r
.23714 .3587 .25814 .35977 .25652 .3477 .23537 .3471 Metetra
.623 .765 .947 r
.23537 .3471 .25652 .3477 .25488 .33586 .23357 .33567 Metetra
.627 .774 .951 r
.23357 .33567 .25488 .33586 .2532 .32422 .23173 .3244 Metetra
.63 .782 .955 r
.23173 .3244 .2532 .32422 .25148 .31277 .22986 .31325 Metetra
.632 .789 .958 r
.22986 .31325 .25148 .31277 .24973 .30146 .22794 .30222 Metetra
.633 .796 .96 r
.22794 .30222 .24973 .30146 .24795 .29028 .226 .29127 Metetra
.635 .801 .963 r
.226 .29127 .24795 .29028 .24613 .27921 .22401 .2804 Metetra
.635 .807 .965 r
.22401 .2804 .24613 .27921 .24428 .26822 .22199 .26958 Metetra
.636 .811 .967 r
.22199 .26958 .24428 .26822 .24239 .25729 .21994 .2588 Metetra
.636 .815 .969 r
.21994 .2588 .24239 .25729 .24047 .2464 .21784 .24804 Metetra
.635 .818 .971 r
.21784 .24804 .24047 .2464 .23852 .23553 .21571 .23729 Metetra
.635 .821 .972 r
.21571 .23729 .23852 .23553 .23652 .22468 .21354 .22653 Metetra
.634 .824 .973 r
.21354 .22653 .23652 .22468 .23449 .21381 .21133 .21574 Metetra
.633 .826 .975 r
.21133 .21574 .23449 .21381 .23243 .20293 .20908 .20492 Metetra
.632 .828 .976 r
.20908 .20492 .23243 .20293 .23033 .192 .2068 .19406 Metetra
.631 .83 .977 r
.2068 .19406 .23033 .192 .22818 .18103 .20447 .18314 Metetra
.63 .832 .978 r
.20447 .18314 .22818 .18103 .22601 .17 .2021 .17215 Metetra
.629 .833 .979 r
.2021 .17215 .22601 .17 .22379 .1589 .19968 .16108 Metetra
.628 .834 .979 r
.19968 .16108 .22379 .1589 .22153 .14772 .19723 .14993 Metetra
.627 .835 .98 r
.19723 .14993 .22153 .14772 .21923 .13644 .19473 .13867 Metetra
.626 .836 .981 r
.19473 .13867 .21923 .13644 .21689 .12506 .19218 .12732 Metetra
.625 .837 .981 r
.19218 .12732 .21689 .12506 .21451 .11357 .18959 .11584 Metetra
.49 .648 .928 r
.28161 .57963 .30043 .58661 .2992 .57812 .2803 .56993 Metetra
.485 .625 .913 r
.2803 .56993 .2992 .57812 .29798 .56853 .279 .55928 Metetra
.482 .607 .899 r
.279 .55928 .29798 .56853 .29678 .55781 .2777 .54773 Metetra
.482 .593 .888 r
.2777 .54773 .29678 .55781 .29558 .54596 .27641 .53534 Metetra
.484 .585 .88 r
.27641 .53534 .29558 .54596 .29439 .53309 .27512 .52227 Metetra
.489 .583 .876 r
.27512 .52227 .29439 .53309 .29321 .51933 .27382 .50865 Metetra
.496 .586 .874 r
.27382 .50865 .29321 .51933 .29203 .50488 .27252 .49466 Metetra
.506 .593 .876 r
.27252 .49466 .29203 .50488 .29084 .48997 .2712 .48047 Metetra
.518 .604 .879 r
.2712 .48047 .29084 .48997 .28964 .47483 .26986 .46623 Metetra
.531 .618 .884 r
.26986 .46623 .28964 .47483 .28843 .45964 .2685 .45206 Metetra
.545 .635 .89 r
.2685 .45206 .28843 .45964 .28719 .44457 .26711 .43805 Metetra
.559 .652 .897 r
.26711 .43805 .28719 .44457 .28592 .42975 .2657 .42428 Metetra
.572 .669 .905 r
.2657 .42428 .28592 .42975 .28463 .41526 .26425 .41079 Metetra
.584 .686 .912 r
.26425 .41079 .28463 .41526 .2833 .40113 .26277 .39759 Metetra
.595 .703 .919 r
.26277 .39759 .2833 .40113 .28195 .3874 .26126 .3847 Metetra
.605 .719 .925 r
.26126 .3847 .28195 .3874 .28056 .37405 .25972 .37209 Metetra
.613 .733 .931 r
.25972 .37209 .28056 .37405 .27913 .36106 .25814 .35977 Metetra
.62 .747 .937 r
.25814 .35977 .27913 .36106 .27768 .34842 .25652 .3477 Metetra
.626 .759 .942 r
.25652 .3477 .27768 .34842 .27619 .33608 .25488 .33586 Metetra
.631 .769 .946 r
.25488 .33586 .27619 .33608 .27466 .32402 .2532 .32422 Metetra
.634 .779 .95 r
.2532 .32422 .27466 .32402 .27311 .31219 .25148 .31277 Metetra
.637 .787 .954 r
.25148 .31277 .27311 .31219 .27152 .30058 .24973 .30146 Metetra
.639 .795 .957 r
.24973 .30146 .27152 .30058 .2699 .28913 .24795 .29028 Metetra
.641 .801 .96 r
.24795 .29028 .2699 .28913 .26825 .27783 .24613 .27921 Metetra
.641 .807 .963 r
.24613 .27921 .26825 .27783 .26656 .26665 .24428 .26822 Metetra
.642 .812 .965 r
.24428 .26822 .26656 .26665 .26485 .25556 .24239 .25729 Metetra
.642 .817 .967 r
.24239 .25729 .26485 .25556 .2631 .24453 .24047 .2464 Metetra
.641 .82 .969 r
.24047 .2464 .2631 .24453 .26131 .23355 .23852 .23553 Metetra
.641 .824 .971 r
.23852 .23553 .26131 .23355 .2595 .2226 .23652 .22468 Metetra
.64 .826 .972 r
.23652 .22468 .2595 .2226 .25765 .21165 .23449 .21381 Metetra
.639 .829 .974 r
.23449 .21381 .25765 .21165 .25577 .2007 .23243 .20293 Metetra
.638 .831 .975 r
.23243 .20293 .25577 .2007 .25385 .18972 .23033 .192 Metetra
.637 .833 .976 r
.23033 .192 .25385 .18972 .2519 .1787 .22818 .18103 Metetra
.635 .834 .977 r
.22818 .18103 .2519 .1787 .24991 .16764 .22601 .17 Metetra
.634 .836 .978 r
.22601 .17 .24991 .16764 .24789 .1565 .22379 .1589 Metetra
.633 .837 .979 r
.22379 .1589 .24789 .1565 .24583 .1453 .22153 .14772 Metetra
.631 .838 .98 r
.22153 .14772 .24583 .1453 .24373 .134 .21923 .13644 Metetra
.63 .839 .98 r
.21923 .13644 .24373 .134 .24159 .12261 .21689 .12506 Metetra
.629 .839 .981 r
.21689 .12506 .24159 .12261 .23942 .11111 .21451 .11357 Metetra
.503 .69 .952 r
.30043 .58661 .31932 .59165 .31818 .58468 .2992 .57812 Metetra
.495 .657 .933 r
.2992 .57812 .31818 .58468 .31704 .57663 .29798 .56853 Metetra
.488 .628 .913 r
.29798 .56853 .31704 .57663 .31591 .56733 .29678 .55781 Metetra
.483 .603 .896 r
.29678 .55781 .31591 .56733 .3148 .55667 .29558 .54596 Metetra
.479 .584 .882 r
.29558 .54596 .3148 .55667 .3137 .54464 .29439 .53309 Metetra
.479 .573 .871 r
.29439 .53309 .3137 .54464 .31262 .53129 .29321 .51933 Metetra
.483 .568 .865 r
.29321 .51933 .31262 .53129 .31155 .51679 .29203 .50488 Metetra
.49 .569 .863 r
.29203 .50488 .31155 .51679 .31049 .50139 .29084 .48997 Metetra
.501 .577 .864 r
.29084 .48997 .31049 .50139 .30942 .48539 .28964 .47483 Metetra
.514 .589 .868 r
.28964 .47483 .30942 .48539 .30835 .4691 .28843 .45964 Metetra
.529 .605 .874 r
.28843 .45964 .30835 .4691 .30725 .45279 .28719 .44457 Metetra
.545 .624 .882 r
.28719 .44457 .30725 .45279 .30614 .43667 .28592 .42975 Metetra
.56 .644 .89 r
.28592 .42975 .30614 .43667 .305 .42091 .28463 .41526 Metetra
.576 .664 .898 r
.28463 .41526 .305 .42091 .30383 .4056 .2833 .40113 Metetra
.59 .684 .907 r
.2833 .40113 .30383 .4056 .30263 .39079 .28195 .3874 Metetra
.602 .703 .915 r
.28195 .3874 .30263 .39079 .30139 .37648 .28056 .37405 Metetra
.613 .721 .922 r
.28056 .37405 .30139 .37648 .30013 .36266 .27913 .36106 Metetra
.622 .737 .929 r
.27913 .36106 .30013 .36266 .29883 .3493 .27768 .34842 Metetra
.629 .751 .935 r
.27768 .34842 .29883 .3493 .2975 .33635 .27619 .33608 Metetra
.635 .764 .941 r
.27619 .33608 .2975 .33635 .29613 .32377 .27466 .32402 Metetra
.64 .776 .945 r
.27466 .32402 .29613 .32377 .29474 .31151 .27311 .31219 Metetra
.643 .785 .95 r
.27311 .31219 .29474 .31151 .29331 .29953 .27152 .30058 Metetra
.646 .794 .954 r
.27152 .30058 .29331 .29953 .29185 .28778 .2699 .28913 Metetra
.647 .802 .957 r
.2699 .28913 .29185 .28778 .29036 .27622 .26825 .27783 Metetra
.648 .808 .96 r
.26825 .27783 .29036 .27622 .28885 .26483 .26656 .26665 Metetra
.649 .814 .963 r
.26656 .26665 .28885 .26483 .2873 .25356 .26485 .25556 Metetra
.649 .819 .965 r
.26485 .25556 .2873 .25356 .28572 .24239 .2631 .24453 Metetra
.648 .823 .967 r
.2631 .24453 .28572 .24239 .28411 .23129 .26131 .23355 Metetra
.647 .826 .969 r
.26131 .23355 .28411 .23129 .28247 .22024 .2595 .2226 Metetra
.646 .829 .971 r
.2595 .2226 .28247 .22024 .2808 .20922 .25765 .21165 Metetra
.645 .832 .972 r
.25765 .21165 .2808 .20922 .2791 .1982 .25577 .2007 Metetra
.644 .834 .974 r
.25577 .2007 .2791 .1982 .27737 .18717 .25385 .18972 Metetra
.642 .836 .975 r
.25385 .18972 .27737 .18717 .2756 .17611 .2519 .1787 Metetra
.641 .838 .976 r
.2519 .1787 .2756 .17611 .27381 .16501 .24991 .16764 Metetra
.639 .839 .977 r
.24991 .16764 .27381 .16501 .27198 .15386 .24789 .1565 Metetra
.638 .84 .978 r
.24789 .1565 .27198 .15386 .27011 .14263 .24583 .1453 Metetra
.636 .841 .979 r
.24583 .1453 .27011 .14263 .26822 .13133 .24373 .134 Metetra
.635 .842 .98 r
.24373 .134 .26822 .13133 .26629 .11993 .24159 .12261 Metetra
.633 .842 .98 r
.24159 .12261 .26629 .11993 .26432 .10843 .23942 .11111 Metetra
.523 .754 .981 r
.31932 .59165 .33829 .59402 .33723 .58864 .31818 .58468 Metetra
.515 .715 .963 r
.31818 .58468 .33723 .58864 .33618 .58238 .31704 .57663 Metetra
.505 .675 .941 r
.31704 .57663 .33618 .58238 .33513 .57498 .31591 .56733 Metetra
.495 .637 .917 r
.31591 .56733 .33513 .57498 .3341 .56621 .3148 .55667 Metetra
.486 .604 .895 r
.3148 .55667 .3341 .56621 .33308 .55587 .3137 .54464 Metetra
.479 .578 .876 r
.3137 .54464 .33308 .55587 .33208 .54382 .31262 .53129 Metetra
.476 .56 .862 r
.31262 .53129 .33208 .54382 .33111 .53007 .31155 .51679 Metetra
.477 .551 .853 r
.31155 .51679 .33111 .53007 .33015 .5148 .31049 .50139 Metetra
.483 .551 .85 r
.31049 .50139 .33015 .5148 .3292 .4983 .30942 .48539 Metetra
.494 .558 .85 r
.30942 .48539 .3292 .4983 .32826 .48099 .30835 .4691 Metetra
.508 .572 .855 r
.30835 .4691 .32826 .48099 .32731 .46329 .30725 .45279 Metetra
.526 .591 .863 r
.30725 .45279 .32731 .46329 .32635 .44561 .30614 .43667 Metetra
.544 .613 .872 r
.30614 .43667 .32635 .44561 .32536 .42824 .305 .42091 Metetra
.563 .636 .882 r
.305 .42091 .32536 .42824 .32435 .41138 .30383 .4056 Metetra
.581 .66 .892 r
.30383 .4056 .32435 .41138 .3233 .39515 .30263 .39079 Metetra
.597 .683 .902 r
.30263 .39079 .3233 .39515 .32223 .37959 .30139 .37648 Metetra
.611 .705 .911 r
.30139 .37648 .32223 .37959 .32112 .36469 .30013 .36266 Metetra
.623 .724 .92 r
.30013 .36266 .32112 .36469 .31998 .35041 .29883 .3493 Metetra
.632 .742 .927 r
.29883 .3493 .31998 .35041 .3188 .33669 .2975 .33635 Metetra
.64 .758 .934 r
.2975 .33635 .3188 .33669 .3176 .32347 .29613 .32377 Metetra
.646 .771 .94 r
.29613 .32377 .3176 .32347 .31636 .31068 .29474 .31151 Metetra
.65 .783 .945 r
.29474 .31151 .31636 .31068 .3151 .29826 .29331 .29953 Metetra
.653 .794 .949 r
.29331 .29953 .3151 .29826 .3138 .28616 .29185 .28778 Metetra
.655 .802 .953 r
.29185 .28778 .3138 .28616 .31248 .27431 .29036 .27622 Metetra
.656 .81 .957 r
.29036 .27622 .31248 .27431 .31113 .26269 .28885 .26483 Metetra
.657 .816 .96 r
.28885 .26483 .31113 .26269 .30975 .25123 .2873 .25356 Metetra
.657 .822 .963 r
.2873 .25356 .30975 .25123 .30834 .23991 .28572 .24239 Metetra
.656 .826 .965 r
.28572 .24239 .30834 .23991 .3069 .22869 .28411 .23129 Metetra
.655 .83 .967 r
.28411 .23129 .3069 .22869 .30544 .21755 .28247 .22024 Metetra
.654 .833 .969 r
.28247 .22024 .30544 .21755 .30395 .20645 .2808 .20922 Metetra
.652 .836 .971 r
.2808 .20922 .30395 .20645 .30243 .19537 .2791 .1982 Metetra
.65 .838 .972 r
.2791 .1982 .30243 .19537 .30088 .1843 .27737 .18717 Metetra
.649 .84 .974 r
.27737 .18717 .30088 .1843 .2993 .17322 .2756 .17611 Metetra
.647 .842 .975 r
.2756 .17611 .2993 .17322 .29769 .16209 .27381 .16501 Metetra
.645 .843 .976 r
.27381 .16501 .29769 .16209 .29606 .15093 .27198 .15386 Metetra
.643 .844 .977 r
.27198 .15386 .29606 .15093 .29439 .13969 .27011 .14263 Metetra
.641 .845 .978 r
.27011 .14263 .29439 .13969 .2927 .12839 .26822 .13133 Metetra
.64 .845 .979 r
.26822 .13133 .2927 .12839 .29097 .11699 .26629 .11993 Metetra
.638 .846 .98 r
.26629 .11993 .29097 .11699 .28921 .10549 .26432 .10843 Metetra
.543 .829 .998 r
.33829 .59402 .35733 .59339 .35637 .58936 .33723 .58864 Metetra
.54 .795 .992 r
.33723 .58864 .35637 .58936 .35541 .58476 .33618 .58238 Metetra
.532 .753 .977 r
.33618 .58238 .35541 .58476 .35445 .57937 .33513 .57498 Metetra
.521 .705 .954 r
.33513 .57498 .35445 .57937 .35349 .57288 .3341 .56621 Metetra
.508 .656 .927 r
.3341 .56621 .35349 .57288 .35255 .56497 .33308 .55587 Metetra
.494 .612 .898 r
.33308 .55587 .35255 .56497 .35162 .55527 .33208 .54382 Metetra
.482 .576 .873 r
.33208 .54382 .35162 .55527 .35072 .54352 .33111 .53007 Metetra
.474 .55 .853 r
.33111 .53007 .35072 .54352 .34985 .52957 .33015 .5148 Metetra
.471 .534 .841 r
.33015 .5148 .34985 .52957 .34901 .51353 .3292 .4983 Metetra
.475 .531 .835 r
.3292 .4983 .34901 .51353 .34818 .49577 .32826 .48099 Metetra
.485 .537 .835 r
.32826 .48099 .34818 .49577 .34737 .47685 .32731 .46329 Metetra
.501 .553 .841 r
.32731 .46329 .34737 .47685 .34655 .4574 .32635 .44561 Metetra
.522 .575 .85 r
.32635 .44561 .34655 .4574 .34572 .43802 .32536 .42824 Metetra
.544 .601 .861 r
.32536 .42824 .34572 .43802 .34486 .41911 .32435 .41138 Metetra
.566 .629 .873 r
.32435 .41138 .34486 .41911 .34398 .40097 .3233 .39515 Metetra
.587 .657 .886 r
.3233 .39515 .34398 .40097 .34306 .3837 .32223 .37959 Metetra
.606 .684 .897 r
.32223 .37959 .34306 .3837 .34211 .36734 .32112 .36469 Metetra
.622 .709 .908 r
.32112 .36469 .34211 .36734 .34113 .35184 .31998 .35041 Metetra
.635 .731 .917 r
.31998 .35041 .34113 .35184 .34011 .33711 .3188 .33669 Metetra
.645 .75 .925 r
.3188 .33669 .34011 .33711 .33907 .32308 .3176 .32347 Metetra
.653 .767 .933 r
.3176 .32347 .33907 .32308 .33799 .30964 .31636 .31068 Metetra
.659 .781 .939 r
.31636 .31068 .33799 .30964 .33688 .2967 .3151 .29826 Metetra
.662 .793 .944 r
.3151 .29826 .33688 .2967 .33575 .28419 .3138 .28616 Metetra
.665 .804 .949 r
.3138 .28616 .33575 .28419 .33459 .27202 .31248 .27431 Metetra
.666 .812 .953 r
.31248 .27431 .33459 .27202 .3334 .26014 .31113 .26269 Metetra
.666 .819 .957 r
.31113 .26269 .3334 .26014 .33219 .24849 .30975 .25123 Metetra
.666 .825 .96 r
.30975 .25123 .33219 .24849 .33095 .23701 .30834 .23991 Metetra
.665 .83 .963 r
.30834 .23991 .33095 .23701 .32969 .22568 .3069 .22869 Metetra
.664 .834 .965 r
.3069 .22869 .32969 .22568 .3284 .21445 .30544 .21755 Metetra
.662 .838 .967 r
.30544 .21755 .3284 .21445 .32708 .20328 .30395 .20645 Metetra
.66 .841 .969 r
.30395 .20645 .32708 .20328 .32574 .19216 .30243 .19537 Metetra
.658 .843 .971 r
.30243 .19537 .32574 .19216 .32438 .18106 .30088 .1843 Metetra
.656 .845 .973 r
.30088 .1843 .32438 .18106 .32299 .16996 .2993 .17322 Metetra
.654 .846 .974 r
.2993 .17322 .32299 .16996 .32157 .15883 .29769 .16209 Metetra
.652 .848 .975 r
.29769 .16209 .32157 .15883 .32013 .14766 .29606 .15093 Metetra
.649 .848 .976 r
.29606 .15093 .32013 .14766 .31866 .13643 .29439 .13969 Metetra
.647 .849 .977 r
.29439 .13969 .31866 .13643 .31716 .12514 .2927 .12839 Metetra
.645 .85 .978 r
.2927 .12839 .31716 .12514 .31564 .11376 .29097 .11699 Metetra
.643 .85 .979 r
.29097 .11699 .31564 .11376 .31409 .10228 .28921 .10549 Metetra
.554 .888 .986 r
.35733 .59339 .3764 .59003 .37556 .58683 .35637 .58936 Metetra
.557 .872 .994 r
.35637 .58936 .37556 .58683 .37471 .5834 .35541 .58476 Metetra
.558 .845 .998 r
.35541 .58476 .37471 .5834 .37385 .5796 .35445 .57937 Metetra
.555 .805 .991 r
.35445 .57937 .37385 .5796 .37299 .57519 .35349 .57288 Metetra
.545 .752 .973 r
.35349 .57288 .37299 .57519 .37213 .56985 .35255 .56497 Metetra
.53 .693 .943 r
.35255 .56497 .37213 .56985 .37128 .56316 .35162 .55527 Metetra
.511 .634 .908 r
.35162 .55527 .37128 .56316 .37045 .5546 .35072 .54352 Metetra
.492 .583 .874 r
.35072 .54352 .37045 .5546 .36964 .54364 .34985 .52957 Metetra
.476 .543 .846 r
.34985 .52957 .36964 .54364 .36887 .52988 .34901 .51353 Metetra
.467 .519 .828 r
.34901 .51353 .36887 .52988 .36813 .51323 .34818 .49577 Metetra
.466 .509 .818 r
.34818 .49577 .36813 .51323 .36743 .49406 .34737 .47685 Metetra
.475 .513 .817 r
.34737 .47685 .36743 .49406 .36674 .47313 .34655 .4574 Metetra
.493 .53 .824 r
.34655 .4574 .36674 .47313 .36606 .45143 .34572 .43802 Metetra
.516 .556 .835 r
.34572 .43802 .36606 .45143 .36536 .42985 .34486 .41911 Metetra
.544 .588 .849 r
.34486 .41911 .36536 .42985 .36464 .40904 .34398 .40097 Metetra
.571 .622 .864 r
.34398 .40097 .36464 .40904 .36389 .38936 .34306 .3837 Metetra
.596 .656 .879 r
.34306 .3837 .36389 .38936 .3631 .37094 .34211 .36734 Metetra
.618 .688 .893 r
.34211 .36734 .3631 .37094 .36228 .35375 .34113 .35184 Metetra
.636 .716 .905 r
.34113 .35184 .36228 .35375 .36142 .33768 .34011 .33711 Metetra
.65 .74 .915 r
.34011 .33711 .36142 .33768 .36053 .32258 .33907 .32308 Metetra
.661 .761 .924 r
.33907 .32308 .36053 .32258 .35961 .30832 .33799 .30964 Metetra
.668 .779 .932 r
.33799 .30964 .35961 .30832 .35867 .29475 .33688 .2967 Metetra
.673 .793 .939 r
.33688 .2967 .35867 .29475 .35769 .28175 .33575 .28419 Metetra
.676 .806 .944 r
.33575 .28419 .35769 .28175 .3567 .26922 .33459 .27202 Metetra
.678 .816 .949 r
.33459 .27202 .3567 .26922 .35567 .25706 .3334 .26014 Metetra
.678 .824 .953 r
.3334 .26014 .35567 .25706 .35463 .2452 .33219 .24849 Metetra
.677 .83 .957 r
.33219 .24849 .35463 .2452 .35356 .23358 .33095 .23701 Metetra
.676 .836 .96 r
.33095 .23701 .35356 .23358 .35246 .22214 .32969 .22568 Metetra
.674 .84 .963 r
.32969 .22568 .35246 .22214 .35135 .21084 .3284 .21445 Metetra
.672 .844 .965 r
.3284 .21445 .35135 .21084 .35021 .19963 .32708 .20328 Metetra
.669 .847 .968 r
.32708 .20328 .35021 .19963 .34905 .18849 .32574 .19216 Metetra
.667 .849 .97 r
.32574 .19216 .34905 .18849 .34787 .17738 .32438 .18106 Metetra
.664 .851 .971 r
.32438 .18106 .34787 .17738 .34666 .16628 .32299 .16996 Metetra
.661 .852 .973 r
.32299 .16996 .34666 .16628 .34544 .15516 .32157 .15883 Metetra
.659 .853 .974 r
.32157 .15883 .34544 .15516 .34419 .14401 .32013 .14766 Metetra
.656 .854 .975 r
.32013 .14766 .34419 .14401 .34291 .13281 .31866 .13643 Metetra
.653 .854 .977 r
.31866 .13643 .34291 .13281 .34162 .12154 .31716 .12514 Metetra
.651 .855 .978 r
.31716 .12514 .34162 .12154 .3403 .11019 .31564 .11376 Metetra
.648 .855 .979 r
.31564 .11376 .3403 .11019 .33895 .09874 .31409 .10228 Metetra
.558 .918 .954 r
.3764 .59003 .39549 .5846 .39477 .58169 .37556 .58683 Metetra
.561 .915 .961 r
.37556 .58683 .39477 .58169 .39405 .57879 .37471 .5834 Metetra
.567 .909 .973 r
.37471 .5834 .39405 .57879 .39331 .57584 .37385 .5796 Metetra
.573 .895 .986 r
.37385 .5796 .39331 .57584 .39256 .57273 .37299 .57519 Metetra
.579 .867 .995 r
.37299 .57519 .39256 .57273 .39181 .56928 .37213 .56985 Metetra
.577 .82 .991 r
.37213 .56985 .39181 .56928 .39106 .56522 .37128 .56316 Metetra
.564 .754 .967 r
.37128 .56316 .39106 .56522 .3903 .56007 .37045 .5546 Metetra
.541 .678 .927 r
.37045 .5546 .3903 .56007 .38956 .55322 .36964 .54364 Metetra
.514 .606 .883 r
.36964 .54364 .38956 .55322 .38885 .54381 .36887 .52988 Metetra
.488 .547 .844 r
.36887 .52988 .38885 .54381 .38817 .531 .36813 .51323 Metetra
.468 .507 .816 r
.36813 .51323 .38817 .531 .38754 .51421 .36743 .49406 Metetra
.459 .486 .8 r
.36743 .49406 .38754 .51421 .38695 .49358 .36674 .47313 Metetra
.463 .486 .797 r
.36674 .47313 .38695 .49358 .3864 .47012 .36606 .45143 Metetra
.481 .503 .804 r
.36606 .45143 .3864 .47012 .38585 .44537 .36536 .42985 Metetra
.51 .535 .818 r
.36536 .42985 .38585 .44537 .38529 .42086 .36464 .40904 Metetra
.544 .575 .836 r
.36464 .40904 .38529 .42086 .3847 .39762 .36389 .38936 Metetra
.579 .618 .855 r
.36389 .38936 .3847 .39762 .38408 .37612 .3631 .37094 Metetra
.61 .659 .873 r
.3631 .37094 .38408 .37612 .38342 .35645 .36228 .35375 Metetra
.635 .696 .889 r
.36228 .35375 .38342 .35645 .38273 .33846 .36142 .33768 Metetra
.655 .728 .902 r
.36142 .33768 .38273 .33846 .382 .32191 .36053 .32258 Metetra
.67 .755 .914 r
.36053 .32258 .382 .32191 .38124 .30657 .35961 .30832 Metetra
.68 .777 .924 r
.35961 .30832 .38124 .30657 .38045 .29222 .35867 .29475 Metetra
.687 .795 .932 r
.35867 .29475 .38045 .29222 .37964 .27865 .35769 .28175 Metetra
.69 .809 .939 r
.35769 .28175 .37964 .27865 .3788 .26571 .3567 .26922 Metetra
.692 .821 .944 r
.3567 .26922 .3788 .26571 .37794 .25327 .35567 .25706 Metetra
.692 .83 .949 r
.35567 .25706 .37794 .25327 .37706 .24122 .35463 .2452 Metetra
.691 .837 .954 r
.35463 .2452 .37706 .24122 .37615 .22947 .35356 .23358 Metetra
.689 .843 .957 r
.35356 .23358 .37615 .22947 .37523 .21795 .35246 .22214 Metetra
.686 .848 .96 r
.35246 .22214 .37523 .21795 .37429 .20661 .35135 .21084 Metetra
.683 .851 .963 r
.35135 .21084 .37429 .20661 .37333 .19538 .35021 .19963 Metetra
.68 .854 .966 r
.35021 .19963 .37333 .19538 .37234 .18425 .34905 .18849 Metetra
.677 .856 .968 r
.34905 .18849 .37234 .18425 .37134 .17316 .34787 .17738 Metetra
.673 .858 .97 r
.34787 .17738 .37134 .17316 .37033 .16209 .34666 .16628 Metetra
.67 .859 .972 r
.34666 .16628 .37033 .16209 .36929 .15101 .34544 .15516 Metetra
.667 .86 .973 r
.34544 .15516 .36929 .15101 .36823 .13991 .34419 .14401 Metetra
.664 .86 .974 r
.34419 .14401 .36823 .13991 .36715 .12876 .34291 .13281 Metetra
.66 .86 .976 r
.34291 .13281 .36715 .12876 .36606 .11754 .34162 .12154 Metetra
.657 .86 .977 r
.34162 .12154 .36606 .11754 .36494 .10624 .3403 .11019 Metetra
.655 .86 .978 r
.3403 .11019 .36494 .10624 .3638 .09485 .33895 .09874 Metetra
.569 .932 .93 r
.39549 .5846 .41456 .57793 .41398 .57489 .39477 .58169 Metetra
.568 .932 .927 r
.39477 .58169 .41398 .57489 .41338 .57196 .39405 .57879 Metetra
.568 .932 .928 r
.39405 .57879 .41338 .57196 .41278 .56914 .39331 .57584 Metetra
.572 .932 .934 r
.39331 .57584 .41278 .56914 .41217 .56642 .39256 .57273 Metetra
.58 .93 .947 r
.39256 .57273 .41217 .56642 .41154 .56376 .39181 .56928 Metetra
.593 .922 .968 r
.39181 .56928 .41154 .56376 .41091 .56106 .39106 .56522 Metetra
.606 .899 .987 r
.39106 .56522 .41091 .56106 .41027 .55815 .3903 .56007 Metetra
.609 .845 .988 r
.3903 .56007 .41027 .55815 .40963 .55466 .38956 .55322 Metetra
.592 .759 .958 r
.38956 .55322 .40963 .55466 .40899 .54997 .38885 .54381 Metetra
.558 .66 .905 r
.38885 .54381 .40899 .54997 .40836 .54307 .38817 .531 Metetra
.517 .572 .85 r
.38817 .531 .40836 .54307 .40777 .5325 .38754 .51421 Metetra
.48 .506 .807 r
.38754 .51421 .40777 .5325 .40724 .51672 .38695 .49358 Metetra
.455 .467 .782 r
.38695 .49358 .40724 .51672 .40676 .49498 .3864 .47012 Metetra
.449 .455 .773 r
.3864 .47012 .40676 .49498 .40633 .46828 .38585 .44537 Metetra
.465 .472 .781 r
.38585 .44537 .40633 .46828 .40593 .43923 .38529 .42086 Metetra
.501 .511 .799 r
.38529 .42086 .40593 .43923 .40551 .41059 .3847 .39762 Metetra
.546 .563 .823 r
.3847 .39762 .40551 .41059 .40506 .38416 .38408 .37612 Metetra
.591 .617 .847 r
.38408 .37612 .40506 .38416 .40457 .36053 .38342 .35645 Metetra
.629 .668 .868 r
.38342 .35645 .40457 .36053 .40404 .3396 .38273 .33846 Metetra
.659 .711 .886 r
.38273 .33846 .40404 .3396 .40347 .32096 .382 .32191 Metetra
.681 .747 .901 r
.382 .32191 .40347 .32096 .40286 .30416 .38124 .30657 Metetra
.695 .775 .913 r
.38124 .30657 .40286 .30416 .40223 .28882 .38045 .29222 Metetra
.704 .798 .923 r
.38045 .29222 .40223 .28882 .40157 .27458 .37964 .27865 Metetra
.708 .815 .932 r
.37964 .27865 .40157 .27458 .40089 .26121 .3788 .26571 Metetra
.71 .829 .938 r
.3788 .26571 .40089 .26121 .40019 .2485 .37794 .25327 Metetra
.709 .839 .944 r
.37794 .25327 .40019 .2485 .39947 .23628 .37706 .24122 Metetra
.707 .847 .949 r
.37706 .24122 .39947 .23628 .39874 .22445 .37615 .22947 Metetra
.704 .853 .954 r
.37615 .22947 .39874 .22445 .39798 .21291 .37523 .21795 Metetra
.7 .858 .957 r
.37523 .21795 .39798 .21291 .39721 .20158 .37429 .20661 Metetra
.696 .861 .961 r
.37429 .20661 .39721 .20158 .39643 .19039 .37333 .19538 Metetra
.692 .863 .963 r
.37333 .19538 .39643 .19039 .39562 .17931 .37234 .18425 Metetra
.688 .865 .966 r
.37234 .18425 .39562 .17931 .3948 .16829 .37134 .17316 Metetra
.684 .866 .968 r
.37134 .17316 .3948 .16829 .39397 .1573 .37033 .16209 Metetra
.68 .867 .97 r
.37033 .16209 .39397 .1573 .39312 .1463 .36929 .15101 Metetra
.676 .867 .972 r
.36929 .15101 .39312 .1463 .39225 .13528 .36823 .13991 Metetra
.672 .867 .973 r
.36823 .13991 .39225 .13528 .39137 .12421 .36715 .12876 Metetra
.668 .867 .975 r
.36715 .12876 .39137 .12421 .39047 .11308 .36606 .11754 Metetra
.665 .867 .976 r
.36606 .11754 .39047 .11308 .38956 .10186 .36494 .10624 Metetra
.661 .867 .977 r
.36494 .10624 .38956 .10186 .38863 .09055 .3638 .09485 Metetra
.589 .941 .927 r
.41456 .57793 .43361 .57074 .43316 .56734 .41398 .57489 Metetra
.586 .942 .917 r
.41398 .57489 .43316 .56734 .4327 .56404 .41338 .57196 Metetra
.583 .942 .907 r
.41338 .57196 .4327 .56404 .43223 .56088 .41278 .56914 Metetra
.58 .942 .897 r
.41278 .56914 .43223 .56088 .43176 .55788 .41217 .56642 Metetra
.578 .942 .89 r
.41217 .56642 .43176 .55788 .43127 .55507 .41154 .56376 Metetra
.58 .943 .889 r
.41154 .56376 .43127 .55507 .43078 .55246 .41091 .56106 Metetra
.589 .946 .898 r
.41091 .56106 .43078 .55246 .43028 .55007 .41027 .55815 Metetra
.61 .949 .925 r
.41027 .55815 .43028 .55007 .42977 .54785 .40963 .55466 Metetra
.64 .939 .963 r
.40963 .55466 .42977 .54785 .42925 .54566 .40899 .54997 Metetra
.658 .884 .981 r
.40899 .54997 .42925 .54566 .42873 .54312 .40836 .54307 Metetra
.635 .77 .945 r
.40836 .54307 .42873 .54312 .42821 .53938 .40777 .5325 Metetra
.581 .639 .873 r
.40777 .5325 .42821 .53938 .4277 .53274 .40724 .51672 Metetra
.519 .532 .809 r
.40724 .51672 .4277 .53274 .42725 .52038 .40676 .49498 Metetra
.466 .459 .766 r
.40676 .49498 .42725 .52038 .42686 .49918 .40633 .46828 Metetra
.436 .424 .747 r
.40633 .46828 .42686 .49918 .42656 .46864 .40593 .43923 Metetra
.443 .433 .753 r
.40593 .43923 .42656 .46864 .4263 .43299 .40551 .41059 Metetra
.488 .482 .777 r
.40551 .41059 .4263 .43299 .42603 .39811 .40506 .38416 Metetra
.551 .553 .809 r
.40506 .38416 .42603 .39811 .42571 .3674 .40457 .36053 Metetra
.613 .626 .84 r
.40457 .36053 .42571 .3674 .42534 .34143 .40404 .3396 Metetra
.661 .688 .865 r
.40404 .3396 .42534 .34143 .42493 .31949 .40347 .32096 Metetra
.694 .738 .885 r
.40347 .32096 .42493 .31949 .42448 .30062 .40286 .30416 Metetra
.715 .776 .9 r
.40286 .30416 .42448 .30062 .424 .28401 .40223 .28882 Metetra
.727 .805 .913 r
.40223 .28882 .424 .28401 .4235 .26903 .40157 .27458 Metetra
.732 .826 .923 r
.40157 .27458 .4235 .26903 .42298 .25525 .40089 .26121 Metetra
.733 .841 .931 r
.40089 .26121 .42298 .25525 .42243 .24233 .40019 .2485 Metetra
.731 .853 .938 r
.40019 .2485 .42243 .24233 .42188 .23005 .39947 .23628 Metetra
.728 .861 .944 r
.39947 .23628 .42188 .23005 .4213 .21824 .39874 .22445 Metetra
.723 .867 .949 r
.39874 .22445 .4213 .21824 .42072 .20676 .39798 .21291 Metetra
.718 .871 .953 r
.39798 .21291 .42072 .20676 .42012 .19553 .39721 .20158 Metetra
.712 .874 .957 r
.39721 .20158 .42012 .19553 .4195 .18447 .39643 .19039 Metetra
.707 .875 .96 r
.39643 .19039 .4195 .18447 .41888 .17353 .39562 .17931 Metetra
.701 .876 .963 r
.39562 .17931 .41888 .17353 .41824 .16264 .3948 .16829 Metetra
.696 .877 .966 r
.3948 .16829 .41824 .16264 .41759 .15179 .39397 .1573 Metetra
.691 .877 .968 r
.39397 .1573 .41759 .15179 .41693 .14093 .39312 .1463 Metetra
.686 .877 .97 r
.39312 .1463 .41693 .14093 .41626 .13004 .39225 .13528 Metetra
.681 .876 .972 r
.39225 .13528 .41626 .13004 .41557 .1191 .39137 .12421 Metetra
.676 .875 .973 r
.39137 .12421 .41557 .1191 .41487 .10809 .39047 .11308 Metetra
.672 .875 .975 r
.39047 .11308 .41487 .10809 .41416 .09699 .38956 .10186 Metetra
.668 .874 .976 r
.38956 .10186 .41416 .09699 .41343 .08579 .38863 .09055 Metetra
.61 .945 .937 r
.43361 .57074 .45262 .56356 .4523 .5597 .43316 .56734 Metetra
.61 .948 .927 r
.43316 .56734 .4523 .5597 .45198 .5559 .4327 .56404 Metetra
.609 .951 .915 r
.4327 .56404 .45198 .5559 .45165 .55218 .43223 .56088 Metetra
.607 .952 .901 r
.43223 .56088 .45165 .55218 .45131 .54859 .43176 .55788 Metetra
.602 .952 .884 r
.43176 .55788 .45131 .54859 .45097 .54514 .43127 .55507 Metetra
.597 .95 .864 r
.43127 .55507 .45097 .54514 .45062 .54189 .43078 .55246 Metetra
.59 .947 .842 r
.43078 .55246 .45062 .54189 .45027 .53889 .43028 .55007 Metetra
.585 .944 .823 r
.43028 .55007 .45027 .53889 .44991 .53621 .42977 .54785 Metetra
.588 .944 .814 r
.42977 .54785 .44991 .53621 .44954 .53393 .42925 .54566 Metetra
.611 .955 .831 r
.42925 .54566 .44954 .53393 .44916 .5321 .42873 .54312 Metetra
.668 .973 .89 r
.42873 .54312 .44916 .5321 .44877 .53074 .42821 .53938 Metetra
.727 .943 .953 r
.42821 .53938 .44877 .53074 .44838 .5296 .4277 .53274 Metetra
.703 .793 .92 r
.4277 .53274 .44838 .5296 .44798 .52774 .42725 .52038 Metetra
.614 .616 .829 r
.42725 .52038 .44798 .52774 .44761 .52229 .42686 .49918 Metetra
.519 .487 .761 r
.42686 .49918 .44761 .52229 .44729 .50671 .42656 .46864 Metetra
.437 .402 .722 r
.42656 .46864 .44729 .50671 .44708 .47346 .4263 .43299 Metetra
.41 .383 .718 r
.4263 .43299 .44708 .47346 .44697 .42666 .42603 .39811 Metetra
.468 .446 .751 r
.42603 .39811 .44697 .42666 .44684 .38123 .42571 .3674 Metetra
.568 .554 .798 r
.42571 .3674 .44684 .38123 .44665 .34487 .42534 .34143 Metetra
.656 .654 .836 r
.42534 .34143 .44665 .34487 .4464 .31695 .42493 .31949 Metetra
.713 .73 .863 r
.42493 .31949 .4464 .31695 .4461 .29493 .42448 .30062 Metetra
.745 .783 .883 r
.42448 .30062 .4461 .29493 .44577 .27674 .424 .28401 Metetra
.761 .819 .898 r
.424 .28401 .44577 .27674 .44541 .26105 .4235 .26903 Metetra
.766 .844 .91 r
.4235 .26903 .44541 .26105 .44504 .24702 .42298 .25525 Metetra
.765 .861 .92 r
.42298 .25525 .44504 .24702 .44466 .23411 .42243 .24233 Metetra
.761 .873 .929 r
.42243 .24233 .44466 .23411 .44426 .22198 .42188 .23005 Metetra
.754 .88 .936 r
.42188 .23005 .44426 .22198 .44385 .21038 .4213 .21824 Metetra
.747 .885 .942 r
.4213 .21824 .44385 .21038 .44343 .19916 .42072 .20676 Metetra
.739 .888 .948 r
.42072 .20676 .44343 .19916 .443 .18819 .42012 .19553 Metetra
.731 .89 .952 r
.42012 .19553 .443 .18819 .44256 .17738 .4195 .18447 Metetra
.724 .891 .956 r
.4195 .18447 .44256 .17738 .44211 .16669 .41888 .17353 Metetra
.716 .89 .96 r
.41888 .17353 .44211 .16669 .44165 .15604 .41824 .16264 Metetra
.709 .89 .963 r
.41824 .16264 .44165 .15604 .44119 .14541 .41759 .15179 Metetra
.703 .889 .966 r
.41759 .15179 .44119 .14541 .44071 .13477 .41693 .14093 Metetra
.697 .888 .968 r
.41693 .14093 .44071 .13477 .44023 .12408 .41626 .13004 Metetra
.691 .887 .97 r
.41626 .13004 .44023 .12408 .43974 .11333 .41557 .1191 Metetra
.685 .885 .972 r
.41557 .1191 .43974 .11333 .43924 .1025 .41487 .10809 Metetra
.68 .884 .973 r
.41487 .10809 .43924 .1025 .43873 .09156 .41416 .09699 Metetra
.676 .882 .975 r
.41416 .09699 .43873 .09156 .43821 .08052 .41343 .08579 Metetra
.628 .944 .951 r
.45262 .56356 .4716 .55671 .47141 .55239 .4523 .5597 Metetra
.631 .949 .944 r
.4523 .5597 .47141 .55239 .47121 .54807 .45198 .5559 Metetra
.634 .953 .935 r
.45198 .5559 .47121 .54807 .47102 .54377 .45165 .55218 Metetra
.635 .958 .923 r
.45165 .55218 .47102 .54377 .47082 .53951 .45131 .54859 Metetra
.636 .961 .909 r
.45131 .54859 .47082 .53951 .47062 .53531 .45097 .54514 Metetra
.635 .963 .89 r
.45097 .54514 .47062 .53531 .47041 .53119 .45062 .54189 Metetra
.631 .963 .866 r
.45062 .54189 .47041 .53119 .47021 .5272 .45027 .53889 Metetra
.623 .959 .835 r
.45027 .53889 .47021 .5272 .46999 .52339 .44991 .53621 Metetra
.611 .95 .796 r
.44991 .53621 .46999 .52339 .46978 .51983 .44954 .53393 Metetra
.593 .934 .747 r
.44954 .53393 .46978 .51983 .46956 .51663 .44916 .5321 Metetra
.575 .915 .695 r
.44916 .5321 .46956 .51663 .46933 .51393 .44877 .53074 Metetra
.574 .904 .66 r
.44877 .53074 .46933 .51393 .4691 .51194 .44838 .5296 Metetra
.635 .937 .695 r
.44838 .5296 .4691 .51194 .46886 .51097 .44798 .52774 Metetra
.796 .999 .846 r
.44798 .52774 .46886 .51097 .46861 .51133 .44761 .52229 Metetra
.804 .826 .868 r
.44761 .52229 .46861 .51133 .46835 .51284 .44729 .50671 Metetra
.662 .595 .77 r
.44729 .50671 .46835 .51284 .4681 .5116 .44708 .47346 Metetra
.505 .434 .71 r
.44708 .47346 .4681 .5116 .46793 .48793 .44697 .42666 Metetra
.363 .32 .676 r
.44697 .42666 .46793 .48793 .46795 .42024 .44684 .38123 Metetra
.431 .397 .721 r
.44684 .38123 .46795 .42024 .46795 .35362 .44665 .34487 Metetra
.625 .591 .796 r
.44665 .34487 .46795 .35362 .46786 .31151 .4464 .31695 Metetra
.746 .727 .835 r
.4464 .31695 .46786 .31151 .4677 .28433 .4461 .29493 Metetra
.798 .804 .857 r
.4461 .29493 .4677 .28433 .46751 .26459 .44577 .27674 Metetra
.815 .849 .875 r
.44577 .27674 .46751 .26459 .4673 .24875 .44541 .26105 Metetra
.816 .876 .89 r
.44541 .26105 .4673 .24875 .46708 .2351 .44504 .24702 Metetra
.81 .893 .903 r
.44504 .24702 .46708 .2351 .46684 .22277 .44466 .23411 Metetra
.8 .903 .914 r
.44466 .23411 .46684 .22277 .4666 .21126 .44426 .22198 Metetra
.788 .908 .924 r
.44426 .22198 .4666 .21126 .46635 .20027 .44385 .21038 Metetra
.776 .911 .932 r
.44385 .21038 .46635 .20027 .4661 .18961 .44343 .19916 Metetra
.764 .911 .939 r
.44343 .19916 .4661 .18961 .46584 .17916 .443 .18819 Metetra
.753 .911 .945 r
.443 .18819 .46584 .17916 .46557 .16883 .44256 .17738 Metetra
.743 .91 .95 r
.44256 .17738 .46557 .16883 .4653 .15856 .44211 .16669 Metetra
.733 .908 .955 r
.44211 .16669 .4653 .15856 .46503 .1483 .44165 .15604 Metetra
.724 .906 .959 r
.44165 .15604 .46503 .1483 .46475 .13802 .44119 .14541 Metetra
.716 .903 .962 r
.44119 .14541 .46475 .13802 .46446 .1277 .44071 .13477 Metetra
.708 .901 .965 r
.44071 .13477 .46446 .1277 .46417 .1173 .44023 .12408 Metetra
.701 .899 .968 r
.44023 .12408 .46417 .1173 .46387 .10681 .43974 .11333 Metetra
.695 .896 .97 r
.43974 .11333 .46387 .10681 .46357 .09622 .43924 .1025 Metetra
.689 .894 .972 r
.43924 .1025 .46357 .09622 .46327 .08551 .43873 .09156 Metetra
.683 .891 .973 r
.43873 .09156 .46327 .08551 .46295 .07467 .43821 .08052 Metetra
.639 .938 .964 r
.4716 .55671 .49054 .55035 .49048 .54561 .47141 .55239 Metetra
.645 .943 .959 r
.47141 .55239 .49048 .54561 .49041 .54082 .47121 .54807 Metetra
.65 .948 .953 r
.47121 .54807 .49041 .54082 .49035 .536 .47102 .54377 Metetra
.655 .954 .946 r
.47102 .54377 .49035 .536 .49028 .53114 .47082 .53951 Metetra
.661 .96 .937 r
.47082 .53951 .49028 .53114 .49022 .52624 .47062 .53531 Metetra
.666 .965 .925 r
.47062 .53531 .49022 .52624 .49015 .52132 .47041 .53119 Metetra
.671 .971 .911 r
.47041 .53119 .49015 .52132 .49008 .51639 .47021 .5272 Metetra
.674 .975 .891 r
.47021 .5272 .49008 .51639 .49001 .51145 .46999 .52339 Metetra
.674 .977 .865 r
.46999 .52339 .49001 .51145 .48994 .50654 .46978 .51983 Metetra
.67 .974 .829 r
.46978 .51983 .48994 .50654 .48987 .50167 .46956 .51663 Metetra
.658 .964 .777 r
.46956 .51663 .48987 .50167 .4898 .4969 .46933 .51393 Metetra
.632 .938 .703 r
.46933 .51393 .4898 .4969 .48972 .49229 .4691 .51194 Metetra
.585 .888 .599 r
.4691 .51194 .48972 .49229 .48965 .48797 .46886 .51097 Metetra
.46886 .51097 .48965 .48797 .48957 .48414 .46861 .51133 Metetra
.46861 .51133 .48957 .48414 .48949 .4812 .46835 .51284 Metetra
.682 .869 .478 r
.46835 .51284 .48949 .4812 .48941 .48006 .4681 .5116 Metetra
.913 .839 .758 r
.4681 .5116 .48941 .48006 .48932 .483 .46793 .48793 Metetra
.723 .588 .703 r
.46793 .48793 .48932 .483 .48921 .49532 .46795 .42024 Metetra
.423 .344 .662 r
.46795 .42024 .48921 .49532 .48924 .41372 .46795 .35362 Metetra
.34 .308 .677 r
.46795 .35362 .48924 .41372 .48931 .2918 .46786 .31151 Metetra
.842 .77 .783 r
.46786 .31151 .48931 .2918 .48927 .25873 .4677 .28433 Metetra
.904 .866 .792 r
.4677 .28433 .48927 .25873 .4892 .24118 .46751 .26459 Metetra
.904 .907 .815 r
.46751 .26459 .4892 .24118 .48913 .22816 .4673 .24875 Metetra
.888 .928 .84 r
.4673 .24875 .48913 .22816 .48905 .21696 .46708 .2351 Metetra
.868 .939 .864 r
.46708 .2351 .48905 .21696 .48897 .20663 .46684 .22277 Metetra
.847 .944 .883 r
.46684 .22277 .48897 .20663 .48889 .19674 .4666 .21126 Metetra
.827 .945 .9 r
.4666 .21126 .48889 .19674 .4888 .18708 .46635 .20027 Metetra
.809 .943 .913 r
.46635 .20027 .4888 .18708 .48872 .17753 .4661 .18961 Metetra
.792 .94 .925 r
.4661 .18961 .48872 .17753 .48863 .16801 .46584 .17916 Metetra
.777 .937 .934 r
.46584 .17916 .48863 .16801 .48854 .15847 .46557 .16883 Metetra
.763 .933 .941 r
.46557 .16883 .48854 .15847 .48845 .14888 .4653 .15856 Metetra
.75 .928 .948 r
.4653 .15856 .48845 .14888 .48836 .13922 .46503 .1483 Metetra
.739 .924 .953 r
.46503 .1483 .48836 .13922 .48826 .12946 .46475 .13802 Metetra
.729 .92 .957 r
.46475 .13802 .48826 .12946 .48817 .11958 .46446 .1277 Metetra
.72 .916 .961 r
.46446 .1277 .48817 .11958 .48807 .10959 .46417 .1173 Metetra
.712 .912 .964 r
.46417 .1173 .48807 .10959 .48797 .09946 .46387 .10681 Metetra
.704 .909 .967 r
.46387 .10681 .48797 .09946 .48787 .0892 .46357 .09622 Metetra
.697 .905 .969 r
.46357 .09622 .48787 .0892 .48777 .07878 .46327 .08551 Metetra
.691 .902 .971 r
.46327 .08551 .48777 .07878 .48766 .06821 .46295 .07467 Metetra
.645 .929 .972 r
.49054 .55035 .50945 .54454 .50952 .53945 .49048 .54561 Metetra
.651 .933 .969 r
.49048 .54561 .50952 .53945 .50958 .53427 .49041 .54082 Metetra
.658 .938 .966 r
.49041 .54082 .50958 .53427 .50964 .529 .49035 .536 Metetra
.665 .943 .961 r
.49035 .536 .50964 .529 .50971 .52365 .49028 .53114 Metetra
.673 .949 .956 r
.49028 .53114 .50971 .52365 .50977 .51819 .49022 .52624 Metetra
.681 .955 .95 r
.49022 .52624 .50977 .51819 .50984 .51262 .49015 .52132 Metetra
.69 .962 .943 r
.49015 .52132 .50984 .51262 .50991 .50693 .49008 .51639 Metetra
.7 .968 .933 r
.49008 .51639 .50991 .50693 .50997 .50111 .49001 .51145 Metetra
.71 .975 .921 r
.49001 .51145 .50997 .50111 .51004 .49513 .48994 .50654 Metetra
.721 .982 .906 r
.48994 .50654 .51004 .49513 .51011 .48899 .48987 .50167 Metetra
.732 .988 .885 r
.48987 .50167 .51011 .48899 .51018 .48263 .4898 .4969 Metetra
.742 .993 .857 r
.4898 .4969 .51018 .48263 .51025 .47602 .48972 .49229 Metetra
.748 .993 .817 r
.48972 .49229 .51025 .47602 .51033 .46907 .48965 .48797 Metetra
.745 .984 .757 r
.48965 .48797 .51033 .46907 .5104 .46166 .48957 .48414 Metetra
.721 .952 .662 r
.48957 .48414 .5104 .46166 .51047 .45357 .48949 .4812 Metetra
.644 .869 .5 r
.48949 .4812 .51047 .45357 .51054 .44434 .48941 .48006 Metetra
.48941 .48006 .51054 .44434 .51061 .43299 .48932 .483 Metetra
0 0 .128 r
.48932 .483 .51061 .43299 .51068 .4167 .48921 .49532 Metetra
.885 .711 .661 r
.48921 .49532 .51068 .4167 .51072 .38416 .48924 .41372 Metetra
.759 .591 .669 r
.48924 .41372 .51072 .38416 .51065 .26291 .48931 .2918 Metetra
.87 .768 .746 r
.48931 .2918 .51065 .26291 .51062 .18286 .48927 .25873 Metetra
.972 .889 .518 r
.48927 .25873 .51062 .18286 .51073 .19219 .4892 .24118 Metetra
.959 .935 .614 r
.4892 .24118 .51073 .19219 .51082 .19268 .48913 .22816 Metetra
.938 .965 .7 r
.48913 .22816 .51082 .19268 .51091 .18914 .48905 .21696 Metetra
.912 .98 .766 r
.48905 .21696 .51091 .18914 .511 .1837 .48897 .20663 Metetra
.886 .984 .815 r
.48897 .20663 .511 .1837 .51108 .17721 .48889 .19674 Metetra
.86 .983 .851 r
.48889 .19674 .51108 .17721 .51117 .17004 .4888 .18708 Metetra
.837 .978 .878 r
.4888 .18708 .51117 .17004 .51126 .16239 .48872 .17753 Metetra
.816 .972 .898 r
.48872 .17753 .51126 .16239 .51135 .15437 .48863 .16801 Metetra
.797 .965 .914 r
.48863 .16801 .51135 .15437 .51144 .14605 .48854 .15847 Metetra
.781 .958 .926 r
.48854 .15847 .51144 .14605 .51153 .13746 .48845 .14888 Metetra
.766 .951 .936 r
.48845 .14888 .51153 .13746 .51163 .12864 .48836 .13922 Metetra
.753 .945 .944 r
.48836 .13922 .51163 .12864 .51172 .11959 .48826 .12946 Metetra
.741 .938 .95 r
.48826 .12946 .51172 .11959 .51182 .11034 .48817 .11958 Metetra
.731 .933 .955 r
.48817 .11958 .51182 .11034 .51192 .10088 .48807 .10959 Metetra
.721 .927 .96 r
.48807 .10959 .51192 .10088 .51202 .09123 .48797 .09946 Metetra
.713 .922 .963 r
.48797 .09946 .51202 .09123 .51212 .08138 .48787 .0892 Metetra
.705 .918 .966 r
.48787 .0892 .51212 .08138 .51222 .07133 .48777 .07878 Metetra
.698 .913 .969 r
.48777 .07878 .51222 .07133 .51233 .06109 .48766 .06821 Metetra
.589 .831 .99 r
.84772 .4978 .86647 .49672 .86882 .49043 .84995 .4915 Metetra
.59 .83 .99 r
.84995 .4915 .86882 .49043 .8712 .48401 .85221 .48507 Metetra
.591 .83 .989 r
.85221 .48507 .8712 .48401 .87361 .47747 .8545 .47851 Metetra
.593 .829 .989 r
.8545 .47851 .87361 .47747 .87605 .47079 .85681 .47182 Metetra
.594 .827 .988 r
.85681 .47182 .87605 .47079 .87852 .46398 .85916 .46498 Metetra
.595 .826 .987 r
.85916 .46498 .87852 .46398 .88102 .45702 .86153 .458 Metetra
.596 .825 .987 r
.86153 .458 .88102 .45702 .88355 .44992 .86393 .45087 Metetra
.597 .824 .986 r
.86393 .45087 .88355 .44992 .88611 .44266 .86635 .44358 Metetra
.599 .822 .985 r
.86635 .44358 .88611 .44266 .8887 .43524 .86881 .43612 Metetra
.6 .82 .984 r
.86881 .43612 .8887 .43524 .89133 .42766 .8713 .42849 Metetra
.601 .819 .983 r
.8713 .42849 .89133 .42766 .89398 .4199 .87382 .42069 Metetra
.602 .817 .982 r
.87382 .42069 .89398 .4199 .89667 .41196 .87637 .41269 Metetra
.603 .814 .981 r
.87637 .41269 .89667 .41196 .89939 .40383 .87894 .4045 Metetra
.604 .812 .98 r
.87894 .4045 .89939 .40383 .90215 .3955 .88155 .3961 Metetra
.605 .809 .979 r
.88155 .3961 .90215 .3955 .90494 .38697 .8842 .38748 Metetra
.606 .807 .977 r
.8842 .38748 .90494 .38697 .90776 .37823 .88687 .37865 Metetra
.606 .804 .976 r
.88687 .37865 .90776 .37823 .91062 .36926 .88957 .36957 Metetra
.607 .801 .974 r
.88957 .36957 .91062 .36926 .91351 .36006 .89231 .36026 Metetra
.607 .797 .972 r
.89231 .36026 .91351 .36006 .91643 .35061 .89508 .35068 Metetra
.608 .793 .97 r
.89508 .35068 .91643 .35061 .91939 .34091 .89788 .34084 Metetra
.608 .789 .968 r
.89788 .34084 .91939 .34091 .92239 .33094 .90072 .33071 Metetra
.608 .785 .966 r
.90072 .33071 .92239 .33094 .92542 .3207 .90359 .32029 Metetra
.607 .781 .964 r
.90359 .32029 .92542 .3207 .92849 .31017 .90649 .30956 Metetra
.607 .776 .961 r
.90649 .30956 .92849 .31017 .9316 .29934 .90942 .29852 Metetra
.606 .77 .959 r
.90942 .29852 .9316 .29934 .93474 .2882 .91239 .28714 Metetra
.605 .765 .956 r
.91239 .28714 .93474 .2882 .93792 .27673 .91539 .27542 Metetra
.604 .759 .953 r
.91539 .27542 .93792 .27673 .94113 .26493 .91842 .26334 Metetra
.602 .753 .95 r
.91842 .26334 .94113 .26493 .94439 .25279 .92149 .25088 Metetra
.6 .747 .947 r
.92149 .25088 .94439 .25279 .94768 .24029 .9246 .23805 Metetra
.598 .74 .944 r
.9246 .23805 .94768 .24029 .95101 .22742 .92774 .22484 Metetra
.595 .734 .941 r
.92774 .22484 .95101 .22742 .95438 .21418 .93091 .21122 Metetra
.592 .727 .938 r
.93091 .21122 .95438 .21418 .95779 .20056 .93412 .19721 Metetra
.589 .72 .934 r
.93412 .19721 .95779 .20056 .96124 .18657 .93737 .18279 Metetra
.585 .713 .931 r
.93737 .18279 .96124 .18657 .96473 .17219 .94066 .16798 Metetra
.581 .706 .928 r
.94066 .16798 .96473 .17219 .96827 .15743 .94398 .15279 Metetra
.577 .699 .925 r
.94398 .15279 .96827 .15743 .97185 .1423 .94735 .13721 Metetra
.573 .693 .923 r
.94735 .13721 .97185 .1423 .97548 .12681 .95076 .12128 Metetra
.568 .687 .921 r
.95076 .12128 .97548 .12681 .97916 .11097 .95422 .10501 Metetra
.563 .681 .919 r
.95422 .10501 .97916 .11097 .98289 .09481 .95773 .08845 Metetra
.591 .833 .99 r
.82897 .49895 .84772 .4978 .84995 .4915 .83109 .49264 Metetra
.592 .832 .99 r
.83109 .49264 .84995 .4915 .85221 .48507 .83322 .4862 Metetra
.594 .831 .989 r
.83322 .4862 .85221 .48507 .8545 .47851 .83538 .47963 Metetra
.595 .83 .989 r
.83538 .47963 .8545 .47851 .85681 .47182 .83757 .47292 Metetra
.596 .829 .988 r
.83757 .47292 .85681 .47182 .85916 .46498 .83979 .46607 Metetra
.598 .828 .987 r
.83979 .46607 .85916 .46498 .86153 .458 .84203 .45906 Metetra
.599 .826 .986 r
.84203 .45906 .86153 .458 .86393 .45087 .8443 .4519 Metetra
.6 .825 .986 r
.8443 .4519 .86393 .45087 .86635 .44358 .84659 .44458 Metetra
.601 .823 .985 r
.84659 .44458 .86635 .44358 .86881 .43612 .84892 .43708 Metetra
.603 .821 .984 r
.84892 .43708 .86881 .43612 .8713 .42849 .85127 .42941 Metetra
.604 .819 .983 r
.85127 .42941 .8713 .42849 .87382 .42069 .85365 .42154 Metetra
.605 .817 .981 r
.85365 .42154 .87382 .42069 .87637 .41269 .85606 .41349 Metetra
.606 .815 .98 r
.85606 .41349 .87637 .41269 .87894 .4045 .85849 .40523 Metetra
.607 .812 .979 r
.85849 .40523 .87894 .4045 .88155 .3961 .86096 .39675 Metetra
.608 .81 .977 r
.86096 .39675 .88155 .3961 .8842 .38748 .86345 .38805 Metetra
.609 .807 .976 r
.86345 .38805 .8842 .38748 .88687 .37865 .86598 .37911 Metetra
.61 .803 .974 r
.86598 .37911 .88687 .37865 .88957 .36957 .86853 .36992 Metetra
.61 .8 .972 r
.86853 .36992 .88957 .36957 .89231 .36026 .87112 .36048 Metetra
.61 .796 .97 r
.87112 .36048 .89231 .36026 .89508 .35068 .87373 .35076 Metetra
.611 .792 .968 r
.87373 .35076 .89508 .35068 .89788 .34084 .87637 .34075 Metetra
.611 .787 .966 r
.87637 .34075 .89788 .34084 .90072 .33071 .87904 .33045 Metetra
.611 .783 .963 r
.87904 .33045 .90072 .33071 .90359 .32029 .88175 .31983 Metetra
.61 .778 .961 r
.88175 .31983 .90359 .32029 .90649 .30956 .88448 .30888 Metetra
.609 .772 .958 r
.88448 .30888 .90649 .30956 .90942 .29852 .88724 .29759 Metetra
.608 .766 .955 r
.88724 .29759 .90942 .29852 .91239 .28714 .89004 .28595 Metetra
.607 .76 .952 r
.89004 .28595 .91239 .28714 .91539 .27542 .89286 .27393 Metetra
.605 .754 .949 r
.89286 .27393 .91539 .27542 .91842 .26334 .89571 .26152 Metetra
.603 .747 .946 r
.89571 .26152 .91842 .26334 .92149 .25088 .8986 .24872 Metetra
.601 .74 .942 r
.8986 .24872 .92149 .25088 .9246 .23805 .90151 .23551 Metetra
.598 .733 .939 r
.90151 .23551 .9246 .23805 .92774 .22484 .90446 .22189 Metetra
.595 .725 .935 r
.90446 .22189 .92774 .22484 .93091 .21122 .90744 .20785 Metetra
.591 .718 .932 r
.90744 .20785 .93091 .21122 .93412 .19721 .91045 .19338 Metetra
.587 .71 .928 r
.91045 .19338 .93412 .19721 .93737 .18279 .91349 .17849 Metetra
.583 .703 .925 r
.91349 .17849 .93737 .18279 .94066 .16798 .91657 .1632 Metetra
.578 .695 .922 r
.91657 .1632 .94066 .16798 .94398 .15279 .91969 .14751 Metetra
.573 .688 .919 r
.91969 .14751 .94398 .15279 .94735 .13721 .92285 .13145 Metetra
.568 .681 .916 r
.92285 .13145 .94735 .13721 .95076 .12128 .92605 .11504 Metetra
.563 .675 .914 r
.92605 .11504 .95076 .12128 .95422 .10501 .92929 .09833 Metetra
.557 .67 .913 r
.92929 .09833 .95422 .10501 .95773 .08845 .93258 .08136 Metetra
.593 .834 .99 r
.81022 .50019 .82897 .49895 .83109 .49264 .81221 .49387 Metetra
.595 .833 .99 r
.81221 .49387 .83109 .49264 .83322 .4862 .81423 .48742 Metetra
.596 .832 .989 r
.81423 .48742 .83322 .4862 .83538 .47963 .81627 .48084 Metetra
.597 .831 .988 r
.81627 .48084 .83538 .47963 .83757 .47292 .81833 .47411 Metetra
.599 .83 .988 r
.81833 .47411 .83757 .47292 .83979 .46607 .82042 .46724 Metetra
.6 .829 .987 r
.82042 .46724 .83979 .46607 .84203 .45906 .82253 .46021 Metetra
.602 .827 .986 r
.82253 .46021 .84203 .45906 .8443 .4519 .82467 .45302 Metetra
.603 .826 .985 r
.82467 .45302 .8443 .4519 .84659 .44458 .82683 .44566 Metetra
.604 .824 .984 r
.82683 .44566 .84659 .44458 .84892 .43708 .82902 .43812 Metetra
.606 .822 .983 r
.82902 .43812 .84892 .43708 .85127 .42941 .83124 .4304 Metetra
.607 .82 .982 r
.83124 .4304 .85127 .42941 .85365 .42154 .83348 .42249 Metetra
.608 .818 .981 r
.83348 .42249 .85365 .42154 .85606 .41349 .83575 .41436 Metetra
.609 .815 .979 r
.83575 .41436 .85606 .41349 .85849 .40523 .83804 .40603 Metetra
.61 .813 .978 r
.83804 .40603 .85849 .40523 .86096 .39675 .84036 .39747 Metetra
.611 .81 .976 r
.84036 .39747 .86096 .39675 .86345 .38805 .84271 .38867 Metetra
.612 .806 .974 r
.84271 .38867 .86345 .38805 .86598 .37911 .84509 .37962 Metetra
.613 .803 .973 r
.84509 .37962 .86598 .37911 .86853 .36992 .84749 .37031 Metetra
.614 .799 .97 r
.84749 .37031 .86853 .36992 .87112 .36048 .84992 .36072 Metetra
.614 .795 .968 r
.84992 .36072 .87112 .36048 .87373 .35076 .85238 .35085 Metetra
.614 .79 .966 r
.85238 .35085 .87373 .35076 .87637 .34075 .85486 .34066 Metetra
.614 .785 .963 r
.85486 .34066 .87637 .34075 .87904 .33045 .85737 .33016 Metetra
.614 .78 .961 r
.85737 .33016 .87904 .33045 .88175 .31983 .85991 .31931 Metetra
.613 .774 .958 r
.85991 .31931 .88175 .31983 .88448 .30888 .86247 .30811 Metetra
.612 .768 .954 r
.86247 .30811 .88448 .30888 .88724 .29759 .86507 .29654 Metetra
.611 .761 .951 r
.86507 .29654 .88724 .29759 .89004 .28595 .86768 .28459 Metetra
.609 .755 .948 r
.86768 .28459 .89004 .28595 .89286 .27393 .87033 .27223 Metetra
.607 .747 .944 r
.87033 .27223 .89286 .27393 .89571 .26152 .873 .25945 Metetra
.604 .74 .94 r
.873 .25945 .89571 .26152 .8986 .24872 .8757 .24625 Metetra
.601 .732 .936 r
.8757 .24625 .8986 .24872 .90151 .23551 .87843 .2326 Metetra
.598 .724 .932 r
.87843 .2326 .90151 .23551 .90446 .22189 .88118 .21851 Metetra
.594 .716 .928 r
.88118 .21851 .90446 .22189 .90744 .20785 .88396 .20397 Metetra
.59 .707 .925 r
.88396 .20397 .90744 .20785 .91045 .19338 .88677 .18898 Metetra
.585 .699 .921 r
.88677 .18898 .91045 .19338 .91349 .17849 .88961 .17356 Metetra
.58 .691 .917 r
.88961 .17356 .91349 .17849 .91657 .1632 .89249 .15772 Metetra
.574 .683 .914 r
.89249 .15772 .91657 .1632 .91969 .14751 .89539 .14149 Metetra
.568 .676 .912 r
.89539 .14149 .91969 .14751 .92285 .13145 .89834 .12491 Metetra
.562 .669 .909 r
.89834 .12491 .92285 .13145 .92605 .11504 .90132 .10801 Metetra
.556 .663 .908 r
.90132 .10801 .92605 .11504 .92929 .09833 .90436 .09085 Metetra
.55 .658 .907 r
.90436 .09085 .92929 .09833 .93258 .08136 .90744 .07349 Metetra
.596 .836 .99 r
.79147 .50151 .81022 .50019 .81221 .49387 .79334 .49519 Metetra
.597 .835 .989 r
.79334 .49519 .81221 .49387 .81423 .48742 .79523 .48874 Metetra
.599 .834 .989 r
.79523 .48874 .81423 .48742 .81627 .48084 .79715 .48214 Metetra
.6 .833 .988 r
.79715 .48214 .81627 .48084 .81833 .47411 .79909 .4754 Metetra
.602 .832 .987 r
.79909 .4754 .81833 .47411 .82042 .46724 .80105 .46851 Metetra
.603 .831 .986 r
.80105 .46851 .82042 .46724 .82253 .46021 .80303 .46146 Metetra
.605 .829 .986 r
.80303 .46146 .82253 .46021 .82467 .45302 .80504 .45424 Metetra
.606 .827 .985 r
.80504 .45424 .82467 .45302 .82683 .44566 .80707 .44685 Metetra
.608 .826 .983 r
.80707 .44685 .82683 .44566 .82902 .43812 .80913 .43927 Metetra
.609 .824 .982 r
.80913 .43927 .82902 .43812 .83124 .4304 .81121 .4315 Metetra
.611 .821 .981 r
.81121 .4315 .83124 .4304 .83348 .42249 .81331 .42352 Metetra
.612 .819 .98 r
.81331 .42352 .83348 .42249 .83575 .41436 .81544 .41533 Metetra
.613 .816 .978 r
.81544 .41533 .83575 .41436 .83804 .40603 .81759 .40692 Metetra
.614 .813 .977 r
.81759 .40692 .83804 .40603 .84036 .39747 .81977 .39827 Metetra
.615 .81 .975 r
.81977 .39827 .84036 .39747 .84271 .38867 .82197 .38936 Metetra
.616 .806 .973 r
.82197 .38936 .84271 .38867 .84509 .37962 .8242 .38019 Metetra
.617 .802 .971 r
.8242 .38019 .84509 .37962 .84749 .37031 .82645 .37075 Metetra
.617 .798 .968 r
.82645 .37075 .84749 .37031 .84992 .36072 .82872 .361 Metetra
.618 .793 .966 r
.82872 .361 .84992 .36072 .85238 .35085 .83102 .35094 Metetra
.618 .788 .963 r
.83102 .35094 .85238 .35085 .85486 .34066 .83335 .34056 Metetra
.618 .782 .96 r
.83335 .34056 .85486 .34066 .85737 .33016 .8357 .32982 Metetra
.617 .776 .957 r
.8357 .32982 .85737 .33016 .85991 .31931 .83807 .31872 Metetra
.616 .77 .954 r
.83807 .31872 .85991 .31931 .86247 .30811 .84047 .30723 Metetra
.615 .763 .95 r
.84047 .30723 .86247 .30811 .86507 .29654 .84289 .29534 Metetra
.613 .756 .946 r
.84289 .29534 .86507 .29654 .86768 .28459 .84533 .28303 Metetra
.611 .748 .942 r
.84533 .28303 .86768 .28459 .87033 .27223 .8478 .27027 Metetra
.608 .74 .938 r
.8478 .27027 .87033 .27223 .873 .25945 .85029 .25706 Metetra
.605 .731 .934 r
.85029 .25706 .873 .25945 .8757 .24625 .8528 .24338 Metetra
.602 .722 .93 r
.8528 .24338 .8757 .24625 .87843 .2326 .85533 .22923 Metetra
.597 .713 .925 r
.85533 .22923 .87843 .2326 .88118 .21851 .85789 .21459 Metetra
.593 .704 .921 r
.85789 .21459 .88118 .21851 .88396 .20397 .86048 .19948 Metetra
.587 .695 .917 r
.86048 .19948 .88396 .20397 .88677 .18898 .86309 .18389 Metetra
.582 .686 .913 r
.86309 .18389 .88677 .18898 .88961 .17356 .86572 .16787 Metetra
.575 .677 .909 r
.86572 .16787 .88961 .17356 .89249 .15772 .86839 .15142 Metetra
.569 .669 .906 r
.86839 .15142 .89249 .15772 .89539 .14149 .87109 .13461 Metetra
.562 .662 .904 r
.87109 .13461 .89539 .14149 .89834 .12491 .87383 .11747 Metetra
.555 .655 .902 r
.87383 .11747 .89834 .12491 .90132 .10801 .8766 .10008 Metetra
.548 .649 .901 r
.8766 .10008 .90132 .10801 .90436 .09085 .87943 .0825 Metetra
.541 .645 .901 r
.87943 .0825 .90436 .09085 .90744 .07349 .8823 .06482 Metetra
.598 .838 .99 r
.77272 .50294 .79147 .50151 .79334 .49519 .77447 .49662 Metetra
.6 .837 .989 r
.77447 .49662 .79334 .49519 .79523 .48874 .77624 .49016 Metetra
.601 .836 .988 r
.77624 .49016 .79523 .48874 .79715 .48214 .77803 .48355 Metetra
.603 .835 .988 r
.77803 .48355 .79715 .48214 .79909 .4754 .77984 .4768 Metetra
.605 .834 .987 r
.77984 .4768 .79909 .4754 .80105 .46851 .78168 .46989 Metetra
.606 .832 .986 r
.78168 .46989 .80105 .46851 .80303 .46146 .78353 .46282 Metetra
.608 .831 .985 r
.78353 .46282 .80303 .46146 .80504 .45424 .78541 .45557 Metetra
.61 .829 .984 r
.78541 .45557 .80504 .45424 .80707 .44685 .78731 .44814 Metetra
.611 .827 .983 r
.78731 .44814 .80707 .44685 .80913 .43927 .78923 .44052 Metetra
.613 .825 .982 r
.78923 .44052 .80913 .43927 .81121 .4315 .79117 .4327 Metetra
.614 .823 .98 r
.79117 .4327 .81121 .4315 .81331 .42352 .79314 .42467 Metetra
.616 .82 .979 r
.79314 .42467 .81331 .42352 .81544 .41533 .79513 .41641 Metetra
.617 .817 .977 r
.79513 .41641 .81544 .41533 .81759 .40692 .79714 .40791 Metetra
.618 .814 .975 r
.79714 .40791 .81759 .40692 .81977 .39827 .79917 .39916 Metetra
.619 .81 .973 r
.79917 .39916 .81977 .39827 .82197 .38936 .80123 .39014 Metetra
.62 .806 .971 r
.80123 .39014 .82197 .38936 .8242 .38019 .80331 .38084 Metetra
.621 .802 .969 r
.80331 .38084 .8242 .38019 .82645 .37075 .80541 .37124 Metetra
.622 .797 .966 r
.80541 .37124 .82645 .37075 .82872 .361 .80753 .36131 Metetra
.622 .791 .963 r
.80753 .36131 .82872 .361 .83102 .35094 .80967 .35106 Metetra
.622 .786 .96 r
.80967 .35106 .83102 .35094 .83335 .34056 .81184 .34044 Metetra
.622 .779 .957 r
.81184 .34044 .83335 .34056 .8357 .32982 .81402 .32944 Metetra
.621 .773 .953 r
.81402 .32944 .8357 .32982 .83807 .31872 .81623 .31804 Metetra
.62 .765 .949 r
.81623 .31804 .83807 .31872 .84047 .30723 .81846 .30622 Metetra
.618 .757 .945 r
.81846 .30622 .84047 .30723 .84289 .29534 .82071 .29395 Metetra
.616 .749 .941 r
.82071 .29395 .84289 .29534 .84533 .28303 .82297 .28121 Metetra
.613 .74 .936 r
.82297 .28121 .84533 .28303 .8478 .27027 .82526 .26799 Metetra
.609 .731 .932 r
.82526 .26799 .8478 .27027 .85029 .25706 .82757 .25427 Metetra
.605 .721 .927 r
.82757 .25427 .85029 .25706 .8528 .24338 .82989 .24004 Metetra
.601 .711 .922 r
.82989 .24004 .8528 .24338 .85533 .22923 .83224 .22528 Metetra
.596 .701 .917 r
.83224 .22528 .85533 .22923 .85789 .21459 .8346 .21001 Metetra
.59 .691 .912 r
.8346 .21001 .85789 .21459 .86048 .19948 .83699 .19423 Metetra
.583 .681 .908 r
.83699 .19423 .86048 .19948 .86309 .18389 .8394 .17796 Metetra
.577 .672 .904 r
.8394 .17796 .86309 .18389 .86572 .16787 .84183 .16125 Metetra
.569 .662 .9 r
.84183 .16125 .86572 .16787 .86839 .15142 .84429 .14415 Metetra
.562 .654 .898 r
.84429 .14415 .86839 .15142 .87109 .13461 .84679 .12671 Metetra
.554 .647 .896 r
.84679 .12671 .87109 .13461 .87383 .11747 .84932 .10903 Metetra
.546 .641 .895 r
.84932 .10903 .87383 .11747 .8766 .10008 .85189 .09118 Metetra
.538 .636 .895 r
.85189 .09118 .8766 .10008 .87943 .0825 .85451 .07328 Metetra
.531 .633 .897 r
.85451 .07328 .87943 .0825 .8823 .06482 .85719 .05542 Metetra
.601 .84 .99 r
.75396 .50448 .77272 .50294 .77447 .49662 .75559 .49816 Metetra
.603 .839 .989 r
.75559 .49816 .77447 .49662 .77624 .49016 .75724 .4917 Metetra
.604 .838 .988 r
.75724 .4917 .77624 .49016 .77803 .48355 .7589 .48509 Metetra
.606 .837 .987 r
.7589 .48509 .77803 .48355 .77984 .4768 .76059 .47833 Metetra
.608 .836 .987 r
.76059 .47833 .77984 .4768 .78168 .46989 .7623 .4714 Metetra
.61 .834 .986 r
.7623 .4714 .78168 .46989 .78353 .46282 .76403 .46431 Metetra
.612 .833 .985 r
.76403 .46431 .78353 .46282 .78541 .45557 .76578 .45703 Metetra
.613 .831 .983 r
.76578 .45703 .78541 .45557 .78731 .44814 .76754 .44957 Metetra
.615 .829 .982 r
.76754 .44957 .78731 .44814 .78923 .44052 .76933 .44191 Metetra
.617 .827 .981 r
.76933 .44191 .78923 .44052 .79117 .4327 .77114 .43404 Metetra
.619 .824 .979 r
.77114 .43404 .79117 .4327 .79314 .42467 .77297 .42594 Metetra
.62 .821 .978 r
.77297 .42594 .79314 .42467 .79513 .41641 .77482 .4176 Metetra
.622 .818 .976 r
.77482 .4176 .79513 .41641 .79714 .40791 .77669 .40901 Metetra
.623 .814 .974 r
.77669 .40901 .79714 .40791 .79917 .39916 .77858 .40016 Metetra
.624 .81 .972 r
.77858 .40016 .79917 .39916 .80123 .39014 .78049 .39101 Metetra
.625 .806 .969 r
.78049 .39101 .80123 .39014 .80331 .38084 .78242 .38157 Metetra
.626 .801 .966 r
.78242 .38157 .80331 .38084 .80541 .37124 .78436 .37179 Metetra
.626 .796 .963 r
.78436 .37179 .80541 .37124 .80753 .36131 .78633 .36167 Metetra
.627 .79 .96 r
.78633 .36167 .80753 .36131 .80967 .35106 .78832 .35118 Metetra
.626 .783 .957 r
.78832 .35118 .80967 .35106 .81184 .34044 .79033 .3403 Metetra
.626 .776 .953 r
.79033 .3403 .81184 .34044 .81402 .32944 .79235 .329 Metetra
.625 .768 .949 r
.79235 .329 .81402 .32944 .81623 .31804 .79439 .31725 Metetra
.623 .76 .944 r
.79439 .31725 .81623 .31804 .81846 .30622 .79645 .30503 Metetra
.621 .751 .939 r
.79645 .30503 .81846 .30622 .82071 .29395 .79853 .29232 Metetra
.618 .741 .934 r
.79853 .29232 .82071 .29395 .82297 .28121 .80062 .27909 Metetra
.614 .731 .929 r
.80062 .27909 .82297 .28121 .82526 .26799 .80272 .26531 Metetra
.61 .72 .924 r
.80272 .26531 .82526 .26799 .82757 .25427 .80485 .25098 Metetra
.605 .71 .918 r
.80485 .25098 .82757 .25427 .82989 .24004 .80698 .23608 Metetra
.599 .698 .913 r
.80698 .23608 .82989 .24004 .83224 .22528 .80914 .22061 Metetra
.593 .687 .907 r
.80914 .22061 .83224 .22528 .8346 .21001 .8113 .20459 Metetra
.586 .676 .902 r
.8113 .20459 .8346 .21001 .83699 .19423 .81349 .18803 Metetra
.578 .665 .898 r
.81349 .18803 .83699 .19423 .8394 .17796 .8157 .17099 Metetra
.57 .655 .894 r
.8157 .17099 .8394 .17796 .84183 .16125 .81793 .15353 Metetra
.561 .646 .891 r
.81793 .15353 .84183 .16125 .84429 .14415 .82019 .13572 Metetra
.552 .638 .889 r
.82019 .13572 .84429 .14415 .84679 .12671 .82248 .11768 Metetra
.543 .631 .888 r
.82248 .11768 .84679 .12671 .84932 .10903 .82482 .0995 Metetra
.535 .626 .889 r
.82482 .0995 .84932 .10903 .85189 .09118 .82719 .08133 Metetra
.526 .623 .891 r
.82719 .08133 .85189 .09118 .85451 .07328 .82962 .06327 Metetra
.519 .623 .895 r
.82962 .06327 .85451 .07328 .85719 .05542 .83211 .04545 Metetra
.604 .843 .989 r
.73519 .50615 .75396 .50448 .75559 .49816 .7367 .49983 Metetra
.606 .842 .989 r
.7367 .49983 .75559 .49816 .75724 .4917 .73823 .49337 Metetra
.607 .841 .988 r
.73823 .49337 .75724 .4917 .7589 .48509 .73978 .48676 Metetra
.609 .84 .987 r
.73978 .48676 .7589 .48509 .76059 .47833 .74134 .47999 Metetra
.611 .838 .986 r
.74134 .47999 .76059 .47833 .7623 .4714 .74292 .47306 Metetra
.613 .837 .985 r
.74292 .47306 .7623 .4714 .76403 .46431 .74452 .46594 Metetra
.615 .835 .984 r
.74452 .46594 .76403 .46431 .76578 .45703 .74614 .45865 Metetra
.617 .833 .983 r
.74614 .45865 .76578 .45703 .76754 .44957 .74777 .45115 Metetra
.619 .831 .981 r
.74777 .45115 .76754 .44957 .76933 .44191 .74943 .44345 Metetra
.621 .829 .98 r
.74943 .44345 .76933 .44191 .77114 .43404 .7511 .43552 Metetra
.623 .826 .978 r
.7511 .43552 .77114 .43404 .77297 .42594 .75279 .42736 Metetra
.625 .823 .976 r
.75279 .42736 .77297 .42594 .77482 .4176 .7545 .41895 Metetra
.627 .819 .974 r
.7545 .41895 .77482 .4176 .77669 .40901 .75623 .41026 Metetra
.628 .815 .972 r
.75623 .41026 .77669 .40901 .77858 .40016 .75798 .40129 Metetra
.629 .811 .97 r
.75798 .40129 .77858 .40016 .78049 .39101 .75974 .39201 Metetra
.63 .806 .967 r
.75974 .39201 .78049 .39101 .78242 .38157 .76152 .3824 Metetra
.631 .8 .964 r
.76152 .3824 .78242 .38157 .78436 .37179 .76332 .37243 Metetra
.632 .794 .96 r
.76332 .37243 .78436 .37179 .78633 .36167 .76514 .36208 Metetra
.632 .787 .957 r
.76514 .36208 .78633 .36167 .78832 .35118 .76697 .35133 Metetra
.631 .78 .953 r
.76697 .35133 .78832 .35118 .79033 .3403 .76882 .34014 Metetra
.63 .772 .948 r
.76882 .34014 .79033 .3403 .79235 .329 .77068 .32848 Metetra
.629 .763 .943 r
.77068 .32848 .79235 .329 .79439 .31725 .77255 .31633 Metetra
.626 .753 .938 r
.77255 .31633 .79439 .31725 .79645 .30503 .77444 .30364 Metetra
.624 .743 .932 r
.77444 .30364 .79645 .30503 .79853 .29232 .77634 .29039 Metetra
.62 .732 .927 r
.77634 .29039 .79853 .29232 .80062 .27909 .77826 .27656 Metetra
.615 .72 .92 r
.77826 .27656 .80062 .27909 .80272 .26531 .78018 .26211 Metetra
.61 .708 .914 r
.78018 .26211 .80272 .26531 .80485 .25098 .78212 .24704 Metetra
.604 .696 .908 r
.78212 .24704 .80485 .25098 .80698 .23608 .78407 .23134 Metetra
.596 .683 .902 r
.78407 .23134 .80698 .23608 .80914 .22061 .78603 .21502 Metetra
.588 .671 .896 r
.78603 .21502 .80914 .22061 .8113 .20459 .788 .19811 Metetra
.58 .658 .891 r
.788 .19811 .8113 .20459 .81349 .18803 .78999 .18067 Metetra
.57 .647 .887 r
.78999 .18067 .81349 .18803 .8157 .17099 .792 .16276 Metetra
.56 .636 .883 r
.792 .16276 .8157 .17099 .81793 .15353 .79403 .1445 Metetra
.55 .627 .881 r
.79403 .1445 .81793 .15353 .82019 .13572 .79609 .126 Metetra
.54 .62 .881 r
.79609 .126 .82019 .13572 .82248 .11768 .79819 .10743 Metetra
.53 .615 .882 r
.79819 .10743 .82248 .11768 .82482 .0995 .80033 .08892 Metetra
.521 .612 .884 r
.80033 .08892 .82482 .0995 .82719 .08133 .80252 .07064 Metetra
.513 .613 .889 r
.80252 .07064 .82719 .08133 .82962 .06327 .80477 .05273 Metetra
.506 .617 .896 r
.80477 .05273 .82962 .06327 .83211 .04545 .80709 .0353 Metetra
.607 .845 .989 r
.71643 .50795 .73519 .50615 .7367 .49983 .71782 .50165 Metetra
.609 .845 .988 r
.71782 .50165 .7367 .49983 .73823 .49337 .71922 .49519 Metetra
.611 .844 .988 r
.71922 .49519 .73823 .49337 .73978 .48676 .72065 .48859 Metetra
.613 .843 .987 r
.72065 .48859 .73978 .48676 .74134 .47999 .72208 .48182 Metetra
.615 .841 .986 r
.72208 .48182 .74134 .47999 .74292 .47306 .72354 .47487 Metetra
.618 .84 .985 r
.72354 .47487 .74292 .47306 .74452 .46594 .72501 .46775 Metetra
.62 .838 .984 r
.72501 .46775 .74452 .46594 .74614 .45865 .7265 .46043 Metetra
.622 .836 .982 r
.7265 .46043 .74614 .45865 .74777 .45115 .728 .45291 Metetra
.624 .834 .981 r
.728 .45291 .74777 .45115 .74943 .44345 .72953 .44517 Metetra
.626 .831 .979 r
.72953 .44517 .74943 .44345 .7511 .43552 .73106 .43719 Metetra
.628 .828 .977 r
.73106 .43719 .7511 .43552 .75279 .42736 .73262 .42896 Metetra
.63 .825 .975 r
.73262 .42896 .75279 .42736 .7545 .41895 .73419 .42046 Metetra
.632 .821 .973 r
.73419 .42046 .7545 .41895 .75623 .41026 .73578 .41168 Metetra
.634 .816 .97 r
.73578 .41168 .75623 .41026 .75798 .40129 .73738 .40258 Metetra
.635 .812 .968 r
.73738 .40258 .75798 .40129 .75974 .39201 .739 .39315 Metetra
.636 .806 .964 r
.739 .39315 .75974 .39201 .76152 .3824 .74063 .38335 Metetra
.637 .8 .961 r
.74063 .38335 .76152 .3824 .76332 .37243 .74228 .37317 Metetra
.637 .793 .957 r
.74228 .37317 .76332 .37243 .76514 .36208 .74394 .36256 Metetra
.637 .785 .953 r
.74394 .36256 .76514 .36208 .76697 .35133 .74562 .3515 Metetra
.637 .776 .948 r
.74562 .3515 .76697 .35133 .76882 .34014 .7473 .33995 Metetra
.635 .767 .942 r
.7473 .33995 .76882 .34014 .77068 .32848 .749 .32787 Metetra
.633 .756 .937 r
.749 .32787 .77068 .32848 .77255 .31633 .75071 .31522 Metetra
.63 .745 .931 r
.75071 .31522 .77255 .31633 .77444 .30364 .75243 .30197 Metetra
.626 .733 .924 r
.75243 .30197 .77444 .30364 .77634 .29039 .75416 .28807 Metetra
.621 .72 .917 r
.75416 .28807 .77634 .29039 .77826 .27656 .7559 .27351 Metetra
.615 .707 .91 r
.7559 .27351 .77826 .27656 .78018 .26211 .75764 .25824 Metetra
.609 .693 .903 r
.75764 .25824 .78018 .26211 .78212 .24704 .75939 .24226 Metetra
.601 .679 .896 r
.75939 .24226 .78212 .24704 .78407 .23134 .76114 .22559 Metetra
.592 .665 .89 r
.76114 .22559 .78407 .23134 .78603 .21502 .76291 .20825 Metetra
.582 .651 .884 r
.76291 .20825 .78603 .21502 .788 .19811 .76469 .1903 Metetra
.571 .638 .879 r
.76469 .1903 .788 .19811 .78999 .18067 .76648 .17184 Metetra
.56 .626 .875 r
.76648 .17184 .78999 .18067 .792 .16276 .76829 .15301 Metetra
.548 .616 .872 r
.76829 .15301 .792 .16276 .79403 .1445 .77013 .13396 Metetra
.536 .608 .872 r
.77013 .13396 .79403 .1445 .79609 .126 .772 .1149 Metetra
.525 .603 .874 r
.772 .1149 .79609 .126 .79819 .10743 .77392 .09601 Metetra
.514 .6 .878 r
.77392 .09601 .79819 .10743 .80033 .08892 .77588 .07749 Metetra
.505 .602 .884 r
.77588 .07749 .80033 .08892 .80252 .07064 .77791 .0595 Metetra
.498 .607 .892 r
.77791 .0595 .80252 .07064 .80477 .05273 .78 .04218 Metetra
.493 .617 .903 r
.78 .04218 .80477 .05273 .80709 .0353 .78215 .02559 Metetra
.61 .849 .989 r
.69766 .50992 .71643 .50795 .71782 .50165 .69893 .50363 Metetra
.612 .848 .988 r
.69893 .50363 .71782 .50165 .71922 .49519 .70021 .49719 Metetra
.615 .847 .987 r
.70021 .49719 .71922 .49519 .72065 .48859 .70151 .49059 Metetra
.617 .846 .986 r
.70151 .49059 .72065 .48859 .72208 .48182 .70282 .48383 Metetra
.619 .845 .985 r
.70282 .48383 .72208 .48182 .72354 .47487 .70415 .47688 Metetra
.622 .843 .984 r
.70415 .47688 .72354 .47487 .72501 .46775 .7055 .46975 Metetra
.624 .841 .983 r
.7055 .46975 .72501 .46775 .7265 .46043 .70686 .46242 Metetra
.627 .839 .982 r
.70686 .46242 .7265 .46043 .728 .45291 .70823 .45487 Metetra
.629 .837 .98 r
.70823 .45487 .728 .45291 .72953 .44517 .70962 .44709 Metetra
.632 .834 .978 r
.70962 .44709 .72953 .44517 .73106 .43719 .71102 .43906 Metetra
.634 .831 .976 r
.71102 .43906 .73106 .43719 .73262 .42896 .71244 .43077 Metetra
.636 .827 .974 r
.71244 .43077 .73262 .42896 .73419 .42046 .71387 .42219 Metetra
.638 .823 .971 r
.71387 .42219 .73419 .42046 .73578 .41168 .71532 .41329 Metetra
.64 .818 .968 r
.71532 .41329 .73578 .41168 .73738 .40258 .71678 .40406 Metetra
.642 .813 .965 r
.71678 .40406 .73738 .40258 .739 .39315 .71825 .39446 Metetra
.643 .806 .961 r
.71825 .39446 .739 .39315 .74063 .38335 .71974 .38447 Metetra
.644 .799 .957 r
.71974 .38447 .74063 .38335 .74228 .37317 .72124 .37403 Metetra
.644 .791 .953 r
.72124 .37403 .74228 .37317 .74394 .36256 .72275 .36313 Metetra
.644 .782 .948 r
.72275 .36313 .74394 .36256 .74562 .3515 .72426 .35171 Metetra
.642 .772 .942 r
.72426 .35171 .74562 .3515 .7473 .33995 .72579 .33973 Metetra
.64 .761 .936 r
.72579 .33973 .7473 .33995 .749 .32787 .72733 .32714 Metetra
.638 .749 .929 r
.72733 .32714 .749 .32787 .75071 .31522 .72887 .31389 Metetra
.634 .736 .922 r
.72887 .31389 .75071 .31522 .75243 .30197 .73042 .29994 Metetra
.628 .721 .914 r
.73042 .29994 .75243 .30197 .75416 .28807 .73197 .28524 Metetra
.622 .707 .906 r
.73197 .28524 .75416 .28807 .7559 .27351 .73353 .26975 Metetra
.615 .691 .898 r
.73353 .26975 .7559 .27351 .75764 .25824 .73509 .25345 Metetra
.606 .675 .89 r
.73509 .25345 .75764 .25824 .75939 .24226 .73665 .23636 Metetra
.596 .659 .882 r
.73665 .23636 .75939 .24226 .76114 .22559 .73822 .21849 Metetra
.584 .643 .875 r
.73822 .21849 .76114 .22559 .76291 .20825 .73979 .19992 Metetra
.572 .629 .869 r
.73979 .19992 .76291 .20825 .76469 .1903 .74137 .18078 Metetra
.559 .615 .865 r
.74137 .18078 .76469 .1903 .76648 .17184 .74297 .16124 Metetra
.545 .604 .863 r
.74297 .16124 .76648 .17184 .76829 .15301 .74459 .14151 Metetra
.531 .595 .863 r
.74459 .14151 .76829 .15301 .77013 .13396 .74625 .12185 Metetra
.518 .589 .865 r
.74625 .12185 .77013 .13396 .772 .1149 .74794 .10252 Metetra
.506 .587 .87 r
.74794 .10252 .772 .1149 .77392 .09601 .74969 .08375 Metetra
.495 .59 .879 r
.74969 .08375 .77392 .09601 .77588 .07749 .7515 .06575 Metetra
.488 .598 .889 r
.7515 .06575 .77588 .07749 .77791 .0595 .75337 .04863 Metetra
.484 .612 .903 r
.75337 .04863 .77791 .0595 .78 .04218 .75532 .03246 Metetra
.483 .631 .918 r
.75532 .03246 .78 .04218 .78215 .02559 .75733 .01721 Metetra
.613 .852 .989 r
.67888 .51207 .69766 .50992 .69893 .50363 .68003 .5058 Metetra
.616 .852 .988 r
.68003 .5058 .69893 .50363 .70021 .49719 .68119 .49938 Metetra
.619 .851 .987 r
.68119 .49938 .70021 .49719 .70151 .49059 .68237 .4928 Metetra
.621 .85 .986 r
.68237 .4928 .70151 .49059 .70282 .48383 .68356 .48605 Metetra
.624 .848 .985 r
.68356 .48605 .70282 .48383 .70415 .47688 .68476 .47911 Metetra
.627 .847 .984 r
.68476 .47911 .70415 .47688 .7055 .46975 .68598 .47198 Metetra
.63 .845 .982 r
.68598 .47198 .7055 .46975 .70686 .46242 .68721 .46464 Metetra
.632 .843 .981 r
.68721 .46464 .70686 .46242 .70823 .45487 .68845 .45708 Metetra
.635 .841 .979 r
.68845 .45708 .70823 .45487 .70962 .44709 .68971 .44927 Metetra
.638 .838 .977 r
.68971 .44927 .70962 .44709 .71102 .43906 .69098 .44119 Metetra
.641 .834 .975 r
.69098 .44119 .71102 .43906 .71244 .43077 .69226 .43283 Metetra
.643 .83 .972 r
.69226 .43283 .71244 .43077 .71387 .42219 .69355 .42417 Metetra
.645 .825 .969 r
.69355 .42417 .71387 .42219 .71532 .41329 .69486 .41516 Metetra
.647 .82 .966 r
.69486 .41516 .71532 .41329 .71678 .40406 .69618 .40579 Metetra
.649 .814 .962 r
.69618 .40579 .71678 .40406 .71825 .39446 .69751 .396 Metetra
.65 .807 .958 r
.69751 .396 .71825 .39446 .71974 .38447 .69884 .38578 Metetra
.651 .799 .953 r
.69884 .38578 .71974 .38447 .72124 .37403 .70019 .37506 Metetra
.651 .789 .948 r
.70019 .37506 .72124 .37403 .72275 .36313 .70155 .36381 Metetra
.651 .779 .942 r
.70155 .36381 .72275 .36313 .72426 .35171 .70291 .35196 Metetra
.649 .767 .935 r
.70291 .35196 .72426 .35171 .72579 .33973 .70428 .33946 Metetra
.646 .754 .928 r
.70428 .33946 .72579 .33973 .72733 .32714 .70566 .32624 Metetra
.642 .739 .919 r
.70566 .32624 .72733 .32714 .72887 .31389 .70703 .31224 Metetra
.637 .724 .911 r
.70703 .31224 .72887 .31389 .73042 .29994 .70841 .29741 Metetra
.63 .707 .902 r
.70841 .29741 .73042 .29994 .73197 .28524 .70978 .28168 Metetra
.622 .69 .892 r
.70978 .28168 .73197 .28524 .73353 .26975 .71116 .26502 Metetra
.612 .671 .883 r
.71116 .26502 .73353 .26975 .73509 .25345 .71253 .24742 Metetra
.6 .653 .874 r
.71253 .24742 .73509 .25345 .73665 .23636 .7139 .22891 Metetra
.587 .635 .866 r
.7139 .22891 .73665 .23636 .73822 .21849 .71528 .20958 Metetra
.573 .618 .859 r
.71528 .20958 .73822 .21849 .73979 .19992 .71666 .18958 Metetra
.558 .603 .854 r
.71666 .18958 .73979 .19992 .74137 .18078 .71805 .16914 Metetra
.542 .59 .852 r
.71805 .16914 .74137 .18078 .74297 .16124 .71946 .14856 Metetra
.525 .58 .852 r
.71946 .14856 .74297 .16124 .74459 .14151 .72091 .12819 Metetra
.51 .573 .856 r
.72091 .12819 .74459 .14151 .74625 .12185 .72239 .10836 Metetra
.495 .573 .863 r
.72239 .10836 .74625 .12185 .74794 .10252 .72394 .08938 Metetra
.484 .578 .874 r
.72394 .08938 .74794 .10252 .74969 .08375 .72554 .07146 Metetra
.476 .59 .888 r
.72554 .07146 .74969 .08375 .7515 .06575 .72721 .05472 Metetra
.473 .609 .905 r
.72721 .05472 .7515 .06575 .75337 .04863 .72895 .03916 Metetra
.475 .634 .924 r
.72895 .03916 .75337 .04863 .75532 .03246 .73076 .02469 Metetra
.483 .664 .942 r
.73076 .02469 .75532 .03246 .75733 .01721 .73263 .01118 Metetra
.617 .856 .988 r
.6601 .51442 .67888 .51207 .68003 .5058 .66113 .50818 Metetra
.62 .856 .988 r
.66113 .50818 .68003 .5058 .68119 .49938 .66217 .5018 Metetra
.623 .855 .987 r
.66217 .5018 .68119 .49938 .68237 .4928 .66322 .49524 Metetra
.626 .854 .986 r
.66322 .49524 .68237 .4928 .68356 .48605 .66429 .48852 Metetra
.629 .853 .985 r
.66429 .48852 .68356 .48605 .68476 .47911 .66537 .4816 Metetra
.632 .852 .983 r
.66537 .4816 .68476 .47911 .68598 .47198 .66645 .47448 Metetra
.635 .85 .982 r
.66645 .47448 .68598 .47198 .68721 .46464 .66755 .46714 Metetra
.638 .848 .98 r
.66755 .46714 .68721 .46464 .68845 .45708 .66867 .45957 Metetra
.642 .845 .978 r
.66867 .45957 .68845 .45708 .68971 .44927 .66979 .45174 Metetra
.645 .842 .976 r
.66979 .45174 .68971 .44927 .69098 .44119 .67093 .44363 Metetra
.648 .838 .974 r
.67093 .44363 .69098 .44119 .69226 .43283 .67207 .43521 Metetra
.651 .834 .971 r
.67207 .43521 .69226 .43283 .69355 .42417 .67323 .42646 Metetra
.653 .829 .967 r
.67323 .42646 .69355 .42417 .69486 .41516 .6744 .41734 Metetra
.656 .823 .964 r
.6744 .41734 .69486 .41516 .69618 .40579 .67557 .40781 Metetra
.658 .816 .959 r
.67557 .40781 .69618 .40579 .69751 .396 .67676 .39783 Metetra
.659 .808 .954 r
.67676 .39783 .69751 .396 .69884 .38578 .67795 .38735 Metetra
.66 .798 .949 r
.67795 .38735 .69884 .38578 .70019 .37506 .67915 .3763 Metetra
.66 .787 .942 r
.67915 .3763 .70019 .37506 .70155 .36381 .68035 .36463 Metetra
.659 .775 .935 r
.68035 .36463 .70155 .36381 .70291 .35196 .68156 .35226 Metetra
.656 .761 .927 r
.68156 .35226 .70291 .35196 .70428 .33946 .68277 .33912 Metetra
.652 .745 .918 r
.68277 .33912 .70428 .33946 .70566 .32624 .68398 .32511 Metetra
.647 .728 .908 r
.68398 .32511 .70566 .32624 .70703 .31224 .68519 .31016 Metetra
.64 .709 .897 r
.68519 .31016 .70703 .31224 .70841 .29741 .68639 .29418 Metetra
.63 .689 .886 r
.68639 .29418 .70841 .29741 .70978 .28168 .68759 .27711 Metetra
.619 .669 .875 r
.68759 .27711 .70978 .28168 .71116 .26502 .68878 .25892 Metetra
.606 .648 .865 r
.68878 .25892 .71116 .26502 .71253 .24742 .68997 .23963 Metetra
.592 .627 .855 r
.68997 .23963 .71253 .24742 .7139 .22891 .69115 .21933 Metetra
.575 .607 .847 r
.69115 .21933 .7139 .22891 .71528 .20958 .69233 .19824 Metetra
.557 .589 .842 r
.69233 .19824 .71528 .20958 .71666 .18958 .69352 .17666 Metetra
.537 .574 .839 r
.69352 .17666 .71666 .18958 .71805 .16914 .69473 .15502 Metetra
.518 .562 .84 r
.69473 .15502 .71805 .16914 .71946 .14856 .69598 .13379 Metetra
.499 .556 .846 r
.69598 .13379 .71946 .14856 .72091 .12819 .69727 .11344 Metetra
.482 .556 .855 r
.69727 .11344 .72091 .12819 .72239 .10836 .69861 .09433 Metetra
.469 .565 .87 r
.69861 .09433 .72239 .10836 .72394 .08938 .70003 .0767 Metetra
.462 .583 .889 r
.70003 .0767 .72394 .08938 .72554 .07146 .70151 .06058 Metetra
.462 .61 .911 r
.70151 .06058 .72554 .07146 .72721 .05472 .70305 .0459 Metetra
.469 .644 .934 r
.70305 .0459 .72721 .05472 .72895 .03916 .70467 .03246 Metetra
.482 .683 .955 r
.70467 .03246 .72895 .03916 .73076 .02469 .70634 .02002 Metetra
.498 .721 .972 r
.70634 .02002 .73076 .02469 .73263 .01118 .70807 .00835 Metetra
.621 .861 .988 r
.64131 .51699 .6601 .51442 .66113 .50818 .64222 .51081 Metetra
.624 .861 .987 r
.64222 .51081 .66113 .50818 .66217 .5018 .64314 .50446 Metetra
.627 .86 .986 r
.64314 .50446 .66217 .5018 .66322 .49524 .64407 .49795 Metetra
.631 .859 .985 r
.64407 .49795 .66322 .49524 .66429 .48852 .64501 .49126 Metetra
.634 .858 .984 r
.64501 .49126 .66429 .48852 .66537 .4816 .64596 .48438 Metetra
.638 .857 .983 r
.64596 .48438 .66537 .4816 .66645 .47448 .64692 .47729 Metetra
.642 .855 .981 r
.64692 .47729 .66645 .47448 .66755 .46714 .6479 .46997 Metetra
.645 .853 .979 r
.6479 .46997 .66755 .46714 .66867 .45957 .64888 .46241 Metetra
.649 .851 .977 r
.64888 .46241 .66867 .45957 .66979 .45174 .64987 .45457 Metetra
.653 .847 .975 r
.64987 .45457 .66979 .45174 .67093 .44363 .65087 .44643 Metetra
.656 .844 .972 r
.65087 .44643 .67093 .44363 .67207 .43521 .65188 .43797 Metetra
.66 .839 .969 r
.65188 .43797 .67207 .43521 .67323 .42646 .6529 .42915 Metetra
.663 .833 .965 r
.6529 .42915 .67323 .42646 .6744 .41734 .65393 .41991 Metetra
.666 .827 .961 r
.65393 .41991 .6744 .41734 .67557 .40781 .65496 .41022 Metetra
.668 .819 .956 r
.65496 .41022 .67557 .40781 .67676 .39783 .65601 .40003 Metetra
.669 .809 .95 r
.65601 .40003 .67676 .39783 .67795 .38735 .65705 .38925 Metetra
.67 .798 .943 r
.65705 .38925 .67795 .38735 .67915 .3763 .6581 .37782 Metetra
.67 .785 .935 r
.6581 .37782 .67915 .3763 .68035 .36463 .65916 .36565 Metetra
.668 .77 .926 r
.65916 .36565 .68035 .36463 .68156 .35226 .66021 .35265 Metetra
.664 .753 .916 r
.66021 .35265 .68156 .35226 .68277 .33912 .66126 .33869 Metetra
.659 .734 .905 r
.66126 .33869 .68277 .33912 .68398 .32511 .66231 .32366 Metetra
.651 .713 .893 r
.66231 .32366 .68398 .32511 .68519 .31016 .66334 .30744 Metetra
.641 .691 .88 r
.66334 .30744 .68519 .31016 .68639 .29418 .66437 .28993 Metetra
.629 .667 .868 r
.66437 .28993 .68639 .29418 .68759 .27711 .66539 .27104 Metetra
.614 .643 .855 r
.66539 .27104 .68759 .27711 .68878 .25892 .6664 .25079 Metetra
.597 .618 .844 r
.6664 .25079 .68878 .25892 .68997 .23963 .66739 .22927 Metetra
.577 .595 .834 r
.66739 .22927 .68997 .23963 .69115 .21933 .66838 .20676 Metetra
.556 .574 .828 r
.66838 .20676 .69115 .21933 .69233 .19824 .66938 .1837 Metetra
.532 .556 .825 r
.66938 .1837 .69233 .19824 .69352 .17666 .67039 .16071 Metetra
.508 .543 .827 r
.67039 .16071 .69352 .17666 .69473 .15502 .67145 .13848 Metetra
.484 .536 .835 r
.67145 .13848 .69473 .15502 .69598 .13379 .67255 .11763 Metetra
.463 .539 .849 r
.67255 .11763 .69598 .13379 .69727 .11344 .67372 .09861 Metetra
.449 .553 .869 r
.67372 .09861 .69727 .11344 .69861 .09433 .67495 .08159 Metetra
.444 .58 .895 r
.67495 .08159 .69861 .09433 .70003 .0767 .67625 .06647 Metetra
.45 .619 .923 r
.67625 .06647 .70003 .0767 .70151 .06058 .67762 .05301 Metetra
.465 .666 .95 r
.67762 .05301 .70151 .06058 .70305 .0459 .67904 .04086 Metetra
.487 .714 .971 r
.67904 .04086 .70305 .0459 .70467 .03246 .68052 .02969 Metetra
.511 .759 .986 r
.68052 .02969 .70467 .03246 .70634 .02002 .68204 .01918 Metetra
.534 .797 .994 r
.68204 .01918 .70634 .02002 .70807 .00835 .68361 .00909 Metetra
.625 .867 .988 r
.62251 .51983 .64131 .51699 .64222 .51081 .6233 .5137 Metetra
.629 .866 .987 r
.6233 .5137 .64222 .51081 .64314 .50446 .6241 .50742 Metetra
.632 .866 .986 r
.6241 .50742 .64314 .50446 .64407 .49795 .62491 .50098 Metetra
.636 .866 .985 r
.62491 .50098 .64407 .49795 .64501 .49126 .62572 .49434 Metetra
.64 .865 .984 r
.62572 .49434 .64501 .49126 .64596 .48438 .62655 .48752 Metetra
.644 .864 .982 r
.62655 .48752 .64596 .48438 .64692 .47729 .62739 .48047 Metetra
.649 .862 .98 r
.62739 .48047 .64692 .47729 .6479 .46997 .62823 .4732 Metetra
.653 .86 .978 r
.62823 .4732 .6479 .46997 .64888 .46241 .62908 .46566 Metetra
.657 .857 .976 r
.62908 .46566 .64888 .46241 .64987 .45457 .62994 .45784 Metetra
.662 .854 .974 r
.62994 .45784 .64987 .45457 .65087 .44643 .63081 .4497 Metetra
.666 .85 .97 r
.63081 .4497 .65087 .44643 .65188 .43797 .63169 .44121 Metetra
.67 .845 .967 r
.63169 .44121 .65188 .43797 .6529 .42915 .63257 .43233 Metetra
.674 .839 .963 r
.63257 .43233 .6529 .42915 .65393 .41991 .63346 .42299 Metetra
.677 .832 .958 r
.63346 .42299 .65393 .41991 .65496 .41022 .63435 .41315 Metetra
.68 .822 .952 r
.63435 .41315 .65496 .41022 .65601 .40003 .63525 .40272 Metetra
.682 .811 .945 r
.63525 .40272 .65601 .40003 .65705 .38925 .63615 .39162 Metetra
.682 .798 .937 r
.63615 .39162 .65705 .38925 .6581 .37782 .63706 .37974 Metetra
.681 .783 .927 r
.63706 .37974 .6581 .37782 .65916 .36565 .63796 .36696 Metetra
.678 .764 .916 r
.63796 .36696 .65916 .36565 .66021 .35265 .63886 .35314 Metetra
.673 .744 .903 r
.63886 .35314 .66021 .35265 .66126 .33869 .63975 .33812 Metetra
.665 .72 .89 r
.63975 .33812 .66126 .33869 .66231 .32366 .64063 .32171 Metetra
.655 .694 .875 r
.64063 .32171 .66231 .32366 .66334 .30744 .6415 .30374 Metetra
.641 .667 .859 r
.6415 .30374 .66334 .30744 .66437 .28993 .64235 .28407 Metetra
.624 .639 .844 r
.64235 .28407 .66437 .28993 .66539 .27104 .64318 .26264 Metetra
.604 .61 .83 r
.64318 .26264 .66539 .27104 .6664 .25079 .644 .23955 Metetra
.581 .583 .819 r
.644 .23955 .6664 .25079 .66739 .22927 .6448 .21516 Metetra
.555 .557 .812 r
.6448 .21516 .66739 .22927 .66838 .20676 .64561 .19012 Metetra
.525 .536 .809 r
.64561 .19012 .66838 .20676 .66938 .1837 .64644 .1654 Metetra
.494 .52 .813 r
.64644 .1654 .66938 .1837 .67039 .16071 .64731 .14203 Metetra
.463 .513 .824 r
.64731 .14203 .67039 .16071 .67145 .13848 .64824 .12086 Metetra
.438 .519 .844 r
.64824 .12086 .67145 .13848 .67255 .11763 .64924 .10235 Metetra
.424 .543 .873 r
.64924 .10235 .67255 .11763 .67372 .09861 .65031 .08647 Metetra
.425 .586 .908 r
.65031 .08647 .67372 .09861 .67495 .08159 .65145 .07286 Metetra
.442 .643 .943 r
.65145 .07286 .67495 .08159 .67625 .06647 .65264 .06101 Metetra
.47 .705 .971 r
.65264 .06101 .67625 .06647 .67762 .05301 .65388 .0504 Metetra
.503 .762 .989 r
.65388 .0504 .67762 .05301 .67904 .04086 .65517 .0406 Metetra
.534 .809 .997 r
.65517 .0406 .67904 .04086 .68052 .02969 .65648 .03127 Metetra
.561 .843 .997 r
.65648 .03127 .68052 .02969 .68204 .01918 .65783 .02216 Metetra
.582 .867 .995 r
.65783 .02216 .68204 .01918 .68361 .00909 .65921 .01311 Metetra
.629 .873 .987 r
.60371 .52296 .62251 .51983 .6233 .5137 .60437 .51692 Metetra
.633 .873 .986 r
.60437 .51692 .6233 .5137 .6241 .50742 .60505 .51072 Metetra
.638 .873 .985 r
.60505 .51072 .6241 .50742 .62491 .50098 .60574 .50436 Metetra
.642 .873 .984 r
.60574 .50436 .62491 .50098 .62572 .49434 .60643 .49781 Metetra
.646 .872 .983 r
.60643 .49781 .62572 .49434 .62655 .48752 .60713 .49106 Metetra
.651 .871 .981 r
.60713 .49106 .62655 .48752 .62739 .48047 .60784 .4841 Metetra
.656 .87 .98 r
.60784 .4841 .62739 .48047 .62823 .4732 .60855 .47689 Metetra
.661 .868 .977 r
.60855 .47689 .62823 .4732 .62908 .46566 .60927 .46942 Metetra
.666 .866 .975 r
.60927 .46942 .62908 .46566 .62994 .45784 .61 .46165 Metetra
.672 .863 .972 r
.61 .46165 .62994 .45784 .63081 .4497 .61074 .45355 Metetra
.677 .859 .969 r
.61074 .45355 .63081 .4497 .63169 .44121 .61148 .44507 Metetra
.682 .854 .965 r
.61148 .44507 .63169 .44121 .63257 .43233 .61223 .43615 Metetra
.687 .847 .96 r
.61223 .43615 .63257 .43233 .63346 .42299 .61298 .42674 Metetra
.691 .839 .954 r
.61298 .42674 .63346 .42299 .63435 .41315 .61373 .41675 Metetra
.694 .828 .947 r
.61373 .41675 .63435 .41315 .63525 .40272 .61449 .40609 Metetra
.696 .815 .939 r
.61449 .40609 .63525 .40272 .63615 .39162 .61525 .39463 Metetra
.697 .8 .929 r
.61525 .39463 .63615 .39162 .63706 .37974 .61601 .38222 Metetra
.695 .78 .917 r
.61601 .38222 .63706 .37974 .63796 .36696 .61676 .36869 Metetra
.691 .758 .903 r
.61676 .36869 .63796 .36696 .63886 .35314 .6175 .35381 Metetra
.683 .732 .887 r
.6175 .35381 .63886 .35314 .63975 .33812 .61824 .33733 Metetra
.672 .702 .87 r
.61824 .33733 .63975 .33812 .64063 .32171 .61895 .31897 Metetra
.657 .67 .851 r
.61895 .31897 .64063 .32171 .6415 .30374 .61965 .29844 Metetra
.638 .637 .833 r
.61965 .29844 .6415 .30374 .64235 .28407 .62032 .27557 Metetra
.615 .603 .816 r
.62032 .27557 .64235 .28407 .64318 .26264 .62096 .25041 Metetra
.587 .57 .802 r
.62096 .25041 .64318 .26264 .644 .23955 .62159 .22342 Metetra
.554 .539 .793 r
.62159 .22342 .644 .23955 .6448 .21516 .62221 .19566 Metetra
.515 .512 .791 r
.62221 .19566 .6448 .21516 .64561 .19012 .62286 .1687 Metetra
.473 .492 .797 r
.62286 .1687 .64561 .19012 .64644 .1654 .62356 .14417 Metetra
.431 .485 .814 r
.62356 .14417 .64644 .1654 .64731 .14203 .62434 .12319 Metetra
.401 .499 .844 r
.62434 .12319 .64731 .14203 .64824 .12086 .62519 .10598 Metetra
.391 .541 .886 r
.62519 .10598 .64824 .12086 .64924 .10235 .62611 .09202 Metetra
.408 .611 .932 r
.62611 .09202 .64924 .10235 .65031 .08647 .62708 .0805 Metetra
.447 .694 .971 r
.62708 .0805 .65031 .08647 .65145 .07286 .62811 .07059 Metetra
.493 .77 .993 r
.62811 .07059 .65145 .07286 .65264 .06101 .62917 .06164 Metetra
.536 .828 .999 r
.62917 .06164 .65264 .06101 .65388 .0504 .63026 .05319 Metetra
.57 .866 .996 r
.63026 .05319 .65388 .0504 .65517 .0406 .63137 .04492 Metetra
.596 .891 .99 r
.63137 .04492 .65517 .0406 .65648 .03127 .63251 .03664 Metetra
.615 .905 .984 r
.63251 .03664 .65648 .03127 .65783 .02216 .63366 .02823 Metetra
.628 .914 .981 r
.63366 .02823 .65783 .02216 .65921 .01311 .63483 .01961 Metetra
.634 .88 .987 r
.58489 .52642 .60371 .52296 .60437 .51692 .58544 .52049 Metetra
.638 .881 .986 r
.58544 .52049 .60437 .51692 .60505 .51072 .58599 .51441 Metetra
.643 .881 .985 r
.58599 .51441 .60505 .51072 .60574 .50436 .58655 .50816 Metetra
.648 .881 .983 r
.58655 .50816 .60574 .50436 .60643 .49781 .58712 .50173 Metetra
.653 .881 .982 r
.58712 .50173 .60643 .49781 .60713 .49106 .5877 .4951 Metetra
.659 .881 .98 r
.5877 .4951 .60713 .49106 .60784 .4841 .58828 .48826 Metetra
.664 .88 .978 r
.58828 .48826 .60784 .4841 .60855 .47689 .58886 .48117 Metetra
.67 .879 .976 r
.58886 .48117 .60855 .47689 .60927 .46942 .58946 .47381 Metetra
.677 .877 .974 r
.58946 .47381 .60927 .46942 .61 .46165 .59005 .46614 Metetra
.683 .874 .97 r
.59005 .46614 .61 .46165 .61074 .45355 .59066 .45813 Metetra
.689 .87 .967 r
.59066 .45813 .61074 .45355 .61148 .44507 .59127 .44971 Metetra
.696 .865 .962 r
.59127 .44971 .61148 .44507 .61223 .43615 .59188 .44083 Metetra
.702 .858 .957 r
.59188 .44083 .61223 .43615 .61298 .42674 .59249 .43139 Metetra
.707 .849 .95 r
.59249 .43139 .61298 .42674 .61373 .41675 .59311 .4213 Metetra
.712 .837 .942 r
.59311 .4213 .61373 .41675 .61449 .40609 .59373 .41042 Metetra
.714 .822 .932 r
.59373 .41042 .61449 .40609 .61525 .39463 .59434 .39858 Metetra
.715 .803 .919 r
.59434 .39858 .61525 .39463 .61601 .38222 .59496 .38557 Metetra
.712 .779 .904 r
.59496 .38557 .61601 .38222 .61676 .36869 .59556 .37108 Metetra
.706 .75 .886 r
.59556 .37108 .61676 .36869 .6175 .35381 .59615 .35477 Metetra
.694 .716 .866 r
.59615 .35477 .6175 .35381 .61824 .33733 .59672 .33619 Metetra
.678 .679 .843 r
.59672 .33619 .61824 .33733 .61895 .31897 .59727 .31483 Metetra
.656 .638 .82 r
.59727 .31483 .61895 .31897 .61965 .29844 .59779 .29025 Metetra
.629 .598 .799 r
.59779 .29025 .61965 .29844 .62032 .27557 .59827 .26229 Metetra
.595 .558 .782 r
.59827 .26229 .62032 .27557 .62096 .25041 .59872 .23156 Metetra
.554 .52 .772 r
.59872 .23156 .62096 .25041 .62159 .22342 .59917 .19985 Metetra
.501 .484 .77 r
.59917 .19985 .62159 .22342 .62221 .19566 .59966 .17001 Metetra
.439 .456 .781 r
.59966 .17001 .62221 .19566 .62286 .1687 .60021 .14473 Metetra
.378 .448 .807 r
.60021 .14473 .62286 .1687 .62356 .14417 .60084 .12512 Metetra
.343 .481 .853 r
.60084 .12512 .62356 .14417 .62434 .12319 .60156 .11051 Metetra
.354 .564 .916 r
.60156 .11051 .62434 .12319 .62519 .10598 .60234 .09943 Metetra
.409 .68 .972 r
.60234 .09943 .62519 .10598 .62611 .09202 .60316 .09047 Metetra
.481 .785 .998 r
.60316 .09047 .62611 .09202 .62708 .0805 .60401 .0826 Metetra
.542 .856 .997 r
.60401 .0826 .62708 .0805 .62811 .07059 .60488 .07518 Metetra
.587 .897 .987 r
.60488 .07518 .62811 .07059 .62917 .06164 .60577 .06783 Metetra
.617 .92 .976 r
.60577 .06783 .62917 .06164 .63026 .05319 .60668 .06035 Metetra
.638 .931 .97 r
.60668 .06035 .63026 .05319 .63137 .04492 .6076 .05262 Metetra
.651 .936 .967 r
.6076 .05262 .63137 .04492 .63251 .03664 .60853 .04461 Metetra
.659 .938 .966 r
.60853 .04461 .63251 .03664 .63366 .02823 .60948 .03628 Metetra
.664 .937 .966 r
.60948 .03628 .63366 .02823 .63483 .01961 .61044 .02763 Metetra
.638 .888 .986 r
.56606 .53026 .58489 .52642 .58544 .52049 .56648 .52447 Metetra
.643 .889 .985 r
.56648 .52447 .58544 .52049 .58599 .51441 .56692 .51854 Metetra
.648 .89 .984 r
.56692 .51854 .58599 .51441 .58655 .50816 .56736 .51245 Metetra
.654 .891 .982 r
.56736 .51245 .58655 .50816 .58712 .50173 .5678 .50618 Metetra
.66 .892 .981 r
.5678 .50618 .58712 .50173 .5877 .4951 .56825 .49972 Metetra
.666 .892 .979 r
.56825 .49972 .5877 .4951 .58828 .48826 .5687 .49305 Metetra
.673 .892 .977 r
.5687 .49305 .58828 .48826 .58886 .48117 .56916 .48615 Metetra
.68 .892 .974 r
.56916 .48615 .58886 .48117 .58946 .47381 .56962 .47897 Metetra
.688 .891 .972 r
.56962 .47897 .58946 .47381 .59005 .46614 .57009 .47149 Metetra
.696 .889 .968 r
.57009 .47149 .59005 .46614 .59066 .45813 .57056 .46365 Metetra
.704 .886 .964 r
.57056 .46365 .59066 .45813 .59127 .44971 .57104 .45539 Metetra
.712 .881 .959 r
.57104 .45539 .59127 .44971 .59188 .44083 .57151 .44664 Metetra
.72 .874 .953 r
.57151 .44664 .59188 .44083 .59249 .43139 .57199 .43728 Metetra
.728 .865 .946 r
.57199 .43728 .59249 .43139 .59311 .4213 .57247 .42719 Metetra
.734 .851 .936 r
.57247 .42719 .59311 .4213 .59373 .41042 .57295 .41618 Metetra
.738 .833 .924 r
.57295 .41618 .59373 .41042 .59434 .39858 .57343 .404 Metetra
.738 .809 .908 r
.57343 .404 .59434 .39858 .59496 .38557 .5739 .3903 Metetra
.734 .779 .889 r
.5739 .3903 .59496 .38557 .59556 .37108 .57436 .3746 Metetra
.724 .741 .865 r
.57436 .3746 .59556 .37108 .59615 .35477 .5748 .35624 Metetra
.707 .696 .838 r
.5748 .35624 .59615 .35477 .59672 .33619 .57521 .33434 Metetra
.682 .647 .809 r
.57521 .33434 .59672 .33619 .59727 .31483 .57559 .30788 Metetra
.65 .597 .781 r
.57559 .30788 .59727 .31483 .59779 .29025 .57592 .2761 Metetra
.61 .548 .76 r
.57592 .2761 .59779 .29025 .59827 .26229 .57621 .23957 Metetra
.555 .499 .748 r
.57621 .23957 .59827 .26229 .59872 .23156 .57649 .20173 Metetra
.475 .448 .748 r
.57649 .20173 .59872 .23156 .59917 .19985 .57682 .1685 Metetra
.371 .401 .763 r
.57682 .1685 .59917 .19985 .59966 .17001 .57725 .14415 Metetra
.277 .396 .804 r
.57725 .14415 .59966 .17001 .60021 .14473 .57777 .1283 Metetra
.259 .485 .885 r
.57777 .1283 .60021 .14473 .60084 .12512 .57836 .11799 Metetra
.345 .658 .971 r
.57836 .11799 .60084 .12512 .60156 .11051 .57899 .11045 Metetra
.467 .814 .998 r
.57899 .11045 .60156 .11051 .60234 .09943 .57964 .10401 Metetra
.56 .898 .981 r
.57964 .10401 .60234 .09943 .60316 .09047 .58031 .0978 Metetra
.616 .936 .96 r
.58031 .0978 .60316 .09047 .60401 .0826 .58099 .09142 Metetra
.65 .951 .948 r
.58099 .09142 .60401 .0826 .60488 .07518 .58168 .08471 Metetra
.669 .958 .944 r
.58168 .08471 .60488 .07518 .60577 .06783 .58237 .0776 Metetra
.681 .959 .945 r
.58237 .0776 .60577 .06783 .60668 .06035 .58308 .07009 Metetra
.686 .957 .948 r
.58308 .07009 .60668 .06035 .6076 .05262 .58379 .06218 Metetra
.689 .954 .952 r
.58379 .06218 .6076 .05262 .60853 .04461 .58452 .0539 Metetra
.689 .95 .956 r
.58452 .0539 .60853 .04461 .60948 .03628 .58525 .04527 Metetra
.688 .945 .96 r
.58525 .04527 .60948 .03628 .61044 .02763 .586 .03629 Metetra
.642 .897 .984 r
.54721 .53453 .56606 .53026 .56648 .52447 .54751 .52892 Metetra
.647 .899 .983 r
.54751 .52892 .56648 .52447 .56692 .51854 .54783 .52318 Metetra
.653 .901 .982 r
.54783 .52318 .56692 .51854 .56736 .51245 .54814 .5173 Metetra
.66 .903 .98 r
.54814 .5173 .56736 .51245 .5678 .50618 .54846 .51125 Metetra
.667 .904 .978 r
.54846 .51125 .5678 .50618 .56825 .49972 .54878 .50503 Metetra
.674 .906 .976 r
.54878 .50503 .56825 .49972 .5687 .49305 .54911 .49861 Metetra
.682 .907 .974 r
.54911 .49861 .5687 .49305 .56916 .48615 .54944 .49198 Metetra
.691 .908 .972 r
.54944 .49198 .56916 .48615 .56962 .47897 .54977 .48509 Metetra
.7 .908 .968 r
.54977 .48509 .56962 .47897 .57009 .47149 .5501 .4779 Metetra
.71 .908 .965 r
.5501 .4779 .57009 .47149 .57056 .46365 .55044 .47038 Metetra
.72 .906 .96 r
.55044 .47038 .57056 .46365 .57104 .45539 .55078 .46244 Metetra
.731 .903 .955 r
.55078 .46244 .57104 .45539 .57151 .44664 .55113 .454 Metetra
.742 .897 .948 r
.55113 .454 .57151 .44664 .57199 .43728 .55147 .44494 Metetra
.753 .888 .94 r
.55147 .44494 .57199 .43728 .57247 .42719 .55182 .43507 Metetra
.762 .875 .929 r
.55182 .43507 .57247 .42719 .57295 .41618 .55216 .42415 Metetra
.769 .854 .914 r
.55216 .42415 .57295 .41618 .57343 .404 .5525 .41181 Metetra
.77 .824 .895 r
.5525 .41181 .57343 .404 .5739 .3903 .55283 .39748 Metetra
.764 .784 .869 r
.55283 .39748 .5739 .3903 .57436 .3746 .55315 .38027 Metetra
.748 .731 .837 r
.55315 .38027 .57436 .3746 .5748 .35624 .55344 .35878 Metetra
.721 .67 .799 r
.55344 .35878 .5748 .35624 .57521 .33434 .5537 .33088 Metetra
.683 .605 .762 r
.5537 .33088 .57521 .33434 .57559 .30788 .55389 .29397 Metetra
.634 .543 .734 r
.55389 .29397 .57559 .30788 .57592 .2761 .55403 .24747 Metetra
.559 .478 .72 r
.55403 .24747 .57592 .2761 .57621 .23957 .55415 .19918 Metetra
.414 .388 .721 r
.55415 .19918 .57621 .23957 .57649 .20173 .55436 .1638 Metetra
.191 .286 .732 r
.55436 .1638 .57649 .20173 .57682 .1685 .5547 .14538 Metetra
.065 .327 .807 r
.5547 .14538 .57682 .1685 .57725 .14415 .55512 .13672 Metetra
.215 .616 .952 r
.55512 .13672 .57725 .14415 .57777 .1283 .55557 .13151 Metetra
.462 .864 .965 r
.55557 .13151 .57777 .1283 .57836 .11799 .55604 .12694 Metetra
.6 .947 .918 r
.55604 .12694 .57836 .11799 .57899 .11045 .55651 .12203 Metetra
.665 .972 .897 r
.55651 .12203 .57899 .11045 .57964 .10401 .55698 .11653 Metetra
.697 .98 .896 r
.55698 .11653 .57964 .10401 .58031 .0978 .55746 .1104 Metetra
.713 .981 .905 r
.55746 .1104 .58031 .0978 .58099 .09142 .55794 .1037 Metetra
.719 .979 .915 r
.55794 .1037 .58099 .09142 .58168 .08471 .55843 .09649 Metetra
.72 .974 .926 r
.55843 .09649 .58168 .08471 .58237 .0776 .55893 .08882 Metetra
.719 .968 .935 r
.55893 .08882 .58237 .0776 .58308 .07009 .55943 .08074 Metetra
.715 .962 .943 r
.55943 .08074 .58308 .07009 .58379 .06218 .55993 .07229 Metetra
.711 .955 .95 r
.55993 .07229 .58379 .06218 .58452 .0539 .56045 .0635 Metetra
.706 .949 .955 r
.56045 .0635 .58452 .0539 .58525 .04527 .56097 .05439 Metetra
.7 .943 .96 r
.56097 .05439 .58525 .04527 .586 .03629 .5615 .04499 Metetra
.645 .907 .982 r
.52834 .53928 .54721 .53453 .54751 .52892 .52853 .5339 Metetra
.651 .91 .98 r
.52853 .5339 .54751 .52892 .54783 .52318 .52871 .5284 Metetra
.657 .913 .979 r
.52871 .5284 .54783 .52318 .54814 .5173 .5289 .52279 Metetra
.664 .916 .977 r
.5289 .52279 .54814 .5173 .54846 .51125 .5291 .51704 Metetra
.672 .919 .975 r
.5291 .51704 .54846 .51125 .54878 .50503 .52929 .51114 Metetra
.681 .922 .972 r
.52929 .51114 .54878 .50503 .54911 .49861 .52949 .50508 Metetra
.69 .924 .969 r
.52949 .50508 .54911 .49861 .54944 .49198 .52969 .49884 Metetra
.7 .927 .966 r
.52969 .49884 .54944 .49198 .54977 .48509 .52989 .49238 Metetra
.711 .93 .962 r
.52989 .49238 .54977 .48509 .5501 .4779 .53009 .48568 Metetra
.723 .932 .958 r
.53009 .48568 .5501 .4779 .55044 .47038 .5303 .47868 Metetra
.737 .933 .953 r
.5303 .47868 .55044 .47038 .55078 .46244 .53051 .47133 Metetra
.751 .933 .947 r
.53051 .47133 .55078 .46244 .55113 .454 .53071 .46353 Metetra
.767 .931 .939 r
.53071 .46353 .55113 .454 .55147 .44494 .53092 .45515 Metetra
.783 .926 .93 r
.53092 .45515 .55147 .44494 .55182 .43507 .53113 .446 Metetra
.799 .914 .918 r
.53113 .446 .55182 .43507 .55216 .42415 .53134 .43576 Metetra
.812 .894 .902 r
.53134 .43576 .55216 .42415 .5525 .41181 .53155 .42391 Metetra
.818 .86 .878 r
.53155 .42391 .5525 .41181 .55283 .39748 .53175 .40954 Metetra
.811 .804 .845 r
.53175 .40954 .55283 .39748 .55315 .38027 .53193 .39087 Metetra
.783 .726 .799 r
.53193 .39087 .55315 .38027 .55344 .35878 .53209 .36424 Metetra
.735 .633 .746 r
.53209 .36424 .55344 .35878 .5537 .33088 .53218 .32211 Metetra
.676 .55 .704 r
.53218 .32211 .5537 .33088 .55389 .29397 .53217 .25525 Metetra
.566 .459 .692 r
.53217 .25525 .55389 .29397 .55403 .24747 .53216 .18742 Metetra
.137 .187 .652 r
.53216 .18742 .55403 .24747 .55415 .19918 .53233 .16188 Metetra
0 0 .539 r
.53233 .16188 .55415 .19918 .55436 .1638 .53259 .15777 Metetra
0 .505 .808 r
.53259 .15777 .55436 .1638 .5547 .14538 .53287 .15631 Metetra
.518 .913 .806 r
.53287 .15631 .5547 .14538 .55512 .13672 .53315 .15369 Metetra
.682 .971 .774 r
.53315 .15369 .55512 .13672 .55557 .13151 .53342 .14965 Metetra
.74 .989 .794 r
.53342 .14965 .55557 .13151 .55604 .12694 .5337 .14447 Metetra
.762 .996 .827 r
.5337 .14447 .55604 .12694 .55651 .12203 .53398 .13841 Metetra
.768 .996 .857 r
.53398 .13841 .55651 .12203 .55698 .11653 .53426 .13167 Metetra
.766 .992 .882 r
.53426 .13167 .55698 .11653 .55746 .1104 .53454 .12437 Metetra
.76 .986 .902 r
.53454 .12437 .55746 .1104 .55794 .1037 .53483 .11662 Metetra
.753 .978 .917 r
.53483 .11662 .55794 .1037 .55843 .09649 .53512 .10847 Metetra
.744 .97 .93 r
.53512 .10847 .55843 .09649 .55893 .08882 .53541 .09999 Metetra
.735 .963 .939 r
.53541 .09999 .55893 .08882 .55943 .08074 .53571 .09119 Metetra
.727 .955 .947 r
.53571 .09119 .55943 .08074 .55993 .07229 .53601 .08211 Metetra
.719 .948 .953 r
.53601 .08211 .55993 .07229 .56045 .0635 .53631 .07277 Metetra
.712 .941 .958 r
.53631 .07277 .56045 .0635 .56097 .05439 .53662 .06317 Metetra
.705 .935 .963 r
.53662 .06317 .56097 .05439 .5615 .04499 .53694 .05332 Metetra
.646 .918 .978 r
.50945 .54454 .52834 .53928 .52853 .5339 .50952 .53945 Metetra
.652 .922 .976 r
.50952 .53945 .52853 .5339 .52871 .5284 .50958 .53427 Metetra
.659 .926 .974 r
.50958 .53427 .52871 .5284 .5289 .52279 .50964 .529 Metetra
.667 .93 .971 r
.50964 .529 .5289 .52279 .5291 .51704 .50971 .52365 Metetra
.675 .934 .968 r
.50971 .52365 .5291 .51704 .52929 .51114 .50977 .51819 Metetra
.684 .939 .965 r
.50977 .51819 .52929 .51114 .52949 .50508 .50984 .51262 Metetra
.694 .944 .96 r
.50984 .51262 .52949 .50508 .52969 .49884 .50991 .50693 Metetra
.705 .949 .955 r
.50991 .50693 .52969 .49884 .52989 .49238 .50997 .50111 Metetra
.718 .954 .95 r
.50997 .50111 .52989 .49238 .53009 .48568 .51004 .49513 Metetra
.731 .96 .943 r
.51004 .49513 .53009 .48568 .5303 .47868 .51011 .48899 Metetra
.747 .965 .935 r
.51011 .48899 .5303 .47868 .53051 .47133 .51018 .48263 Metetra
.765 .97 .925 r
.51018 .48263 .53051 .47133 .53071 .46353 .51025 .47602 Metetra
.784 .975 .913 r
.51025 .47602 .53071 .46353 .53092 .45515 .51033 .46907 Metetra
.807 .978 .898 r
.51033 .46907 .53092 .45515 .53113 .446 .5104 .46166 Metetra
.833 .978 .882 r
.5104 .46166 .53113 .446 .53134 .43576 .51047 .45357 Metetra
.861 .972 .862 r
.51047 .45357 .53134 .43576 .53155 .42391 .51054 .44434 Metetra
.889 .952 .84 r
.51054 .44434 .53155 .42391 .53175 .40954 .51061 .43299 Metetra
.904 .896 .81 r
.51061 .43299 .53175 .40954 .53193 .39087 .51068 .4167 Metetra
.857 .758 .753 r
.51068 .4167 .53193 .39087 .53209 .36424 .51072 .38416 Metetra
.743 .577 .67 r
.51072 .38416 .53209 .36424 .53218 .32211 .51065 .26291 Metetra
.524 .416 .673 r
.51065 .26291 .53218 .32211 .53217 .25525 .51062 .18286 Metetra
.869 .535 .025 r
.51062 .18286 .53217 .25525 .53216 .18742 .51073 .19219 Metetra
.51073 .19219 .53216 .18742 .53233 .16188 .51082 .19268 Metetra
.755 .924 .562 r
.51082 .19268 .53233 .16188 .53259 .15777 .51091 .18914 Metetra
.823 .958 .622 r
.51091 .18914 .53259 .15777 .53287 .15631 .511 .1837 Metetra
.842 .984 .703 r
.511 .1837 .53287 .15631 .53315 .15369 .51108 .17721 Metetra
.842 .997 .769 r
.51108 .17721 .53315 .15369 .53342 .14965 .51117 .17004 Metetra
.832 .999 .82 r
.51117 .17004 .53342 .14965 .5337 .14447 .51126 .16239 Metetra
.818 .996 .857 r
.51126 .16239 .5337 .14447 .53398 .13841 .51135 .15437 Metetra
.802 .989 .884 r
.51135 .15437 .53398 .13841 .53426 .13167 .51144 .14605 Metetra
.787 .981 .904 r
.51144 .14605 .53426 .13167 .53454 .12437 .51153 .13746 Metetra
.773 .973 .919 r
.51153 .13746 .53454 .12437 .53483 .11662 .51163 .12864 Metetra
.76 .964 .931 r
.51163 .12864 .53483 .11662 .53512 .10847 .51172 .11959 Metetra
.748 .957 .94 r
.51172 .11959 .53512 .10847 .53541 .09999 .51182 .11034 Metetra
.737 .949 .948 r
.51182 .11034 .53541 .09999 .53571 .09119 .51192 .10088 Metetra
.727 .942 .954 r
.51192 .10088 .53571 .09119 .53601 .08211 .51202 .09123 Metetra
.718 .936 .959 r
.51202 .09123 .53601 .08211 .53631 .07277 .51212 .08138 Metetra
.71 .93 .963 r
.51212 .08138 .53631 .07277 .53662 .06317 .51222 .07133 Metetra
.703 .925 .966 r
.51222 .07133 .53662 .06317 .53694 .05332 .51233 .06109 Metetra
0 g
.25 Mabswid
.02321 0 m
0 .36096 L
s
.02268 .0082 m
.02893 .0082 L
s
[(-1)] .01018 .0082 1 0 Mshowa
.01734 .09126 m
.02359 .09126 L
s
[(-0.5)] .00484 .09126 1 0 Mshowa
.01188 .17619 m
.01813 .17619 L
s
[(0)] -0.00062 .17619 1 0 Mshowa
.00629 .26307 m
.01254 .26307 L
s
[(0.5)] -0.00621 .26307 1 0 Mshowa
.00058 .35196 m
.00683 .35196 L
s
[(1)] -0.01192 .35196 1 0 Mshowa
.125 Mabswid
.02162 .02467 m
.02537 .02467 L
s
.02056 .0412 m
.02431 .0412 L
s
.01949 .05781 m
.02324 .05781 L
s
.01842 .0745 m
.02217 .0745 L
s
.01626 .10809 m
.02001 .10809 L
s
.01517 .125 m
.01892 .125 L
s
.01408 .14199 m
.01783 .14199 L
s
.01298 .15905 m
.01673 .15905 L
s
.01077 .19341 m
.01452 .19341 L
s
.00966 .21071 m
.01341 .21071 L
s
.00854 .22808 m
.01229 .22808 L
s
.00742 .24554 m
.01117 .24554 L
s
.00516 .28069 m
.00891 .28069 L
s
.00402 .29838 m
.00777 .29838 L
s
.00288 .31616 m
.00663 .31616 L
s
.00173 .33402 m
.00548 .33402 L
s
gsave
-0.06312 .17619 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
69.000000 12.812500 moveto
(@) show
75.000000 12.812500 moveto
(@) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 12.812500 moveto
(D) show
93.000000 12.812500 moveto
(D) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{288, 173.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000[A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00:Eoo`05001oogoo001oo`03001cOol00:Ioo`80009o
o`03001oogoo07=oo`00YWoo0P000goo00<007ooOol0LWoo002UOol01000Oomoo`000Woo00<007oo
Ool0LWoo002ZOol00`00Ool0001cOol00:]oo`03001oogoo079oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001eOol5000_Ool00`00Oomoo`0_Ool5
0010Ool0049oo`<0039oo`03001oogoo02ioo`03001oo`00039oo`03001oogoo031oo`<000eoo`00
@Woo00<007ooOol0;7oo0`000goo00<007ooOol0;Woo00<007oo0000<Woo00<007ooOol0<7oo00<0
07ooOol03Goo000mOol30003Ool00`00Oomoo`0aOol00`00Oomoo`0^Ool00`00Ool0000bOol00`00
Oomoo`0aOol00`00Oomoo`0<Ool004=oo`03001oogoo035oo`03001oogoo02ioo`03001oo`00039o
o`03001oogoo035oo`03001oogoo00aoo`00@Woo00<007oo0000<Goo0P00<Goo00<007ooOol0<7oo
0P00<Woo00<007oo00003Goo0013Ool00`00Oomoo`3;Ool00`00Oomoo`0<Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00?7oo1@000gooc00047oo000nOol00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`0>Ool003Qoo`<000=oo`03001oogoo00=oo`8008Uoo`h004=oo`00?Woo00<007ooOol00goo00<0
07ooOol0Pgoo1@000T]o00<004<o@cl00T<o00<003kN?]h00SkN00<003ZM00000P00@7oo000nOol0
0`00Oomoo`03Ool00`00Oomoo`1nOol500000dnN001;O`02Bgl:0002?]h00`00>YdjW@02>Yd4000l
Ool003eoo`8000Eoo`03001oogoo07aoo`800004Dkh004nNCih600000dMO000o7`04?al00`00>[hj
_P040004>Yd00`00>W`jO003000iOol004Aoo`03001oogoo07Uoo`<0009C_P@0009?WP030017GdMO
00D0008o7`03000j_SZn00<j_P06000jW@00000jW@001CYl0`00=goo0014Ool00`00Oomoo`1gOol2
00000eNn001C_P02000015>n001?WTnN1@000T<o00<003kN?]h01@000cZn00@003ZM>YdjW@<000<j
O004000nO3il?W`2000eOol004=oo`03001oogoo07Eoo`<0009G_P<0009C_P@0009;W`030013?d<o
0093?`03000ngSkN008ngP03000jWCZM00D000<jW@06000jO000000jO0001Cil0P00<goo0013Ool2
001dOol200000eNn001G_P0200000eON001C_P02000015>n001;Wd^O2P000SkN00<003ZM>Yd00cZM
00H003Yl000003ZM0003>W`30004?W`00`00?W`00002000`Ool004=oo`03001oogoo06moo`@0009G
_P<0009GgP<00003Dkh0000000<00097O`03000o7clO008o7`03000j_CZm00@000<jW@03000jO3Yl
008jO08000@jO003000nO00000800003?W`003il00<nO0<002eoo`00@goo00<007ooOol0Jgoo1000
0U^n00L005Nn000005_N001GgP0D0003>[d01P00>W`00000>Yd000DjO0<0008jO003000nO3il008n
O08000DnO0040012O000000[Ool004=oo`8006Uoo`<00004Ekh005^nFkh40002Fmh600001Dnn0000
04nn000014=O00<003[N>]h00c[N00H003Im000003Zm0003>W`30003>W`01000?U/nFciK0`001Cil
0`000Sil00<0049l@W`00T9l0`00:7oo0013Ool00`00Oomoo`1UOol30003Ekh40002Fkh00`00Fmh0
000400001EOM00000000Ckh02P000S[N00<003Im=Wd00SIm0`000cYl00H003YK000003Yl0005?U/2
0003?W`01000?W/nNcik0`001D9l00@004:L000002Ioo`00@goo00<007ooOol0Hgoo0P0000=GWP00
Ekh00`0000=K_P00Fkh00U^n1P0000AGg@00001Gg@<0009;W`03000o7clO008o7`03000fWCJM00@0
00@fO@06000jF`00000jO0000cYK0P001CiK00H003ik000003il0005?W/20003@W`00`00@Ya2W002
@Y`3000SOol004=oo`03001oogoo05moo`@0009GWP<000=K_P03001K_P0000@0009Kg@<00004Emd0
00000002Bil50002?al00`00=YdfW@02=Yd01P00=U`00000=Wd000@jF`8000@jF`<000<nF`04000n
Ncik?W/30004?W/01P00@W`00000@W`000E2W0030012W0000080021oo`00@goo0P00Fgoo1@000UNN
00H005NN000005^n0002Fkh400001E_M00000000Fmd00P0000EKg@00000005?M00@00093O`03000f
_SJn00D0008fW@04000fG3IL=U`20005>U/30002>U/00`00?U/nF`0200000ciK000nN`03?W/00`00
@W/0000200000cik0012O002@W`30004@Y`00`00@Ya2W002@Y`4000LOol003=oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo05Eoo`D0009GWP03001GWUNN00@0009K_P@0
009K_P<00004Fmd000000002Fmd200001E?M000005?M00000T=o1@000SJn00<003IL=U`00`0013IL
0`000SYK00@003YK>U/jF`<000@nF`<000<nN`030012Nd9k0092N`<000=2O0030012W00000800003
@Y`004:L00A2W0030016W4JL00@001Qoo`00<Woo00<007oo00001goo00<007oo000017oo00<007oo
Ool0Cgoo1P000UMn00@005NNEiiGWP@0009GWP06001K_P00001K_P000U^n0`0000IKg@00001Og@00
Fmd200000e_M00000002Dmd40002>al00`00<WdbO@030004=U`30002=U`00`00>S/j>`030005>U/2
0004?U/01P00?U/00000?W/000E2N`060012N`000012O00014:L10000T:L00<004JLAY`00dJL00@0
04Jl000001Ioo`00;Goo0`000Woo00<007oo00002Goo00<007ooOol00Woo0P00Bgoo1@000U=n00<0
05MnEgh00eMn00H005NN000005NN0003Eih30002Fkh40002Fkh20002Gmd300001E_M00000000Dmd0
1P000S/O00<0039m<Wd00S9m0`000SIL00<003Hk=S/00`0013Xk00<003YK>U/00cYK00H003iK0000
03iK0004?U/30003@W/00`00@W]2N`02@W/30004@Y`00`00AYa6W0040003AY`00`00A[a6_002A[`4
000BOol0039oo`03001oo`0000Moo`8000Eoo`03001oogoo04Eoo`D0009COP03001COU=n009COP04
001GOUMnEgh40003Eih01`00Eih00000Fih005^n00800004Fkh005^nFkh3000015oM000005oM0`00
00=Ko00000000`0000A7WP00<[hb_P@000<bO@03000f>cHk00<000@f>`03000j>cXk008j>`<000<j
F`04000nFciK?U/20005?U/01P00@W/00000@W/000E2N`060012W0000012W0001DJL00H004JL0000
04JL0005A[`00`00A[a6_004000>Ool0039oo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo
03moo`H0009COP03001COU=n009COP03001COU=n00H0009GWP03001GWUNN00@0009KWP<000=K_P<0
009Og@80009Og@800004Fo`00000Fo`2000014NN0000000013:n00H0038k0000039m0004=S/00`00
=S/f>`02=S/30002>S/00`00?U/nF`0200000cYK000nF`03?U/30002?U/00`00@W]2N`02@W/30003
@W/00`00@Ya2W002@Y`30003AY`00`00AYa6W002AY`40003A[`00`00A[a6_003A[`00`00Oomoo`0<
Ool003=oo`03001oogoo00Ioo`<000Aoo`03001oogoo03Yoo`D0009COP03001COU=n00=COP03001C
OU=n00D000=GOP03001GWUNN00D0009GWP06001KWP00001KWP000U^n0`000UoM0`0000AOg@00001O
o0800003Fo`0000000<0008k?`<00003<[h0038k00<b>`8000@f>`<0008f>`03000j>SXj00<000@n
F`8000@nF`030012Nd9k00<000E2N`060012N`000012N`001D:L00H004JL000004JL0005AY`00`00
A[a6_0050003A[`00`00Oomoo`0=Ool0049oo`80035oo`/0009CGP03001COU=n00=COP03001COU=n
00D0009COP04001GOUMnEgh50002Eih00`00EiiGWP040002Fih40002Fkh30002Gmd200000eol0000
00060003>cl01000:S`Z?2Xl0P001C8k0`000SHk00<003XJ>QX00`0013Xj00<003iK?U/00ciK0`00
0SiK00<0049k@W/00T9k0P00149k00@0049k@W]2N`<000=2W0030016W4JL0096W0<000A6W0030016
_4Jl00=6_0060016_0000016_0003goo0012Ool00`00Oomoo`0VOol:0002Ceh00`00Cei?GP03Ceh0
0`00DeiCGP0;0002Dgh00`00DgiCOP060002Egh00`00EiiGWP050002Eih01P00Fih00000Fkh000=K
_P80009Og@D0009Oo0<00003Dm`0000000D000<Z?0<0008b>`04000f6SHJ=QX30004>QX00`00>SXj
>P02>SX30002?U/01000@U]2Fd9K0`00149k00<0049k00000P0000=2N`00@W/00d9k00H004JL0000
04:L0005AY`00`00A[`0000200000dJL0016_003A[`00`00A[a6_002A[`2000?Ool0049oo`03001o
ogoo01]oo`/0009?GP03001?GTmN00=?GP03001?GTmN009?GP03001?GTmN00D0009CGP03001COU=n
00=COP03001COU=n00D0009COP03001GOUMn009GOP@0009GWP03001GWUNN00@000=K_P05001K_P00
001O_@0300000eoM00000002Go`300000e?L000000020003:Yh01P00:OX00000:S`0008anP<000Df
6P03000j6SXJ008j6P<0008j>P03000nFSiJ00<000E2F`8000=2N`030012Nd9k0092N`<000=2N`04
0016W4JLAY`30004AY`00`00A[a6_002A[`40002A[`00`00A[a6_003A[`00`00Oomoo`0=Ool0049o
o`03001oogoo00]ooa00009?GP03001?GTmN00=?GP03001?GTmN009?GP04001?GTmNCeh:0002Ceh0
0`00DeiCGP03Deh00`00DgiCOP050002Dgh00`00DgiCOP03Dgh01P00Egh00000Egh000=GWP@0009K
WP03001K_U^n00@0009O_@800004Gmd00000Hm`:00001Agk000002ZN00000bWj0P00137j00<003HJ
=QX00cHJ0P000cXJ00<003hj?SX00`0013iJ00<0049K@U/00d9K00H0049k0000049k0005@W/01P00
AY/00000@W/000A6W0030016W00000800003AY`004Jl00A6_0030016_4Jl00D00096_003001oogoo
00ioo`00@Woo3P000T]N00<004mNCeh00dmN00<004mNCeh00TmN00<004mNCeh00dmN00<004mNCeh0
2`000TmN00<004mNCeh00TmN00<004mNCeh02`000U=n00<005=nDgh02P000eMn00H005NN000005NN
0003Fih40002Fkh01@00Gkd00000Gkd00P000V?L100000ESnP00000003]n008000<Mn`8000@YnP80
00<anP8000@f6P06000j6P00000j6P0013hj00<003iJ?UX00SiJ0`000T9K00<0049k@W/00T9k0`00
0d9k00<004JKAY/00TJK0`000dJL00<004JLAY`00TJL10000TJl00<004JlA[`00dJl00<004JmA[d0
0`0047oo0012Ool00`00Bei;GP03Beh00`00Bei;GP03Beh00`00Bei;GP02Beh00`00Cei?GP0@0002
Ceh00`00Cei?GP03Ceh00`00Cei?GP02Ceh00`00Cei?GP050002Deh00`00DeiCGP03Deh00`00DgiC
OP050002Dgh00`00EgiGOP03Egh00`00EgiGOP040003Eih01P00Fih00000Fih0009K_P@00005Gkd0
0000001Sg00200000f?l001SnP0600000aYm000000037O/20003:OX01`00=OT00000<OX003XI0080
0003=QX003XJ00<j6P8000@n>P<0008nFP030012Fd9K00<000E2N`060016N`000012N`001DJK00H0
04JL000004JL0005AY`00`00A[a6_0050002A[`00`00A[e6_@03A[d00`00Oomoo`0>Ool0049oo`80
009;GQ00009?GP03001?GTmN00=?GP03001?GTmN009?GP03001?GTmN00=?GP03001?GTmN00X000=?
GP03001CGU=N009CGP03001CGU=N00D0009COP03001COU=n00=COP03001GOUMn00D0009GOP03001G
WUNN00@0009KWP@0009O_@<0009Sg@800003Ho`0000000H000<JO@07000QV@00000Mn`00;MT00P00
00<YnP00=OT00SGi0P000cXI0P001CXJ00<003hj?SX00Shj00<0049J@UX00`00149K0P000d9k00<0
04IkAW/00TIk0`000dJK00<004JLAY`00TJL10000TJL00<004JlA[`00dJl00<004JlA[`01@000TJm
00<007ooOol03goo0012Ool40002Beh00`00Bei;GP03Beh00`00Bei;GP03Beh00`00Cei?GP02Ceh0
0`00Cei?GP0@0002Ceh00`00Cei?GP02Ceh01000Cei?GTmN2P000U=N00<005=nDgh00U=n00@005=n
DgiCOPD0009GOP03001GOUMn00D0009GWP06001KWP00001KWP000enm0P000V?M1@000VOk1@0000D5
F@00000JO@0000<QV@8000<]f@8000@en@03000j6CXI008j6@03000j6SXJ00<j6P<0008n>P030012
FT9J0092FP030012Fd9K0092F`060016N`000012N`001DIk00H004JL000004JK0005AY`00`00A[a6
_0050002A[`00`00A[a6_003A[`00`00A]e6g@03000AOol0049oo`03001oo`0000A;GP03001;GT]N
0100009?GP03001?GTmN00=?GP03001?GTmN009?GP03001?GTmN009?GP03001?GTmN00H0009?GP03
001CGU=N009CGP03001CGU=N009CGP03001COU=n00H0009COP03001GOUMn00D0009GOP03001GWUNN
00@000=KWP05001O_@00001O_@030002Hmd00`00Io]Wn`0500000d>I0005F@021ET200048IT00`00
;MT]f@02;MT00`00=OTen@02=OT20003>QT30002>QX01000@SY2>T8j0`00149J0`000T9K00@004Ik
AW]6N`<000A6N`040016W4JLAY`40002AY`00`00A[a6_003A[`00`00A[a6_0040003A[`00`00A]e6
g@03A]d00`00Oomoo`0?Ool0049oo`03001oo`0000L0009;GP03001?GTmN00=?GP03001?GTmN00=?
GP03001?GTmN009?GP03001?GTmN00l000=?GP03001?GTmN009?GP03001CGU=N00X000=COP03001C
OU=n00D0009GOP04001GOUMnEgh40002Fih00`00FiiKWP040002Gkd20002Hmd500000fOj00000005
00031ET200038IT20003;MT20003=OT01P00?QT00000>QT0008n>@<000E2>P8000=2FP030012Nd9k
00<000A6N`030016V`0000800003AW/004JL00=6W0030016W4JL00@000=6_0030016_4Jl00=6_006
0016_@000016_0001DKM00<007ooOol03goo0012Ool01000Oomoo`0014]N00<004]NBeh00T]N00<0
04mNCeh00TmN00@004mNCei?GPX0009?GP03001?GTmN00=?GP03001?GTmN009?GP03001?GTmN00X0
009CGP03001CGU=N00=CGP03001COU=n00D0009COP03001GOUMn009GOP06001GOP00001GOP000e^N
10000U^N00D005nm000005nm00<0009Wg003001WnP0000@00081n@03000E5P000085F@03000]U`00
008QV@03000ef000008]f@06000in@00000en@000chI0P0013hi00<0048j@SX00d8j00H0049J0000
049J0004@W/20003AW/00`00AY]6V`02AY/40002AY`00`00AYa6W002AY`01P00A[`00000A[`000E6
_0040016_DJmA[d40003A]d00`00Oomoo`0?Ool001Eoo`8000Aoo`8000Qoo`8000Aoo`8001Eoo`80
0003Ool000000140009?GP03001?GTmN009?GP03001?GTmN009?GP04001?GTmNCeh:0002Ceh00`00
Cei?GP02Ceh00`00DeiCGP03Deh00`00DeiCGP050002Dgh00`00DgiCOP02Dgh00`00EgiGOP040003
Egh01P00Fih00000Fih000=KWP<0009O_@80009Wg0T00081n@06000E5QDF0005F@000RfG00<0026I
00000SGH00<002gI00000cWi0P0013hI00<003hi?ST00Shi0`000T8j00<0049J@UX00T9J0P00149k
00H004Ik000004Ik0005AY/00`00AYa6W0040003AY`01000A[a6_4Jl10000dJl00<004JmA[d00TJm
00<004[MB]d010004Goo000EOol00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00
Oomoo`0COol01000Oomoo`001D]N00<004]NBeh00T]N00<004mNCeh00TmN00<004mNCeh00TmN00<0
04mNCeh02`000TmN00<004mNCeh00TmN00<004mNCeh00TmN00<004mNCeh02`000U=N00<005=nDgh0
2P000UMn00<005MnEgh010000e^N00L005^N000005nM001O_@02000016>m000000000VOL0P0000E[
n0000000000@00<000<E5P8000<]U`8000<ef08000@in@03000n6ChI008n6@8000<n>@030012FT9J
00<000E2FP<00092N`040016NdIkAW/40002AY/00`00AYa6W003AY`01P00A[`00000AY`000A6_003
001:_4Zl00H00096_@03001:gD[M00=:g@03001oogoo00moo`003Woo0`0017oo00<007ooOol00goo
00<007ooOol01@000goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol00goo00D007ooOomo
o`00009;GQ@0009?GP03001?GTmN00=?GP03001?GTmN009?GP03001?GTmN00X0009CGP03001CGU=N
00=CGP03001CGU=N00D0009CGP03001GOUMn009GOP03001GOUMn00D0009GOP03001KWU^N00@0009O
W@<0009S_@80009Wg0<00003JoP0000000<00080408000<E5P03000]UbfG008]U`03000ef3GH008e
f003000inCWi008in@8000<n6@060012>@00000n>@00149J00<0049J@UX00d9J00<004IkAW/00`00
14Ik00<004JKAY/010000dJL00<004JlA[`00TJl10000TJl00<004ZlB[`00dZl00<004[MB]d01@00
0T[M00<007ooOol047oo000=Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol037oo00<007oo000017oo00@007ooOomoo`<0009;
GP03001;GT]N009;GP03001?GTmN00=?GP03001?GTmN009?GP03001?GTmN009?GP03001?GTmN00X0
009?GP03001?GTmN00=?GP03001CGU=N009CGP03001CGU=N00D0009CGP03001CGU=N009CGP03001G
OUMn00D0009GOP03001GOUMn00D0009KWP07001OW@00001OW@00Hkd00P0000ES_@00000006_k00P0
0080408000<E5P8000<]U`8000<ef08000<in@0600126@00000n6@000d8i0P00149J0`000T9J00<0
04IkAW/00dIk0P000dIk00<004JKAY/00TJK00H004Jl000004JL0005A[`00`00B[a:_0050002B[`0
0`00B]e:g@03B]d00`00B]e:g@03000BOol000eoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Ool00004Ool20002
Ool00`00Bei;GP02Beh00`00Bei;GP03Beh00`00Cei?GP0?0003Ceh00`00Cei?GP02Ceh00`00Cei?
GP02Ceh00`00Cei?GP0:0002Deh00`00DeiCGP02Deh00`00DeiCGP050002Egh00`00EgiGOP050003
Fgh00`00FiiKWP030003Gid20002Hkd2000016_k000006oj1P0000H<]0000100036F00025AH20003
;IL00`00?OP00002=MP00`00?QP00002>OT01000@QU26D8I0P00148i0P000d9J00<004IjAWX00`00
1DIk00H004JK000004Ik0004AY/01000A[a6_4Jl10000TJl00<004ZlB[`00dZl00<004[LB]`01@00
0T[M00<004[MB]d00d[M00<007ooOol047oo000<Ool200000goo00000004Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Ool00003Ool0
0`00Oomoo`02Ool>0002Ceh00`00Cei?GP02Ceh00`00Cei?GP03Ceh00`00Cei?GP0?0002Ceh00`00
DeiCGP02Deh00`00DeiCGP0:0002Deh00`00EgiGOP050002Egh00`00FgiKOP02Fgh40002Fid00`00
Gid00002000016>m000006Nl0P000Voj1`0000@<]0000100008aUP05000E5P00>ML00002;IL01P00
?OPmn000=MP0008n6003000in@0000A26@030012>D8i0092>@060016FP000012FP0014Ij0P000dIk
00<004JKAY/00TJK10000TJK00<004JlA[`00TJl00<004ZlB[`01@000TZl00<004[LB]`00d[L00<0
04[MB]d01@000T[M00<007ooOol04Goo000EOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Bei;
GP02Beh00`00Bei;GP02Beh00`00Cei?GP02Ceh00`00Cei?GP0;0002Ceh00`00Cei?GP02Ceh00`00
Cei?GP02Ceh00`00Cei?GP0:0002Deh00`00DeiCGP03Deh00`00DeiCGP040002Egh00`00EgiGOP03
Egh01P00Fgh00000Fgh000=KW@<0009OW@8000=W_003001_nP0000P0008<]080008aUP03000E5P00
008ie`03000]U`00008mn003000ef00000<n608000A26@<00092>@040016FTIJAUX20004AWX01P00
AW/00000AW/000E6V`03001:W4ZL00D00096_003001:_4Zl009:_003001:_4Zl00D0009:g003001:
gD[M00=:g@03001:gD[M00<001=oo`005Goo0P0017oo0P000Woo0P0017oo0P0017oo0P003goo00<0
07ooOol00Woo0P0017oo4P000TmN00<004mNCeh00dmN00<004mNCeh00TmN00<004mNCeh02P000TmN
00<005=NDeh00e=N00<005=NDeh00U=N00<005=NDeh01@0000=CGP00Egh015Mn00<005MnEgh01000
0e]n00H005^M000005nM0002Gid20003Ik`300000foi000000030002KP000`003;@<]0020003<IH2
0003>ML20003?OP20004?QP00`00@QU26@02@QT00`00AUU6F@030004AUX30002AWX01000AW]6NdIk
10000TJK00<004ZLBY`00dZL00<004ZlB[`010000dZl00<004ZlB[`00TZl00<004[MB]d01@000T[M
00<004[MB]d00d[M00<007ooOol04Goo0011Ool00`00Oomoo`03Ool00`00Bci;?P03Bch00`00Bci;
?P02Bch00`00Cei?GP02Ceh00`00Cei?GP02Ceh00`00Cei?GP0:0002Ceh00`00Cei?GP03Ceh00`00
Cei?GP02Ceh00`00DeiCGP0:0002Deh00`00DeiCGP02Deh00`00EgiGOP050002Egh00`00FgiKOP04
0003Gid30002Hid300000fNl001_n@050003KP0200023;@01000<IHaUS6F0P000cWG0P0013gh00<0
03hH?QP00ShH0`000T8I00<004IIAUT00TII00<004IJAUX00TIJ00<004IjAWX00`0014Ik00<004ZK
BY/010000dZL00<004ZlB[`00dZl00H004Zl000004Zl0004B[`00`00B]e:g@02B]d00`00B]e:g@05
0002B]d00`00Oomoo`0BOol0045oo`03001oogoo00Aoo`03001;?T/n01@000=?GP03001?GTmN009?
GP03001?GTmN009?GP03001?GTmN00X0009CGP03001CGU=N009CGP03001CGU=N00X0009GGP03001G
OUMn00D0009KO@03001OWEnM00<000=SW@80009W_0@00004MmD000000003KP0200023;@00`00<IHa
UP02<IH00`00>MLie`02>ML00`00?OPmn002?OP20003?QP00`00ASU6>@030004AUT30002AUX00`00
AWY6NP02AWX30002AW/00`00BY]:V`02BY/01P00B[`00000BY`000A:_003001:_4Zl009:_0@0009:
_003001:gD[M009:g@03001:gD[M009:g@03001:oD[m00<001Aoo`00@Goo00<007ooOol017oo0`00
0T/n00<004lnCch00dln00<004lnCch00Tln00<004mNCeh00TmN00<004mNCeh03`000TmN00<004mN
Ceh00TmN00<005=NDeh00U=N00<005=NDeh01@000U=N00<005MNEeh00UMN00<005MNEeh01@000UMn
00<005]mFgd01@000UnM00D006>M000006>M00<00003Jk/007?h00800004KaL0046e0002KP020002
3;@20003<IH20003>ML20003?OP01P00AQP00000?QP000A6>@030016FDII0096F@030016NTIj00<0
00A6NP03001:VdZK00@000=:V`04001:_4ZlB[`40002B[`00`00B[a:_003B[`00`00B]a:g00:0002
B]d00`00B_e:o@02B_d00`00Oomoo`0BOol0045oo`8000Ioo`03001;?T/n009;?P03001??Tln00l0
009?GP03001?GTmN009?GP03001?GTmN009?GP03001?GTmN009?GP03001?GTmN00X0009CGP03001C
GU=N009CGP03001GGUMN00D0009GGP04001GOUMnEgh40002Fgd01000GieOWEnM0`000V>M0P000V^k
1@0000A_5`00@KD0009^00040015e@003;@20003<IH00`00AOL00002>ML00`00AQP00002?OP01000
AQQ664HH0P0014Hi0P000TII00<004IjAWX00dIj0P000dIj00<004ZKBY/00TZK00H004Zk000004ZK
0004B[`00`00B[a:_0050002B[`00`00B]a:g003B]`00`00B]e:g@02B]d00`00B]e:g@050002B_d0
0`00Oomoo`0BOol0045oo`03001oogoo00Eoo`P0009??P03001??Tln009??P03001??Tln009??P03
001?GTmN009?GP03001?GTmN00l0009?GP03001CGU=N009CGP03001CGU=N00X0009GGP03001GGUMN
009GGP06001GOP00001KOP0015]m00L005nM000005mm001SW@0200001fNL001[^`00Kk/007OE0080
0004KaL0046e0002KP001`00AMD000bd0015mP00008aUP060015mdGg000ie`000THH00<003gh0000
14HH00<004HiAST00THi00<004IJ00000P001DIj00H004ZK000004Ij0003BY/00`00B[]:^`02B[/4
0002B[`00`00B[a:_002B[`00`00B]a:g0050002B]`00`00B]e:g@02B]d00`00B]e:g@03B]d00`00
B_e:o@03000DOol0045oo`03001oogoo00Eoo`03001;?T/n009;?P03001??Tln009??P03001??Tln
00l0009??P03001?GTmN00=?GP05001?GTmNCeh00004Ceh00`00DeiCGP050002Deh00`00DeiCGP02
Deh00`00EeiGGP090003Fgh00`00FgeKO@040002Ggd30003Ii`200000fnk000000020002KaL02P00
@KE1]@00KP0004GE000<]0000TGf00<0036F00000TGg00<003WG00000dHH0P0014HH0P000THi00<0
04IJAUX00TIJ0P000dIj00<004ZKBY/00TZK0`000TZK00<004ZkB[/00dZk00<004ZlB[`01@000TZl
00<004[LB]`00T[L00<004[MB]d02P000T[M00<004[mB_d00d[m00<007ooOol04Woo0011Ool00`00
Oomoo`05Ool=0002Cch00`00Cci??P03Cch00`00Cci??P02Cch00`00Cci??P02Cch00`00Cei?GP0>
0003Deh01@00DeiCGU=N00000U=N1@000UMN00<005MNEeh00UMN00<005]nFgh01@000U]m00H005mm
000005mm0003Ii`200000fnk001_^P030002KaL02P00@KE1]@00KP0004GE000<]0000TGf00<0036F
00000dGg0P0014HH00<004HHAQP00THH00<004YI00000P0014IJ00H004Yj000004Ij0005BY/00`00
BY/000040002B[/00`00B[a:_003B[`00`00B]a:g0050002B]`00`00B]e:g@02B]d00`00B]e:g@02
B]d00`00B_e:o@050002B_d00`00Oomoo`0COol0045oo`8000Moo`03001;?T/n009;?P03001??Tln
009??P03001??Tln009??P03001??Tln00l0009??P03001?GTmN009?GP03001CGU=N009CGP03001C
GU=N00T0009CGP03001GGUMN009GGP03001GGUMN00D0009KG@03001KOE]m00@000=OO@05001WW000
001WW0020002KkX30002KaL01P00@KE1]@00KP000095e@8000=5mP8000A5m`03001664HH00966080
00966003001:FDYI009:F@8000=6FP04001:NTYjBWX40002BY/00`00BY]:V`02BY/00`00B[a:_005
0002B[`00`00B]a:g003B]`00`00B]e:g@040002B]d00`00B]e:g@02B]d00`00B_e:o@03B_d00`00
B_e:o@03000EOol0045oo`03001oogoo00Iooa80009??P03001??Tln009??P03001??Tln009??P03
001??Tln009??P03001?GTmN00X0009CGP03001CGU=N009CGP03001CGU=N009CGP03001GGUMN00@0
009GGP03001KGE]M00D0009KO@04001OOEmmGgd30003Ii`00`00KkY_^P0200001G^@001_5flG0000
0d6e0P000TGE0P000dGf0P0014Gg0P000dHH00<004Xi00000P0014YI00H004Yj000004IJ0004BWX0
0`00BY]:V`040003BY/00`00B[a:_002B[`00`00B]a:g0050002B]`00`00B]e:g@03B]d00`00B]d0
00090002B_d00`00B_e:o@02B_d00`00Oomoo`0DOol0045oo`03001oogoo00Moo`03001;?T/n009;
?P03001??Tln009??P03001??Tln009??P05001??TlnCch00002Cch?0002Cch00`00DciC?P02Dch0
0`00DeiCGP02Deh00`00DeiCGP0:0002Eeh00`00EeiGGP040002Fed00`00FgeKO@02Fgd01P00Ggd0
0000Gg`0009WW0<00003KkX007>I008000=_5`040011]D6e@KD20002AMD20004AOH00`00AOM5m`02
AOL01P00BSP00000AQP000=:>@03001:FDYI009:F@04001:NTYjBWX30003BWX00`00BY]:V`02BY/0
1P00B[/00000BY/000A:_003001:g4[L009:g003001:g4[L00D0009:g@03001:gD[M009:g@03001:
oD[m009:o@03001:oD[m00P001Ioo`00@Goo00<007ooOol01goo5P000Tln00<004lnCch00dln00D0
04lnCci??P0000A??P03001C?U<n00X0009CGP03001CGU=N009CGP03001GGUMN00D00003Eed005]M
00=KG@03001KOE]m00@000=OO0<0009WN`800004LiT000000003KaL01000@KE1]D6e0P000dGE00<0
04GfAOH00TGf0P000dGg00@004XhBSQ:>08000=:>@<0009:F@03001:NTYj009:NP06001:V`00001:
NP0014ZK00@004ZkB[]:^`@0009:_003001:g4[L009:g003001:g4[L009:g003001:gD[M00D0009:
g@03001:oD[m009:o@03001:oD[m009:o@03001:oD[m009:o@03001oogoo01Aoo`00@Goo00<007oo
Ool01goo00<004/nBch00d/n00D004lnCci??P0000A??P03001??Tln009??P03001??Tln009??P03
001??Tln00h0009C?P03001C?U<n009C?P03001CGU=N009CGP03001CGU=N00D0009GG@03001GGEMM
009GG@03001KGE]M00@0009KG@03001OO5ml00<000AWN`04001cV@00LgP20003KaL00`00@KE1]@02
@KD01@00AME5eDGE000014Gf00<004hg00000TGg00<004XhBSP00TXh00D004XiBSU:>@00009:NP<0
00A:NP04001:VdZKBY/40002BY/00`00B[]:^`02B[/00`00B[a:_0050002B]`00`00B]a:g002B]`0
0`00B]e:g@02B]d00`00B_e:o@0:0002B_d00`00B_e:o@02B_d00`00Oomoo`0DOol0035oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Uoo`03001;?T/n01P0009??P03
001??Tln009??P03001??Tln009??P03001C?U<n009C?P03001C?U<n00T0009C?P03001GGEMM009G
G@03001GGEMM00D00003Fed005]M00=KG@<0009SG003001WNfMk00<00004LiT007=h0004KaL00`00
@KE1]@02@KD01000AME5eDGE0P000dGf00H004hgCSL004Gg0004BSP20002BST00`00BWY:NP02BWX3
0002BWX00`00BY]:V`02BY/00`00C[]>^`050002B[/00`00B[a:_002B[`00`00C]a>g0090002B]d0
0`00B_e:o@02B_d00`00B_e:o@03B_d00`00B_e:o@08000FOol0031oo`03001oo`0000Moo`03001o
o`0000=oo`03001oogoo00Uoo`<0009;?P03001??Tln009??P03001??Tln009??P03001??Tln009?
?P05001??TlnCch00004Cch00`00Cci??P0?00000e<n001C?P03Dch00`00DciC?P02Dch00`00EeeG
G@050002Eed00`00FeeKG@02Fed00`00Fed000020004He`30002Ie/20002LgP00`00KaM_5`02KaL0
0`00@KE1]@02@KD01`00AME5eDGE001>=P000095mP04001>=dhgCSL20004BSP00`00CWT000020004
BWX00`00CYY>VP040003BY/00`00C[]>^`02C[/00`00C[a>_0040002B[`00`00C]a>g003C]`00`00
C]e>g@02C]d00`00B_d000090002B_d00`00B_e:o@02B_d00`00B_e:o@03B_d00`00Oomoo`0DOol0
031oo`03001oo`0000Uoo`04001oogooOol30009Ool00`00Bci;?P02Bch00`00Cci??P0H0002Cch0
0`00Cci??P02Cch00`00DciC?P02Dch00`00DciC?P02Dch00`00DciC?P090002Ecd00`00EeeGG@02
Eed00`00FeeKG@040002Fed00`00HeaSG0030004Ie/00`00LgQcN0020004KaL00`00@KE1]@02@KD2
0002AMD01P00CSI>=P00AOH000A>=`05001:>4XhBSP00004CWT20003BWX00`00CYY>VP02CYX01P00
C[/00000BY/000A>^`03001>_4jl009>_003001>g00000@0009>g003001>gDkM009>g@03001:oD[m
009:o@03001:oD[m009:o@03001:oD[m00X0009:o@03001oogoo01Eoo`00<7oo00<007oo00001goo
0P0017oo00<007ooOol02Goo20000Tln00<004lnCch00Tln00<004lnCch00Tln00<004lnCch00Tln
00<004lnCch00Tln00D004lnCci??P00009??Pl00003Dch005<m00=C?@03001G?ELm00X0009K?@04
001KGE]MFed30002Gc`00`00Ie]WF`030002LgP20003KaL20004@KD20002AMD01P00CSI>=P00AOH0
00A>=`80009:>003001>NDii009>N@06001>VP00001:NP0014jJ00@004jkC[]>^`@0009>^`05001>
_4jlC[`00004C]`00`00C]a>g00:0002B_d00`00B_e:o@02B_d00`00B_e:o@02B_d00`00B_e:o@02
B_d00`00Bae;7@03000GOol0031oo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo00Yoo`03
001;?T/n009;?P03001??Tln009??P03001??Tln01L0009??P03001C?U<n009C?P03001C?U<n009C
?P03001C?U<n009C?P03001C?E<m00@0009G?@03001G?ELm009G?@03001K?E/m009K?@03001KG@00
008000AO?0<0009W>P05001cN000JaP00002KaL01000GU@000000d6e00D005Hf0015e@0000=>=P80
00A>=`03001>F@00008000A>N@04001>VTjJCYX40002CYX00`00C[]>^`02C[/00`00C[a>_0090002
C]`00`00C]a>g002C]`00`00C_e>o@02C_d00`00C_e>o@0>0002B_d00`00Bae;7@02Bad00`00Oomo
o`0FOol0035oo`03001oogoo00Ioo`<000=oo`03001oogoo00Yoo`d00003Cch004ln00A??P05001?
?TlnCch00004Cch00`00Cci??P02Cch00`00Cci??P02Cch00`00DciC?P0>00000e<m001G?@03Ecd0
0`00EceG?@090002Fc`01000GcaO?5ll0P0016Lj0P000V/H00<006lG00000UiD0P000d6e00D005Hf
0015e@0000A>=P03001>=dhg009>=`04001>FDiICUT20003CWT00`00CYY>VP02CYX00`00C[]>^`04
0002C[/00`00C[a>_003C[`01@00C]a>g4kL00000TkL1@000TkL00<004kmC_d00Tkm00D004kmC_e>
o@0000E>o@03001:oD[m009:o@03001;7@0000L001Qoo`00@7oo0P0037oo00D004/nBci;?P0000A?
?P03001??Tln009??P03001??Tln01P00003Dch005<n00=C?P03001C?E<m009C?@03001C?E<m009C
?@03001G?ELm00@0009G?@03001K?E/m009K?@06001K?5/lFc`005ll0P0000=O6`00IcX00fLj0P00
0V/H00<006lG00000UiD00<005iD00000T6e00<005HfESH00P0014hf0`000Thg00H004iICUU>F@00
CYX200000dii001>VP03CYX00`00C[]>^`02C[/00`00C[/000040002C[`00`00C]a>g002C]`00`00
C]a>g002C]`00`00C_e>o@0>0002C_d00`00B_e:o@02B_d00`00Bae;7@02Bad00`00Bai;7P02Bah0
0`00Oomoo`0FOol0041oo`03001oogoo00]ooa40009??P05001??TlnCch00005Cch01@00Cci??Tln
000014ln00<005<nDch00U<n00<005<nDch03P0000=G?@00Ecd00eLm00<005/mFcd00U/m00<005/l
Fc`00`000elK00@006LjIcYW>P8000=[608000=NE003001NE0000091]@03001F=UHf008000A>=P03
001BF59H00<000=>F@04001>VTjJCYX40002CYX01@00C[]>^djk000014jk00<004kLC]`02P000TkL
00D004kmC_e>o@0000E>o@05001>oDkmC_d00002C_d>0002Bah00`00Oomoo`0GOol0041oo`03001o
ogoo00]oo`03001;?T/n009;?P03001??Tln009??P05001??TlnCch00004Cch00`00Cci??P02Cch0
0`00Cci??P0C00000e<n001C?@03Dcd00`00DceC?@02Dcd00`00EceG?@02Ecd00`00EceG?@090000
0e/L001O6`03Ga/01P00IcX00000G_X000=[6003001NE5iD009NE003001NE0000091]@05001F=UHf
ESH00004CSH00`00DUQBF002DUP01@00CUU>FDiI000014jJ00<005:jD[X010000Tjk00<004jkC[/0
0Tjk00<004kLC]`00TkL00<004kLC]`00TkL00<004kmC_d02@000Tkm00<004kmC_d00Tkm00<004km
C_d00Tkm00<004lMCad00TlM00<004/NBah00T/N00<004/N00000P006Goo0010Ool00`00Oomoo`0;
OolK0002Cch00`00Cci??P02Cch01@00Cci??Tln000014ln00<005<nDch00U<n00D005<mDceC?@00
009C?@X00003Ead005LL00=G7003001K75/L009K7003001O6elK00<000=NnP03001[66/H008000AN
E006001NE5iD0011]@000eHf00<004hfCSH00Thf00<0059HDUP00U9H0`0000=>F@00CYX00djJ00<0
05:jD[X00U:j00<005:k00002@000TkL00<004kLC]`00TkL00<004kmC_d00Tkm00D004kmC_e>o@00
009>o@h0009?7@03001;7T/N009;7P03001;7T/N009;7P03001oogoo01Moo`00@7oo0P003Goo00<0
04/nBch00T/n00D004/nBci;?P0000A??P03001??Tln009??P05001??TlnCch00004Cch00`00Cci?
?P0G0002Dad00`00DaeC7@02Dad01@00EaeG7ELM000015LL00<005/LFa`01@0000=Jn`00G_X00ekj
00D006/H000Y=@0000ANE006001NE5iD0011]@000eHf0`000Thf00<0059HDUP00U9H00<005:IDYT0
10000TjJ00<005:jD[X00U:j00D005:kD[]B^`0000A>g003001>g4kL00T0009>o@03001>oDkm009>
o@03001>oDkm009>o@03001>oDkm009>o@03001?7DlM009?7@03001?7P0000`001Uoo`00@7oo00<0
07ooOol037oo7`000Tln00D004lNCai?7P0000A?7P03001C7E<M009C7@03001C7E<M009C7@05001C
7E<MDad00004Dad00`00EaeG7@090002E_/01@00F_]Jne[k000015kj0P000RTe00<005iDGU@00UiD
00H005iDGU@0046e0003ESH00`00EWMFM`030003DUP00`00DYUBV@02DYT00`00D[YB^P050002D[X0
1@00D[]B^e:k000014kL00<004kLC]`00TkL00<004kmC_d00Tkm00<004km00003@000Tkm00<004lM
Cad00TlM00<004lNCah00TlN00D004/NBai;7P0000A;7P03001oogoo01Qoo`00@7oo00<007ooOol0
3Goo00D004/nBci;?P0000A;?P03001??Tln009??P05001??TlnCch00004Cch01@00Cci??Tln0000
14ln00<004lNCah00TlN00D004lNCai?7P00009C7A<00003D_`005Kl00=Fo003001FneKk009Fn`05
001Jne[kF_/00003G_X20003:CD00`00GUANE002GU@01000GUANE5iD0P000eHf00<005IgEWL00UIg
0P000U9H00<005:IDYT00U:I00<005:jD[X00U:j00<005:kD[/02@000TkL00<004kLC]`00TkL00D0
04kmC_e>o@0000A>o@03001>oDkm009>o@03001?7DlM009?7@03001?7@0001D001Yoo`00@7oo00<0
07ooOol03Goo;0000TlM00<005<MDad00U<M00D005<MDaeC7@0000AC7@03001Bo5;l009Bo005001F
o5KlE_`00004E_/01P00F_]Jne[k001NnP800003CUP002Te008Y=@03001NE5iD009NE004001NE5iD
GU@20003ESH00`00EWMFM`02EWL00`00EYT000040002DYT00`00D[YB^P02D[X00`00D[]B^`02D[/0
1@00D]aBg5;L00000U;l3P000Tkm00<004kmC_d00Tkm00D004lMCae?7@0000A?7@03001?7TlN009?
7P05001?7TlNCah00004Cah01@00Bai;7T/N00006goo0010Ool00`00Oomoo`0=Ool00`00Bci;?P02
Bch00`00Bci;?P02Bch01@00Cci??Tln000014ln00D004lNCai?7P0000A?7P05001?7TlNCah00004
Cah00`00Cae?7@02Cad01@00Cae?7DlM000015<M00D005<MDaeC7@0000AC7@03001Bo5;l009Bo003
001Fo5Kl00`000=>F005000Y=BTe:CD00004GU@00`00GUANE002GU@01@00ESIF=UHf000015Ig00D0
05JIEYUFV@00009F^PD0009B^P05001B^e:kD[/00004D]`00`00D_aBo002D_`00`00D_aBo002D_`0
1@00C_e>oDkm00000Tkm8`006goo0010Ool00`00Oomoo`0=Oom400000e;K001B^`03D[/01@00DYYB
VU:J000014iH00D002Te:CDY=@0000ANE003001NE5iD009NE005001F=UHfESH00004EWL01@00EYUF
VEJI000015Jj00<005KKE]/03P000U;l00D005;lD_aBo00000A>o@05001>oDkmC_d00004Cad00`00
Cae?7@02Cad01@00Cae?7DlM000014lN00<004lNCah00TlN00<004lNCah00TlN00D004/NBai;7P00
01]oo`00?goo00<007ooOol03goo00<004/nBch00T/n00D004/nBci;?P0000=;7P03001?7TlN009?
7P05001?7TlNCah00004Cah01@00Cai?7TlN000014lM00<004lMCad00TlM00D004lMCae?7@0000A?
7@05001BoE;mD_d00004D_`00`00D_aBo002D_`01@00D]]Bfe;K000015:k00D005:JDYYBVP0000A>
F005000Y=BTe:CD00004GU@00`00GUANE002GU@300000eHf001FM`03EWL01@00EYUFVEJI000015Jj
00<005KKE]/00UKK00D005;KD]]Bf`0000ABo003001Bo5;l02D0009?7P05001?7TlNCah00004Bah0
0`00Oomoo`0IOol003moo`80011oo`L0009;?P03001;7T/N009;7P05001?7TlNCah00004Cah01@00
Cai?7TlN000014lN00D004lMCae?7@0000A?7@05001?7DlMCad00004Cad00`00D_eBo@02D_d01@00
D_aBo5;l000015;l00D005;KD]]Bf`0000AB^`05001BVU:JDYX00004CUP01@00:CDY=BTe000015iD
00<005iDGU@00UiD00<005jGGYL020000UJI00<005JjE[X00UJj00<005KKE]/00UKK00D005;KD]]B
f`0000ABo005001Bo5;lD_`00004D_d00`00Cae?7@02Cad01@00Cae?7DlM000014lM00<004lMCad0
0TlM00D004lNCai?7P0000A?7P03001?7TlN00`001]oo`00?goo00<007ooOol03goo00<004/NBah0
0T/N00<004/N0000?`000U:k00D005:JDYYBVP0000A>F005000Y=BTe:CD00004GU@00`00GUANE002
GU@01@00GYMNUejG000015Zi00<005[J00006`000U;m00D004lMCae?7@0000A?7@03001?7DlM009?
7@05001?7DlMCad00004Cah01@00Cai?7TlN000014lN00<004lNCah00TlN00D004/NBai;7P0001ao
o`00=goo1@000goo00<007ooOol047oo00D004/NBai;7P0000A;7P05001;7T/NBah00004Cah01@00
Cai?7TlN000014lN00D004lMCae?7@0000A?7@05001?7DlMCad00003C_d00`00C_e>o@02C_d00`00
C_a>o002C_`01@00C]a>g4kL000014kK00D004jkC[]>^`00009>NP@0009BVP03001>F4iH009>F005
000Y=BTe:CD00004GU@00`00GUANE002GU@01@00GYMNUejG000015Zi00D005[JF]YJfP0000AFf`03
001FneKk009Fn`05001Fo5KlE_`00004D_`01@00DaeC7E<M00000U<M;00077oo000iOol00`00Oomo
o`03Ool00`00Oomoo`0@Ool[0002C_d01@00C_e>oDkm000014kl00D004kLC]a>g00000A>f`05001>
^djkC[/00004CWX00`00AST000040002CUP01@00:CDY=BTe000015iD00<005iDGU@00UiD00D005jG
GYMNU`0000AJ^@05001JfU[JF]X00004E]/01@00E_]FneKk000015Kl00D005;lD_aBo00000AC7@03
001C7E<M009C7@05001C7E<MDad00004Cad01@00Cae?7DlM000014lN00D004lNCai?7P0000A?7P05
001??TlnCch00004Cch00`00Bci;?P02Bch00`00Oomoo`0JOol003Qoo`<000Aoo`80015oo`03001;
7T/N009;7P05001;7T/NBah00004Bah01@00Bai;7T/N000014lN00D004lMCae?7@0000=?7@03001>
oDkm009>o@05001>oDkmC_d00002C_dB0002C]/01@00C[]>^djk000014ij00D004HiASU6>@00008e
UP<000<Y=@03001NE5iD009NE003001NE5iD009NE005001NUejGGYL00004F[T01@00F]YJfU[J0000
15KK00<005KkE_/0?P0077oo000hOol20005Ool00`00Oomoo`0@OolN0002Cad01@00C_e>oDkm0000
14km00D004kmC_e>o@0000=>g003001>g4kL009>g005001>_4jlC[`00002CY/40002C[/00`00CWY>
NP02CWX01@00ASU6>DHi000013FF00D002Te:CDY=@0000ANE003001NE5iD009NE005001NUejGGYL0
0002F[T>00000eLL001G7003Ea`01@00DaeC7E<M000015<M00D005<MDaeC7@0000AC7@05001?7DlM
Cad00004Cah01@00Cci??Tln000014ln00D004lnCci??P0000A??P05001??TlnCch00004Bch00`00
Oomoo`0KOol003Uoo`03001oogoo00=oo`80019oo`05001;7T/NBah00004Bah01@00Bai;7T/N0000
14/N00D004/NBai;7P0000=?7@03001>oDkm0180009>g005001>g4kLC]`00003C[`00`00CY]>V`02
CY/00`00BWX000040002CWX01@00ASU6>DHi000013FF0P000RTe00<005iDGU@00UiD00<005iDGU@0
0UiD00<005jGGYL010000Ukj00D005[kF_]Jn`0000AJn`05001G75LLEa`00004Ea`01@00DaeC7E<M
000015<M00<005<MDad0:`007Goo000hOol20006Ool00`00Oomoo`0@OolD0002Bah00`00Cae?7@02
Cad01@00C_e>oDkm00000dkm00<004kmC_d00Tkm00D004kMC]e>g@00009>g0P0009>_003001>VdjK
009>V`05001:NTYjBWX00002AST30003AST00`00=IHeUP02=IH20002:CD00`00GUANE002GU@00`00
GUANE002GU@300000f;I001NnP03G_X01@00F_]Jne[k000015[k00<005LLEa`04P0000=C7@00Dcd0
0e<m00D004lnCci??P0000=??P03001??Tln009??P05001??TlnCch00004Cch01@00Cci??Tln0000
14ln00D004/nBci;?P0001ioo`00>7oo00<007oo00001Goo00<007ooOol047oo00<004/NBah00T/N
00D004/NBai;7P0000A;7P06001;7T/NBah004[m4P000Tkm00D004kMC]e>g@0000A>g006001:_4Zl
B[`004ZK1@000TjK00D004YjBWY:NP0000A6>@800096>@03000eUSFF008eUP80008Y=@03001NE5iD
009NE004001NE5iDGU@20003H]T00`00G_YNnP02G_X00`00F_]Jn`0900000eLL001G7@03Ead01@00
DaeC7E<M00000e<M00<005<MDad00U<M00D005<mDceC?@00009??R8001ioo`00>Goo00<007ooOol0
1Goo0P0047oo40000T/N00<004[mB_d00T[m00D004[mB_e:o@0000=:o@05001:oD[mB_d00002B]d9
0002C]`01@00B[a:_4Zl00000dZK00<004YjBWX00`000dYj00<004HiAST00THi00<003WG00000P00
13FF00D003ED000Y=@0000ANE006001NE000001[5`000f;I00<005kjG_X01@0000=K6`00Fa`00e/L
00D005LLEaaG700000=G7@03001C7E<M0180009??P05001??TlnCch00003Cch00`00Cci??P02Cch0
1@00Cci??Tln000014ln00D004lnCci??P0000A;?P03001oogoo01aoo`00@Goo00<007ooOol047oo
00D004/NBai;7P0000A;7P06001;7T/NBah004[m3@000T[m00<004[mB_d00T[m00D004[MB]e:g@00
00=:g003001:_4Zl00@0009:_003001:VdZK009:V`04001:NTYjBWX300000dYj0016>@03AST01@00
>MLiecWG000013FF00D003ED000Y=@0000ANE08000=[5`04001RfF;IH]T30002Ga/01@00Fa]K6e/K
00000e/L00<005LLEa`02@000U<m00D005<mDceC?@0000AC?@05001C?U<nDch00004Cch00`00Cci?
?P0M000NOol0049oo`03001oogoo00moo`/0009;7P03001:oD[m009:o@05001:oD[mB_d00003B_d0
0`00B_d000080002B]d00`00B]a:g002B]`01P00B[a:_4Zl001:V`D0009:V`05001:NTYjBWX00002
@ST20004AST01000>MLiecWG0P000cFF00D003ED000Y=@0000ANE003001[5f/G009[5`03001Rf@00
008000=O6`03001K6e/K00T0009G?@05001G?ELmEcd00004Dcd00`00DceC?@0B00000dln001??P02
Cch01@00Cci??Tln000014ln00D004lnCci??P0000A;?P05001;?T/nBch0000OOol0049oo`03001o
ogoo011oo`05001;7T/NBah00003Bah00`00B_h0000<0002B_d00`00B_e:o@02B_d01P00B]e:gD[M
001:g0T0009:_005001:VdZKBY/00002AW/30003BWX01000@SU2>D8i0`000THi00@003WG>MLie`80
00<eUP05000eE000:CD00003GU@20004JaL20002IcX01000Ga]O6elK0`000Ull00D005/lFcaK?000
00AG?@03001G?ELm00T00003Dch005<n009C?P03001C?U<n009C?P05001??TlnCch00002CchM000O
Ool004=oo`03001oogoo00moo`H0009;7P03001:oT[n009:oP05001:oD[mB_d00003B_d00`00B_d0
00080002B]d01@00B]a:g4[L000014Zl00<004ZL00000P000dZK00<004IkAW/00TIk0`0000=:NP00
@ST00T8i00<003gh?OP00`000cWG00<002de00000SFF00<003ED=E@00P000UiD00<006kD00000f/G
0P000fLj00<005lK00000P0015ll00<005/lFc`02@0000=G?@00Dcd00U<m00<005<nDch00U<n00<0
05<nDch03@0000=??P00Cch00dln00D004lnCci??P0000=??P03001??Tln009??P05001;?T/nBch0
0002Bch3000OOol004=oo`03001oogoo00moo`06001;7T/NBah004[n3@000T[m00<004[mB_d00T[m
00H004[MB]e:g@00B]d40002B]`00`00B[a:_002B[`01000BYa:W4ZL0`0000=:V`00AW/00dIk00<0
049J@UX00P00148i00D003gh?OPmn00000<ie`03000]=@00008eUP03000eE3ED00800005GU@006kD
K]@00002JaL20003IcX30002He`00`00GcaO?00500000e]M001G?@03Ecd00`00EceG?@0=00000e<n
001C?P02Dch00`00Cci??P02Cch00`00Cci??P0J00000d/n001oo`0OOol004Aoo`03001oogoo00io
o`L0009:oP05001:oD[mB_d00003B_d00`00B_d000080002B]d01P00B]e:gD[M001:_0D0009:_005
001:W4ZLBY`00002AW/40002AW/01000@UY2FT9J0`000T8i00@003gh?OPmn080008ie`06000]=Bde
000eUP000SED0P0000YNE000K]A^e000JaL007>I001W>P800003Ig/006=L009SG0<0009OG@05001K
GE]MFed00002Ecd500000eMM001C?P02Dch00`00DciC?P02Dch00`00DciC?P0=00000dln001??P02
Cch01@00Cci??Tln000014ln00<004lnCch02`0087oo0014Ool2000@Ool01000B_i:oP000T[m2000
0T[m00<004[mB_d00T[m00H004[MB]e:g@00B]d40002B]d01@00B[a:_4Zl00000TJL10000TZL00D0
04IkAW]6N`000092FP<000=2FP03000n6ChI00<000<mn080008ie`06000]=Bde000eUP000cED0P00
0fkD00@006/G001cV@8000=WN`03001SG000008000AOG@03001KGE]M00@00003Eed005MM00=GG@03
001C?U<n00T00003Dch004ln009??P05001??TlnCch00002CchB00000d/n001;?P02Bch01@00Bci;
?T/n00008Goo0015Ool00`00Oomoo`0>Ool20002B_h01@00B_e:oD[m000014[m2P000T[M00H004[M
B]e:g@00B[`50002B[`01P00AYa6W4JL0016V`D00096N`040012FT9J@UX20002@UX00`00?QTn6@02
?QT02@00?OPmn3gh000aUP00>ML00003;CD20003=E@00`00K]A^e002K]@200000g>I00000003Ig/3
0002Hg`00`00GeeOG@05000015]M001GGEMM2@0000=CGP00Deh00U=N00<005<nDch03@0000=??P00
Cch00dln00D004lnCci??P00009??Pl0025oo`00AGoo00<007ooOol03Woo00<004[n000030000T[m
00H004[MB]e:g@00B]d40002B]d01@00B[a:_4Zl00000TJl10000TJL00D004JKAY]6V`000092F`<0
00=2FP03000n6@00008000@n6@80008mn003000aUS6F008000<]=@8000<eE003001^e6kD009^e006
001cV@00KmX006Mk0P0000=WW000Hg`00V=l0`000U]M00<005]MFed0100000=GGP00Eeh00eMN00<0
05=NDeh0200000=CGP00Ceh00dmN00<004mNCeh04@0000=??P00Bch00T/n00D004/nBci;?P0000A;
?P03001oogoo01moo`00AWoo0P003Woo0P000T[n00<004[mB_d00T[m00H004[mB_e:o@00B]d40002
B]d01P00B]e:gD[M0016_0D0009:_0060016_4JlA[`004JK10000TJK00<0049K@U/00T9K0P000T9J
00D003hI?QTn6@0000@n6@05000e]`00?OP00002<IH20004;CD01@00=E@eE3ED000016kD00@007>I
001_fP8000=WW003001SO0000080009KG@D00004Fed005MNEeh900000e=N001CGP02Deh00`00DeiC
GP0900000dmN001?GP02Ceh01@00Cei?GTmN00000Tln50008Goo0010Ool500000goo001oo`0?Ool:
0002B_d01P00B]e:gD[M0016g@T00096_0030016_00000<00096_0060016VdJKAY/0049k10000d9K
00<0048j00000P000chI0P000chI00<003Fg=KL00P000c6F00<002de;CD00Rde00D003ED=E@eE000
00=^e0<00003KmX0000000=WW0<0009OO@<00004Fgd005]MFed500000eMN001GGP02Eeh00`00DeiC
GP0900000e=N001?GP02Ceh00`00Cei?GP0=00000dmN001?GP02Ceh00`00Bci;?P02Bch00`00Bci;
?P06000ROol0049oo`03001oogoo009oo`03001oogoo00eoo`80009:o@06001:oD[mB_d004KM2@00
0TKM00@004KMA]d00096_0@00096_0030016W00000<00096V`060012Nd9k@W/0049J0P0000=2F`00
@SX00T8j00H003hI?QTn6@00>MP200000chI000e]`02=KL01@00<IHaUS6F000012de0P000SED00@0
06kDK]A^e0800005KmX006oK001WW00200000fNL001OO@030002Fgd40002Egh00`00EeiGGP080000
15=N001CGU=N3@0000=?GP00Ceh00dmN00<004mNCeh04P0014/n00<007ooOol087oo0012Ool00`00
Oomoo`02Ool3000=Ool00`00A_d000070002A]d01@00A]e6gDKM00000TKM10000TKM00H004JlA[a6
_000AY`30003AY`00`00@W/000030003@W/00`00@UY2FP020003@SX20002?QT01000>MPif3WH0P00
0cFg00@0036F<IHaUP8000<]=@80008eE004001^e6kDK]@200000foJ001_f`020002Ii`30002Gid3
000015]m001GOUMn1@0000AGOP00DeiCGPP00003Deh005=N00=CGP03001?GTmN00h000A?GP05001;
GT]NBeh00002Beh;000ROol0049oo`03001oogoo00=oo`03001oogoo00aoo`050016oDKmA_d00003
A]d00`00A]d000040002A]d01P00A]e6gDKM0016_0@00096_0040016W4JLAY`300000dJL0012N`02
@W/01P00@U/00000@W/000=2FP800092>P03000in@00008000@if004000e]cFg=KL20002<IH20003
;CD20002=E@01000K]A^e6kD0`0000A_f`00001WW0800003Hkd005nM00<0009KO@@00004Egh005Mn
Egh500000e=N001CGP02Deh00`00DeiCGP0900000dmN001?GP02Ceh00`00Cei?GP0A00000d]N001;
G`02Bel00`00Bem;G`02000SOol0049oo`03001oogoo00Aoo`03001oogoo00]oo`L00096g@060016
gDKMA]d004KM10000TKM00H004JlA[a6_000A[`40002AY`00`00@Y]2V`030003@W/00`00@U]2F`02
0003@UX00`00?QT000020003>OT00`00>MPif002>MP20002=KL20002<IH00`00?KH00002;CD20002
=E@00`00K]A^e00300000foK001[n`020002Hkd30002Gid3000015]n001GOUMn10000UMn00<005=N
Deh0200000ACGP00Cei?GPd00003Ceh004mN009?GP03001?GTmN01400003Bel007oo029oo`00@Goo
0P001Woo0P003Goo00H004KmA_e6o@00A]d80002A]d00`00A[d000030002A[`01P00A[a6_4Jl0012
W0@00092V`060012N`000012N`000d9K0P000T9J00D003hI?QTn6@0000<in@8000<if080008e]`07
000eUP00<IH003ff00000Rde00D005YE000eE000009^e0@00004Jo/00000Hkd200000f>m001OW@03
0002Fgh4000015Mn001GOUMn1@0000ACOP00DeiCGPP00003Ceh004mN009?GP03001?GTmN00d00003
Ceh004]O009;G`03001;Gd]O00/002=oo`00BWoo00<007ooOol02goo1P000TKM00H004KMA]e6g@00
A[d40002A[d00`00A[`000030002A[`01P00@Ya2W4:L0012N`800004@Y/0049k@W/20003@U/00`00
?SX000020003?QT20002>OT00`00=MP00002>MP02`00=KL003Fg000eUP00<IH003ff00000Rde00D0
05YE000eE000009^e0<00003Jo/006Ol0080009S_@<0009KWP<00004Fih005MnEgh4000015Mn001C
OU=n1@0000=CGP00Deh00U=N00<004mNCeh0200000=?GP00Ceh00TmN00<004mNCeh03@0000=;G`00
Bel00T]O00D004]OBem;G`0002Aoo`00BWoo00<007ooOol02goo00H004KMA]e6g@00A]d40002A]d0
1P00A[e6_DJm0016_@@00096_0030012W00000<000=2W0030012Nd9k008000=2N`<00003@U/003hj
008n>P09000n6ChI?QT003Wi000in@00008ef003000if000008e]`80008eUP80008m]P08000]=@00
FUD003ED001^e0D00004Io`00000Hkd200000enm001KWP030002Fih4000015Mn001GOUMn100000AC
OP00DeiCGPT00004Ceh004mNCeh<000014mO001;Gd]O4`0097oo001;Ool00`00Oomoo`0:Ool20002
A]d00`00A]e6g@02A]d50002A[d01P00A[e6_DJm0012W0@00092W0060012O0000012W0000d9k0`00
00A2N`00?UXnFP8000<n>P80008n6@03000inCWi008000<ef080008e]`80008eUP80008m]P08000]
=@00FUD003ED001^e0800005Fm@00000001Sg0020002Gkd800000eNN0000000=000015=n001?GTmN
2@0000A?GP00Cei?GP`00003Bel004]O009;G`03001;Gd]O00X002Eoo`00Bgoo00<007ooOol02goo
2P000TKM1P000TJm00D004:L@Y`004:L00800004@Y`0049l@W`30002@W/00`00?U/nF`020003?UX2
0002?SX00`00>QT000020003>OT00`00=MPef002=MP01@00=KLe]cFg00000cFF00H003ff?KH002de
0002FUD200000fkD001Ke0020002Hm`200000enm000000030002Fih00`00Eih000020002Egh40000
15=n001COU=n200000A?GP00Cei?GPT00003Cel004mO009?G`03001?GdmO00`00003Bel004]O009;
G`03001;Gd]O008002Eoo`00C7oo0P002goo0P000TKM00H004KMA]e6g@00A[d40002A[d00`00@[`0
00030002@Y`00`00@Ya2W0020003@W`00`00@W/000020003?U/20002?UX00`00?QX000020003>QT0
1000>OTinCWi0P000cGH0P000SFg0P000SFF00@003ff?KHm]P80009JE@T00003Gmd0000000<0009K
WP@00003Eih0000000800004Dgh005=nDgh4000015=n001COU=n200000A?GP00Cei?GPh0009;Ga80
02Ioo`00C7oo00<007ooOol02Woo00<004KM00000`000TKM00H004JmA[e6_@00@[d40002@[`00`00
@Y`000020003@Y`300000d9l0012N`02@W/20002?U/00`00?SX000020003?QX01000>QTj6CXI0P00
0SWi00<003WH00000SGH0P000SFg0P000SFF0P000Sff0P000UYE1@0000=On@00Gmd010000U^n0`00
00=GWP0000000P0000AGWP00DgiCOP@00004Dgh005=nDgh4000014mn001?OTmn200000A?G`00Cem?
G``00003Bel004]O009;G`03001;Gd]O00X002Ioo`00CGoo00<007ooOol02Goo0P000TKM00<004Jm
00000`000TJm00H004:m@[e2_@00@Y`30003@Y`3000014:L0012Nd9k0P000d9k00<003iK00000P00
0chj00@003hJ?QXn6P80008j6@0A000in@00000in@00>MP003GH000if000=KL0047g000eUP020003
?KH00`00FUEJE@030002GoT600001E^n00000000Eih00`000UNN5@0000A?O`00Cem?G`P00003Cel0
04]O009;G`03001;Gd]O00`00003Bel004]O009;G`03001;Gd]O008002Ioo`00BGoo00@007ooOomo
o`8000]oo`D00096_@030012_@0000<00092_@040012W4:L@Y`3000014:L0012O49l0P000d9k0`00
00=2N`00?U/00SiK00@003hj?SXn>P80008n6P03000j6@00008000<in@80000>>MP003GH000if000
=KL0047g000eUP00DUP0008m]P/0009Kg@800005Fkh00000001GWP09000015=n001COU=n100000A?
OP00Cgi?OPP00004Cel004mOCel<000014]O001;Gd]O4@009goo000bOol00`00Oomoo`06000=Ool0
0`00Ool00003Ool00`00Oomoo`09Ool20002A]d60002@[d50002@Y`00`00@Ya2W0020003@W`30000
149k000nFciK0P000ciK0`0000<n>P00>QX00`000cXI00<003Wi>OT00SWi00<003WH>MP00P000SWH
0P000T7g0P000U9H00@003ff001cE`P00003Fmd0000000/00004Dih005=nDgh=000014mo001?Odmo
2@000TmO3P000T]O3P009goo000cOol20003Ool00`00Oomoo`0=Ool00`00Ool00003Ool30009Ool0
0`00@[d000030002@[d00`00@[d000030002@[`40003@Y`30000149l000nNcik0P000ciK0`0000@n
F`00>SXj>P8000<j6P04000j6CXI>QT20003>OT20002>MP00`00>MPif0020002@OL20002DUP01P00
?KH007=G001;TP@00003Fo`0000000D00006Ekh00000001GWP000U>N200000ACOP00Cgm?O`X0009?
G`P00004Bel004]OBel<000014]O001;Gd]O2P009goo000cOol20003Ool00`00Oomoo`0=Ool00`00
Ool00004Ool00`00Oomoo`08Ool20002@[d00`00@[d000030002@[d00`00@Y`000020002@Y`30000
14:L000nO3il0P000cik0`0000@nF`00?S/n>`8000<j>P80008j6P80008j6@03000in@00008in@04
000in@00>MP20002>MP01@00@OM1md7g00000e9H1`0000=Ko00000001@0000AG_P000000009GWPP0
0004Dgh005=nDgh4000014mo001?Odmo500000A;G`00Bem;G``0035oo`00<Woo00@007ooOol0009o
o`03001oogoo00eoo`03001oo`0000Aoo`03001oogoo00Uoo`D00092_@030012_@00008000=2W0<0
0003@Y`004:L00@0008nO0800004?W/003iK?U/20003?S/20002>SX01P00>QX003XJ000j6@80000=
>QT003Wi000in@00>OT003WH00126@00>MP00P000T7g0`0000=BF00000002P0000EG_P00000005Nn
02000004Cgl004mOCel<000mOol003Qoo`03001oogoo00ioo`03001oogoo00Aoo`8000Uoo`050012
_D:m0012_@030003@[d3000014:L0012W4:L0`000T:L00<003il00000P0000@nF`000000008nF`<0
0003?S/003Xj00<0008j6P8000<j6@80008in@80008in@800005@QT003WH001>NP030002Ie/>0000
0eNn00000009000015>N001COe=o100000A?O`00Cgm?O`@00004Cgl004moCgl80019Ool003Moo`80
01Moo`03001oogoo00Qoo`<00004@[d004:m@[d3000014:m0012W4:L0`000T:L00<003il00000P00
0cil0`0000LnF`00000003iK000j>`020003>SX01@00>QXj6SXJ000013XI00D003Wi>OTin@0000<i
n@0300126D8I008000=>NP800003Ie/0000000X00003Ekh0000000<00006Dkh00000001CWP000U>N
5000DGoo001AOol20008Ool00`00@[e2_@030002@[d00`00@Yd000020002@Y`00`00?Y`000020003
?W`3000013il000nFciK0P000SiK0P000SXk0`0000Dj>P00000003XJ00<0008j6@80008in@80008i
n@8000926@8000=>NP/00003Emd0000000@00004Dkh000000002Dih8000014mo001?Odmo1000FGoo
001BOol00`00Oomoo`06Ool20002@[d00`00@[d000030002@Yd40003?Y`3000013il000nO3il0P00
0ciK0P000SiK0`0000<j>`00>S/00`0000Dj>P00000003Xj00<0000=?SX000000012FP00>OT004ZK
00126@00Ec`00P0000=>NP0000003@0000EC_P00000005>N010005eoo`00DWoo00<007ooOol027oo
10000T:m00<004:M00000`000T:L0P0000@nW000?W`nO08000<nO0<00003?U/003YK00<0008jF`80
00<j>`05000j>SXj>SX00003>SX01@00?SXn>Shj00000T9J0P000TZK0P000ULl7P00IGoo001COol0
0`00Oomoo`0;Ool40002@Yd00`00?Y`00002000013jL000000000Sil0`0000@nO000?U/nF`8000<j
F`04000jFcYK>U/20002>S/20002>SX20002>SX20002?SX20002@UX20002BY/=00000e?M0000000=
001YOol005=oo`03001oogoo00moo`<000<nW0<00003?Y`000000080008nO08000<nF`80008jF`<0
0003>U/003YK00<00005>U/00000000nF`0300001Cik00000000AY`00`0000=?7@0000002`0000=C
g@0000002`00KGoo001=Ool50002Ool2000BOol2000013jL000nO3il0P000Sil0`0000LnO0000000
03iK000jF`030002>U/20003>U/01@00>U/jFcYK00000ciK00@003ik?W/nN`800096W1T0075oo`00
Cgoo00<007ooOol00Woo00<007ooOol04goo0`000Sil0`0000<nO000?W`00`0000<nO00000000cYK
00@003YK>U/jF`80008jF`80008jF`<00007?U/00000000nN`00Bah05`00MGoo0019Ool30003Ool0
0`00Oomoo`03Ool2000FOol30002?W`20002?W`01@00>W`00000?W`00P0000LjF`00000003YK000n
O003000013il000000000SjL0P000T:m5`00N7oo001?Ool00`00Oomoo`03Ool00`00Oomoo`0HOol2
00001Sil00000000?W`0008jO0800003>W`00000008jO08000<nO004000nO3il?W`20002?Y`30000
14:m001;Gd]O4@00NWoo001?Ool00`00Oomoo`04Ool2000JOol20002?W`20003>W`3000013Yl0000
03Yl0`0000LnO000000003il0012_@0400000dKn0000000<000014nm00000000OGoo001>Ool20006
Ool00`00Oomoo`0KOol200001Sil00000000>W`0008nO0800005?W`00000000nW003000013jM0000
00000T:m00<004Lo0000300000=?_@000000P7oo001GOol2000MOol20002?W`30002?W`300001Cil
00000000?Y`02P0000=;O`0000002P00PWoo001GOol00`00Oomoo`0NOol200000cil000nW@030002
?Yd3000013jm000000000T;N00<004Lo00003000QWoo001HOol2000POol30002?Yd300000cjM000n
gP0B0029Ool005Qoo`03001oogoo029oo`@00004?[d000000002?]h00`00@cl0000;002;Ool005Ao
o`<0009oo`8002Iooa4008ioo`00E7oo00<007ooOol00Woo00<007ooOol0:Goo2@00TWoo001?Ool3
0003Ool00`00Oomoo`02Ool30033Ool005Eoo`03001oogoo0<Qoo`00E7oo00<007oo0000bGoo001E
Ool00`00Oomoo`38Ool00?moob5oo`00ogoo8Goo002`Ool3001]Ool00;5oo`03001oogoo06aoo`00
Dgoo0P0000Aoo`00001oo`<00003Ool00000009oo`03001oo`0000800006Ool007oo001oo`000Woo
100000Aoo`00Ool000moo`80009oo`<00006Ool007oo001oo`000Woo0P0037oo0`000goo0P000Woo
0P000goo0`000goo0P0000=oo`0000000Woo00@007oo000000Aoo`80011oo`<000=oo`800003Ool0
0000009oo`03001oogoo0080009oo`<000=oo`80009oo`<002Moo`00Dgoo00D007ooOomoo`00009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00L007oo001oo`00Ool00002Ool2000017oo001o
o`003Woo00@007ooOol0009oo`0:001oogoo001oo`00Ool007oo000?Ool01@00Oomoogoo00001Woo
00@007ooOol0009oo`03001oo`00009oo`03001oo`00009oo`05001oogooOol00002Ool00`00Oomo
o`0@Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`04001oogoo0003Ool0
1000Oomoo`000Woo00<007ooOol09Woo001COol01@00Ool007oo00000Woo00D007ooOomoo`00009o
o`04001oogoo0002Ool01`00Ool007oo001oo`00009oo`800004Ool007oo000>Ool00`00Oomoo`03
Ool02@00Oomoo`00Ool007oo001oo`03000=Ool01000Oomoogoo0`000goo00D007ooOomoo`00009o
o`03001oo`00009oo`03001oo`00009oo`04001oogoo0003Ool3000@Ool00`00Oomoo`02Ool01P00
Oomoo`00Ool0009oo`03001oo`0000Eoo`05001oogooOol00002Ool01000Oomoo`00:7oo001COol2
000017oo000007oo0P000Woo10000Woo0P000Woo0P0000=oo`00Ool00P0000=oo`0000000P0000=o
o`00Ool03Goo10000Woo0P000Woo0P0000Aoo`00Oomoo`<000aoo`@00004Ool000000003Ool20000
0goo000000020003Ool200000goo000000020003Ool20002Ool3000@Ool30003Ool200000goo0000
000200000goo000000020002Ool40002Ool20003Ool00`00Oomoo`0VOol005=oo`800003Ool00000
02aoo`03001oogoo061oo`03001oogoo00eoo`03001oogoo02Ioo`00Dgoo0P0000=oo`0000000Woo
00<007ooOol01goo00<007ooOol08goo00<007ooOol0JGoo0P00:7oo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {172.062, 0}} -> {-0.297533, 0.0282327, 
  0.00468592, 0.00468592}},
  CellTags->"12.2"]
}, Open  ]],

Cell["This is the second component of the control signal. ", "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[u[[2]], {x1, -2, 2}, {x2, -2, 2},
 PlotPoints -> 40,
 Boxed -> False,
 AxesLabel -> {\"x1\", \"x2\", \"u[[2]]\"},
 ViewPoint->{2.141, 2.209, 1.080},
 PlotLabel -> \"Minimum time response control\"
];\
\>", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"12.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6066 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00326485 1.00326 -0.142438 1.00326 [
[.5 .6191 -89 0 ]
[.5 .6191 89 12.5625 ]
[.979 .21566 -6.45843 -9 ]
[.979 .21566 5.54157 0 ]
[.87564 .16752 -6.36262 -9 ]
[.87564 .16752 5.63738 0 ]
[.76091 .11409 -3.12726 -9 ]
[.76091 .11409 2.87274 0 ]
[.63286 .05445 -3.06583 -9 ]
[.63286 .05445 2.93417 0 ]
[.489 -0.01254 -2.99536 -9 ]
[.489 -0.01254 3.00464 0 ]
[.75826 .05144 -8.33937 -12.5625 ]
[.75826 .05144 7.66063 0 ]
[.02074 .22143 -5.54485 -9 ]
[.02074 .22143 6.45515 0 ]
[.11903 .17232 -5.63567 -9 ]
[.11903 .17232 6.36433 0 ]
[.22842 .11766 -2.86923 -9 ]
[.22842 .11766 3.13077 0 ]
[.35091 .05645 -2.92785 -9 ]
[.35091 .05645 3.07215 0 ]
[.489 -0.01254 -2.99536 -9 ]
[.489 -0.01254 3.00464 0 ]
[.23115 .05501 -7.65127 -12.5625 ]
[.23115 .05501 8.34873 0 ]
[.99233 .23026 0 -5.97419 ]
[.99233 .23026 12 3.02581 ]
[.99704 .29115 0 -5.87452 ]
[.99704 .29115 24 3.12548 ]
[1.00184 .35324 0 -5.77325 ]
[1.00184 .35324 6 3.22675 ]
[1.00673 .41654 0 -5.67035 ]
[1.00673 .41654 18 3.32965 ]
[1.01171 .4811 0 -5.56577 ]
[1.01171 .4811 6 3.43423 ]
[1.06218 .33616 0 -8.0585 ]
[1.06218 .33616 40 4.504 ]
[ 0 0 0 0 ]
[ 1 .6066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .6191 -150 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Minimum) show
111.000000 12.812500 moveto
(time) show
141.000000 12.812500 moveto
(response) show
195.000000 12.812500 moveto
(control) show
237.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.25 Mabswid
.97996 .22816 m
.48898 0 L
s
.97996 .22816 m
.98043 .23441 L
s
[(-2)] .979 .21566 .07641 1 Mshowa
.87639 .18003 m
.87677 .18629 L
s
[(-1)] .87564 .16752 .06044 1 Mshowa
.76145 .12662 m
.76171 .13288 L
s
[(0)] .76091 .11409 .04242 1 Mshowa
.63313 .06699 m
.63327 .07326 L
s
[(1)] .63286 .05445 .02194 1 Mshowa
.48898 0 m
.48897 .00627 L
s
[(2)] .489 -0.01254 -0.00155 1 Mshowa
.125 Mabswid
.96007 .21892 m
.96035 .22267 L
s
.93979 .20949 m
.94005 .21325 L
s
.91909 .19987 m
.91934 .20363 L
s
.89796 .19006 m
.8982 .19381 L
s
.85437 .1698 m
.85458 .17356 L
s
.83188 .15935 m
.83208 .16311 L
s
.80891 .14867 m
.80909 .15243 L
s
.78543 .13777 m
.78561 .14152 L
s
.73692 .11522 m
.73707 .11898 L
s
.71185 .10357 m
.71198 .10733 L
s
.68621 .09165 m
.68632 .09541 L
s
.65998 .07946 m
.66007 .08322 L
s
.60566 .05422 m
.60573 .05798 L
s
.57753 .04115 m
.57758 .04491 L
s
.54873 .02776 m
.54876 .03153 L
s
.51922 .01405 m
.51923 .01781 L
s
gsave
.75826 .05144 -69.3394 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x1) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.25 Mabswid
.01979 .23394 m
.48898 0 L
s
.01979 .23394 m
.01931 .24019 L
s
[(-2)] .02074 .22143 -0.07586 1 Mshowa
.11827 .18483 m
.11789 .19109 L
s
[(-1)] .11903 .17232 -0.06072 1 Mshowa
.22788 .13018 m
.2276 .13645 L
s
[(0)] .22842 .11766 -0.04359 1 Mshowa
.35061 .06899 m
.35046 .07526 L
s
[(1)] .35091 .05645 -0.02405 1 Mshowa
.48898 0 m
.48897 .00627 L
s
[(2)] .489 -0.01254 -0.00155 1 Mshowa
.125 Mabswid
.03868 .22452 m
.0384 .22827 L
s
.05796 .21491 m
.05769 .21866 L
s
.07764 .20509 m
.07739 .20885 L
s
.09774 .19507 m
.0975 .19883 L
s
.13924 .17438 m
.13903 .17813 L
s
.16068 .16369 m
.16047 .16745 L
s
.18258 .15277 m
.18239 .15653 L
s
.20498 .1416 m
.2048 .14536 L
s
.2513 .1185 m
.25115 .12226 L
s
.27527 .10656 m
.27513 .11032 L
s
.2998 .09433 m
.29968 .09809 L
s
.3249 .08181 m
.3248 .08557 L
s
.37694 .05586 m
.37687 .05962 L
s
.40392 .04241 m
.40386 .04617 L
s
.43157 .02862 m
.43153 .03239 L
s
.45991 .01449 m
.45989 .01825 L
s
gsave
.23115 .05501 -68.6513 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x2) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.25 Mabswid
.97996 .22816 m
1 .49049 L
s
.98042 .23416 m
.97446 .23612 L
s
[(-1)] .99233 .23026 -1 .3276 Mshowa
.98505 .29482 m
.97905 .29665 L
s
[(-0.5)] .99704 .29115 -1 .30545 Mshowa
.98977 .35665 m
.98374 .35836 L
s
[(0)] 1.00184 .35324 -1 .28295 Mshowa
.99459 .41969 m
.98852 .42127 L
s
[(0.5)] 1.00673 .41654 -1 .26008 Mshowa
.9995 .48399 m
.9934 .48543 L
s
[(1)] 1.01171 .4811 -1 .23684 Mshowa
.125 Mabswid
.98134 .2462 m
.97776 .24736 L
s
.98226 .25829 m
.97867 .25943 L
s
.98319 .27042 m
.9796 .27155 L
s
.98412 .28259 m
.98052 .28371 L
s
.98599 .30709 m
.98238 .30817 L
s
.98693 .31941 m
.98332 .32048 L
s
.98787 .33177 m
.98426 .33283 L
s
.98882 .34419 m
.98521 .34523 L
s
.99073 .36916 m
.98711 .37017 L
s
.99169 .38172 m
.98806 .38271 L
s
.99265 .39433 m
.98902 .39531 L
s
.99362 .40699 m
.98998 .40795 L
s
.99557 .43245 m
.99192 .43338 L
s
.99654 .44526 m
.9929 .44618 L
s
.99753 .45812 m
.99387 .45902 L
s
.99851 .47103 m
.99486 .47191 L
s
gsave
1.06218 .33616 -61 -12.0585 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
69.000000 12.812500 moveto
(@) show
75.000000 12.812500 moveto
(@) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 12.812500 moveto
(D) show
93.000000 12.812500 moveto
(D) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 .6066 L
0 .6066 L
closepath
clip
newpath
.5 Mabswid
.615 .895 .988 r
.50482 .58786 .5153 .58295 .50454 .58283 .49405 .58742 Metetra
.597 .887 .991 r
.49405 .58742 .50454 .58283 .49368 .58246 .48319 .58675 Metetra
.58 .879 .993 r
.48319 .58675 .49368 .58246 .48272 .58185 .47223 .58588 Metetra
.564 .871 .995 r
.47223 .58588 .48272 .58185 .47165 .581 .46117 .58479 Metetra
.549 .864 .996 r
.46117 .58479 .47165 .581 .46049 .57993 .45 .58352 Metetra
.537 .857 .997 r
.45 .58352 .46049 .57993 .44922 .57864 .43873 .58206 Metetra
.525 .85 .998 r
.43873 .58206 .44922 .57864 .43784 .57715 .42736 .58043 Metetra
.516 .844 .998 r
.42736 .58043 .43784 .57715 .42636 .57548 .41588 .57864 Metetra
.508 .839 .998 r
.41588 .57864 .42636 .57548 .41477 .57363 .4043 .5767 Metetra
.502 .834 .999 r
.4043 .5767 .41477 .57363 .40308 .57163 .39262 .57462 Metetra
.497 .83 .999 r
.39262 .57462 .40308 .57163 .39128 .56948 .38082 .57242 Metetra
.493 .827 .999 r
.38082 .57242 .39128 .56948 .37937 .5672 .36892 .5701 Metetra
.49 .824 .999 r
.36892 .5701 .37937 .5672 .36735 .56479 .35691 .56768 Metetra
.488 .821 .999 r
.35691 .56768 .36735 .56479 .35521 .56228 .34479 .56515 Metetra
.486 .819 .999 r
.34479 .56515 .35521 .56228 .34297 .55966 .33256 .56254 Metetra
.486 .818 .999 r
.33256 .56254 .34297 .55966 .33061 .55695 .32021 .55984 Metetra
.485 .817 1 r
.32021 .55984 .33061 .55695 .31814 .55416 .30775 .55706 Metetra
.486 .815 1 r
.30775 .55706 .31814 .55416 .30555 .55128 .29517 .55421 Metetra
.486 .815 1 r
.29517 .55421 .30555 .55128 .29284 .54834 .28247 .55129 Metetra
.487 .814 1 r
.28247 .55129 .29284 .54834 .28001 .54532 .26966 .54832 Metetra
.488 .814 1 r
.26966 .54832 .28001 .54532 .26706 .54225 .25672 .54528 Metetra
.489 .813 1 r
.25672 .54528 .26706 .54225 .25398 .53912 .24366 .54219 Metetra
.49 .813 1 r
.24366 .54219 .25398 .53912 .24078 .53593 .23047 .53904 Metetra
.491 .813 1 r
.23047 .53904 .24078 .53593 .22745 .53269 .21716 .53585 Metetra
.493 .813 1 r
.21716 .53585 .22745 .53269 .21399 .5294 .20372 .53261 Metetra
.494 .813 1 r
.20372 .53261 .21399 .5294 .2004 .52607 .19015 .52933 Metetra
.496 .813 1 r
.19015 .52933 .2004 .52607 .18668 .52269 .17644 .526 Metetra
.497 .813 1 r
.17644 .526 .18668 .52269 .17282 .51927 .1626 .52263 Metetra
.498 .814 1 r
.1626 .52263 .17282 .51927 .15883 .5158 .14863 .51922 Metetra
.499 .814 1 r
.14863 .51922 .15883 .5158 .14469 .5123 .13452 .51577 Metetra
.501 .814 1 r
.13452 .51577 .14469 .5123 .13041 .50876 .12026 .51228 Metetra
.502 .814 1 r
.12026 .51228 .13041 .50876 .11599 .50518 .10586 .50875 Metetra
.503 .815 1 r
.10586 .50875 .11599 .50518 .10143 .50156 .09132 .50519 Metetra
.504 .815 1 r
.09132 .50519 .10143 .50156 .08671 .4979 .07663 .50158 Metetra
.505 .815 1 r
.07663 .50158 .08671 .4979 .07185 .49421 .06179 .49794 Metetra
.506 .815 1 r
.06179 .49794 .07185 .49421 .05683 .49048 .0468 .49427 Metetra
.507 .816 1 r
.0468 .49427 .05683 .49048 .04166 .48671 .03166 .49055 Metetra
.508 .816 1 r
.03166 .49055 .04166 .48671 .02633 .48291 .01635 .4868 Metetra
.509 .816 1 r
.01635 .4868 .02633 .48291 .01083 .47906 .00089 .48302 Metetra
.643 .907 .982 r
.5153 .58295 .52586 .57742 .51511 .57771 .50454 .58283 Metetra
.622 .899 .986 r
.50454 .58283 .51511 .57771 .50426 .57771 .49368 .58246 Metetra
.602 .89 .99 r
.49368 .58246 .50426 .57771 .4933 .57743 .48272 .58185 Metetra
.583 .881 .992 r
.48272 .58185 .4933 .57743 .48224 .57688 .47165 .581 Metetra
.566 .873 .994 r
.47165 .581 .48224 .57688 .47107 .57606 .46049 .57993 Metetra
.55 .865 .996 r
.46049 .57993 .47107 .57606 .45979 .57499 .44922 .57864 Metetra
.536 .857 .997 r
.44922 .57864 .45979 .57499 .44842 .57369 .43784 .57715 Metetra
.524 .85 .998 r
.43784 .57715 .44842 .57369 .43693 .57217 .42636 .57548 Metetra
.515 .843 .998 r
.42636 .57548 .43693 .57217 .42534 .57045 .41477 .57363 Metetra
.507 .838 .998 r
.41477 .57363 .42534 .57045 .41364 .56854 .40308 .57163 Metetra
.5 .833 .999 r
.40308 .57163 .41364 .56854 .40183 .56646 .39128 .56948 Metetra
.495 .829 .999 r
.39128 .56948 .40183 .56646 .38991 .56423 .37937 .5672 Metetra
.491 .825 .999 r
.37937 .5672 .38991 .56423 .37788 .56186 .36735 .56479 Metetra
.489 .823 .999 r
.36735 .56479 .37788 .56186 .36574 .55936 .35521 .56228 Metetra
.487 .82 .999 r
.35521 .56228 .36574 .55936 .35349 .55675 .34297 .55966 Metetra
.486 .818 .999 r
.34297 .55966 .35349 .55675 .34112 .55404 .33061 .55695 Metetra
.486 .817 1 r
.33061 .55695 .34112 .55404 .32863 .55123 .31814 .55416 Metetra
.486 .816 1 r
.31814 .55416 .32863 .55123 .31603 .54833 .30555 .55128 Metetra
.486 .815 1 r
.30555 .55128 .31603 .54833 .30331 .54535 .29284 .54834 Metetra
.487 .814 1 r
.29284 .54834 .30331 .54535 .29046 .5423 .28001 .54532 Metetra
.488 .813 1 r
.28001 .54532 .29046 .5423 .2775 .53919 .26706 .54225 Metetra
.489 .813 1 r
.26706 .54225 .2775 .53919 .26441 .53601 .25398 .53912 Metetra
.491 .813 1 r
.25398 .53912 .26441 .53601 .25119 .53277 .24078 .53593 Metetra
.492 .813 1 r
.24078 .53593 .25119 .53277 .23784 .52949 .22745 .53269 Metetra
.494 .813 1 r
.22745 .53269 .23784 .52949 .22437 .52615 .21399 .5294 Metetra
.495 .813 1 r
.21399 .5294 .22437 .52615 .21076 .52276 .2004 .52607 Metetra
.497 .813 1 r
.2004 .52607 .21076 .52276 .19702 .51933 .18668 .52269 Metetra
.498 .813 1 r
.18668 .52269 .19702 .51933 .18314 .51585 .17282 .51927 Metetra
.499 .814 1 r
.17282 .51927 .18314 .51585 .16913 .51233 .15883 .5158 Metetra
.501 .814 1 r
.15883 .5158 .16913 .51233 .15497 .50878 .14469 .5123 Metetra
.502 .814 1 r
.14469 .5123 .15497 .50878 .14068 .50518 .13041 .50876 Metetra
.504 .814 1 r
.13041 .50876 .14068 .50518 .12623 .50154 .11599 .50518 Metetra
.505 .815 1 r
.11599 .50518 .12623 .50154 .11164 .49787 .10143 .50156 Metetra
.506 .815 1 r
.10143 .50156 .11164 .49787 .0969 .49415 .08671 .4979 Metetra
.507 .815 1 r
.08671 .4979 .0969 .49415 .08201 .4904 .07185 .49421 Metetra
.508 .816 1 r
.07185 .49421 .08201 .4904 .06697 .48662 .05683 .49048 Metetra
.509 .816 1 r
.05683 .49048 .06697 .48662 .05177 .48279 .04166 .48671 Metetra
.51 .816 1 r
.04166 .48671 .05177 .48279 .03641 .47893 .02633 .48291 Metetra
.511 .816 1 r
.02633 .48291 .03641 .47893 .02089 .47504 .01083 .47906 Metetra
.676 .918 .974 r
.52586 .57742 .53651 .57111 .52577 .57189 .51511 .57771 Metetra
.653 .911 .98 r
.51511 .57771 .52577 .57189 .51492 .57235 .50426 .57771 Metetra
.63 .902 .985 r
.50426 .57771 .51492 .57235 .50397 .5725 .4933 .57743 Metetra
.608 .893 .989 r
.4933 .57743 .50397 .5725 .49291 .57232 .48224 .57688 Metetra
.587 .884 .992 r
.48224 .57688 .49291 .57232 .48175 .57183 .47107 .57606 Metetra
.568 .874 .994 r
.47107 .57606 .48175 .57183 .47047 .57105 .45979 .57499 Metetra
.551 .865 .996 r
.45979 .57499 .47047 .57105 .45909 .56999 .44842 .57369 Metetra
.536 .857 .997 r
.44842 .57369 .45909 .56999 .4476 .56867 .43693 .57217 Metetra
.523 .849 .998 r
.43693 .57217 .4476 .56867 .436 .56711 .42534 .57045 Metetra
.513 .843 .998 r
.42534 .57045 .436 .56711 .4243 .56533 .41364 .56854 Metetra
.505 .837 .998 r
.41364 .56854 .4243 .56533 .41248 .56335 .40183 .56646 Metetra
.498 .832 .999 r
.40183 .56646 .41248 .56335 .40055 .5612 .38991 .56423 Metetra
.493 .827 .999 r
.38991 .56423 .40055 .5612 .38852 .55887 .37788 .56186 Metetra
.49 .824 .999 r
.37788 .56186 .38852 .55887 .37637 .55641 .36574 .55936 Metetra
.488 .821 .999 r
.36574 .55936 .37637 .55641 .3641 .55381 .35349 .55675 Metetra
.486 .819 .999 r
.35349 .55675 .3641 .55381 .35172 .55109 .34112 .55404 Metetra
.486 .817 1 r
.34112 .55404 .35172 .55109 .33923 .54826 .32863 .55123 Metetra
.486 .816 1 r
.32863 .55123 .33923 .54826 .32661 .54534 .31603 .54833 Metetra
.486 .815 1 r
.31603 .54833 .32661 .54534 .31388 .54234 .30331 .54535 Metetra
.487 .814 1 r
.30331 .54535 .31388 .54234 .30102 .53925 .29046 .5423 Metetra
.488 .813 1 r
.29046 .5423 .30102 .53925 .28804 .53609 .2775 .53919 Metetra
.49 .813 1 r
.2775 .53919 .28804 .53609 .27494 .53287 .26441 .53601 Metetra
.491 .813 1 r
.26441 .53601 .27494 .53287 .2617 .52958 .25119 .53277 Metetra
.493 .813 1 r
.25119 .53277 .2617 .52958 .24834 .52624 .23784 .52949 Metetra
.494 .813 1 r
.23784 .52949 .24834 .52624 .23485 .52285 .22437 .52615 Metetra
.496 .813 1 r
.22437 .52615 .23485 .52285 .22123 .51941 .21076 .52276 Metetra
.498 .813 1 r
.21076 .52276 .22123 .51941 .20747 .51592 .19702 .51933 Metetra
.499 .813 1 r
.19702 .51933 .20747 .51592 .19357 .51238 .18314 .51585 Metetra
.501 .814 1 r
.18314 .51585 .19357 .51238 .17954 .50881 .16913 .51233 Metetra
.503 .814 1 r
.16913 .51233 .17954 .50881 .16536 .50519 .15497 .50878 Metetra
.504 .814 1 r
.15497 .50878 .16536 .50519 .15104 .50153 .14068 .50518 Metetra
.505 .814 1 r
.14068 .50518 .15104 .50153 .13658 .49784 .12623 .50154 Metetra
.507 .815 1 r
.12623 .50154 .13658 .49784 .12197 .49411 .11164 .49787 Metetra
.508 .815 1 r
.11164 .49787 .12197 .49411 .1072 .49034 .0969 .49415 Metetra
.509 .815 1 r
.0969 .49415 .1072 .49034 .09229 .48653 .08201 .4904 Metetra
.51 .816 1 r
.08201 .4904 .09229 .48653 .07722 .48268 .06697 .48662 Metetra
.512 .816 1 r
.06697 .48662 .07722 .48268 .06199 .4788 .05177 .48279 Metetra
.513 .816 1 r
.05177 .48279 .06199 .4788 .0466 .47488 .03641 .47893 Metetra
.514 .817 1 r
.03641 .47893 .0466 .47488 .03105 .47093 .02089 .47504 Metetra
.713 .93 .962 r
.53651 .57111 .54723 .5638 .53651 .56518 .52577 .57189 Metetra
.688 .923 .97 r
.52577 .57189 .53651 .56518 .52568 .56621 .51492 .57235 Metetra
.663 .915 .977 r
.51492 .57235 .52568 .56621 .51473 .56688 .50397 .5725 Metetra
.638 .906 .983 r
.50397 .5725 .51473 .56688 .50368 .56719 .49291 .57232 Metetra
.614 .896 .988 r
.49291 .57232 .50368 .56719 .49252 .56713 .48175 .57183 Metetra
.591 .886 .991 r
.48175 .57183 .49252 .56713 .48124 .56672 .47047 .57105 Metetra
.57 .876 .994 r
.47047 .57105 .48124 .56672 .46986 .56598 .45909 .56999 Metetra
.551 .866 .995 r
.45909 .56999 .46986 .56598 .45837 .56493 .4476 .56867 Metetra
.535 .857 .997 r
.4476 .56867 .45837 .56493 .44677 .56358 .436 .56711 Metetra
.522 .849 .998 r
.436 .56711 .44677 .56358 .43506 .56198 .4243 .56533 Metetra
.511 .841 .998 r
.4243 .56533 .43506 .56198 .42324 .56013 .41248 .56335 Metetra
.502 .835 .999 r
.41248 .56335 .42324 .56013 .4113 .55807 .40055 .5612 Metetra
.496 .83 .999 r
.40055 .5612 .4113 .55807 .39926 .55582 .38852 .55887 Metetra
.492 .826 .999 r
.38852 .55887 .39926 .55582 .3871 .5534 .37637 .55641 Metetra
.488 .822 .999 r
.37637 .55641 .3871 .5534 .37482 .55082 .3641 .55381 Metetra
.487 .82 .999 r
.3641 .55381 .37482 .55082 .36243 .5481 .35172 .55109 Metetra
.486 .817 1 r
.35172 .55109 .36243 .5481 .34993 .54527 .33923 .54826 Metetra
.486 .816 1 r
.33923 .54826 .34993 .54527 .3373 .54233 .32661 .54534 Metetra
.486 .815 1 r
.32661 .54534 .3373 .54233 .32455 .53929 .31388 .54234 Metetra
.487 .814 1 r
.31388 .54234 .32455 .53929 .31169 .53616 .30102 .53925 Metetra
.488 .813 1 r
.30102 .53925 .31169 .53616 .29869 .53296 .28804 .53609 Metetra
.49 .813 1 r
.28804 .53609 .29869 .53296 .28557 .52969 .27494 .53287 Metetra
.492 .813 1 r
.27494 .53287 .28557 .52969 .27233 .52635 .2617 .52958 Metetra
.494 .812 1 r
.2617 .52958 .27233 .52635 .25895 .52295 .24834 .52624 Metetra
.495 .813 1 r
.24834 .52624 .25895 .52295 .24545 .5195 .23485 .52285 Metetra
.497 .813 1 r
.23485 .52285 .24545 .5195 .2318 .516 .22123 .51941 Metetra
.499 .813 1 r
.22123 .51941 .2318 .516 .21803 .51245 .20747 .51592 Metetra
.501 .813 1 r
.20747 .51592 .21803 .51245 .20411 .50886 .19357 .51238 Metetra
.503 .814 1 r
.19357 .51238 .20411 .50886 .19006 .50522 .17954 .50881 Metetra
.504 .814 1 r
.17954 .50881 .19006 .50522 .17586 .50154 .16536 .50519 Metetra
.506 .814 1 r
.16536 .50519 .17586 .50154 .16152 .49782 .15104 .50153 Metetra
.508 .815 1 r
.15104 .50153 .16152 .49782 .14704 .49407 .13658 .49784 Metetra
.509 .815 1 r
.13658 .49784 .14704 .49407 .1324 .49027 .12197 .49411 Metetra
.51 .815 1 r
.12197 .49411 .1324 .49027 .11762 .48644 .1072 .49034 Metetra
.512 .816 1 r
.1072 .49034 .11762 .48644 .10268 .48257 .09229 .48653 Metetra
.513 .816 1 r
.09229 .48653 .10268 .48257 .08758 .47867 .07722 .48268 Metetra
.514 .816 1 r
.07722 .48268 .08758 .47867 .07232 .47472 .06199 .4788 Metetra
.515 .817 1 r
.06199 .4788 .07232 .47472 .05691 .47074 .0466 .47488 Metetra
.516 .817 1 r
.0466 .47488 .05691 .47074 .04133 .46673 .03105 .47093 Metetra
.753 .938 .945 r
.54723 .5638 .55803 .55522 .54733 .5573 .53651 .56518 Metetra
.729 .934 .956 r
.53651 .56518 .54733 .5573 .53651 .55903 .52568 .56621 Metetra
.703 .928 .965 r
.52568 .56621 .53651 .55903 .52558 .56036 .51473 .56688 Metetra
.676 .92 .974 r
.51473 .56688 .52558 .56036 .51454 .56128 .50368 .56719 Metetra
.648 .91 .981 r
.50368 .56719 .51454 .56128 .50338 .56178 .49252 .56713 Metetra
.62 .9 .986 r
.49252 .56713 .50338 .56178 .49212 .56186 .48124 .56672 Metetra
.595 .888 .99 r
.48124 .56672 .49212 .56186 .48073 .56154 .46986 .56598 Metetra
.571 .877 .993 r
.46986 .56598 .48073 .56154 .46924 .56084 .45837 .56493 Metetra
.551 .866 .995 r
.45837 .56493 .46924 .56084 .45764 .5598 .44677 .56358 Metetra
.534 .856 .997 r
.44677 .56358 .45764 .5598 .44592 .55842 .43506 .56198 Metetra
.52 .847 .998 r
.43506 .56198 .44592 .55842 .4341 .55676 .42324 .56013 Metetra
.509 .84 .998 r
.42324 .56013 .4341 .55676 .42216 .55484 .4113 .55807 Metetra
.5 .833 .999 r
.4113 .55807 .42216 .55484 .4101 .55268 .39926 .55582 Metetra
.494 .828 .999 r
.39926 .55582 .4101 .55268 .39793 .55032 .3871 .5534 Metetra
.49 .824 .999 r
.3871 .5534 .39793 .55032 .38565 .54778 .37482 .55082 Metetra
.487 .821 .999 r
.37482 .55082 .38565 .54778 .37325 .54508 .36243 .5481 Metetra
.486 .818 .999 r
.36243 .5481 .37325 .54508 .36073 .54225 .34993 .54527 Metetra
.486 .816 1 r
.34993 .54527 .36073 .54225 .3481 .53928 .3373 .54233 Metetra
.486 .815 1 r
.3373 .54233 .3481 .53928 .33534 .53621 .32455 .53929 Metetra
.487 .814 1 r
.32455 .53929 .33534 .53621 .32246 .53305 .31169 .53616 Metetra
.489 .813 1 r
.31169 .53616 .32246 .53305 .30945 .5298 .29869 .53296 Metetra
.491 .812 1 r
.29869 .53296 .30945 .5298 .29632 .52647 .28557 .52969 Metetra
.492 .812 1 r
.28557 .52969 .29632 .52647 .28306 .52308 .27233 .52635 Metetra
.495 .812 1 r
.27233 .52635 .28306 .52308 .26967 .51962 .25895 .52295 Metetra
.497 .812 1 r
.25895 .52295 .26967 .51962 .25615 .51611 .24545 .5195 Metetra
.499 .813 1 r
.24545 .5195 .25615 .51611 .24249 .51254 .2318 .516 Metetra
.501 .813 1 r
.2318 .516 .24249 .51254 .2287 .50893 .21803 .51245 Metetra
.503 .813 1 r
.21803 .51245 .2287 .50893 .21477 .50527 .20411 .50886 Metetra
.505 .814 1 r
.20411 .50886 .21477 .50527 .20069 .50156 .19006 .50522 Metetra
.507 .814 1 r
.19006 .50522 .20069 .50156 .18648 .49782 .17586 .50154 Metetra
.508 .814 1 r
.17586 .50154 .18648 .49782 .17212 .49404 .16152 .49782 Metetra
.51 .815 1 r
.16152 .49782 .17212 .49404 .15761 .49021 .14704 .49407 Metetra
.512 .815 1 r
.14704 .49407 .15761 .49021 .14295 .48636 .1324 .49027 Metetra
.513 .816 1 r
.1324 .49027 .14295 .48636 .12814 .48246 .11762 .48644 Metetra
.515 .816 1 r
.11762 .48644 .12814 .48246 .11318 .47853 .10268 .48257 Metetra
.516 .816 1 r
.10268 .48257 .11318 .47853 .09806 .47456 .08758 .47867 Metetra
.517 .817 .999 r
.08758 .47867 .09806 .47456 .08277 .47055 .07232 .47472 Metetra
.518 .817 .999 r
.07232 .47472 .08277 .47055 .06733 .46651 .05691 .47074 Metetra
.519 .817 .999 r
.05691 .47074 .06733 .46651 .05172 .46244 .04133 .46673 Metetra
.793 .943 .924 r
.55803 .55522 .56889 .54507 .55822 .54795 .54733 .5573 Metetra
.772 .942 .936 r
.54733 .5573 .55822 .54795 .54742 .55049 .53651 .55903 Metetra
.747 .939 .948 r
.53651 .55903 .54742 .55049 .53651 .55263 .52558 .56036 Metetra
.719 .933 .959 r
.52558 .56036 .53651 .55263 .52549 .55432 .51454 .56128 Metetra
.689 .925 .969 r
.51454 .56128 .52549 .55432 .51434 .55554 .50338 .56178 Metetra
.658 .915 .978 r
.50338 .56178 .51434 .55554 .50308 .55627 .49212 .56186 Metetra
.628 .903 .985 r
.49212 .56186 .50308 .55627 .49171 .55652 .48073 .56154 Metetra
.599 .891 .99 r
.48073 .56154 .49171 .55652 .48021 .5563 .46924 .56084 Metetra
.573 .878 .993 r
.46924 .56084 .48021 .5563 .46861 .55565 .45764 .5598 Metetra
.551 .866 .995 r
.45764 .5598 .46861 .55565 .45689 .5546 .44592 .55842 Metetra
.532 .856 .997 r
.44592 .55842 .45689 .5546 .44506 .55319 .4341 .55676 Metetra
.517 .846 .998 r
.4341 .55676 .44506 .55319 .43311 .55146 .42216 .55484 Metetra
.506 .838 .998 r
.42216 .55484 .43311 .55146 .42105 .54944 .4101 .55268 Metetra
.498 .831 .999 r
.4101 .55268 .42105 .54944 .40888 .54718 .39793 .55032 Metetra
.492 .826 .999 r
.39793 .55032 .40888 .54718 .39659 .54469 .38565 .54778 Metetra
.488 .822 .999 r
.38565 .54778 .39659 .54469 .38418 .54202 .37325 .54508 Metetra
.486 .819 .999 r
.37325 .54508 .38418 .54202 .37165 .53919 .36073 .54225 Metetra
.486 .816 1 r
.36073 .54225 .37165 .53919 .359 .53621 .3481 .53928 Metetra
.486 .815 1 r
.3481 .53928 .359 .53621 .34623 .53311 .33534 .53621 Metetra
.487 .813 1 r
.33534 .53621 .34623 .53311 .33334 .5299 .32246 .53305 Metetra
.489 .813 1 r
.32246 .53305 .33334 .5299 .32032 .5266 .30945 .5298 Metetra
.491 .812 1 r
.30945 .5298 .32032 .5266 .30718 .52321 .29632 .52647 Metetra
.493 .812 1 r
.29632 .52647 .30718 .52321 .2939 .51976 .28306 .52308 Metetra
.496 .812 1 r
.28306 .52308 .2939 .51976 .2805 .51623 .26967 .51962 Metetra
.498 .812 1 r
.26967 .51962 .2805 .51623 .26696 .51265 .25615 .51611 Metetra
.5 .812 1 r
.25615 .51611 .26696 .51265 .25329 .50902 .24249 .51254 Metetra
.503 .813 1 r
.24249 .51254 .25329 .50902 .23948 .50533 .2287 .50893 Metetra
.505 .813 1 r
.2287 .50893 .23948 .50533 .22553 .5016 .21477 .50527 Metetra
.507 .814 1 r
.21477 .50527 .22553 .5016 .21144 .49783 .20069 .50156 Metetra
.509 .814 1 r
.20069 .50156 .21144 .49783 .19721 .49402 .18648 .49782 Metetra
.511 .814 1 r
.18648 .49782 .19721 .49402 .18283 .49016 .17212 .49404 Metetra
.513 .815 1 r
.17212 .49404 .18283 .49016 .1683 .48627 .15761 .49021 Metetra
.515 .815 .999 r
.15761 .49021 .1683 .48627 .15362 .48235 .14295 .48636 Metetra
.516 .816 .999 r
.14295 .48636 .15362 .48235 .13879 .47838 .12814 .48246 Metetra
.518 .816 .999 r
.12814 .48246 .13879 .47838 .1238 .47439 .11318 .47853 Metetra
.519 .817 .999 r
.11318 .47853 .1238 .47439 .10865 .47035 .09806 .47456 Metetra
.52 .817 .999 r
.09806 .47456 .10865 .47035 .09334 .46628 .08277 .47055 Metetra
.522 .818 .999 r
.08277 .47055 .09334 .46628 .07787 .46218 .06733 .46651 Metetra
.523 .818 .999 r
.06733 .46651 .07787 .46218 .06223 .45804 .05172 .46244 Metetra
.831 .943 .898 r
.56889 .54507 .57981 .53303 .56917 .53673 .55822 .54795 Metetra
.814 .945 .91 r
.55822 .54795 .56917 .53673 .5584 .54019 .54742 .55049 Metetra
.793 .945 .924 r
.54742 .55049 .5584 .54019 .54752 .54328 .53651 .55263 Metetra
.767 .943 .938 r
.53651 .55263 .54752 .54328 .53651 .54593 .52549 .55432 Metetra
.738 .938 .952 r
.52549 .55432 .53651 .54593 .52539 .54807 .51434 .55554 Metetra
.705 .93 .964 r
.51434 .55554 .52539 .54807 .51414 .54965 .50308 .55627 Metetra
.671 .92 .975 r
.50308 .55627 .51414 .54965 .50277 .55066 .49171 .55652 Metetra
.636 .907 .983 r
.49171 .55652 .50277 .55066 .49129 .5511 .48021 .5563 Metetra
.604 .894 .989 r
.48021 .5563 .49129 .5511 .47969 .551 .46861 .55565 Metetra
.575 .88 .993 r
.46861 .55565 .47969 .551 .46797 .5504 .45689 .5546 Metetra
.55 .866 .995 r
.45689 .5546 .46797 .5504 .45613 .54935 .44506 .55319 Metetra
.53 .854 .997 r
.44506 .55319 .45613 .54935 .44418 .54788 .43311 .55146 Metetra
.514 .844 .998 r
.43311 .55146 .44418 .54788 .43211 .54606 .42105 .54944 Metetra
.503 .836 .998 r
.42105 .54944 .43211 .54606 .41993 .54394 .40888 .54718 Metetra
.495 .829 .999 r
.40888 .54718 .41993 .54394 .40763 .54154 .39659 .54469 Metetra
.49 .824 .999 r
.39659 .54469 .40763 .54154 .39521 .53891 .38418 .54202 Metetra
.487 .82 .999 r
.38418 .54202 .39521 .53891 .38268 .53609 .37165 .53919 Metetra
.486 .817 1 r
.37165 .53919 .38268 .53609 .37002 .5331 .359 .53621 Metetra
.486 .815 1 r
.359 .53621 .37002 .5331 .35724 .52997 .34623 .53311 Metetra
.488 .813 1 r
.34623 .53311 .35724 .52997 .34433 .52672 .33334 .5299 Metetra
.489 .812 1 r
.33334 .5299 .34433 .52672 .3313 .52336 .32032 .5266 Metetra
.492 .812 1 r
.32032 .5266 .3313 .52336 .31815 .51991 .30718 .52321 Metetra
.494 .812 1 r
.30718 .52321 .31815 .51991 .30486 .51639 .2939 .51976 Metetra
.497 .812 1 r
.2939 .51976 .30486 .51639 .29144 .51279 .2805 .51623 Metetra
.5 .812 1 r
.2805 .51623 .29144 .51279 .27789 .50914 .26696 .51265 Metetra
.503 .812 1 r
.26696 .51265 .27789 .50914 .2642 .50543 .25329 .50902 Metetra
.505 .813 1 r
.25329 .50902 .2642 .50543 .25038 .50167 .23948 .50533 Metetra
.508 .813 1 r
.23948 .50533 .25038 .50167 .23641 .49786 .22553 .5016 Metetra
.51 .814 1 r
.22553 .5016 .23641 .49786 .2223 .49401 .21144 .49783 Metetra
.512 .814 1 r
.21144 .49783 .2223 .49401 .20805 .49012 .19721 .49402 Metetra
.514 .815 .999 r
.19721 .49402 .20805 .49012 .19365 .4862 .18283 .49016 Metetra
.516 .815 .999 r
.18283 .49016 .19365 .4862 .1791 .48224 .1683 .48627 Metetra
.518 .816 .999 r
.1683 .48627 .1791 .48224 .1644 .47824 .15362 .48235 Metetra
.52 .816 .999 r
.15362 .48235 .1644 .47824 .14955 .47421 .13879 .47838 Metetra
.521 .817 .999 r
.13879 .47838 .14955 .47421 .13453 .47014 .1238 .47439 Metetra
.523 .817 .999 r
.1238 .47439 .13453 .47014 .11936 .46604 .10865 .47035 Metetra
.524 .818 .999 r
.10865 .47035 .11936 .46604 .10403 .4619 .09334 .46628 Metetra
.525 .818 .999 r
.09334 .46628 .10403 .4619 .08853 .45773 .07787 .46218 Metetra
.526 .818 .999 r
.07787 .46218 .08853 .45773 .07287 .45352 .06223 .45804 Metetra
.862 .938 .87 r
.57981 .53303 .59077 .51885 .58016 .52331 .56917 .53673 Metetra
.851 .942 .88 r
.56917 .53673 .58016 .52331 .56944 .52768 .5584 .54019 Metetra
.836 .945 .893 r
.5584 .54019 .56944 .52768 .55859 .53183 .54752 .54328 Metetra
.815 .947 .909 r
.54752 .54328 .55859 .53183 .54761 .53561 .53651 .54593 Metetra
.789 .946 .925 r
.53651 .54593 .54761 .53561 .53651 .53888 .52539 .54807 Metetra
.758 .943 .942 r
.52539 .54807 .53651 .53888 .52529 .54157 .51414 .54965 Metetra
.723 .936 .957 r
.51414 .54965 .52529 .54157 .51393 .54359 .50277 .55066 Metetra
.684 .925 .97 r
.50277 .55066 .51393 .54359 .50246 .54494 .49129 .5511 Metetra
.646 .912 .981 r
.49129 .5511 .50246 .54494 .49086 .54561 .47969 .551 Metetra
.609 .896 .988 r
.47969 .551 .49086 .54561 .47914 .54565 .46797 .5504 Metetra
.576 .881 .993 r
.46797 .5504 .47914 .54565 .46731 .5451 .45613 .54935 Metetra
.549 .866 .995 r
.45613 .54935 .46731 .5451 .45535 .54403 .44418 .54788 Metetra
.527 .853 .997 r
.44418 .54788 .45535 .54403 .44328 .5425 .43211 .54606 Metetra
.511 .842 .998 r
.43211 .54606 .44328 .5425 .43109 .54057 .41993 .54394 Metetra
.499 .833 .999 r
.41993 .54394 .43109 .54057 .41879 .5383 .40763 .54154 Metetra
.492 .826 .999 r
.40763 .54154 .41879 .5383 .40636 .53575 .39521 .53891 Metetra
.488 .821 .999 r
.39521 .53891 .40636 .53575 .39381 .53295 .38268 .53609 Metetra
.486 .817 1 r
.38268 .53609 .39381 .53295 .38114 .52996 .37002 .5331 Metetra
.486 .815 1 r
.37002 .5331 .38114 .52996 .36835 .5268 .35724 .52997 Metetra
.488 .813 1 r
.35724 .52997 .36835 .5268 .35544 .5235 .34433 .52672 Metetra
.49 .812 1 r
.34433 .52672 .35544 .5235 .3424 .52008 .3313 .52336 Metetra
.493 .811 1 r
.3313 .52336 .3424 .52008 .32923 .51657 .31815 .51991 Metetra
.496 .811 1 r
.31815 .51991 .32923 .51657 .31593 .51296 .30486 .51639 Metetra
.499 .811 1 r
.30486 .51639 .31593 .51296 .3025 .50929 .29144 .51279 Metetra
.502 .812 1 r
.29144 .51279 .3025 .50929 .28893 .50555 .27789 .50914 Metetra
.505 .812 1 r
.27789 .50914 .28893 .50555 .27523 .50176 .2642 .50543 Metetra
.508 .813 1 r
.2642 .50543 .27523 .50176 .26139 .49791 .25038 .50167 Metetra
.511 .813 1 r
.25038 .50167 .26139 .49791 .24741 .49403 .23641 .49786 Metetra
.514 .814 .999 r
.23641 .49786 .24741 .49403 .23328 .4901 .2223 .49401 Metetra
.516 .814 .999 r
.2223 .49401 .23328 .4901 .21901 .48613 .20805 .49012 Metetra
.518 .815 .999 r
.20805 .49012 .21901 .48613 .20459 .48212 .19365 .4862 Metetra
.521 .816 .999 r
.19365 .4862 .20459 .48212 .19003 .47809 .1791 .48224 Metetra
.522 .816 .999 r
.1791 .48224 .19003 .47809 .1753 .47401 .1644 .47824 Metetra
.524 .817 .999 r
.1644 .47824 .1753 .47401 .16043 .46991 .14955 .47421 Metetra
.526 .817 .999 r
.14955 .47421 .16043 .46991 .14539 .46577 .13453 .47014 Metetra
.527 .818 .999 r
.13453 .47014 .14539 .46577 .1302 .46159 .11936 .46604 Metetra
.529 .818 .999 r
.11936 .46604 .1302 .46159 .11484 .45739 .10403 .4619 Metetra
.53 .819 .999 r
.10403 .4619 .11484 .45739 .09932 .45315 .08853 .45773 Metetra
.531 .819 .999 r
.08853 .45773 .09932 .45315 .08362 .44888 .07287 .45352 Metetra
.885 .93 .845 r
.59077 .51885 .60175 .50251 .59119 .50746 .58016 .52331 Metetra
.88 .935 .851 r
.58016 .52331 .59119 .50746 .58051 .5126 .56944 .52768 Metetra
.871 .939 .861 r
.56944 .52768 .58051 .5126 .5697 .51775 .55859 .53183 Metetra
.858 .943 .874 r
.55859 .53183 .5697 .51775 .55877 .52272 .54761 .53561 Metetra
.839 .947 .891 r
.54761 .53561 .55877 .52272 .54771 .52733 .53651 .53888 Metetra
.814 .948 .91 r
.53651 .53888 .54771 .52733 .53651 .53139 .52529 .54157 Metetra
.781 .947 .93 r
.52529 .54157 .53651 .53139 .52518 .53476 .51393 .54359 Metetra
.743 .941 .949 r
.51393 .54359 .52518 .53476 .51372 .53734 .50246 .54494 Metetra
.701 .931 .965 r
.50246 .54494 .51372 .53734 .50214 .53911 .49086 .54561 Metetra
.656 .916 .978 r
.49086 .54561 .50214 .53911 .49043 .54006 .47914 .54565 Metetra
.614 .899 .987 r
.47914 .54565 .49043 .54006 .47859 .54026 .46731 .5451 Metetra
.577 .881 .992 r
.46731 .5451 .47859 .54026 .46664 .53976 .45535 .54403 Metetra
.547 .865 .996 r
.45535 .54403 .46664 .53976 .45456 .53865 .44328 .5425 Metetra
.523 .85 .997 r
.44328 .5425 .45456 .53865 .44237 .53702 .43109 .54057 Metetra
.506 .838 .998 r
.43109 .54057 .44237 .53702 .43005 .53495 .41879 .5383 Metetra
.496 .829 .999 r
.41879 .5383 .43005 .53495 .41762 .53251 .40636 .53575 Metetra
.489 .823 .999 r
.40636 .53575 .41762 .53251 .40506 .52977 .39381 .53295 Metetra
.487 .818 1 r
.39381 .53295 .40506 .52977 .39238 .52679 .38114 .52996 Metetra
.486 .815 1 r
.38114 .52996 .39238 .52679 .37958 .5236 .36835 .5268 Metetra
.488 .813 1 r
.36835 .5268 .37958 .5236 .36666 .52025 .35544 .5235 Metetra
.491 .811 1 r
.35544 .5235 .36666 .52025 .35361 .51676 .3424 .52008 Metetra
.494 .811 1 r
.3424 .52008 .35361 .51676 .34043 .51317 .32923 .51657 Metetra
.497 .811 1 r
.32923 .51657 .34043 .51317 .32711 .50948 .31593 .51296 Metetra
.501 .811 1 r
.31593 .51296 .32711 .50948 .31367 .50571 .3025 .50929 Metetra
.505 .811 1 r
.3025 .50929 .31367 .50571 .30009 .50188 .28893 .50555 Metetra
.508 .812 1 r
.28893 .50555 .30009 .50188 .28638 .498 .27523 .50176 Metetra
.512 .812 .999 r
.27523 .50176 .28638 .498 .27252 .49406 .26139 .49791 Metetra
.515 .813 .999 r
.26139 .49791 .27252 .49406 .25852 .49008 .24741 .49403 Metetra
.518 .814 .999 r
.24741 .49403 .25852 .49008 .24438 .48607 .23328 .4901 Metetra
.521 .815 .999 r
.23328 .4901 .24438 .48607 .23009 .48201 .21901 .48613 Metetra
.523 .815 .999 r
.21901 .48613 .23009 .48201 .21566 .47792 .20459 .48212 Metetra
.525 .816 .999 r
.20459 .48212 .21566 .47792 .20107 .4738 .19003 .47809 Metetra
.527 .817 .999 r
.19003 .47809 .20107 .4738 .18633 .46965 .1753 .47401 Metetra
.529 .817 .998 r
.1753 .47401 .18633 .46965 .17143 .46547 .16043 .46991 Metetra
.531 .818 .998 r
.16043 .46991 .17143 .46547 .15638 .46126 .14539 .46577 Metetra
.532 .818 .998 r
.14539 .46577 .15638 .46126 .14116 .45701 .1302 .46159 Metetra
.534 .819 .998 r
.1302 .46159 .14116 .45701 .12578 .45273 .11484 .45739 Metetra
.535 .819 .998 r
.11484 .45739 .12578 .45273 .11023 .44843 .09932 .45315 Metetra
.536 .82 .998 r
.09932 .45315 .11023 .44843 .09451 .44408 .08362 .44888 Metetra
.899 .921 .826 r
.60175 .50251 .61277 .48431 .60225 .4893 .59119 .50746 Metetra
.899 .925 .826 r
.59119 .50746 .60225 .4893 .59161 .49479 .58051 .5126 Metetra
.897 .929 .83 r
.58051 .5126 .59161 .49479 .58085 .50064 .5697 .51775 Metetra
.891 .934 .839 r
.5697 .51775 .58085 .50064 .56997 .50668 .55877 .52272 Metetra
.88 .939 .851 r
.55877 .52272 .56997 .50668 .55895 .51265 .54771 .52733 Metetra
.863 .944 .869 r
.54771 .52733 .55895 .51265 .5478 .51828 .53651 .53139 Metetra
.839 .948 .89 r
.53651 .53139 .5478 .51828 .5365 .52333 .52518 .53476 Metetra
.807 .949 .914 r
.52518 .53476 .5365 .52333 .52508 .52758 .51372 .53734 Metetra
.766 .946 .937 r
.51372 .53734 .52508 .52758 .51351 .53088 .50214 .53911 Metetra
.719 .936 .958 r
.50214 .53911 .51351 .53088 .50181 .53317 .49043 .54006 Metetra
.669 .921 .975 r
.49043 .54006 .50181 .53317 .48999 .53446 .47859 .54026 Metetra
.62 .902 .986 r
.47859 .54026 .48999 .53446 .47803 .53483 .46664 .53976 Metetra
.577 .881 .992 r
.46664 .53976 .47803 .53483 .46595 .53437 .45456 .53865 Metetra
.543 .863 .996 r
.45456 .53865 .46595 .53437 .45375 .5332 .44237 .53702 Metetra
.518 .847 .998 r
.44237 .53702 .45375 .5332 .44143 .53144 .43005 .53495 Metetra
.502 .834 .999 r
.43005 .53495 .44143 .53144 .42899 .52918 .41762 .53251 Metetra
.492 .825 .999 r
.41762 .53251 .42899 .52918 .41643 .52654 .40506 .52977 Metetra
.487 .819 .999 r
.40506 .52977 .41643 .52654 .40374 .52358 .39238 .52679 Metetra
.487 .815 1 r
.39238 .52679 .40374 .52358 .39093 .52037 .37958 .5236 Metetra
.488 .812 1 r
.37958 .5236 .39093 .52037 .37799 .51696 .36666 .52025 Metetra
.491 .811 1 r
.36666 .52025 .37799 .51696 .36493 .5134 .35361 .51676 Metetra
.495 .81 1 r
.35361 .51676 .36493 .5134 .35174 .50971 .34043 .51317 Metetra
.5 .81 1 r
.34043 .51317 .35174 .50971 .33842 .50592 .32711 .50948 Metetra
.504 .81 1 r
.32711 .50948 .33842 .50592 .32496 .50205 .31367 .50571 Metetra
.508 .811 1 r
.31367 .50571 .32496 .50205 .31137 .49812 .30009 .50188 Metetra
.512 .812 .999 r
.30009 .50188 .31137 .49812 .29764 .49413 .28638 .498 Metetra
.516 .813 .999 r
.28638 .498 .29764 .49413 .28377 .49009 .27252 .49406 Metetra
.52 .813 .999 r
.27252 .49406 .28377 .49009 .26976 .48601 .25852 .49008 Metetra
.523 .814 .999 r
.25852 .49008 .26976 .48601 .2556 .4819 .24438 .48607 Metetra
.526 .815 .999 r
.24438 .48607 .2556 .4819 .2413 .47775 .23009 .48201 Metetra
.529 .816 .998 r
.23009 .48201 .2413 .47775 .22685 .47358 .21566 .47792 Metetra
.531 .817 .998 r
.21566 .47792 .22685 .47358 .21224 .46937 .20107 .4738 Metetra
.533 .817 .998 r
.20107 .4738 .21224 .46937 .19748 .46514 .18633 .46965 Metetra
.535 .818 .998 r
.18633 .46965 .19748 .46514 .18256 .46087 .17143 .46547 Metetra
.537 .819 .998 r
.17143 .46547 .18256 .46087 .16748 .45658 .15638 .46126 Metetra
.539 .819 .998 r
.15638 .46126 .16748 .45658 .15224 .45226 .14116 .45701 Metetra
.54 .82 .998 r
.14116 .45701 .15224 .45226 .13684 .44791 .12578 .45273 Metetra
.541 .82 .997 r
.12578 .45273 .13684 .44791 .12126 .44353 .11023 .44843 Metetra
.542 .821 .997 r
.11023 .44843 .12126 .44353 .10552 .43912 .09451 .44408 Metetra
.904 .911 .816 r
.61277 .48431 .62381 .46496 .61332 .4694 .60225 .4893 Metetra
.909 .915 .811 r
.60225 .4893 .61332 .4694 .60273 .47461 .59161 .49479 Metetra
.912 .918 .808 r
.59161 .49479 .60273 .47461 .59202 .48057 .58085 .50064 Metetra
.912 .922 .809 r
.58085 .50064 .59202 .48057 .58118 .48714 .56997 .50668 Metetra
.909 .927 .815 r
.56997 .50668 .58118 .48714 .57022 .49415 .55895 .51265 Metetra
.901 .932 .826 r
.55895 .51265 .57022 .49415 .55912 .50128 .5478 .51828 Metetra
.887 .939 .843 r
.5478 .51828 .55912 .50128 .54788 .5082 .5365 .52333 Metetra
.866 .945 .866 r
.5365 .52333 .54788 .5082 .5365 .51451 .52508 .52758 Metetra
.835 .95 .893 r
.52508 .52758 .5365 .51451 .52497 .51991 .51351 .53088 Metetra
.793 .949 .923 r
.51351 .53088 .52497 .51991 .51329 .52414 .50181 .53317 Metetra
.741 .941 .95 r
.50181 .53317 .51329 .52414 .50148 .52711 .48999 .53446 Metetra
.683 .926 .971 r
.48999 .53446 .50148 .52711 .48953 .52883 .47803 .53483 Metetra
.626 .904 .985 r
.47803 .53483 .48953 .52883 .47746 .52939 .46595 .53437 Metetra
.576 .881 .992 r
.46595 .53437 .47746 .52939 .46526 .52895 .45375 .5332 Metetra
.538 .859 .996 r
.45375 .5332 .46526 .52895 .45293 .52768 .44143 .53144 Metetra
.512 .842 .998 r
.44143 .53144 .45293 .52768 .44048 .52572 .42899 .52918 Metetra
.497 .829 .999 r
.42899 .52918 .44048 .52572 .42791 .52323 .41643 .52654 Metetra
.489 .821 .999 r
.41643 .52654 .42791 .52323 .41521 .52033 .40374 .52358 Metetra
.487 .815 1 r
.40374 .52358 .41521 .52033 .40239 .51711 .39093 .52037 Metetra
.488 .812 1 r
.39093 .52037 .40239 .51711 .38945 .51364 .37799 .51696 Metetra
.492 .81 1 r
.37799 .51696 .38945 .51364 .37638 .50998 .36493 .5134 Metetra
.497 .809 1 r
.36493 .5134 .37638 .50998 .36317 .50619 .35174 .50971 Metetra
.502 .809 1 r
.35174 .50971 .36317 .50619 .34984 .50228 .33842 .50592 Metetra
.508 .81 .999 r
.33842 .50592 .34984 .50228 .33637 .49829 .32496 .50205 Metetra
.513 .811 .999 r
.32496 .50205 .33637 .49829 .32277 .49423 .31137 .49812 Metetra
.518 .812 .999 r
.31137 .49812 .32277 .49423 .30903 .49013 .29764 .49413 Metetra
.522 .813 .999 r
.29764 .49413 .30903 .49013 .29515 .48598 .28377 .49009 Metetra
.526 .814 .998 r
.28377 .49009 .29515 .48598 .28112 .48179 .26976 .48601 Metetra
.53 .815 .998 r
.26976 .48601 .28112 .48179 .26695 .47757 .2556 .4819 Metetra
.533 .816 .998 r
.2556 .4819 .26695 .47757 .25263 .47333 .2413 .47775 Metetra
.536 .816 .998 r
.2413 .47775 .25263 .47333 .23816 .46905 .22685 .47358 Metetra
.538 .817 .997 r
.22685 .47358 .23816 .46905 .22354 .46476 .21224 .46937 Metetra
.541 .818 .997 r
.21224 .46937 .22354 .46476 .20876 .46044 .19748 .46514 Metetra
.543 .819 .997 r
.19748 .46514 .20876 .46044 .19382 .45609 .18256 .46087 Metetra
.544 .82 .997 r
.18256 .46087 .19382 .45609 .17872 .45172 .16748 .45658 Metetra
.546 .82 .997 r
.16748 .45658 .17872 .45172 .16346 .44732 .15224 .45226 Metetra
.547 .821 .997 r
.15224 .45226 .16346 .44732 .14803 .4429 .13684 .44791 Metetra
.548 .821 .997 r
.13684 .44791 .14803 .4429 .13243 .43845 .12126 .44353 Metetra
.549 .822 .997 r
.12126 .44353 .13243 .43845 .11666 .43397 .10552 .43912 Metetra
.9 .903 .818 r
.62381 .46496 .63491 .44548 .62444 .44882 .61332 .4694 Metetra
.909 .905 .807 r
.61332 .4694 .62444 .44882 .61387 .45307 .60273 .47461 Metetra
.917 .908 .798 r
.60273 .47461 .61387 .45307 .60319 .45829 .59202 .48057 Metetra
.922 .911 .791 r
.59202 .48057 .60319 .45829 .5924 .46453 .58118 .48714 Metetra
.925 .914 .788 r
.58118 .48714 .5924 .46453 .5815 .47172 .57022 .49415 Metetra
.925 .918 .789 r
.57022 .49415 .5815 .47172 .57046 .47971 .55912 .50128 Metetra
.92 .923 .797 r
.55912 .50128 .57046 .47971 .55928 .48819 .54788 .5082 Metetra
.911 .93 .813 r
.54788 .5082 .55928 .48819 .54796 .49668 .5365 .51451 Metetra
.893 .938 .836 r
.5365 .51451 .54796 .49668 .53648 .50465 .52497 .51991 Metetra
.865 .946 .867 r
.52497 .51991 .53648 .50465 .52485 .51157 .51329 .52414 Metetra
.823 .95 .903 r
.51329 .52414 .52485 .51157 .51307 .51707 .50148 .52711 Metetra
.766 .946 .938 r
.50148 .52711 .51307 .51707 .50114 .52093 .48953 .52883 Metetra
.699 .93 .966 r
.48953 .52883 .50114 .52093 .48907 .52318 .47746 .52939 Metetra
.631 .906 .984 r
.47746 .52939 .48907 .52318 .47687 .52396 .46526 .52895 Metetra
.573 .879 .993 r
.46526 .52895 .47687 .52396 .46454 .5235 .45293 .52768 Metetra
.531 .855 .997 r
.45293 .52768 .46454 .5235 .45209 .52205 .44048 .52572 Metetra
.505 .836 .999 r
.44048 .52572 .45209 .52205 .43951 .51983 .42791 .52323 Metetra
.492 .824 .999 r
.42791 .52323 .43951 .51983 .42681 .51703 .41521 .52033 Metetra
.487 .816 1 r
.41521 .52033 .42681 .51703 .41398 .51381 .40239 .51711 Metetra
.489 .811 1 r
.40239 .51711 .41398 .51381 .40102 .51027 .38945 .51364 Metetra
.493 .809 1 r
.38945 .51364 .40102 .51027 .38794 .50651 .37638 .50998 Metetra
.499 .808 1 r
.37638 .50998 .38794 .50651 .37473 .50258 .36317 .50619 Metetra
.506 .809 .999 r
.36317 .50619 .37473 .50258 .36139 .49853 .34984 .50228 Metetra
.513 .809 .999 r
.34984 .50228 .36139 .49853 .34791 .4944 .33637 .49829 Metetra
.519 .81 .999 r
.33637 .49829 .34791 .4944 .3343 .4902 .32277 .49423 Metetra
.525 .812 .998 r
.32277 .49423 .3343 .4902 .32054 .48596 .30903 .49013 Metetra
.53 .813 .998 r
.30903 .49013 .32054 .48596 .30665 .48168 .29515 .48598 Metetra
.534 .814 .997 r
.29515 .48598 .30665 .48168 .29261 .47737 .28112 .48179 Metetra
.538 .815 .997 r
.28112 .48179 .29261 .47737 .27842 .47304 .26695 .47757 Metetra
.542 .816 .997 r
.26695 .47757 .27842 .47304 .26409 .46868 .25263 .47333 Metetra
.545 .817 .996 r
.25263 .47333 .26409 .46868 .2496 .46431 .23816 .46905 Metetra
.547 .818 .996 r
.23816 .46905 .2496 .46431 .23496 .45992 .22354 .46476 Metetra
.549 .819 .996 r
.22354 .46476 .23496 .45992 .22017 .45551 .20876 .46044 Metetra
.551 .82 .996 r
.20876 .46044 .22017 .45551 .20521 .45108 .19382 .45609 Metetra
.553 .821 .996 r
.19382 .45609 .20521 .45108 .19009 .44663 .17872 .45172 Metetra
.554 .821 .996 r
.17872 .45172 .19009 .44663 .17481 .44216 .16346 .44732 Metetra
.555 .822 .996 r
.16346 .44732 .17481 .44216 .15936 .43766 .14803 .4429 Metetra
.556 .823 .996 r
.14803 .4429 .15936 .43766 .14373 .43314 .13243 .43845 Metetra
.557 .823 .996 r
.13243 .43845 .14373 .43314 .12794 .4286 .11666 .43397 Metetra
.888 .893 .828 r
.63491 .44548 .64607 .42685 .63561 .42878 .62444 .44882 Metetra
.9 .896 .815 r
.62444 .44882 .63561 .42878 .62506 .43155 .61387 .45307 Metetra
.911 .899 .801 r
.61387 .45307 .62506 .43155 .6144 .43532 .60319 .45829 Metetra
.922 .901 .788 r
.60319 .45829 .6144 .43532 .60364 .44023 .5924 .46453 Metetra
.93 .903 .777 r
.5924 .46453 .60364 .44023 .59277 .44642 .5815 .47172 Metetra
.936 .905 .768 r
.5815 .47172 .59277 .44642 .58179 .45398 .57046 .47971 Metetra
.938 .907 .764 r
.57046 .47971 .58179 .45398 .57067 .46283 .55928 .48819 Metetra
.937 .911 .767 r
.55928 .48819 .57067 .46283 .55942 .47271 .54796 .49668 Metetra
.931 .917 .779 r
.54796 .49668 .55942 .47271 .54802 .48311 .53648 .50465 Metetra
.918 .926 .801 r
.53648 .50465 .54802 .48311 .53646 .49324 .52485 .51157 Metetra
.895 .937 .834 r
.52485 .51157 .53646 .49324 .52473 .50229 .51307 .51707 Metetra
.855 .947 .877 r
.51307 .51707 .52473 .50229 .51284 .50954 .50114 .52093 Metetra
.795 .948 .922 r
.50114 .52093 .51284 .50954 .5008 .51463 .48907 .52318 Metetra
.717 .934 .96 r
.48907 .52318 .5008 .51463 .4886 .51755 .47687 .52396 Metetra
.636 .907 .983 r
.47687 .52396 .4886 .51755 .47628 .51856 .46454 .5235 Metetra
.568 .875 .994 r
.46454 .5235 .47628 .51856 .46382 .518 .45209 .52205 Metetra
.522 .847 .998 r
.45209 .52205 .46382 .518 .45123 .51627 .43951 .51983 Metetra
.497 .828 .999 r
.43951 .51983 .45123 .51627 .43852 .51368 .42681 .51703 Metetra
.489 .817 1 r
.42681 .51703 .43852 .51368 .42568 .51048 .41398 .51381 Metetra
.489 .811 1 r
.41398 .51381 .42568 .51048 .41272 .50686 .40102 .51027 Metetra
.495 .808 1 r
.40102 .51027 .41272 .50686 .39963 .50296 .38794 .50651 Metetra
.503 .807 1 r
.38794 .50651 .39963 .50296 .38641 .49886 .37473 .50258 Metetra
.511 .808 .999 r
.37473 .50258 .38641 .49886 .37306 .49464 .36139 .49853 Metetra
.52 .809 .998 r
.36139 .49853 .37306 .49464 .35957 .49033 .34791 .4944 Metetra
.527 .81 .998 r
.34791 .4944 .35957 .49033 .34595 .48597 .3343 .4902 Metetra
.534 .812 .997 r
.3343 .4902 .34595 .48597 .33218 .48156 .32054 .48596 Metetra
.54 .813 .996 r
.32054 .48596 .33218 .48156 .31828 .47714 .30665 .48168 Metetra
.545 .815 .996 r
.30665 .48168 .31828 .47714 .30423 .4727 .29261 .47737 Metetra
.549 .816 .996 r
.29261 .47737 .30423 .4727 .29003 .46824 .27842 .47304 Metetra
.553 .817 .995 r
.27842 .47304 .29003 .46824 .27568 .46377 .26409 .46868 Metetra
.556 .818 .995 r
.26409 .46868 .27568 .46377 .26118 .4593 .2496 .46431 Metetra
.558 .82 .995 r
.2496 .46431 .26118 .4593 .24652 .45481 .23496 .45992 Metetra
.56 .821 .994 r
.23496 .45992 .24652 .45481 .23171 .45031 .22017 .45551 Metetra
.562 .821 .994 r
.22017 .45551 .23171 .45031 .21674 .4458 .20521 .45108 Metetra
.563 .822 .994 r
.20521 .45108 .21674 .4458 .2016 .44127 .19009 .44663 Metetra
.564 .823 .994 r
.19009 .44663 .2016 .44127 .18629 .43672 .17481 .44216 Metetra
.565 .824 .994 r
.17481 .44216 .18629 .43672 .17082 .43216 .15936 .43766 Metetra
.566 .824 .994 r
.15936 .43766 .17082 .43216 .15517 .42757 .14373 .43314 Metetra
.566 .825 .994 r
.14373 .43314 .15517 .42757 .13935 .42296 .12794 .4286 Metetra
.867 .883 .845 r
.64607 .42685 .65732 .4098 .64687 .41028 .63561 .42878 Metetra
.882 .886 .832 r
.63561 .42878 .64687 .41028 .63632 .41141 .62506 .43155 Metetra
.896 .89 .817 r
.62506 .43155 .63632 .41141 .62567 .41335 .6144 .43532 Metetra
.91 .892 .8 r
.6144 .43532 .62567 .41335 .61492 .4163 .60364 .44023 Metetra
.923 .895 .784 r
.60364 .44023 .61492 .4163 .60408 .42048 .59277 .44642 Metetra
.934 .896 .767 r
.59277 .44642 .60408 .42048 .59312 .42615 .58179 .45398 Metetra
.943 .897 .752 r
.58179 .45398 .59312 .42615 .58205 .43355 .57067 .46283 Metetra
.949 .898 .742 r
.57067 .46283 .58205 .43355 .57086 .44285 .55942 .47271 Metetra
.951 .899 .738 r
.55942 .47271 .57086 .44285 .55954 .45399 .54802 .48311 Metetra
.949 .902 .744 r
.54802 .48311 .55954 .45399 .54806 .46652 .53646 .49324 Metetra
.94 .908 .762 r
.53646 .49324 .54806 .46652 .53642 .47947 .52473 .50229 Metetra
.922 .921 .794 r
.52473 .50229 .53642 .47947 .5246 .49152 .51284 .50954 Metetra
.888 .936 .842 r
.51284 .50954 .5246 .49152 .51261 .50135 .5008 .51463 Metetra
.828 .946 .9 r
.5008 .51463 .51261 .50135 .50044 .5082 .4886 .51755 Metetra
.738 .937 .952 r
.4886 .51755 .50044 .5082 .48812 .51201 .47628 .51856 Metetra
.638 .906 .983 r
.47628 .51856 .48812 .51201 .47566 .51321 .46382 .518 Metetra
.557 .868 .995 r
.46382 .518 .47566 .51321 .46307 .51242 .45123 .51627 Metetra
.51 .837 .999 r
.45123 .51627 .46307 .51242 .45035 .51023 .43852 .51368 Metetra
.491 .819 1 r
.43852 .51368 .45035 .51023 .43751 .50712 .42568 .51048 Metetra
.49 .81 1 r
.42568 .51048 .43751 .50712 .42454 .5034 .41272 .50686 Metetra
.497 .806 1 r
.41272 .50686 .42454 .5034 .41144 .49931 .39963 .50296 Metetra
.508 .806 .999 r
.39963 .50296 .41144 .49931 .39821 .495 .38641 .49886 Metetra
.519 .807 .998 r
.38641 .49886 .39821 .495 .38485 .49055 .37306 .49464 Metetra
.529 .808 .997 r
.37306 .49464 .38485 .49055 .37136 .48602 .35957 .49033 Metetra
.539 .81 .996 r
.35957 .49033 .37136 .48602 .35773 .48145 .34595 .48597 Metetra
.546 .812 .995 r
.34595 .48597 .35773 .48145 .34395 .47687 .33218 .48156 Metetra
.553 .814 .994 r
.33218 .48156 .34395 .47687 .33004 .47228 .31828 .47714 Metetra
.558 .816 .994 r
.31828 .47714 .33004 .47228 .31598 .46769 .30423 .4727 Metetra
.563 .817 .993 r
.30423 .4727 .31598 .46769 .30177 .4631 .29003 .46824 Metetra
.566 .819 .993 r
.29003 .46824 .30177 .4631 .28741 .45852 .27568 .46377 Metetra
.569 .82 .992 r
.27568 .46377 .28741 .45852 .27289 .45394 .26118 .4593 Metetra
.572 .821 .992 r
.26118 .4593 .27289 .45394 .25822 .44935 .24652 .45481 Metetra
.573 .822 .992 r
.24652 .45481 .25822 .44935 .24339 .44477 .23171 .45031 Metetra
.575 .823 .992 r
.23171 .45031 .24339 .44477 .2284 .44017 .21674 .4458 Metetra
.576 .824 .992 r
.21674 .4458 .2284 .44017 .21324 .43557 .2016 .44127 Metetra
.577 .825 .992 r
.2016 .44127 .21324 .43557 .19792 .43096 .18629 .43672 Metetra
.577 .825 .992 r
.18629 .43672 .19792 .43096 .18242 .42633 .17082 .43216 Metetra
.577 .826 .992 r
.17082 .43216 .18242 .42633 .16675 .42168 .15517 .42757 Metetra
.578 .827 .992 r
.15517 .42757 .16675 .42168 .15091 .41701 .13935 .42296 Metetra
.841 .872 .865 r
.65732 .4098 .66869 .39467 .65823 .39385 .64687 .41028 Metetra
.855 .875 .853 r
.64687 .41028 .65823 .39385 .64768 .39347 .63632 .41141 Metetra
.871 .878 .839 r
.63632 .41141 .64768 .39347 .63703 .39365 .62567 .41335 Metetra
.887 .882 .823 r
.62567 .41335 .63703 .39365 .62629 .39455 .61492 .4163 Metetra
.903 .885 .805 r
.61492 .4163 .62629 .39455 .61544 .39636 .60408 .42048 Metetra
.919 .888 .785 r
.60408 .42048 .61544 .39636 .6045 .39935 .59312 .42615 Metetra
.934 .89 .764 r
.59312 .42615 .6045 .39935 .59345 .40387 .58205 .43355 Metetra
.946 .891 .743 r
.58205 .43355 .59345 .40387 .58229 .41035 .57086 .44285 Metetra
.956 .89 .724 r
.57086 .44285 .58229 .41035 .57102 .41925 .55954 .45399 Metetra
.961 .888 .712 r
.55954 .45399 .57102 .41925 .55962 .43094 .54806 .46652 Metetra
.962 .886 .709 r
.54806 .46652 .55962 .43094 .54808 .44543 .53642 .47947 Metetra
.958 .888 .72 r
.53642 .47947 .54808 .44543 .53637 .46184 .5246 .49152 Metetra
.945 .897 .747 r
.5246 .49152 .53637 .46184 .52446 .47822 .51261 .50135 Metetra
.919 .915 .797 r
.51261 .50135 .52446 .47822 .51237 .49208 .50044 .5082 Metetra
.864 .937 .868 r
.50044 .5082 .51237 .49208 .50008 .50164 .48812 .51201 Metetra
.762 .937 .941 r
.48812 .51201 .50008 .50164 .48763 .50664 .47566 .51321 Metetra
.636 .902 .984 r
.47566 .51321 .48763 .50664 .47504 .50792 .46307 .51242 Metetra
.541 .855 .997 r
.46307 .51242 .47504 .50792 .46231 .50662 .45035 .51023 Metetra
.498 .823 1 r
.45035 .51023 .46231 .50662 .44946 .50372 .43751 .50712 Metetra
.491 .809 1 r
.43751 .50712 .44946 .50372 .43648 .49988 .42454 .5034 Metetra
.5 .804 .999 r
.42454 .5034 .43648 .49988 .42338 .49553 .41144 .49931 Metetra
.516 .804 .998 r
.41144 .49931 .42338 .49553 .41015 .4909 .39821 .495 Metetra
.531 .805 .996 r
.39821 .495 .41015 .4909 .39678 .48615 .38485 .49055 Metetra
.544 .808 .995 r
.38485 .49055 .39678 .48615 .38328 .48134 .37136 .48602 Metetra
.555 .81 .993 r
.37136 .48602 .38328 .48134 .36964 .47653 .35773 .48145 Metetra
.564 .813 .992 r
.35773 .48145 .36964 .47653 .35586 .47173 .34395 .47687 Metetra
.571 .815 .991 r
.34395 .47687 .35586 .47173 .34193 .46696 .33004 .47228 Metetra
.577 .817 .99 r
.33004 .47228 .34193 .46696 .32786 .46222 .31598 .46769 Metetra
.581 .819 .989 r
.31598 .46769 .32786 .46222 .31364 .4575 .30177 .4631 Metetra
.584 .82 .989 r
.30177 .4631 .31364 .4575 .29927 .4528 .28741 .45852 Metetra
.587 .822 .988 r
.28741 .45852 .29927 .4528 .28474 .44812 .27289 .45394 Metetra
.589 .823 .988 r
.27289 .45394 .28474 .44812 .27006 .44344 .25822 .44935 Metetra
.59 .824 .988 r
.25822 .44935 .27006 .44344 .25521 .43878 .24339 .44477 Metetra
.591 .825 .988 r
.24339 .44477 .25521 .43878 .2402 .43412 .2284 .44017 Metetra
.591 .826 .989 r
.2284 .44017 .2402 .43412 .22503 .42946 .21324 .43557 Metetra
.591 .827 .989 r
.21324 .43557 .22503 .42946 .20969 .42478 .19792 .43096 Metetra
.591 .827 .989 r
.19792 .43096 .20969 .42478 .19417 .4201 .18242 .42633 Metetra
.591 .828 .989 r
.18242 .42633 .19417 .4201 .17848 .41541 .16675 .42168 Metetra
.591 .829 .989 r
.16675 .42168 .17848 .41541 .16261 .41069 .15091 .41701 Metetra
.811 .86 .885 r
.66869 .39467 .68018 .38143 .66972 .37958 .65823 .39385 Metetra
.825 .863 .875 r
.65823 .39385 .66972 .37958 .65916 .37798 .64768 .39347 Metetra
.839 .866 .863 r
.64768 .39347 .65916 .37798 .64851 .37671 .63703 .39365 Metetra
.855 .869 .85 r
.63703 .39365 .64851 .37671 .63776 .37586 .62629 .39455 Metetra
.872 .873 .834 r
.62629 .39455 .63776 .37586 .62692 .37556 .61544 .39636 Metetra
.89 .876 .816 r
.61544 .39636 .62692 .37556 .61597 .37599 .6045 .39935 Metetra
.908 .88 .795 r
.6045 .39935 .61597 .37599 .60492 .37741 .59345 .40387 Metetra
.927 .883 .771 r
.59345 .40387 .60492 .37741 .59377 .38017 .58229 .41035 Metetra
.944 .885 .744 r
.58229 .41035 .59377 .38017 .58251 .3848 .57102 .41925 Metetra
.958 .884 .716 r
.57102 .41925 .58251 .3848 .57114 .39201 .55962 .43094 Metetra
.968 .881 .692 r
.55962 .43094 .57114 .39201 .55966 .40272 .54808 .44543 Metetra
.973 .874 .677 r
.54808 .44543 .55966 .40272 .54804 .41786 .53637 .46184 Metetra
.971 .868 .678 r
.53637 .46184 .54804 .41786 .53627 .43764 .52446 .47822 Metetra
.962 .867 .698 r
.52446 .47822 .53627 .43764 .52431 .46015 .51237 .49208 Metetra
.943 .881 .743 r
.51237 .49208 .52431 .46015 .51212 .48078 .50008 .50164 Metetra
.899 .912 .824 r
.50008 .50164 .51212 .48078 .49972 .49495 .48763 .50664 Metetra
.788 .931 .927 r
.48763 .50664 .49972 .49495 .48713 .5016 .47504 .50792 Metetra
.624 .891 .988 r
.47504 .50792 .48713 .5016 .4744 .50259 .46231 .50662 Metetra
.517 .835 .999 r
.46231 .50662 .4744 .50259 .46154 .50028 .44946 .50372 Metetra
.492 .807 1 r
.44946 .50372 .46154 .50028 .44856 .49628 .43648 .49988 Metetra
.506 .8 .998 r
.43648 .49988 .44856 .49628 .43545 .4915 .42338 .49553 Metetra
.529 .801 .996 r
.42338 .49553 .43545 .4915 .42221 .48641 .41015 .4909 Metetra
.55 .804 .992 r
.41015 .4909 .42221 .48641 .40884 .48123 .39678 .48615 Metetra
.567 .807 .989 r
.39678 .48615 .40884 .48123 .39533 .47607 .38328 .48134 Metetra
.58 .81 .987 r
.38328 .48134 .39533 .47607 .38169 .47096 .36964 .47653 Metetra
.589 .813 .985 r
.36964 .47653 .38169 .47096 .3679 .46593 .35586 .47173 Metetra
.596 .816 .984 r
.35586 .47173 .3679 .46593 .35397 .46097 .34193 .46696 Metetra
.601 .818 .983 r
.34193 .46696 .35397 .46097 .33989 .45607 .32786 .46222 Metetra
.605 .82 .983 r
.32786 .46222 .33989 .45607 .32566 .45123 .31364 .4575 Metetra
.607 .822 .982 r
.31364 .4575 .32566 .45123 .31128 .44644 .29927 .4528 Metetra
.609 .824 .982 r
.29927 .4528 .31128 .44644 .29674 .44168 .28474 .44812 Metetra
.61 .825 .983 r
.28474 .44812 .29674 .44168 .28204 .43694 .27006 .44344 Metetra
.61 .826 .983 r
.27006 .44344 .28204 .43694 .26718 .43222 .25521 .43878 Metetra
.61 .827 .983 r
.25521 .43878 .26718 .43222 .25215 .42751 .2402 .43412 Metetra
.609 .828 .984 r
.2402 .43412 .25215 .42751 .23696 .42281 .22503 .42946 Metetra
.609 .829 .984 r
.22503 .42946 .23696 .42281 .2216 .4181 .20969 .42478 Metetra
.608 .83 .985 r
.20969 .42478 .2216 .4181 .20607 .41339 .19417 .4201 Metetra
.607 .83 .985 r
.19417 .4201 .20607 .41339 .19036 .40866 .17848 .41541 Metetra
.606 .831 .986 r
.17848 .41541 .19036 .40866 .17447 .40391 .16261 .41069 Metetra
.781 .849 .902 r
.68018 .38143 .69179 .36991 .68133 .36728 .66972 .37958 Metetra
.792 .851 .895 r
.66972 .37958 .68133 .36728 .67078 .36477 .65916 .37798 Metetra
.805 .853 .886 r
.65916 .37798 .67078 .36477 .66012 .36241 .64851 .37671 Metetra
.819 .855 .875 r
.64851 .37671 .66012 .36241 .64937 .36026 .63776 .37586 Metetra
.834 .858 .863 r
.63776 .37586 .64937 .36026 .63852 .35838 .62692 .37556 Metetra
.851 .862 .849 r
.62692 .37556 .63852 .35838 .62757 .35685 .61597 .37599 Metetra
.869 .865 .832 r
.61597 .37599 .62757 .35685 .61651 .35582 .60492 .37741 Metetra
.889 .87 .812 r
.60492 .37741 .61651 .35582 .60535 .35546 .59377 .38017 Metetra
.911 .874 .788 r
.59377 .38017 .60535 .35546 .59409 .35607 .58251 .3848 Metetra
.933 .878 .758 r
.58251 .3848 .59409 .35607 .58272 .35809 .57114 .39201 Metetra
.954 .881 .723 r
.57114 .39201 .58272 .35809 .57124 .36224 .55966 .40272 Metetra
.971 .879 .685 r
.55966 .40272 .57124 .36224 .55965 .36968 .54804 .41786 Metetra
.981 .871 .652 r
.54804 .41786 .55965 .36968 .54795 .38229 .53627 .43764 Metetra
.982 .857 .639 r
.53627 .43764 .54795 .38229 .53611 .4026 .52431 .46015 Metetra
.973 .841 .65 r
.52431 .46015 .53611 .4026 .5241 .43195 .51212 .48078 Metetra
.955 .835 .686 r
.51212 .48078 .5241 .43195 .51186 .46473 .49972 .49495 Metetra
.924 .864 .763 r
.49972 .49495 .51186 .46473 .49934 .48812 .48713 .5016 Metetra
.813 .913 .907 r
.48713 .5016 .49934 .48812 .48662 .49707 .4744 .50259 Metetra
.589 .865 .994 r
.4744 .50259 .48662 .49707 .47375 .49676 .46154 .50028 Metetra
.497 .806 1 r
.46154 .50028 .47375 .49676 .46076 .49252 .44856 .49628 Metetra
.516 .794 .996 r
.44856 .49628 .46076 .49252 .44765 .48696 .43545 .4915 Metetra
.553 .797 .989 r
.43545 .4915 .44765 .48696 .43441 .48112 .42221 .48641 Metetra
.583 .802 .983 r
.42221 .48641 .43441 .48112 .42104 .47534 .40884 .48123 Metetra
.604 .806 .978 r
.40884 .48123 .42104 .47534 .40753 .46973 .39533 .47607 Metetra
.617 .81 .974 r
.39533 .47607 .40753 .46973 .39388 .4643 .38169 .47096 Metetra
.626 .814 .972 r
.38169 .47096 .39388 .4643 .38009 .45905 .3679 .46593 Metetra
.631 .817 .971 r
.3679 .46593 .38009 .45905 .36615 .45393 .35397 .46097 Metetra
.635 .82 .971 r
.35397 .46097 .36615 .45393 .35206 .44893 .33989 .45607 Metetra
.636 .822 .972 r
.33989 .45607 .35206 .44893 .33782 .44402 .32566 .45123 Metetra
.637 .824 .972 r
.32566 .45123 .33782 .44402 .32343 .43917 .31128 .44644 Metetra
.637 .826 .973 r
.31128 .44644 .32343 .43917 .30888 .43438 .29674 .44168 Metetra
.636 .827 .974 r
.29674 .44168 .30888 .43438 .29417 .42963 .28204 .43694 Metetra
.635 .829 .975 r
.28204 .43694 .29417 .42963 .2793 .4249 .26718 .43222 Metetra
.633 .83 .976 r
.26718 .43222 .2793 .4249 .26426 .42019 .25215 .42751 Metetra
.631 .831 .977 r
.25215 .42751 .26426 .42019 .24905 .41548 .23696 .42281 Metetra
.63 .832 .978 r
.23696 .42281 .24905 .41548 .23367 .41077 .2216 .4181 Metetra
.628 .832 .979 r
.2216 .4181 .23367 .41077 .21812 .40606 .20607 .41339 Metetra
.626 .833 .98 r
.20607 .41339 .21812 .40606 .20239 .40133 .19036 .40866 Metetra
.623 .834 .981 r
.19036 .40866 .20239 .40133 .18647 .39658 .17447 .40391 Metetra
.752 .839 .917 r
.69179 .36991 .70354 .35982 .69308 .35663 .68133 .36728 Metetra
.761 .84 .912 r
.68133 .36728 .69308 .35663 .68253 .35347 .67078 .36477 Metetra
.771 .841 .905 r
.67078 .36477 .68253 .35347 .67187 .35035 .66012 .36241 Metetra
.782 .843 .897 r
.66012 .36241 .67187 .35035 .66112 .3473 .64937 .36026 Metetra
.795 .844 .889 r
.64937 .36026 .66112 .3473 .65026 .34434 .63852 .35838 Metetra
.808 .846 .878 r
.63852 .35838 .65026 .34434 .63931 .34151 .62757 .35685 Metetra
.824 .849 .867 r
.62757 .35685 .63931 .34151 .62825 .33885 .61651 .35582 Metetra
.841 .851 .852 r
.61651 .35582 .62825 .33885 .61708 .33643 .60535 .35546 Metetra
.86 .855 .835 r
.60535 .35546 .61708 .33643 .60581 .33436 .59409 .35607 Metetra
.882 .86 .814 r
.59409 .35607 .60581 .33436 .59443 .33278 .58272 .35809 Metetra
.907 .866 .787 r
.58272 .35809 .59443 .33278 .58294 .33197 .57124 .36224 Metetra
.935 .873 .752 r
.57124 .36224 .58294 .33197 .57134 .33235 .55965 .36968 Metetra
.962 .879 .706 r
.55965 .36968 .57134 .33235 .55963 .33473 .54795 .38229 Metetra
.983 .878 .647 r
.54795 .38229 .55963 .33473 .54781 .34076 .53611 .4026 Metetra
.993 .863 .599 r
.53611 .4026 .54781 .34076 .53588 .35395 .5241 .43195 Metetra
.988 .833 .6 r
.5241 .43195 .53588 .35395 .52382 .38199 .51186 .46473 Metetra
.958 .794 .635 r
.51186 .46473 .52382 .38199 .51156 .43331 .49934 .48812 Metetra
.925 .789 .691 r
.49934 .48812 .51156 .43331 .49896 .48114 .48662 .49707 Metetra
.826 .871 .879 r
.48662 .49707 .49896 .48114 .48609 .49285 .47375 .49676 Metetra
.519 .807 .998 r
.47375 .49676 .48609 .49285 .4731 .48832 .46076 .49252 Metetra
.54 .783 .988 r
.46076 .49252 .4731 .48832 .45999 .481 .44765 .48696 Metetra
.607 .79 .969 r
.44765 .48696 .45999 .481 .44675 .47386 .43441 .48112 Metetra
.644 .796 .956 r
.43441 .48112 .44675 .47386 .43338 .4673 .42104 .47534 Metetra
.663 .802 .949 r
.42104 .47534 .43338 .4673 .41987 .46127 .40753 .46973 Metetra
.673 .807 .947 r
.40753 .46973 .41987 .46127 .40622 .45563 .39388 .4643 Metetra
.678 .812 .947 r
.39388 .4643 .40622 .45563 .39243 .45029 .38009 .45905 Metetra
.679 .816 .949 r
.38009 .45905 .39243 .45029 .37849 .44517 .36615 .45393 Metetra
.679 .82 .951 r
.36615 .45393 .37849 .44517 .36439 .44021 .35206 .44893 Metetra
.677 .823 .953 r
.35206 .44893 .36439 .44021 .35015 .43535 .33782 .44402 Metetra
.674 .825 .956 r
.33782 .44402 .35015 .43535 .33574 .43058 .32343 .43917 Metetra
.671 .827 .958 r
.32343 .43917 .33574 .43058 .32118 .42587 .30888 .43438 Metetra
.668 .829 .961 r
.30888 .43438 .32118 .42587 .30646 .42119 .29417 .42963 Metetra
.665 .831 .963 r
.29417 .42963 .30646 .42119 .29158 .41654 .2793 .4249 Metetra
.661 .832 .965 r
.2793 .4249 .29158 .41654 .27652 .4119 .26426 .42019 Metetra
.658 .833 .967 r
.26426 .42019 .27652 .4119 .2613 .40726 .24905 .41548 Metetra
.654 .834 .969 r
.24905 .41548 .2613 .40726 .2459 .40261 .23367 .41077 Metetra
.651 .835 .971 r
.23367 .41077 .2459 .40261 .23033 .39795 .21812 .40606 Metetra
.647 .836 .973 r
.21812 .40606 .23033 .39795 .21458 .39326 .20239 .40133 Metetra
.644 .836 .974 r
.20239 .40133 .21458 .39326 .19864 .38856 .18647 .39658 Metetra
.726 .831 .93 r
.70354 .35982 .71542 .35089 .70496 .3473 .69308 .35663 Metetra
.733 .831 .926 r
.69308 .35663 .70496 .3473 .69441 .34368 .68253 .35347 Metetra
.741 .832 .921 r
.68253 .35347 .69441 .34368 .68376 .34005 .67187 .35035 Metetra
.749 .832 .915 r
.67187 .35035 .68376 .34005 .673 .33641 .66112 .3473 Metetra
.758 .833 .909 r
.66112 .3473 .673 .33641 .66215 .33277 .65026 .34434 Metetra
.768 .833 .902 r
.65026 .34434 .66215 .33277 .65119 .32912 .63931 .34151 Metetra
.779 .834 .894 r
.63931 .34151 .65119 .32912 .64013 .32547 .62825 .33885 Metetra
.792 .835 .885 r
.62825 .33885 .64013 .32547 .62896 .32185 .61708 .33643 Metetra
.806 .836 .874 r
.61708 .33643 .62896 .32185 .61769 .31827 .60581 .33436 Metetra
.822 .838 .86 r
.60581 .33436 .61769 .31827 .6063 .31475 .59443 .33278 Metetra
.841 .84 .844 r
.59443 .33278 .6063 .31475 .59481 .31133 .58294 .33197 Metetra
.863 .845 .824 r
.58294 .33197 .59481 .31133 .5832 .30808 .57134 .33235 Metetra
.89 .852 .798 r
.57134 .33235 .5832 .30808 .57148 .30511 .55963 .33473 Metetra
.924 .864 .762 r
.55963 .33473 .57148 .30511 .55964 .30263 .54781 .34076 Metetra
.964 .881 .702 r
.54781 .34076 .55964 .30263 .54769 .30107 .53588 .35395 Metetra
.991 .887 .59 r
.53588 .35395 .54769 .30107 .53562 .3015 .52382 .38199 Metetra
.986 .853 .48 r
.52382 .38199 .53562 .3015 .52343 .30745 .51156 .43331 Metetra
.981 .796 .581 r
.51156 .43331 .52343 .30745 .51113 .33758 .49896 .48114 Metetra
.905 .714 .633 r
.49896 .48114 .51113 .33758 .49857 .47401 .48609 .49285 Metetra
.804 .789 .838 r
.48609 .49285 .49857 .47401 .48557 .48089 .4731 .48832 Metetra
.642 .763 .936 r
.4731 .48832 .48557 .48089 .47247 .46845 .45999 .481 Metetra
.729 .767 .883 r
.45999 .481 .47247 .46845 .45925 .46006 .44675 .47386 Metetra
.747 .776 .876 r
.44675 .47386 .45925 .46006 .44589 .45355 .43338 .4673 Metetra
.751 .786 .882 r
.43338 .4673 .44589 .45355 .43238 .44796 .41987 .46127 Metetra
.749 .795 .89 r
.41987 .46127 .43238 .44796 .41873 .44286 .40622 .45563 Metetra
.745 .803 .899 r
.40622 .45563 .41873 .44286 .40494 .43806 .39243 .45029 Metetra
.739 .81 .908 r
.39243 .45029 .40494 .43806 .39099 .43342 .37849 .44517 Metetra
.733 .816 .916 r
.37849 .44517 .39099 .43342 .37689 .42889 .36439 .44021 Metetra
.726 .821 .923 r
.36439 .44021 .37689 .42889 .36264 .42443 .35015 .43535 Metetra
.72 .824 .93 r
.35015 .43535 .36264 .42443 .34823 .42 .33574 .43058 Metetra
.713 .828 .936 r
.33574 .43058 .34823 .42 .33365 .41558 .32118 .42587 Metetra
.706 .83 .941 r
.32118 .42587 .33365 .41558 .31892 .41117 .30646 .42119 Metetra
.7 .832 .946 r
.30646 .42119 .31892 .41117 .30402 .40675 .29158 .41654 Metetra
.694 .834 .95 r
.29158 .41654 .30402 .40675 .28895 .40231 .27652 .4119 Metetra
.688 .836 .954 r
.27652 .4119 .28895 .40231 .27371 .39785 .2613 .40726 Metetra
.683 .837 .957 r
.2613 .40726 .27371 .39785 .2583 .39336 .2459 .40261 Metetra
.677 .838 .96 r
.2459 .40261 .2583 .39336 .24271 .38883 .23033 .39795 Metetra
.672 .838 .963 r
.23033 .39795 .24271 .38883 .22693 .38427 .21458 .39326 Metetra
.667 .839 .966 r
.21458 .39326 .22693 .38427 .21098 .37968 .19864 .38856 Metetra
.703 .824 .94 r
.71542 .35089 .72742 .34287 .71697 .339 .70496 .3473 Metetra
.708 .824 .937 r
.70496 .3473 .71697 .339 .70642 .33507 .69441 .34368 Metetra
.714 .824 .934 r
.69441 .34368 .70642 .33507 .69578 .3311 .68376 .34005 Metetra
.719 .824 .93 r
.68376 .34005 .69578 .3311 .68503 .32708 .673 .33641 Metetra
.726 .824 .926 r
.673 .33641 .68503 .32708 .67418 .323 .66215 .33277 Metetra
.733 .823 .921 r
.66215 .33277 .67418 .323 .66322 .31886 .65119 .32912 Metetra
.74 .823 .915 r
.65119 .32912 .66322 .31886 .65216 .31465 .64013 .32547 Metetra
.748 .822 .909 r
.64013 .32547 .65216 .31465 .641 .31037 .62896 .32185 Metetra
.757 .821 .902 r
.62896 .32185 .641 .31037 .62972 .306 .61769 .31827 Metetra
.767 .82 .894 r
.61769 .31827 .62972 .306 .61834 .30154 .6063 .31475 Metetra
.778 .819 .885 r
.6063 .31475 .61834 .30154 .60684 .29696 .59481 .31133 Metetra
.791 .818 .874 r
.59481 .31133 .60684 .29696 .59524 .29223 .5832 .30808 Metetra
.805 .818 .861 r
.5832 .30808 .59524 .29223 .58351 .28733 .57148 .30511 Metetra
.822 .818 .845 r
.57148 .30511 .58351 .28733 .57168 .28218 .55964 .30263 Metetra
.843 .82 .826 r
.55964 .30263 .57168 .28218 .55972 .27667 .54769 .30107 Metetra
.873 .828 .8 r
.54769 .30107 .55972 .27667 .54764 .27061 .53562 .3015 Metetra
.924 .858 .759 r
.53562 .3015 .54764 .27061 .53545 .26359 .52343 .30745 Metetra
.948 .901 .516 r
.52343 .30745 .53545 .26359 .52313 .25471 .51113 .33758 Metetra
0 0 .286 r
.51113 .33758 .52313 .25471 .5107 .24191 .49857 .47401 Metetra
.892 .689 .621 r
.49857 .47401 .5107 .24191 .49817 .24704 .48557 .48089 Metetra
.871 .669 .628 r
.48557 .48089 .49817 .24704 .48522 .38147 .47247 .46845 Metetra
.862 .691 .67 r
.47247 .46845 .48522 .38147 .47198 .41368 .45925 .46006 Metetra
.85 .722 .721 r
.45925 .46006 .47198 .41368 .45861 .42077 .44589 .45355 Metetra
.839 .747 .762 r
.44589 .45355 .45861 .42077 .4451 .42198 .43238 .44796 Metetra
.828 .767 .795 r
.43238 .44796 .4451 .42198 .43144 .42098 .41873 .44286 Metetra
.816 .783 .822 r
.41873 .44286 .43144 .42098 .41764 .41891 .40494 .43806 Metetra
.804 .796 .844 r
.40494 .43806 .41764 .41891 .40368 .41624 .39099 .43342 Metetra
.792 .806 .863 r
.39099 .43342 .40368 .41624 .38957 .41319 .37689 .42889 Metetra
.781 .814 .879 r
.37689 .42889 .38957 .41319 .37531 .40987 .36264 .42443 Metetra
.77 .82 .892 r
.36264 .42443 .37531 .40987 .36089 .40635 .34823 .42 Metetra
.759 .825 .903 r
.34823 .42 .36089 .40635 .3463 .40268 .33365 .41558 Metetra
.749 .829 .913 r
.33365 .41558 .3463 .40268 .33156 .39887 .31892 .41117 Metetra
.74 .832 .922 r
.31892 .41117 .33156 .39887 .31664 .39496 .30402 .40675 Metetra
.731 .835 .929 r
.30402 .40675 .31664 .39496 .30156 .39095 .28895 .40231 Metetra
.723 .837 .935 r
.28895 .40231 .30156 .39095 .2863 .38686 .27371 .39785 Metetra
.715 .839 .941 r
.27371 .39785 .2863 .38686 .27087 .38268 .2583 .39336 Metetra
.707 .84 .946 r
.2583 .39336 .27087 .38268 .25526 .37843 .24271 .38883 Metetra
.7 .841 .95 r
.24271 .38883 .25526 .37843 .23947 .37411 .22693 .38427 Metetra
.694 .842 .954 r
.22693 .38427 .23947 .37411 .22349 .36971 .21098 .37968 Metetra
.683 .819 .948 r
.72742 .34287 .73956 .33557 .72912 .33149 .71697 .339 Metetra
.687 .819 .946 r
.71697 .339 .72912 .33149 .71857 .32736 .70642 .33507 Metetra
.69 .818 .944 r
.70642 .33507 .71857 .32736 .70793 .32316 .69578 .3311 Metetra
.694 .818 .941 r
.69578 .3311 .70793 .32316 .69719 .31889 .68503 .32708 Metetra
.699 .817 .938 r
.68503 .32708 .69719 .31889 .68634 .31454 .67418 .323 Metetra
.703 .816 .935 r
.67418 .323 .68634 .31454 .67539 .3101 .66322 .31886 Metetra
.708 .815 .932 r
.66322 .31886 .67539 .3101 .66434 .30558 .65216 .31465 Metetra
.713 .813 .928 r
.65216 .31465 .66434 .30558 .65318 .30094 .641 .31037 Metetra
.718 .812 .923 r
.641 .31037 .65318 .30094 .64191 .29618 .62972 .306 Metetra
.723 .81 .919 r
.62972 .306 .64191 .29618 .63053 .29129 .61834 .30154 Metetra
.728 .807 .913 r
.61834 .30154 .63053 .29129 .61903 .28623 .60684 .29696 Metetra
.734 .804 .907 r
.60684 .29696 .61903 .28623 .60743 .28098 .59524 .29223 Metetra
.739 .8 .901 r
.59524 .29223 .60743 .28098 .59571 .27549 .58351 .28733 Metetra
.744 .794 .893 r
.58351 .28733 .59571 .27549 .58388 .2697 .57168 .28218 Metetra
.748 .787 .884 r
.57168 .28218 .58388 .2697 .57193 .26354 .55972 .27667 Metetra
.749 .776 .875 r
.55972 .27667 .57193 .26354 .55986 .25691 .54764 .27061 Metetra
.746 .76 .864 r
.54764 .27061 .55986 .25691 .54767 .24967 .53545 .26359 Metetra
.732 .732 .851 r
.53545 .26359 .54767 .24967 .53537 .24177 .52313 .25471 Metetra
.691 .679 .833 r
.52313 .25471 .53537 .24177 .52295 .23356 .5107 .24191 Metetra
.578 .941 .826 r
.5107 .24191 .52295 .23356 .51043 .22785 .49817 .24704 Metetra
.347 .189 .519 r
.49817 .24704 .51043 .22785 .49778 .23755 .48522 .38147 Metetra
.946 .753 .611 r
.48522 .38147 .49778 .23755 .48486 .2833 .47198 .41368 Metetra
.901 .713 .638 r
.47198 .41368 .48486 .2833 .47158 .3352 .45861 .42077 Metetra
.891 .722 .666 r
.45861 .42077 .47158 .3352 .45806 .36483 .4451 .42198 Metetra
.883 .741 .7 r
.4451 .42198 .45806 .36483 .44439 .37933 .43144 .42098 Metetra
.872 .76 .735 r
.43144 .42098 .44439 .37933 .43056 .38627 .41764 .41891 Metetra
.86 .776 .768 r
.41764 .41891 .43056 .38627 .41659 .38928 .40368 .41624 Metetra
.847 .791 .797 r
.40368 .41624 .41659 .38928 .40246 .39007 .38957 .41319 Metetra
.833 .802 .821 r
.38957 .41319 .40246 .39007 .38818 .38949 .37531 .40987 Metetra
.82 .812 .843 r
.37531 .40987 .38818 .38949 .37375 .388 .36089 .40635 Metetra
.807 .819 .861 r
.36089 .40635 .37375 .388 .35915 .38589 .3463 .40268 Metetra
.794 .825 .876 r
.3463 .40268 .35915 .38589 .34438 .38331 .33156 .39887 Metetra
.782 .83 .89 r
.33156 .39887 .34438 .38331 .32945 .38039 .31664 .39496 Metetra
.77 .834 .901 r
.31664 .39496 .32945 .38039 .31435 .37719 .30156 .39095 Metetra
.76 .837 .911 r
.30156 .39095 .31435 .37719 .29908 .37376 .2863 .38686 Metetra
.75 .84 .919 r
.2863 .38686 .29908 .37376 .28363 .37014 .27087 .38268 Metetra
.74 .841 .927 r
.27087 .38268 .28363 .37014 .268 .36636 .25526 .37843 Metetra
.731 .843 .933 r
.25526 .37843 .268 .36636 .25218 .36244 .23947 .37411 Metetra
.723 .844 .939 r
.23947 .37411 .25218 .36244 .23618 .35839 .22349 .36971 Metetra
.666 .815 .955 r
.73956 .33557 .75182 .32881 .74139 .3246 .72912 .33149 Metetra
.669 .815 .953 r
.72912 .33149 .74139 .3246 .73085 .32032 .71857 .32736 Metetra
.671 .814 .952 r
.71857 .32736 .73085 .32032 .72022 .31597 .70793 .32316 Metetra
.674 .813 .95 r
.70793 .32316 .72022 .31597 .70948 .31153 .69719 .31889 Metetra
.676 .812 .948 r
.69719 .31889 .70948 .31153 .69864 .30702 .68634 .31454 Metetra
.679 .811 .946 r
.68634 .31454 .69864 .30702 .6877 .30241 .67539 .3101 Metetra
.681 .81 .944 r
.67539 .3101 .6877 .30241 .67665 .2977 .66434 .30558 Metetra
.684 .808 .941 r
.66434 .30558 .67665 .2977 .66549 .29288 .65318 .30094 Metetra
.686 .806 .939 r
.65318 .30094 .66549 .29288 .65423 .28794 .64191 .29618 Metetra
.689 .804 .936 r
.64191 .29618 .65423 .28794 .64286 .28286 .63053 .29129 Metetra
.69 .801 .933 r
.63053 .29129 .64286 .28286 .63137 .27762 .61903 .28623 Metetra
.692 .797 .93 r
.61903 .28623 .63137 .27762 .61977 .27221 .60743 .28098 Metetra
.692 .793 .927 r
.60743 .28098 .61977 .27221 .60806 .26659 .59571 .27549 Metetra
.692 .787 .924 r
.59571 .27549 .60806 .26659 .59623 .26075 .58388 .2697 Metetra
.689 .781 .921 r
.58388 .2697 .59623 .26075 .58429 .25465 .57193 .26354 Metetra
.684 .772 .918 r
.57193 .26354 .58429 .25465 .57223 .24827 .55986 .25691 Metetra
.674 .76 .916 r
.55986 .25691 .57223 .24827 .56005 .24162 .54767 .24967 Metetra
.657 .747 .917 r
.54767 .24967 .56005 .24162 .54775 .23479 .53537 .24177 Metetra
.63 .74 .926 r
.53537 .24177 .54775 .23479 .53534 .22811 .52295 .23356 Metetra
.593 .789 .974 r
.52295 .23356 .53534 .22811 .52281 .22257 .51043 .22785 Metetra
.51043 .22785 .52281 .22257 .51017 .22072 .49778 .23755 Metetra
.132 0 .315 r
.49778 .23755 .51017 .22072 .49738 .22787 .48486 .2833 Metetra
.808 .782 .278 r
.48486 .2833 .49738 .22787 .48437 .24967 .47158 .3352 Metetra
.976 .814 .617 r
.47158 .3352 .48437 .24967 .47107 .28203 .45806 .36483 Metetra
.935 .77 .653 r
.45806 .36483 .47107 .28203 .45749 .31218 .44439 .37933 Metetra
.916 .764 .679 r
.44439 .37933 .45749 .31218 .44369 .33373 .43056 .38627 Metetra
.902 .771 .707 r
.43056 .38627 .44369 .33373 .42971 .34745 .41659 .38928 Metetra
.89 .782 .736 r
.41659 .38928 .42971 .34745 .41557 .35574 .40246 .39007 Metetra
.877 .793 .764 r
.40246 .39007 .41557 .35574 .40127 .36047 .38818 .38949 Metetra
.864 .804 .79 r
.38818 .38949 .40127 .36047 .38681 .36284 .37375 .388 Metetra
.85 .813 .813 r
.37375 .388 .38681 .36284 .3722 .3636 .35915 .38589 Metetra
.836 .82 .834 r
.35915 .38589 .3722 .3636 .35741 .36322 .34438 .38331 Metetra
.823 .827 .852 r
.34438 .38331 .35741 .36322 .34246 .36202 .32945 .38039 Metetra
.81 .832 .867 r
.32945 .38039 .34246 .36202 .32734 .36019 .31435 .37719 Metetra
.797 .836 .881 r
.31435 .37719 .32734 .36019 .31205 .35788 .29908 .37376 Metetra
.785 .839 .893 r
.29908 .37376 .31205 .35788 .29658 .35518 .28363 .37014 Metetra
.774 .842 .904 r
.28363 .37014 .29658 .35518 .28093 .35217 .268 .36636 Metetra
.763 .844 .913 r
.268 .36636 .28093 .35217 .26509 .34889 .25218 .36244 Metetra
.753 .846 .921 r
.25218 .36244 .26509 .34889 .24907 .34538 .23618 .35839 Metetra
.652 .812 .96 r
.75182 .32881 .76422 .32249 .75379 .31818 .74139 .3246 Metetra
.654 .811 .959 r
.74139 .3246 .75379 .31818 .74326 .31379 .73085 .32032 Metetra
.655 .811 .958 r
.73085 .32032 .74326 .31379 .73264 .30933 .72022 .31597 Metetra
.656 .81 .957 r
.72022 .31597 .73264 .30933 .72191 .30479 .70948 .31153 Metetra
.658 .809 .956 r
.70948 .31153 .72191 .30479 .71108 .30017 .69864 .30702 Metetra
.659 .807 .954 r
.69864 .30702 .71108 .30017 .70014 .29546 .6877 .30241 Metetra
.66 .806 .953 r
.6877 .30241 .70014 .29546 .6891 .29065 .67665 .2977 Metetra
.661 .804 .952 r
.67665 .2977 .6891 .29065 .67795 .28573 .66549 .29288 Metetra
.662 .803 .95 r
.66549 .29288 .67795 .28573 .66669 .2807 .65423 .28794 Metetra
.662 .8 .949 r
.65423 .28794 .66669 .2807 .65532 .27555 .64286 .28286 Metetra
.662 .798 .947 r
.64286 .28286 .65532 .27555 .64385 .27026 .63137 .27762 Metetra
.661 .795 .946 r
.63137 .27762 .64385 .27026 .63225 .26483 .61977 .27221 Metetra
.66 .791 .945 r
.61977 .27221 .63225 .26483 .62055 .25924 .60806 .26659 Metetra
.657 .787 .944 r
.60806 .26659 .62055 .25924 .60873 .25348 .59623 .26075 Metetra
.652 .782 .943 r
.59623 .26075 .60873 .25348 .59679 .24756 .58429 .25465 Metetra
.645 .777 .943 r
.58429 .25465 .59679 .24756 .58473 .24147 .57223 .24827 Metetra
.635 .771 .945 r
.57223 .24827 .58473 .24147 .57256 .23526 .56005 .24162 Metetra
.621 .767 .949 r
.56005 .24162 .57256 .23526 .56027 .22903 .54775 .23479 Metetra
.602 .768 .959 r
.54775 .23479 .56027 .22903 .54786 .22298 .53534 .22811 Metetra
.579 .792 .98 r
.53534 .22811 .54786 .22298 .53533 .21758 .52281 .22257 Metetra
.542 .868 .994 r
.52281 .22257 .53533 .21758 .52268 .21371 .51017 .22072 Metetra
.346 .786 .618 r
.51017 .22072 .52268 .21371 .5099 .21303 .49738 .22787 Metetra
.49738 .22787 .5099 .21303 .49697 .21797 .48437 .24967 Metetra
.689 .776 .295 r
.48437 .24967 .49697 .21797 .48384 .2307 .47107 .28203 Metetra
.983 .9 .577 r
.47107 .28203 .48384 .2307 .47046 .25057 .45749 .31218 Metetra
.975 .843 .649 r
.45749 .31218 .47046 .25057 .45682 .2732 .44369 .33373 Metetra
.948 .81 .675 r
.44369 .33373 .45682 .2732 .44293 .29373 .42971 .34745 Metetra
.928 .8 .698 r
.42971 .34745 .44293 .29373 .42883 .30981 .41557 .35574 Metetra
.913 .8 .721 r
.41557 .35574 .42883 .30981 .41454 .3214 .40127 .36047 Metetra
.9 .805 .746 r
.40127 .36047 .41454 .3214 .40008 .32928 .38681 .36284 Metetra
.886 .811 .769 r
.38681 .36284 .40008 .32928 .38544 .33436 .3722 .3636 Metetra
.873 .818 .792 r
.3722 .3636 .38544 .33436 .37064 .33736 .35741 .36322 Metetra
.859 .824 .813 r
.35741 .36322 .37064 .33736 .35568 .33882 .34246 .36202 Metetra
.846 .83 .832 r
.34246 .36202 .35568 .33882 .34054 .33911 .32734 .36019 Metetra
.832 .835 .849 r
.32734 .36019 .34054 .33911 .32522 .3385 .31205 .35788 Metetra
.819 .839 .864 r
.31205 .35788 .32522 .3385 .30973 .33719 .29658 .35518 Metetra
.807 .842 .877 r
.29658 .35518 .30973 .33719 .29405 .33532 .28093 .35217 Metetra
.795 .845 .889 r
.28093 .35217 .29405 .33532 .27819 .333 .26509 .34889 Metetra
.783 .847 .899 r
.26509 .34889 .27819 .333 .26215 .3303 .24907 .34538 Metetra
.64 .81 .965 r
.76422 .32249 .77674 .3165 .76632 .31211 .75379 .31818 Metetra
.641 .809 .964 r
.75379 .31818 .76632 .31211 .7558 .30765 .74326 .31379 Metetra
.642 .808 .963 r
.74326 .31379 .7558 .30765 .74518 .30312 .73264 .30933 Metetra
.642 .807 .962 r
.73264 .30933 .74518 .30312 .73447 .29851 .72191 .30479 Metetra
.643 .806 .961 r
.72191 .30479 .73447 .29851 .72364 .29381 .71108 .30017 Metetra
.643 .805 .961 r
.71108 .30017 .72364 .29381 .71271 .28904 .70014 .29546 Metetra
.644 .804 .96 r
.70014 .29546 .71271 .28904 .70168 .28417 .6891 .29065 Metetra
.644 .802 .959 r
.6891 .29065 .70168 .28417 .69054 .2792 .67795 .28573 Metetra
.643 .801 .958 r
.67795 .28573 .69054 .2792 .67929 .27414 .66669 .2807 Metetra
.643 .799 .958 r
.66669 .2807 .67929 .27414 .66793 .26896 .65532 .27555 Metetra
.641 .796 .957 r
.65532 .27555 .66793 .26896 .65646 .26367 .64385 .27026 Metetra
.64 .794 .957 r
.64385 .27026 .65646 .26367 .64487 .25827 .63225 .26483 Metetra
.637 .791 .956 r
.63225 .26483 .64487 .25827 .63317 .25274 .62055 .25924 Metetra
.633 .788 .956 r
.62055 .25924 .63317 .25274 .62136 .24709 .60873 .25348 Metetra
.628 .785 .957 r
.60873 .25348 .62136 .24709 .60943 .24133 .59679 .24756 Metetra
.621 .782 .958 r
.59679 .24756 .60943 .24133 .59738 .23546 .58473 .24147 Metetra
.613 .779 .961 r
.58473 .24147 .59738 .23546 .58521 .22955 .57256 .23526 Metetra
.602 .778 .965 r
.57256 .23526 .58521 .22955 .57292 .22365 .56027 .22903 Metetra
.588 .782 .972 r
.56027 .22903 .57292 .22365 .56051 .21791 .54786 .22298 Metetra
.574 .795 .983 r
.54786 .22298 .56051 .21791 .54798 .21257 .53533 .21758 Metetra
.562 .83 .996 r
.53533 .21758 .54798 .21257 .53533 .20806 .52268 .21371 Metetra
.554 .894 .982 r
.52268 .21371 .53533 .20806 .52255 .20505 .5099 .21303 Metetra
.54 .924 .821 r
.5099 .21303 .52255 .20505 .50962 .20457 .49697 .21797 Metetra
.571 .867 .557 r
.49697 .21797 .50962 .20457 .49655 .20787 .48384 .2307 Metetra
.761 .903 .511 r
.48384 .2307 .49655 .20787 .48328 .21598 .47046 .25057 Metetra
.941 .94 .601 r
.47046 .25057 .48328 .21598 .46979 .22887 .45682 .2732 Metetra
.981 .903 .658 r
.45682 .2732 .46979 .22887 .45606 .24492 .44293 .29373 Metetra
.967 .862 .683 r
.44293 .29373 .45606 .24492 .44209 .26156 .42883 .30981 Metetra
.948 .838 .702 r
.42883 .30981 .44209 .26156 .42788 .27663 .41454 .3214 Metetra
.931 .827 .72 r
.41454 .3214 .42788 .27663 .41346 .28901 .40008 .32928 Metetra
.917 .824 .74 r
.40008 .32928 .41346 .28901 .39885 .29854 .38544 .33436 Metetra
.903 .825 .76 r
.38544 .33436 .39885 .29854 .38405 .30548 .37064 .33736 Metetra
.89 .828 .78 r
.37064 .33736 .38405 .30548 .36907 .31028 .35568 .33882 Metetra
.877 .832 .799 r
.35568 .33882 .36907 .31028 .35392 .31335 .34054 .33911 Metetra
.864 .836 .817 r
.34054 .33911 .35392 .31335 .33859 .31504 .32522 .3385 Metetra
.85 .84 .834 r
.32522 .3385 .33859 .31504 .32308 .31563 .30973 .33719 Metetra
.838 .843 .85 r
.30973 .33719 .32308 .31563 .30738 .31535 .29405 .33532 Metetra
.825 .846 .863 r
.29405 .33532 .30738 .31535 .2915 .31435 .27819 .333 Metetra
.813 .848 .876 r
.27819 .333 .2915 .31435 .27543 .31277 .26215 .3303 Metetra
.63 .808 .968 r
.77674 .3165 .78939 .31077 .77898 .30632 .76632 .31211 Metetra
.63 .807 .968 r
.76632 .31211 .77898 .30632 .76847 .3018 .7558 .30765 Metetra
.631 .807 .967 r
.7558 .30765 .76847 .3018 .75787 .29721 .74518 .30312 Metetra
.631 .806 .967 r
.74518 .30312 .75787 .29721 .74716 .29255 .73447 .29851 Metetra
.631 .805 .966 r
.73447 .29851 .74716 .29255 .73634 .28781 .72364 .29381 Metetra
.631 .804 .966 r
.72364 .29381 .73634 .28781 .72542 .28299 .71271 .28904 Metetra
.63 .802 .965 r
.71271 .28904 .72542 .28299 .7144 .27809 .70168 .28417 Metetra
.63 .801 .965 r
.70168 .28417 .7144 .27809 .70327 .2731 .69054 .2792 Metetra
.629 .8 .964 r
.69054 .2792 .70327 .2731 .69202 .26802 .67929 .27414 Metetra
.628 .798 .964 r
.67929 .27414 .69202 .26802 .68067 .26284 .66793 .26896 Metetra
.626 .796 .964 r
.66793 .26896 .68067 .26284 .66921 .25757 .65646 .26367 Metetra
.624 .794 .964 r
.65646 .26367 .66921 .25757 .65763 .2522 .64487 .25827 Metetra
.621 .792 .964 r
.64487 .25827 .65763 .2522 .64594 .24674 .63317 .25274 Metetra
.617 .79 .965 r
.63317 .25274 .64594 .24674 .63413 .24118 .62136 .24709 Metetra
.612 .788 .966 r
.62136 .24709 .63413 .24118 .6222 .23554 .60943 .24133 Metetra
.606 .786 .967 r
.60943 .24133 .6222 .23554 .61016 .22984 .59738 .23546 Metetra
.599 .785 .97 r
.59738 .23546 .61016 .22984 .59799 .22411 .58521 .22955 Metetra
.591 .785 .973 r
.58521 .22955 .59799 .22411 .58571 .21841 .57292 .22365 Metetra
.581 .789 .978 r
.57292 .22365 .58571 .21841 .5733 .21283 .56051 .21791 Metetra
.572 .798 .985 r
.56051 .21791 .5733 .21283 .56077 .20751 .54798 .21257 Metetra
.565 .816 .992 r
.54798 .21257 .56077 .20751 .54811 .2027 .53533 .20806 Metetra
.566 .852 .997 r
.53533 .20806 .54811 .2027 .53533 .19874 .52255 .20505 Metetra
.581 .906 .98 r
.52255 .20505 .53533 .19874 .52241 .19611 .50962 .20457 Metetra
.621 .957 .905 r
.50962 .20457 .52241 .19611 .50934 .19547 .49655 .20787 Metetra
.693 .974 .776 r
.49655 .20787 .50934 .19547 .49612 .19754 .48328 .21598 Metetra
.805 .978 .691 r
.48328 .21598 .49612 .19754 .48271 .20287 .46979 .22887 Metetra
.911 .973 .679 r
.46979 .22887 .48271 .20287 .46909 .21155 .45606 .24492 Metetra
.961 .943 .691 r
.45606 .24492 .46909 .21155 .45525 .22292 .44209 .26156 Metetra
.967 .906 .704 r
.44209 .26156 .45525 .22292 .44117 .23567 .42788 .27663 Metetra
.956 .876 .715 r
.42788 .27663 .44117 .23567 .42685 .24837 .41346 .28901 Metetra
.942 .858 .728 r
.41346 .28901 .42685 .24837 .41231 .2599 .39885 .29854 Metetra
.929 .848 .743 r
.39885 .29854 .41231 .2599 .39756 .26963 .38405 .30548 Metetra
.915 .843 .759 r
.38405 .30548 .39756 .26963 .38261 .2774 .36907 .31028 Metetra
.902 .842 .775 r
.36907 .31028 .38261 .2774 .36746 .2833 .35392 .31335 Metetra
.89 .843 .792 r
.35392 .31335 .36746 .2833 .35213 .28754 .33859 .31504 Metetra
.877 .844 .809 r
.33859 .31504 .35213 .28754 .33661 .29037 .32308 .31563 Metetra
.864 .846 .824 r
.32308 .31563 .33661 .29037 .3209 .29202 .30738 .31535 Metetra
.852 .849 .839 r
.30738 .31535 .3209 .29202 .305 .29268 .2915 .31435 Metetra
.84 .851 .853 r
.2915 .31435 .305 .29268 .28891 .29251 .27543 .31277 Metetra
.622 .807 .971 r
.78939 .31077 .80217 .30524 .79177 .30074 .77898 .30632 Metetra
.622 .806 .971 r
.77898 .30632 .79177 .30074 .78128 .29618 .76847 .3018 Metetra
.622 .805 .97 r
.76847 .3018 .78128 .29618 .77068 .29154 .75787 .29721 Metetra
.621 .804 .97 r
.75787 .29721 .77068 .29154 .75998 .28684 .74716 .29255 Metetra
.621 .804 .97 r
.74716 .29255 .75998 .28684 .74918 .28207 .73634 .28781 Metetra
.621 .803 .969 r
.73634 .28781 .74918 .28207 .73827 .27722 .72542 .28299 Metetra
.62 .802 .969 r
.72542 .28299 .73827 .27722 .72725 .2723 .7144 .27809 Metetra
.619 .8 .969 r
.7144 .27809 .72725 .2723 .71613 .26729 .70327 .2731 Metetra
.618 .799 .969 r
.70327 .2731 .71613 .26729 .7049 .2622 .69202 .26802 Metetra
.616 .798 .969 r
.69202 .26802 .7049 .2622 .69355 .25703 .68067 .26284 Metetra
.614 .796 .969 r
.68067 .26284 .69355 .25703 .68209 .25178 .66921 .25757 Metetra
.612 .795 .969 r
.66921 .25757 .68209 .25178 .67052 .24645 .65763 .2522 Metetra
.609 .793 .97 r
.65763 .2522 .67052 .24645 .65884 .24103 .64594 .24674 Metetra
.605 .792 .97 r
.64594 .24674 .65884 .24103 .64704 .23554 .63413 .24118 Metetra
.601 .791 .971 r
.63413 .24118 .64704 .23554 .63512 .22999 .6222 .23554 Metetra
.596 .79 .973 r
.6222 .23554 .63512 .22999 .62308 .2244 .61016 .22984 Metetra
.59 .789 .975 r
.61016 .22984 .62308 .2244 .61092 .21879 .59799 .22411 Metetra
.584 .79 .978 r
.59799 .22411 .61092 .21879 .59864 .2132 .58571 .21841 Metetra
.577 .793 .981 r
.58571 .21841 .59864 .2132 .58623 .20771 .5733 .21283 Metetra
.571 .799 .985 r
.5733 .21283 .58623 .20771 .5737 .2024 .56077 .20751 Metetra
.566 .811 .991 r
.56077 .20751 .5737 .2024 .56104 .19742 .54811 .2027 Metetra
.567 .832 .995 r
.54811 .2027 .56104 .19742 .54825 .19297 .53533 .19874 Metetra
.577 .864 .996 r
.53533 .19874 .54825 .19297 .53533 .18931 .52241 .19611 Metetra
.603 .909 .982 r
.52241 .19611 .53533 .18931 .52227 .18681 .50934 .19547 Metetra
.652 .956 .94 r
.50934 .19547 .52227 .18681 .50905 .18588 .49612 .19754 Metetra
.724 .989 .871 r
.49612 .19754 .50905 .18588 .49568 .18698 .48271 .20287 Metetra
.809 .999 .801 r
.48271 .20287 .49568 .18698 .48212 .19044 .46909 .21155 Metetra
.886 .991 .759 r
.46909 .21155 .48212 .19044 .46837 .19636 .45525 .22292 Metetra
.934 .967 .741 r
.45525 .22292 .46837 .19636 .45439 .20444 .44117 .23567 Metetra
.952 .937 .737 r
.44117 .23567 .45439 .20444 .44019 .21402 .42685 .24837 Metetra
.952 .908 .738 r
.42685 .24837 .44019 .21402 .42576 .22419 .41231 .2599 Metetra
.944 .887 .744 r
.41231 .2599 .42576 .22419 .41109 .23411 .39756 .26963 Metetra
.934 .872 .753 r
.39756 .26963 .41109 .23411 .3962 .24312 .38261 .2774 Metetra
.922 .863 .764 r
.38261 .2774 .3962 .24312 .3811 .25084 .36746 .2833 Metetra
.91 .858 .777 r
.36746 .2833 .3811 .25084 .36579 .25715 .35213 .28754 Metetra
.898 .855 .791 r
.35213 .28754 .36579 .25715 .35028 .26205 .33661 .29037 Metetra
.887 .855 .805 r
.33661 .29037 .35028 .26205 .33457 .26564 .3209 .29202 Metetra
.875 .855 .819 r
.3209 .29202 .33457 .26564 .31867 .26808 .305 .29268 Metetra
.863 .856 .833 r
.305 .29268 .31867 .26808 .30257 .26951 .28891 .29251 Metetra
.615 .806 .973 r
.80217 .30524 .81508 .29986 .8047 .29532 .79177 .30074 Metetra
.614 .805 .973 r
.79177 .30074 .8047 .29532 .79421 .29072 .78128 .29618 Metetra
.614 .804 .973 r
.78128 .29618 .79421 .29072 .78363 .28605 .77068 .29154 Metetra
.614 .804 .973 r
.77068 .29154 .78363 .28605 .77294 .28132 .75998 .28684 Metetra
.613 .803 .973 r
.75998 .28684 .77294 .28132 .76214 .27652 .74918 .28207 Metetra
.612 .802 .972 r
.74918 .28207 .76214 .27652 .75125 .27165 .73827 .27722 Metetra
.612 .801 .972 r
.73827 .27722 .75125 .27165 .74024 .2667 .72725 .2723 Metetra
.61 .8 .972 r
.72725 .2723 .74024 .2667 .72913 .26169 .71613 .26729 Metetra
.609 .799 .972 r
.71613 .26729 .72913 .26169 .7179 .2566 .7049 .2622 Metetra
.607 .798 .973 r
.7049 .2622 .7179 .2566 .70657 .25143 .69355 .25703 Metetra
.605 .797 .973 r
.69355 .25703 .70657 .25143 .69512 .24619 .68209 .25178 Metetra
.603 .796 .973 r
.68209 .25178 .69512 .24619 .68356 .24088 .67052 .24645 Metetra
.6 .795 .974 r
.67052 .24645 .68356 .24088 .67188 .23551 .65884 .24103 Metetra
.597 .794 .974 r
.65884 .24103 .67188 .23551 .66008 .23007 .64704 .23554 Metetra
.593 .793 .975 r
.64704 .23554 .66008 .23007 .64817 .22458 .63512 .22999 Metetra
.589 .792 .977 r
.63512 .22999 .64817 .22458 .63614 .21906 .62308 .2244 Metetra
.585 .792 .978 r
.62308 .2244 .63614 .21906 .62398 .21352 .61092 .21879 Metetra
.58 .793 .98 r
.61092 .21879 .62398 .21352 .6117 .208 .59864 .2132 Metetra
.575 .796 .983 r
.59864 .2132 .6117 .208 .5993 .20255 .58623 .20771 Metetra
.57 .8 .986 r
.58623 .20771 .5993 .20255 .58677 .19724 .5737 .2024 Metetra
.567 .809 .99 r
.5737 .2024 .58677 .19724 .57411 .19214 .56104 .19742 Metetra
.567 .822 .993 r
.56104 .19742 .57411 .19214 .56132 .18739 .54825 .19297 Metetra
.573 .842 .996 r
.54825 .19297 .56132 .18739 .54839 .18316 .53533 .18931 Metetra
.588 .871 .994 r
.53533 .18931 .54839 .18316 .53533 .17965 .52227 .18681 Metetra
.617 .908 .983 r
.52227 .18681 .53533 .17965 .52212 .17712 .50905 .18588 Metetra
.664 .947 .958 r
.50905 .18588 .52212 .17712 .50876 .17587 .49568 .18698 Metetra
.727 .979 .915 r
.49568 .18698 .50876 .17587 .49523 .17618 .48212 .19044 Metetra
.796 .996 .865 r
.48212 .19044 .49523 .17618 .48152 .17829 .46837 .19636 Metetra
.859 .994 .822 r
.46837 .19636 .48152 .17829 .46762 .18227 .45439 .20444 Metetra
.905 .979 .792 r
.45439 .20444 .46762 .18227 .4535 .18798 .44019 .21402 Metetra
.93 .956 .775 r
.44019 .21402 .4535 .18798 .43917 .19507 .42576 .22419 Metetra
.939 .932 .768 r
.42576 .22419 .43917 .19507 .4246 .20299 .41109 .23411 Metetra
.938 .911 .766 r
.41109 .23411 .4246 .20299 .4098 .21113 .3962 .24312 Metetra
.932 .895 .769 r
.3962 .24312 .4098 .21113 .39478 .21897 .3811 .25084 Metetra
.923 .883 .776 r
.3811 .25084 .39478 .21897 .37952 .22608 .36579 .25715 Metetra
.913 .875 .785 r
.36579 .25715 .37952 .22608 .36406 .23222 .35028 .26205 Metetra
.903 .869 .795 r
.35028 .26205 .36406 .23222 .34837 .23729 .33457 .26564 Metetra
.892 .866 .806 r
.33457 .26564 .34837 .23729 .33248 .24126 .31867 .26808 Metetra
.881 .865 .818 r
.31867 .26808 .33248 .24126 .31638 .24419 .30257 .26951 Metetra
.609 .805 .975 r
.81508 .29986 .82813 .29459 .81775 .29002 .8047 .29532 Metetra
.608 .804 .975 r
.8047 .29532 .81775 .29002 .80728 .28539 .79421 .29072 Metetra
.608 .804 .975 r
.79421 .29072 .80728 .28539 .79671 .28069 .78363 .28605 Metetra
.607 .803 .975 r
.78363 .28605 .79671 .28069 .78603 .27593 .77294 .28132 Metetra
.607 .802 .975 r
.77294 .28132 .78603 .27593 .77525 .2711 .76214 .27652 Metetra
.606 .802 .975 r
.76214 .27652 .77525 .2711 .76436 .26621 .75125 .27165 Metetra
.605 .801 .975 r
.75125 .27165 .76436 .26621 .75337 .26125 .74024 .2667 Metetra
.604 .8 .975 r
.74024 .2667 .75337 .26125 .74226 .25622 .72913 .26169 Metetra
.602 .799 .975 r
.72913 .26169 .74226 .25622 .73105 .25113 .7179 .2566 Metetra
.601 .798 .975 r
.7179 .2566 .73105 .25113 .71972 .24597 .70657 .25143 Metetra
.599 .797 .976 r
.70657 .25143 .71972 .24597 .70828 .24074 .69512 .24619 Metetra
.597 .797 .976 r
.69512 .24619 .70828 .24074 .69673 .23545 .68356 .24088 Metetra
.594 .796 .977 r
.68356 .24088 .69673 .23545 .68506 .23009 .67188 .23551 Metetra
.591 .795 .977 r
.67188 .23551 .68506 .23009 .67327 .22469 .66008 .23007 Metetra
.588 .795 .978 r
.66008 .23007 .67327 .22469 .66136 .21924 .64817 .22458 Metetra
.585 .794 .979 r
.64817 .22458 .66136 .21924 .64933 .21376 .63614 .21906 Metetra
.581 .795 .981 r
.63614 .21906 .64933 .21376 .63718 .20826 .62398 .21352 Metetra
.577 .796 .982 r
.62398 .21352 .63718 .20826 .62491 .20278 .6117 .208 Metetra
.573 .798 .984 r
.6117 .208 .62491 .20278 .61251 .19735 .5993 .20255 Metetra
.57 .801 .987 r
.5993 .20255 .61251 .19735 .59998 .19201 .58677 .19724 Metetra
.567 .807 .989 r
.58677 .19724 .59998 .19201 .58732 .18682 .57411 .19214 Metetra
.567 .816 .992 r
.57411 .19214 .58732 .18682 .57453 .18188 .56132 .18739 Metetra
.57 .83 .994 r
.56132 .18739 .57453 .18188 .5616 .17728 .54839 .18316 Metetra
.579 .849 .995 r
.54839 .18316 .5616 .17728 .54854 .17317 .53533 .17965 Metetra
.597 .874 .993 r
.53533 .17965 .54854 .17317 .53533 .1697 .52212 .17712 Metetra
.626 .904 .985 r
.52212 .17712 .53533 .1697 .52197 .16707 .50876 .17587 Metetra
.667 .937 .967 r
.50876 .17587 .52197 .16707 .50845 .16548 .49523 .17618 Metetra
.72 .965 .938 r
.49523 .17618 .50845 .16548 .49477 .16515 .48152 .17829 Metetra
.778 .984 .903 r
.48152 .17829 .49477 .16515 .48091 .16621 .46762 .18227 Metetra
.832 .989 .866 r
.46762 .18227 .48091 .16621 .46685 .16874 .4535 .18798 Metetra
.875 .982 .836 r
.4535 .18798 .46685 .16874 .45258 .17269 .43917 .19507 Metetra
.904 .966 .813 r
.43917 .19507 .45258 .17269 .4381 .17783 .4246 .20299 Metetra
.919 .948 .799 r
.4246 .20299 .4381 .17783 .42339 .18384 .4098 .21113 Metetra
.925 .929 .792 r
.4098 .21113 .42339 .18384 .40845 .19031 .39478 .21897 Metetra
.924 .913 .79 r
.39478 .21897 .40845 .19031 .39328 .19683 .37952 .22608 Metetra
.919 .9 .791 r
.37952 .22608 .39328 .19683 .37788 .20303 .36406 .23222 Metetra
.912 .891 .796 r
.36406 .23222 .37788 .20303 .36224 .20865 .34837 .23729 Metetra
.904 .883 .803 r
.34837 .23729 .36224 .20865 .34639 .2135 .33248 .24126 Metetra
.895 .878 .812 r
.33248 .24126 .34639 .2135 .33032 .2175 .31638 .24419 Metetra
.604 .804 .977 r
.82813 .29459 .8413 .28942 .83094 .28481 .81775 .29002 Metetra
.603 .804 .977 r
.81775 .29002 .83094 .28481 .82048 .28015 .80728 .28539 Metetra
.603 .803 .977 r
.80728 .28539 .82048 .28015 .80992 .27542 .79671 .28069 Metetra
.602 .803 .977 r
.79671 .28069 .80992 .27542 .79926 .27063 .78603 .27593 Metetra
.601 .802 .977 r
.78603 .27593 .79926 .27063 .78849 .26579 .77525 .2711 Metetra
.6 .801 .977 r
.77525 .2711 .78849 .26579 .77761 .26087 .76436 .26621 Metetra
.599 .801 .977 r
.76436 .26621 .77761 .26087 .76663 .2559 .75337 .26125 Metetra
.598 .8 .977 r
.75337 .26125 .76663 .2559 .75554 .25086 .74226 .25622 Metetra
.597 .799 .977 r
.74226 .25622 .75554 .25086 .74433 .24576 .73105 .25113 Metetra
.595 .799 .977 r
.73105 .25113 .74433 .24576 .73302 .24059 .71972 .24597 Metetra
.593 .798 .978 r
.71972 .24597 .73302 .24059 .72159 .23536 .70828 .24074 Metetra
.591 .797 .978 r
.70828 .24074 .72159 .23536 .71004 .23008 .69673 .23545 Metetra
.589 .797 .979 r
.69673 .23545 .71004 .23008 .69838 .22474 .68506 .23009 Metetra
.587 .796 .979 r
.68506 .23009 .69838 .22474 .6866 .21935 .67327 .22469 Metetra
.584 .796 .98 r
.67327 .22469 .6866 .21935 .6747 .21393 .66136 .21924 Metetra
.581 .796 .981 r
.66136 .21924 .6747 .21393 .66268 .20847 .64933 .21376 Metetra
.578 .796 .982 r
.64933 .21376 .66268 .20847 .65053 .203 .63718 .20826 Metetra
.575 .797 .984 r
.63718 .20826 .65053 .203 .63826 .19753 .62491 .20278 Metetra
.572 .799 .985 r
.62491 .20278 .63826 .19753 .62586 .19209 .61251 .19735 Metetra
.569 .802 .987 r
.61251 .19735 .62586 .19209 .61334 .18672 .59998 .19201 Metetra
.567 .807 .989 r
.59998 .19201 .61334 .18672 .60068 .18146 .58732 .18682 Metetra
.567 .813 .991 r
.58732 .18682 .60068 .18146 .58789 .17637 .57453 .18188 Metetra
.569 .823 .993 r
.57453 .18188 .58789 .17637 .57496 .17152 .5616 .17728 Metetra
.575 .836 .994 r
.5616 .17728 .57496 .17152 .56189 .16701 .54854 .17317 Metetra
.585 .853 .995 r
.54854 .17317 .56189 .16701 .54869 .16294 .53533 .1697 Metetra
.603 .875 .992 r
.53533 .1697 .54869 .16294 .53533 .15944 .52197 .16707 Metetra
.63 .9 .985 r
.52197 .16707 .53533 .15944 .52182 .15666 .50845 .16548 Metetra
.667 .927 .972 r
.50845 .16548 .52182 .15666 .50814 .15475 .49477 .16515 Metetra
.712 .952 .952 r
.49477 .16515 .50814 .15475 .4943 .15386 .48091 .16621 Metetra
.76 .97 .926 r
.48091 .16621 .4943 .15386 .48028 .15409 .46685 .16874 Metetra
.807 .979 .897 r
.46685 .16874 .48028 .15409 .46606 .1555 .45258 .17269 Metetra
.847 .978 .87 r
.45258 .17269 .46606 .1555 .45164 .15807 .4381 .17783 Metetra
.877 .969 .847 r
.4381 .17783 .45164 .15807 .437 .16167 .42339 .18384 Metetra
.897 .956 .829 r
.42339 .18384 .437 .16167 .42214 .1661 .40845 .19031 Metetra
.907 .941 .818 r
.40845 .19031 .42214 .1661 .40704 .17108 .39328 .19683 Metetra
.911 .927 .812 r
.39328 .19683 .40704 .17108 .39172 .1763 .37788 .20303 Metetra
.91 .915 .81 r
.37788 .20303 .39172 .1763 .37615 .18147 .36224 .20865 Metetra
.906 .904 .811 r
.36224 .20865 .37615 .18147 .36036 .18635 .34639 .2135 Metetra
.9 .896 .814 r
.34639 .2135 .36036 .18635 .34433 .19073 .33032 .2175 Metetra
.599 .804 .978 r
.8413 .28942 .85461 .28431 .84427 .27967 .83094 .28481 Metetra
.599 .804 .978 r
.83094 .28481 .84427 .27967 .83382 .27498 .82048 .28015 Metetra
.598 .803 .978 r
.82048 .28015 .83382 .27498 .82328 .27022 .80992 .27542 Metetra
.598 .803 .978 r
.80992 .27542 .82328 .27022 .81262 .26541 .79926 .27063 Metetra
.597 .802 .978 r
.79926 .27063 .81262 .26541 .80187 .26054 .78849 .26579 Metetra
.596 .801 .978 r
.78849 .26579 .80187 .26054 .791 .2556 .77761 .26087 Metetra
.595 .801 .978 r
.77761 .26087 .791 .2556 .78003 .25061 .76663 .2559 Metetra
.594 .8 .979 r
.76663 .2559 .78003 .25061 .76895 .24556 .75554 .25086 Metetra
.592 .8 .979 r
.75554 .25086 .76895 .24556 .75776 .24044 .74433 .24576 Metetra
.591 .799 .979 r
.74433 .24576 .75776 .24044 .74645 .23527 .73302 .24059 Metetra
.589 .799 .979 r
.73302 .24059 .74645 .23527 .73503 .23004 .72159 .23536 Metetra
.588 .798 .98 r
.72159 .23536 .73503 .23004 .7235 .22476 .71004 .23008 Metetra
.586 .798 .98 r
.71004 .23008 .7235 .22476 .71185 .21942 .69838 .22474 Metetra
.583 .797 .981 r
.69838 .22474 .71185 .21942 .70007 .21404 .6866 .21935 Metetra
.581 .797 .982 r
.6866 .21935 .70007 .21404 .68818 .20862 .6747 .21393 Metetra
.579 .797 .982 r
.6747 .21393 .68818 .20862 .67616 .20317 .66268 .20847 Metetra
.576 .798 .983 r
.66268 .20847 .67616 .20317 .66402 .1977 .65053 .203 Metetra
.574 .799 .984 r
.65053 .203 .66402 .1977 .65176 .19223 .63826 .19753 Metetra
.571 .8 .986 r
.63826 .19753 .65176 .19223 .63937 .18678 .62586 .19209 Metetra
.569 .803 .987 r
.62586 .19209 .63937 .18678 .62684 .18138 .61334 .18672 Metetra
.568 .806 .989 r
.61334 .18672 .62684 .18138 .61419 .17605 .60068 .18146 Metetra
.567 .811 .99 r
.60068 .18146 .61419 .17605 .6014 .17084 .58789 .17637 Metetra
.568 .818 .992 r
.58789 .17637 .6014 .17084 .58847 .16581 .57496 .17152 Metetra
.572 .827 .993 r
.57496 .17152 .58847 .16581 .5754 .16101 .56189 .16701 Metetra
.579 .84 .994 r
.56189 .16701 .5754 .16101 .56219 .15652 .54869 .16294 Metetra
.591 .855 .994 r
.54869 .16294 .56219 .15652 .54884 .15244 .53533 .15944 Metetra
.608 .874 .991 r
.53533 .15944 .54884 .15244 .53533 .14887 .52182 .15666 Metetra
.633 .896 .986 r
.52182 .15666 .53533 .14887 .52166 .14591 .50814 .15475 Metetra
.665 .918 .976 r
.50814 .15475 .52166 .14591 .50783 .14369 .4943 .15386 Metetra
.703 .94 .961 r
.4943 .15386 .50783 .14369 .49382 .1423 .48028 .15409 Metetra
.744 .957 .942 r
.48028 .15409 .49382 .1423 .47963 .14184 .46606 .1555 Metetra
.785 .968 .919 r
.46606 .1555 .47963 .14184 .46525 .14235 .45164 .15807 Metetra
.821 .971 .896 r
.45164 .15807 .46525 .14235 .45066 .14382 .437 .16167 Metetra
.851 .967 .874 r
.437 .16167 .45066 .14382 .43586 .14618 .42214 .1661 Metetra
.873 .959 .857 r
.42214 .1661 .43586 .14618 .42083 .14929 .40704 .17108 Metetra
.887 .948 .843 r
.40704 .17108 .42083 .14929 .40558 .15297 .39172 .1763 Metetra
.895 .937 .834 r
.39172 .1763 .40558 .15297 .39009 .15699 .37615 .18147 Metetra
.898 .926 .829 r
.37615 .18147 .39009 .15699 .37436 .16112 .36036 .18635 Metetra
.897 .916 .827 r
.36036 .18635 .37436 .16112 .3584 .16516 .34433 .19073 Metetra
.596 .804 .979 r
.85461 .28431 .86806 .27925 .85773 .27458 .84427 .27967 Metetra
.595 .803 .979 r
.84427 .27967 .85773 .27458 .8473 .26986 .83382 .27498 Metetra
.595 .803 .979 r
.83382 .27498 .8473 .26986 .83677 .26507 .82328 .27022 Metetra
.594 .802 .979 r
.82328 .27022 .83677 .26507 .82613 .26024 .81262 .26541 Metetra
.593 .802 .98 r
.81262 .26541 .82613 .26024 .81539 .25534 .80187 .26054 Metetra
.592 .802 .98 r
.80187 .26054 .81539 .25534 .80454 .25038 .791 .2556 Metetra
.591 .801 .98 r
.791 .2556 .80454 .25038 .79358 .24537 .78003 .25061 Metetra
.59 .801 .98 r
.78003 .25061 .79358 .24537 .78251 .2403 .76895 .24556 Metetra
.589 .8 .98 r
.76895 .24556 .78251 .2403 .77133 .23517 .75776 .24044 Metetra
.587 .8 .98 r
.75776 .24044 .77133 .23517 .76003 .22998 .74645 .23527 Metetra
.586 .799 .981 r
.74645 .23527 .76003 .22998 .74862 .22474 .73503 .23004 Metetra
.584 .799 .981 r
.73503 .23004 .74862 .22474 .7371 .21945 .7235 .22476 Metetra
.583 .799 .982 r
.7235 .22476 .7371 .21945 .72546 .21411 .71185 .21942 Metetra
.581 .798 .982 r
.71185 .21942 .72546 .21411 .71369 .20873 .70007 .21404 Metetra
.579 .798 .983 r
.70007 .21404 .71369 .20873 .70181 .2033 .68818 .20862 Metetra
.577 .799 .983 r
.68818 .20862 .70181 .2033 .6898 .19785 .67616 .20317 Metetra
.575 .799 .984 r
.67616 .20317 .6898 .19785 .67767 .19237 .66402 .1977 Metetra
.573 .8 .985 r
.66402 .1977 .67767 .19237 .66541 .18689 .65176 .19223 Metetra
.571 .801 .986 r
.65176 .19223 .66541 .18689 .65302 .18141 .63937 .18678 Metetra
.569 .803 .987 r
.63937 .18678 .65302 .18141 .6405 .17597 .62684 .18138 Metetra
.568 .806 .989 r
.62684 .18138 .6405 .17597 .62785 .17058 .61419 .17605 Metetra
.567 .81 .99 r
.61419 .17605 .62785 .17058 .61506 .16527 .6014 .17084 Metetra
.568 .815 .991 r
.6014 .17084 .61506 .16527 .60213 .16009 .58847 .16581 Metetra
.57 .822 .993 r
.58847 .16581 .60213 .16009 .58907 .15507 .5754 .16101 Metetra
.575 .831 .994 r
.5754 .16101 .58907 .15507 .57586 .15029 .56219 .15652 Metetra
.583 .843 .994 r
.56219 .15652 .57586 .15029 .5625 .14579 .54884 .15244 Metetra
.595 .857 .993 r
.54884 .15244 .5625 .14579 .54899 .14166 .53533 .14887 Metetra
.612 .873 .991 r
.53533 .14887 .54899 .14166 .53533 .13798 .52166 .14591 Metetra
.634 .891 .986 r
.52166 .14591 .53533 .13798 .5215 .13483 .50783 .14369 Metetra
.662 .911 .979 r
.50783 .14369 .5215 .13483 .5075 .1323 .49382 .1423 Metetra
.694 .929 .967 r
.49382 .1423 .5075 .1323 .49333 .13048 .47963 .14184 Metetra
.729 .945 .952 r
.47963 .14184 .49333 .13048 .47897 .12943 .46525 .14235 Metetra
.765 .956 .934 r
.46525 .14235 .47897 .12943 .46442 .12918 .45066 .14382 Metetra
.798 .962 .915 r
.45066 .14382 .46442 .12918 .44966 .12975 .43586 .14618 Metetra
.827 .962 .896 r
.43586 .14618 .44966 .12975 .43469 .13108 .42083 .14929 Metetra
.849 .958 .88 r
.42083 .14929 .43469 .13108 .41949 .13308 .40558 .15297 Metetra
.866 .951 .866 r
.40558 .15297 .41949 .13308 .40407 .13563 .39009 .15699 Metetra
.877 .942 .855 r
.39009 .15699 .40407 .13563 .38841 .13856 .37436 .16112 Metetra
.883 .933 .848 r
.37436 .16112 .38841 .13856 .3725 .14171 .3584 .16516 Metetra
.593 .804 .98 r
.86806 .27925 .88165 .27423 .87134 .26952 .85773 .27458 Metetra
.592 .803 .98 r
.85773 .27458 .87134 .26952 .86092 .26477 .8473 .26986 Metetra
.591 .803 .98 r
.8473 .26986 .86092 .26477 .8504 .25996 .83677 .26507 Metetra
.591 .802 .981 r
.83677 .26507 .8504 .25996 .83978 .25509 .82613 .26024 Metetra
.59 .802 .981 r
.82613 .26024 .83978 .25509 .82905 .25017 .81539 .25534 Metetra
.589 .802 .981 r
.81539 .25534 .82905 .25017 .81821 .24519 .80454 .25038 Metetra
.588 .801 .981 r
.80454 .25038 .81821 .24519 .80727 .24015 .79358 .24537 Metetra
.587 .801 .981 r
.79358 .24537 .80727 .24015 .79621 .23506 .78251 .2403 Metetra
.586 .8 .981 r
.78251 .2403 .79621 .23506 .78504 .22991 .77133 .23517 Metetra
.585 .8 .982 r
.77133 .23517 .78504 .22991 .77376 .22471 .76003 .22998 Metetra
.583 .8 .982 r
.76003 .22998 .77376 .22471 .76236 .21945 .74862 .22474 Metetra
.582 .799 .982 r
.74862 .22474 .76236 .21945 .75085 .21415 .7371 .21945 Metetra
.58 .799 .983 r
.7371 .21945 .75085 .21415 .73921 .20879 .72546 .21411 Metetra
.579 .799 .983 r
.72546 .21411 .73921 .20879 .72746 .2034 .71369 .20873 Metetra
.577 .799 .984 r
.71369 .20873 .72746 .2034 .71558 .19796 .70181 .2033 Metetra
.575 .799 .984 r
.70181 .2033 .71558 .19796 .70358 .19249 .6898 .19785 Metetra
.573 .8 .985 r
.6898 .19785 .70358 .19249 .69146 .187 .67767 .19237 Metetra
.572 .801 .986 r
.67767 .19237 .69146 .187 .67921 .1815 .66541 .18689 Metetra
.57 .802 .987 r
.66541 .18689 .67921 .1815 .66682 .17599 .65302 .18141 Metetra
.569 .803 .988 r
.65302 .18141 .66682 .17599 .65431 .1705 .6405 .17597 Metetra
.568 .806 .989 r
.6405 .17597 .65431 .1705 .64166 .16504 .62785 .17058 Metetra
.567 .809 .99 r
.62785 .17058 .64166 .16504 .62887 .15965 .61506 .16527 Metetra
.568 .813 .991 r
.61506 .16527 .62887 .15965 .61595 .15434 .60213 .16009 Metetra
.569 .818 .992 r
.60213 .16009 .61595 .15434 .60289 .14916 .58907 .15507 Metetra
.573 .825 .993 r
.58907 .15507 .60289 .14916 .58968 .14414 .57586 .15029 Metetra
.578 .834 .993 r
.57586 .15029 .58968 .14414 .57632 .13933 .5625 .14579 Metetra
.586 .844 .994 r
.5625 .14579 .57632 .13933 .56281 .13479 .54899 .14166 Metetra
.598 .857 .993 r
.54899 .14166 .56281 .13479 .54915 .13058 .53533 .13798 Metetra
.614 .871 .991 r
.53533 .13798 .54915 .13058 .53532 .12676 .5215 .13483 Metetra
.634 .887 .987 r
.5215 .13483 .53532 .12676 .52133 .12341 .5075 .1323 Metetra
.658 .904 .98 r
.5075 .1323 .52133 .12341 .50717 .1206 .49333 .13048 Metetra
.686 .92 .971 r
.49333 .13048 .50717 .1206 .49283 .11838 .47897 .12943 Metetra
.717 .935 .96 r
.47897 .12943 .49283 .11838 .47829 .11681 .46442 .12918 Metetra
.748 .946 .945 r
.46442 .12918 .47829 .11681 .46357 .11592 .44966 .12975 Metetra
.778 .953 .93 r
.44966 .12975 .46357 .11592 .44863 .11572 .43469 .13108 Metetra
.805 .956 .914 r
.43469 .13108 .44863 .11572 .43348 .11618 .41949 .13308 Metetra
.827 .954 .899 r
.41949 .13308 .43348 .11618 .41811 .11724 .40407 .13563 Metetra
.845 .95 .885 r
.40407 .13563 .41811 .11724 .40251 .11881 .38841 .13856 Metetra
.858 .944 .874 r
.38841 .13856 .40251 .11881 .38666 .12077 .3725 .14171 Metetra
.59 .804 .981 r
.88165 .27423 .89538 .26922 .88508 .26449 .87134 .26952 Metetra
.589 .803 .981 r
.87134 .26952 .88508 .26449 .87468 .2597 .86092 .26477 Metetra
.589 .803 .981 r
.86092 .26477 .87468 .2597 .86418 .25486 .8504 .25996 Metetra
.588 .803 .981 r
.8504 .25996 .86418 .25486 .85357 .24996 .83978 .25509 Metetra
.587 .802 .982 r
.83978 .25509 .85357 .24996 .84285 .24501 .82905 .25017 Metetra
.586 .802 .982 r
.82905 .25017 .84285 .24501 .83203 .24 .81821 .24519 Metetra
.586 .801 .982 r
.81821 .24519 .83203 .24 .8211 .23494 .80727 .24015 Metetra
.585 .801 .982 r
.80727 .24015 .8211 .23494 .81006 .22982 .79621 .23506 Metetra
.584 .801 .982 r
.79621 .23506 .81006 .22982 .7989 .22465 .78504 .22991 Metetra
.582 .8 .982 r
.78504 .22991 .7989 .22465 .78763 .21943 .77376 .22471 Metetra
.581 .8 .983 r
.77376 .22471 .78763 .21943 .77625 .21416 .76236 .21945 Metetra
.58 .8 .983 r
.76236 .21945 .77625 .21416 .76474 .20883 .75085 .21415 Metetra
.579 .8 .983 r
.75085 .21415 .76474 .20883 .75312 .20346 .73921 .20879 Metetra
.577 .8 .984 r
.73921 .20879 .75312 .20346 .74138 .19804 .72746 .2034 Metetra
.576 .8 .984 r
.72746 .2034 .74138 .19804 .72951 .19259 .71558 .19796 Metetra
.574 .8 .985 r
.71558 .19796 .72951 .19259 .71752 .1871 .70358 .19249 Metetra
.573 .801 .986 r
.70358 .19249 .71752 .1871 .7054 .18158 .69146 .187 Metetra
.571 .801 .986 r
.69146 .187 .7054 .18158 .69316 .17605 .67921 .1815 Metetra
.57 .802 .987 r
.67921 .1815 .69316 .17605 .68078 .17051 .66682 .17599 Metetra
.569 .804 .988 r
.66682 .17599 .68078 .17051 .66827 .16497 .65431 .1705 Metetra
.568 .806 .989 r
.65431 .1705 .66827 .16497 .65563 .15945 .64166 .16504 Metetra
.567 .808 .99 r
.64166 .16504 .65563 .15945 .64285 .15397 .62887 .15965 Metetra
.568 .812 .99 r
.62887 .15965 .64285 .15397 .62993 .14856 .61595 .15434 Metetra
.569 .816 .991 r
.61595 .15434 .62993 .14856 .61686 .14323 .60289 .14916 Metetra
.571 .821 .992 r
.60289 .14916 .61686 .14323 .60366 .13802 .58968 .14414 Metetra
.575 .828 .993 r
.58968 .14414 .60366 .13802 .5903 .13297 .57632 .13933 Metetra
.581 .836 .993 r
.57632 .13933 .5903 .13297 .57679 .12812 .56281 .13479 Metetra
.589 .846 .993 r
.56281 .13479 .57679 .12812 .56313 .12351 .54915 .13058 Metetra
.6 .857 .992 r
.54915 .13058 .56313 .12351 .54931 .11919 .53532 .12676 Metetra
.615 .87 .99 r
.53532 .12676 .54931 .11919 .53532 .11522 .52133 .12341 Metetra
.633 .884 .987 r
.52133 .12341 .53532 .11522 .52116 .11167 .50717 .1206 Metetra
.655 .898 .982 r
.50717 .1206 .52116 .11167 .50683 .10857 .49283 .11838 Metetra
.679 .912 .974 r
.49283 .11838 .50683 .10857 .49231 .10599 .47829 .11681 Metetra
.706 .925 .965 r
.47829 .11681 .49231 .10599 .4776 .10395 .46357 .11592 Metetra
.733 .936 .954 r
.46357 .11592 .4776 .10395 .46269 .1025 .44863 .11572 Metetra
.76 .944 .941 r
.44863 .11572 .46269 .1025 .44758 .10164 .43348 .11618 Metetra
.785 .948 .927 r
.43348 .11618 .44758 .10164 .43224 .10135 .41811 .11724 Metetra
.807 .949 .914 r
.41811 .11724 .43224 .10135 .41669 .10159 .40251 .11881 Metetra
.825 .948 .902 r
.40251 .11881 .41669 .10159 .4009 .1023 .38666 .12077 Metetra
.588 .804 .982 r
.89538 .26922 .90925 .26422 .89897 .25946 .88508 .26449 Metetra
.587 .803 .982 r
.88508 .26449 .89897 .25946 .88858 .25464 .87468 .2597 Metetra
.586 .803 .982 r
.87468 .2597 .88858 .25464 .8781 .24976 .86418 .25486 Metetra
.586 .803 .982 r
.86418 .25486 .8781 .24976 .8675 .24484 .85357 .24996 Metetra
.585 .802 .982 r
.85357 .24996 .8675 .24484 .85681 .23986 .84285 .24501 Metetra
.584 .802 .982 r
.84285 .24501 .85681 .23986 .846 .23482 .83203 .24 Metetra
.583 .802 .983 r
.83203 .24 .846 .23482 .83508 .22973 .8211 .23494 Metetra
.583 .801 .983 r
.8211 .23494 .83508 .22973 .82405 .22459 .81006 .22982 Metetra
.582 .801 .983 r
.81006 .22982 .82405 .22459 .81291 .21939 .7989 .22465 Metetra
.581 .801 .983 r
.7989 .22465 .81291 .21939 .80166 .21414 .78763 .21943 Metetra
.579 .801 .983 r
.78763 .21943 .80166 .21414 .79028 .20884 .77625 .21416 Metetra
.578 .801 .984 r
.77625 .21416 .79028 .20884 .77879 .20349 .76474 .20883 Metetra
.577 .8 .984 r
.76474 .20883 .77879 .20349 .76718 .1981 .75312 .20346 Metetra
.576 .801 .984 r
.75312 .20346 .76718 .1981 .75545 .19266 .74138 .19804 Metetra
.575 .801 .985 r
.74138 .19804 .75545 .19266 .74359 .18718 .72951 .19259 Metetra
.573 .801 .985 r
.72951 .19259 .74359 .18718 .73161 .18166 .71752 .1871 Metetra
.572 .801 .986 r
.71752 .1871 .73161 .18166 .71951 .17611 .7054 .18158 Metetra
.571 .802 .987 r
.7054 .18158 .71951 .17611 .70727 .17054 .69316 .17605 Metetra
.57 .803 .987 r
.69316 .17605 .70727 .17054 .6949 .16496 .68078 .17051 Metetra
.569 .804 .988 r
.68078 .17051 .6949 .16496 .6824 .15937 .66827 .16497 Metetra
.568 .806 .989 r
.66827 .16497 .6824 .15937 .66976 .1538 .65563 .15945 Metetra
.567 .808 .989 r
.65563 .15945 .66976 .1538 .65698 .14824 .64285 .15397 Metetra
.568 .811 .99 r
.64285 .15397 .65698 .14824 .64407 .14273 .62993 .14856 Metetra
.568 .814 .991 r
.62993 .14856 .64407 .14273 .63101 .13727 .61686 .14323 Metetra
.57 .818 .992 r
.61686 .14323 .63101 .13727 .6178 .13191 .60366 .13802 Metetra
.573 .824 .992 r
.60366 .13802 .6178 .13191 .60445 .12666 .5903 .13297 Metetra
.577 .83 .993 r
.5903 .13297 .60445 .12666 .59094 .12155 .57679 .12812 Metetra
.583 .838 .993 r
.57679 .12812 .59094 .12155 .57728 .11663 .56313 .12351 Metetra
.592 .846 .993 r
.56313 .12351 .57728 .11663 .56346 .11192 .54931 .11919 Metetra
.602 .857 .992 r
.54931 .11919 .56346 .11192 .54947 .10749 .53532 .11522 Metetra
.616 .868 .99 r
.53532 .11522 .54947 .10749 .53532 .10336 .52116 .11167 Metetra
.632 .88 .987 r
.52116 .11167 .53532 .10336 .52099 .09959 .50683 .10857 Metetra
.651 .893 .983 r
.50683 .10857 .52099 .09959 .50648 .09622 .49231 .10599 Metetra
.673 .906 .977 r
.49231 .10599 .50648 .09622 .49178 .09329 .4776 .10395 Metetra
.696 .917 .969 r
.4776 .10395 .49178 .09329 .47689 .09084 .46269 .1025 Metetra
.721 .927 .96 r
.46269 .1025 .47689 .09084 .4618 .08889 .44758 .10164 Metetra
.745 .935 .949 r
.44758 .10164 .4618 .08889 .44649 .08744 .43224 .10135 Metetra
.767 .941 .938 r
.43224 .10135 .44649 .08744 .43097 .08649 .41669 .10159 Metetra
.788 .943 .926 r
.41669 .10159 .43097 .08649 .41522 .08602 .4009 .1023 Metetra
.586 .804 .983 r
.90925 .26422 .92326 .25922 .913 .25442 .89897 .25946 Metetra
.585 .803 .983 r
.89897 .25946 .913 .25442 .90263 .24957 .88858 .25464 Metetra
.584 .803 .983 r
.88858 .25464 .90263 .24957 .89216 .24467 .8781 .24976 Metetra
.584 .803 .983 r
.8781 .24976 .89216 .24467 .88159 .23971 .8675 .24484 Metetra
.583 .802 .983 r
.8675 .24484 .88159 .23971 .8709 .2347 .85681 .23986 Metetra
.582 .802 .983 r
.85681 .23986 .8709 .2347 .86011 .22963 .846 .23482 Metetra
.582 .802 .983 r
.846 .23482 .86011 .22963 .84921 .22451 .83508 .22973 Metetra
.581 .802 .983 r
.83508 .22973 .84921 .22451 .8382 .21934 .82405 .22459 Metetra
.58 .801 .984 r
.82405 .22459 .8382 .21934 .82707 .21411 .81291 .21939 Metetra
.579 .801 .984 r
.81291 .21939 .82707 .21411 .81583 .20883 .80166 .21414 Metetra
.578 .801 .984 r
.80166 .21414 .81583 .20883 .80447 .2035 .79028 .20884 Metetra
.577 .801 .984 r
.79028 .20884 .80447 .2035 .793 .19813 .77879 .20349 Metetra
.576 .801 .985 r
.77879 .20349 .793 .19813 .7814 .1927 .76718 .1981 Metetra
.575 .801 .985 r
.76718 .1981 .7814 .1927 .76968 .18723 .75545 .19266 Metetra
.574 .801 .985 r
.75545 .19266 .76968 .18723 .75783 .18172 .74359 .18718 Metetra
.572 .801 .986 r
.74359 .18718 .75783 .18172 .74586 .17617 .73161 .18166 Metetra
.571 .802 .986 r
.73161 .18166 .74586 .17617 .73376 .17059 .71951 .17611 Metetra
.57 .802 .987 r
.71951 .17611 .73376 .17059 .72154 .16498 .70727 .17054 Metetra
.569 .803 .987 r
.70727 .17054 .72154 .16498 .70918 .15935 .6949 .16496 Metetra
.568 .804 .988 r
.6949 .16496 .70918 .15935 .69668 .15372 .6824 .15937 Metetra
.568 .806 .989 r
.6824 .15937 .69668 .15372 .68405 .14807 .66976 .1538 Metetra
.567 .808 .989 r
.66976 .1538 .68405 .14807 .67128 .14244 .65698 .14824 Metetra
.568 .81 .99 r
.65698 .14824 .67128 .14244 .65837 .13684 .64407 .14273 Metetra
.568 .813 .991 r
.64407 .14273 .65837 .13684 .64531 .13127 .63101 .13727 Metetra
.569 .816 .991 r
.63101 .13727 .64531 .13127 .63211 .12577 .6178 .13191 Metetra
.572 .82 .992 r
.6178 .13191 .63211 .12577 .61876 .12035 .60445 .12666 Metetra
.575 .825 .992 r
.60445 .12666 .61876 .12035 .60526 .11504 .59094 .12155 Metetra
.579 .832 .993 r
.59094 .12155 .60526 .11504 .5916 .10986 .57728 .11663 Metetra
.585 .839 .993 r
.57728 .11663 .5916 .10986 .57778 .10485 .56346 .11192 Metetra
.593 .847 .992 r
.56346 .11192 .57778 .10485 .56379 .10003 .54947 .10749 Metetra
.604 .856 .992 r
.54947 .10749 .56379 .10003 .54964 .09546 .53532 .10336 Metetra
.616 .866 .99 r
.53532 .10336 .54964 .09546 .53532 .09116 .52099 .09959 Metetra
.631 .877 .987 r
.52099 .09959 .53532 .09116 .52081 .08717 .50648 .09622 Metetra
.648 .888 .984 r
.50648 .09622 .52081 .08717 .50612 .08354 .49178 .09329 Metetra
.667 .899 .979 r
.49178 .09329 .50612 .08354 .49124 .08029 .47689 .09084 Metetra
.688 .91 .972 r
.47689 .09084 .49124 .08029 .47617 .07745 .4618 .08889 Metetra
.709 .92 .965 r
.4618 .08889 .47617 .07745 .46088 .07504 .44649 .08744 Metetra
.731 .927 .956 r
.44649 .08744 .46088 .07504 .44538 .07307 .43097 .08649 Metetra
.752 .933 .946 r
.43097 .08649 .44538 .07307 .42966 .07153 .41522 .08602 Metetra
.584 .804 .983 r
.92326 .25922 .93742 .25422 .92718 .24939 .913 .25442 Metetra
.583 .803 .983 r
.913 .25442 .92718 .24939 .91683 .2445 .90263 .24957 Metetra
.583 .803 .983 r
.90263 .24957 .91683 .2445 .90638 .23956 .89216 .24467 Metetra
.582 .803 .983 r
.89216 .24467 .90638 .23956 .89582 .23457 .88159 .23971 Metetra
.582 .803 .984 r
.88159 .23971 .89582 .23457 .88515 .22952 .8709 .2347 Metetra
.581 .802 .984 r
.8709 .2347 .88515 .22952 .87438 .22442 .86011 .22963 Metetra
.58 .802 .984 r
.86011 .22963 .87438 .22442 .8635 .21927 .84921 .22451 Metetra
.579 .802 .984 r
.84921 .22451 .8635 .21927 .8525 .21406 .8382 .21934 Metetra
.579 .802 .984 r
.8382 .21934 .8525 .21406 .84139 .20881 .82707 .21411 Metetra
.578 .802 .984 r
.82707 .21411 .84139 .20881 .83016 .2035 .81583 .20883 Metetra
.577 .802 .985 r
.81583 .20883 .83016 .2035 .81882 .19814 .80447 .2035 Metetra
.576 .801 .985 r
.80447 .2035 .81882 .19814 .80736 .19273 .793 .19813 Metetra
.575 .801 .985 r
.793 .19813 .80736 .19273 .79577 .18727 .7814 .1927 Metetra
.574 .802 .985 r
.7814 .1927 .79577 .18727 .78406 .18177 .76968 .18723 Metetra
.573 .802 .986 r
.76968 .18723 .78406 .18177 .77223 .17622 .75783 .18172 Metetra
.572 .802 .986 r
.75783 .18172 .77223 .17622 .76027 .17063 .74586 .17617 Metetra
.571 .802 .987 r
.74586 .17617 .76027 .17063 .74819 .16501 .73376 .17059 Metetra
.57 .803 .987 r
.73376 .17059 .74819 .16501 .73597 .15936 .72154 .16498 Metetra
.569 .804 .988 r
.72154 .16498 .73597 .15936 .72362 .15369 .70918 .15935 Metetra
.568 .805 .988 r
.70918 .15935 .72362 .15369 .71113 .14799 .69668 .15372 Metetra
.568 .806 .989 r
.69668 .15372 .71113 .14799 .69851 .14229 .68405 .14807 Metetra
.568 .807 .989 r
.68405 .14807 .69851 .14229 .68574 .13658 .67128 .14244 Metetra
.568 .809 .99 r
.67128 .14244 .68574 .13658 .67284 .13089 .65837 .13684 Metetra
.568 .812 .99 r
.65837 .13684 .67284 .13089 .65979 .12522 .64531 .13127 Metetra
.569 .814 .991 r
.64531 .13127 .65979 .12522 .64659 .1196 .63211 .12577 Metetra
.571 .818 .992 r
.63211 .12577 .64659 .1196 .63324 .11403 .61876 .12035 Metetra
.573 .822 .992 r
.61876 .12035 .63324 .11403 .61974 .10854 .60526 .11504 Metetra
.576 .827 .992 r
.60526 .11504 .61974 .10854 .60608 .10314 .5916 .10986 Metetra
.581 .833 .993 r
.5916 .10986 .60608 .10314 .59227 .09788 .57778 .10485 Metetra
.587 .839 .993 r
.57778 .10485 .59227 .09788 .57828 .09276 .56379 .10003 Metetra
.595 .847 .992 r
.56379 .10003 .57828 .09276 .56413 .08783 .54964 .09546 Metetra
.604 .855 .991 r
.54964 .09546 .56413 .08783 .54981 .0831 .53532 .09116 Metetra
.616 .864 .99 r
.53532 .09116 .54981 .0831 .53531 .07862 .52081 .08717 Metetra
.629 .874 .987 r
.52081 .08717 .53531 .07862 .52063 .07442 .50612 .08354 Metetra
.645 .884 .984 r
.50612 .08354 .52063 .07442 .50576 .07052 .49124 .08029 Metetra
.662 .894 .98 r
.49124 .08029 .50576 .07052 .49069 .06696 .47617 .07745 Metetra
.68 .904 .975 r
.47617 .07745 .49069 .06696 .47542 .06375 .46088 .07504 Metetra
.7 .913 .969 r
.46088 .07504 .47542 .06375 .45994 .06092 .44538 .07307 Metetra
.719 .92 .961 r
.44538 .07307 .45994 .06092 .44424 .05848 .42966 .07153 Metetra
.582 .804 .984 r
.93742 .25422 .95173 .24921 .9415 .24434 .92718 .24939 Metetra
.582 .803 .984 r
.92718 .24939 .9415 .24434 .93117 .23941 .91683 .2445 Metetra
.581 .803 .984 r
.91683 .2445 .93117 .23941 .92074 .23444 .90638 .23956 Metetra
.581 .803 .984 r
.90638 .23956 .92074 .23444 .9102 .22941 .89582 .23457 Metetra
.58 .803 .984 r
.89582 .23457 .9102 .22941 .89956 .22433 .88515 .22952 Metetra
.579 .803 .984 r
.88515 .22952 .89956 .22433 .8888 .21919 .87438 .22442 Metetra
.579 .802 .984 r
.87438 .22442 .8888 .21919 .87793 .21401 .8635 .21927 Metetra
.578 .802 .984 r
.8635 .21927 .87793 .21401 .86695 .20877 .8525 .21406 Metetra
.577 .802 .985 r
.8525 .21406 .86695 .20877 .85586 .20347 .84139 .20881 Metetra
.577 .802 .985 r
.84139 .20881 .85586 .20347 .84465 .19813 .83016 .2035 Metetra
.576 .802 .985 r
.83016 .2035 .84465 .19813 .83332 .19273 .81882 .19814 Metetra
.575 .802 .985 r
.81882 .19814 .83332 .19273 .82187 .18729 .80736 .19273 Metetra
.574 .802 .986 r
.80736 .19273 .82187 .18729 .8103 .18179 .79577 .18727 Metetra
.573 .802 .986 r
.79577 .18727 .8103 .18179 .79861 .17625 .78406 .18177 Metetra
.572 .802 .986 r
.78406 .18177 .79861 .17625 .78679 .17067 .77223 .17622 Metetra
.571 .802 .986 r
.77223 .17622 .78679 .17067 .77484 .16504 .76027 .17063 Metetra
.571 .803 .987 r
.76027 .17063 .77484 .16504 .76277 .15938 .74819 .16501 Metetra
.57 .803 .987 r
.74819 .16501 .76277 .15938 .75056 .15368 .73597 .15936 Metetra
.569 .804 .988 r
.73597 .15936 .75056 .15368 .73822 .14795 .72362 .15369 Metetra
.568 .805 .988 r
.72362 .15369 .73822 .14795 .72574 .1422 .71113 .14799 Metetra
.568 .806 .989 r
.71113 .14799 .72574 .1422 .71313 .13643 .69851 .14229 Metetra
.568 .807 .989 r
.69851 .14229 .71313 .13643 .70037 .13066 .68574 .13658 Metetra
.568 .809 .99 r
.68574 .13658 .70037 .13066 .68748 .12488 .67284 .13089 Metetra
.568 .811 .99 r
.67284 .13089 .68748 .12488 .67443 .11912 .65979 .12522 Metetra
.569 .813 .991 r
.65979 .12522 .67443 .11912 .66124 .11338 .64659 .1196 Metetra
.57 .816 .991 r
.64659 .1196 .66124 .11338 .6479 .10768 .63324 .11403 Metetra
.572 .82 .992 r
.63324 .11403 .6479 .10768 .6344 .10203 .61974 .10854 Metetra
.574 .824 .992 r
.61974 .10854 .6344 .10203 .62075 .09645 .60608 .10314 Metetra
.578 .828 .992 r
.60608 .10314 .62075 .09645 .60693 .09097 .59227 .09788 Metetra
.583 .834 .992 r
.59227 .09788 .60693 .09097 .59295 .08559 .57828 .09276 Metetra
.589 .84 .992 r
.57828 .09276 .59295 .08559 .5788 .08036 .56413 .08783 Metetra
.596 .847 .992 r
.56413 .08783 .5788 .08036 .56449 .07529 .54981 .0831 Metetra
.605 .854 .991 r
.54981 .0831 .56449 .07529 .54999 .0704 .53531 .07862 Metetra
.616 .863 .99 r
.53531 .07862 .54999 .0704 .53531 .06574 .52063 .07442 Metetra
.628 .871 .988 r
.52063 .07442 .53531 .06574 .52044 .06131 .50576 .07052 Metetra
.642 .88 .985 r
.50576 .07052 .52044 .06131 .50538 .05716 .49069 .06696 Metetra
.657 .889 .981 r
.49069 .06696 .50538 .05716 .49012 .05329 .47542 .06375 Metetra
.674 .898 .977 r
.47542 .06375 .49012 .05329 .47466 .04974 .45994 .06092 Metetra
.691 .906 .972 r
.45994 .06092 .47466 .04974 .45898 .04652 .44424 .05848 Metetra
.581 .804 .984 r
.95173 .24921 .96618 .24417 .95598 .23927 .9415 .24434 Metetra
.58 .803 .984 r
.9415 .24434 .95598 .23927 .94567 .23431 .93117 .23941 Metetra
.58 .803 .984 r
.93117 .23941 .94567 .23431 .93526 .22929 .92074 .23444 Metetra
.579 .803 .984 r
.92074 .23444 .93526 .22929 .92474 .22423 .9102 .22941 Metetra
.579 .803 .984 r
.9102 .22941 .92474 .22423 .91411 .21911 .89956 .22433 Metetra
.578 .803 .985 r
.89956 .22433 .91411 .21911 .90338 .21394 .8888 .21919 Metetra
.578 .803 .985 r
.8888 .21919 .90338 .21394 .89253 .20871 .87793 .21401 Metetra
.577 .802 .985 r
.87793 .21401 .89253 .20871 .88157 .20344 .86695 .20877 Metetra
.576 .802 .985 r
.86695 .20877 .88157 .20344 .87049 .19811 .85586 .20347 Metetra
.576 .802 .985 r
.85586 .20347 .87049 .19811 .8593 .19272 .84465 .19813 Metetra
.575 .802 .985 r
.84465 .19813 .8593 .19272 .84799 .18729 .83332 .19273 Metetra
.574 .802 .986 r
.83332 .19273 .84799 .18729 .83655 .1818 .82187 .18729 Metetra
.573 .802 .986 r
.82187 .18729 .83655 .1818 .825 .17627 .8103 .18179 Metetra
.573 .802 .986 r
.8103 .18179 .825 .17627 .81332 .17069 .79861 .17625 Metetra
.572 .803 .986 r
.79861 .17625 .81332 .17069 .80152 .16506 .78679 .17067 Metetra
.571 .803 .987 r
.78679 .17067 .80152 .16506 .78958 .15939 .77484 .16504 Metetra
.57 .803 .987 r
.77484 .16504 .78958 .15939 .77752 .15368 .76277 .15938 Metetra
.569 .804 .987 r
.76277 .15938 .77752 .15368 .76532 .14793 .75056 .15368 Metetra
.569 .804 .988 r
.75056 .15368 .76532 .14793 .753 .14215 .73822 .14795 Metetra
.568 .805 .988 r
.73822 .14795 .753 .14215 .74053 .13634 .72574 .1422 Metetra
.568 .806 .989 r
.72574 .1422 .74053 .13634 .72792 .13051 .71313 .13643 Metetra
.568 .807 .989 r
.71313 .13643 .72792 .13051 .71518 .12466 .70037 .13066 Metetra
.568 .808 .99 r
.70037 .13066 .71518 .12466 .70229 .11881 .68748 .12488 Metetra
.568 .81 .99 r
.68748 .12488 .70229 .11881 .68925 .11295 .67443 .11912 Metetra
.568 .812 .99 r
.67443 .11912 .68925 .11295 .67607 .1071 .66124 .11338 Metetra
.569 .815 .991 r
.66124 .11338 .67607 .1071 .66273 .10128 .6479 .10768 Metetra
.571 .818 .991 r
.6479 .10768 .66273 .10128 .64924 .09549 .6344 .10203 Metetra
.573 .821 .992 r
.6344 .10203 .64924 .09549 .63559 .08975 .62075 .09645 Metetra
.576 .825 .992 r
.62075 .09645 .63559 .08975 .62178 .08408 .60693 .09097 Metetra
.579 .829 .992 r
.60693 .09097 .62178 .08408 .6078 .07849 .59295 .08559 Metetra
.584 .834 .992 r
.59295 .08559 .6078 .07849 .59366 .073 .5788 .08036 Metetra
.59 .84 .992 r
.5788 .08036 .59366 .073 .57934 .06763 .56449 .07529 Metetra
.597 .846 .992 r
.56449 .07529 .57934 .06763 .56484 .06241 .54999 .0704 Metetra
.605 .853 .991 r
.54999 .0704 .56484 .06241 .55017 .05736 .53531 .06574 Metetra
.615 .861 .99 r
.53531 .06574 .55017 .05736 .5353 .0525 .52044 .06131 Metetra
.626 .869 .988 r
.52044 .06131 .5353 .0525 .52025 .04785 .50538 .05716 Metetra
.639 .877 .985 r
.50538 .05716 .52025 .04785 .505 .04344 .49012 .05329 Metetra
.653 .885 .982 r
.49012 .05329 .505 .04344 .48954 .03928 .47466 .04974 Metetra
.668 .893 .979 r
.47466 .04974 .48954 .03928 .47387 .0354 .45898 .04652 Metetra
.58 .804 .985 r
.96618 .24417 .98079 .23912 .97061 .23417 .95598 .23927 Metetra
.579 .804 .985 r
.95598 .23927 .97061 .23417 .96033 .22917 .94567 .23431 Metetra
.579 .803 .985 r
.94567 .23431 .96033 .22917 .94993 .22412 .93526 .22929 Metetra
.578 .803 .985 r
.93526 .22929 .94993 .22412 .93944 .21902 .92474 .22423 Metetra
.578 .803 .985 r
.92474 .22423 .93944 .21902 .92883 .21386 .91411 .21911 Metetra
.577 .803 .985 r
.91411 .21911 .92883 .21386 .91811 .20865 .90338 .21394 Metetra
.577 .803 .985 r
.90338 .21394 .91811 .20865 .90728 .20339 .89253 .20871 Metetra
.576 .803 .985 r
.89253 .20871 .90728 .20339 .89634 .19807 .88157 .20344 Metetra
.575 .803 .985 r
.88157 .20344 .89634 .19807 .88528 .1927 .87049 .19811 Metetra
.575 .803 .986 r
.87049 .19811 .88528 .1927 .87411 .18728 .8593 .19272 Metetra
.574 .803 .986 r
.8593 .19272 .87411 .18728 .86281 .1818 .84799 .18729 Metetra
.573 .803 .986 r
.84799 .18729 .86281 .1818 .8514 .17627 .83655 .1818 Metetra
.573 .803 .986 r
.83655 .1818 .8514 .17627 .83986 .1707 .825 .17627 Metetra
.572 .803 .986 r
.825 .17627 .83986 .1707 .8282 .16507 .81332 .17069 Metetra
.571 .803 .987 r
.81332 .17069 .8282 .16507 .81641 .1594 .80152 .16506 Metetra
.571 .803 .987 r
.80152 .16506 .81641 .1594 .80449 .15368 .78958 .15939 Metetra
.57 .803 .987 r
.78958 .15939 .80449 .15368 .79244 .14792 .77752 .15368 Metetra
.569 .804 .988 r
.77752 .15368 .79244 .14792 .78026 .14212 .76532 .14793 Metetra
.569 .804 .988 r
.76532 .14793 .78026 .14212 .76794 .13628 .753 .14215 Metetra
.568 .805 .988 r
.753 .14215 .76794 .13628 .75549 .13041 .74053 .13634 Metetra
.568 .806 .989 r
.74053 .13634 .75549 .13041 .74289 .12452 .72792 .13051 Metetra
.568 .807 .989 r
.72792 .13051 .74289 .12452 .73016 .1186 .71518 .12466 Metetra
.568 .808 .989 r
.71518 .12466 .73016 .1186 .71728 .11266 .70229 .11881 Metetra
.568 .81 .99 r
.70229 .11881 .71728 .11266 .70425 .10672 .68925 .11295 Metetra
.568 .811 .99 r
.68925 .11295 .70425 .10672 .69107 .10077 .67607 .1071 Metetra
.569 .814 .991 r
.67607 .1071 .69107 .10077 .67774 .09483 .66273 .10128 Metetra
.57 .816 .991 r
.66273 .10128 .67774 .09483 .66425 .08891 .64924 .09549 Metetra
.572 .819 .991 r
.64924 .09549 .66425 .08891 .65061 .08303 .63559 .08975 Metetra
.574 .822 .992 r
.63559 .08975 .65061 .08303 .6368 .07718 .62178 .08408 Metetra
.577 .826 .992 r
.62178 .08408 .6368 .07718 .62283 .0714 .6078 .07849 Metetra
.581 .83 .992 r
.6078 .07849 .62283 .0714 .60869 .06569 .59366 .073 Metetra
.585 .835 .992 r
.59366 .073 .60869 .06569 .59438 .06007 .57934 .06763 Metetra
.591 .84 .992 r
.57934 .06763 .59438 .06007 .57988 .05456 .56484 .06241 Metetra
.598 .846 .991 r
.56484 .06241 .57988 .05456 .56521 .04918 .55017 .05736 Metetra
.605 .852 .991 r
.55017 .05736 .56521 .04918 .55035 .04395 .5353 .0525 Metetra
.615 .859 .99 r
.5353 .0525 .55035 .04395 .5353 .03889 .52025 .04785 Metetra
.625 .866 .988 r
.52025 .04785 .5353 .03889 .52005 .03402 .505 .04344 Metetra
.636 .874 .986 r
.505 .04344 .52005 .03402 .5046 .02935 .48954 .03928 Metetra
.649 .881 .983 r
.48954 .03928 .5046 .02935 .48894 .02491 .47387 .0354 Metetra
0 g
.25 Mabswid
.97996 .22816 m
.48898 0 L
s
.97996 .22816 m
.98043 .23441 L
s
[(-2)] .979 .21566 .07641 1 Mshowa
.87639 .18003 m
.87677 .18629 L
s
[(-1)] .87564 .16752 .06044 1 Mshowa
.76145 .12662 m
.76171 .13288 L
s
[(0)] .76091 .11409 .04242 1 Mshowa
.63313 .06699 m
.63327 .07326 L
s
[(1)] .63286 .05445 .02194 1 Mshowa
.48898 0 m
.48897 .00627 L
s
[(2)] .489 -0.01254 -0.00155 1 Mshowa
.125 Mabswid
.96007 .21892 m
.96035 .22267 L
s
.93979 .20949 m
.94005 .21325 L
s
.91909 .19987 m
.91934 .20363 L
s
.89796 .19006 m
.8982 .19381 L
s
.85437 .1698 m
.85458 .17356 L
s
.83188 .15935 m
.83208 .16311 L
s
.80891 .14867 m
.80909 .15243 L
s
.78543 .13777 m
.78561 .14152 L
s
.73692 .11522 m
.73707 .11898 L
s
.71185 .10357 m
.71198 .10733 L
s
.68621 .09165 m
.68632 .09541 L
s
.65998 .07946 m
.66007 .08322 L
s
.60566 .05422 m
.60573 .05798 L
s
.57753 .04115 m
.57758 .04491 L
s
.54873 .02776 m
.54876 .03153 L
s
.51922 .01405 m
.51923 .01781 L
s
gsave
.75826 .05144 -69.3394 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x1) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ImageSize->{288, 174.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000[Q000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo001`Ool3002]Ool0071oo`03001oogoo0:eoo`00LGoo00<007ooOol0
[7oo001aOol00`00Oomoo`2/Ool0071oo`03001oo`000:eoo`00LGoo00<007ooOol0[7oo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00LGoo0`00[7oo001_Ool200000goo001o
o`02002ZOol006eoo`8000Moo`800:Qoo`00Jgoo0P002goo0P00YWoo001YOol3000=Ool3000DOol5
000FOol00`00Oomoo`06001/Ool0035oo`05001oogoo001oo`03000FOol5000COol20009Ool20008
Ool2000DOol00`00Oomoo`0GOol20003Ool00`00Oomoo`1/Ool0039oo`80009oo`03001oogoo01Qo
o`03001oogoo011oo`<000Yoo`03001COU=n00<000Moo`<0015oo`03001oogoo01Moo`8000=oo`03
001oogoo06aoo`00<Woo0P000goo00<007ooOol05goo00<007ooOol03goo0P002Woo0P000e=n00<0
04moCgl00`001Goo00@007oo000000moo`03001oogoo01Ioo`04001oogoo0002Ool00`00Oomoo`1/
Ool0035oo`04001oogoo0002Ool00`00Oomoo`0GOol00`00Oomoo`0=Ool2000;Ool20003Dgh00`00
Cgm?O`02Cgl01000Cgl000001goo0P003Goo00<007ooOol077oo00<007ooOol0K7oo000fOol00`00
Ool0000HOol00`00Oomoo`0:Ool3000;Ool20002Dih40002Cgl20004Cgl20007Ool2000:Ool2000M
Ool2001^Ool003Moo`03001oogoo01Ioo`8000]oo`8000aoo`8000=CWP80009CWP<000=?O`80009?
O`@000Aoo`<009Moo`00Fgoo0P003Goo00<005NNEih00`000e>N0P000Tmo10000dmo0P000T]o0`00
17oo0P00UGoo001IOol2000=Ool20003Eih00`00EiiGWP040003Cgl20002Cgl30003Bgl20002Bel4
0002Ool3002BOol005Moo`8000ioo`8000=GWP04001GWUNNEih20002Dih30003Cgl20002Cgl40003
Bel20002Bel20002Ool3002@Ool005Eoo`8000moo`03001K_U^n00L000=CWP80009CO`@000=?O`80
009;O`<000=;G`800003Bel0000000=oo`8008ioo`00Dgoo0P0047oo00@005^nFkiK_P80009GWP03
001GWUNN00@000=CO`80009?O`<000=;O`80009;G`@000=;G`<000=oo`8008aoo`00DGoo0P004Goo
1@000eNN00<005NNEih00UNN00<005>NDih00`000dmo0P000Tmo10000d]O0P000T]O0`000d]O1`00
RWoo001?Ool3000AOol01000GkeO_@000U^n10000eNN00<005>NDih00P000U>N10000dmo0P000T]o
0`000d]O0P0000=;G`0000000T]O0P000TMO0P0000Aoo`00000008Moo`00CGoo0P004goo00@005nm
Gkd000AK_P03001K_U^n00L000=CWP80009?O`<000=;O`80009;G`<000A;G`<000=7G`800003Ael0
0000009oo`8001Eoo`03001oogoo06eoo`00=Goo00<007ooOol04goo0P005Goo00@005nmGkd000=K
_P04001K_U^nFkh20002Eih00`00DiiCWP040002Cgl20002Cgl40002Bel20002Bel40003Bel30004
Ael400000goo0000000BOol00`00Ool0001^Ool003Aoo`03001oo`00019oo`8001Ioo``000=GWP04
001CWU>NDih20002Dih30003Cgl20002Bgl30003Bel2000014]O000004]O0P000TMO10000dLo0P00
0Woo0P0047oo00<007oo0000KWoo000dOol00`00Ool0000?Ool3000GOol01000HkeS_@000f>m00@0
05nmGkd0009K_PL000=CWP80009?O`<000=;O`80009;G`<000A;G`<000=7G`800004Ael00000Acl2
00000dLo00000002Ool2000>Ool00`00Ool0001^Ool003Aoo`03001oo`0000ioo`8001Moo`80009S
_@03001S_F>m0080009O_@04001K_U^nFkh20002Ekh00`00EiiGWP040002Cgl20002Cgl40002Bel2
0002Bel40003Ael30004Ael30003Acl400000goo0000000<Ool00`00Ool0001^Ool003Aoo`03001o
o`0000aoo`8001Qooa40009G_P04001GWUNNEih20002Dih30003Cgl20002Bgl30003Bel20002Bel3
0003Ael40003Acl30003Acl3000017oo000000002Woo00<007ooOol0KGoo000eOol00`00Oomoo`08
Ool3000IOol01@00ImaWg6OL00000VOL00D006?MHmeSg@0000=O_@03001K_U^n00H000=CWP80009?
O`L000=;G`<000=;G`800004Ael00000Ael200000dLo00000002Acl20002Acl30003Acl6001hOol0
03moo`8001]oo`04001Wg6OL0002Im`01@00HmeSgF?M00000Unm0P000U^n0P000U^n00<005NNEih0
1`000dmo0P0000A;O`00001;G`80009;G`<000A7G`<000=7?`<000=7?`800003Acl000000097?`80
0004Acl00000Ool2001fOol003eoo`8001aoo`05001Wg6OLIm`00002Im`00`00Hmd000090002Fkh0
1000EiiGWUNN0P000U>N00<004nOCil00`0014]o0`000T]O0P000T]O10000dMO0`000dLo10000dLo
0`0014Lo0`0000=oo`000000M7oo000kOol2000NOol00`00Im`000070002Im`01@00HmeSgF?M0000
0UoM1P000e>N00<004nOCil00P000Tmo10000d]O0`000d]O0P000TMO0`000dLo10000dLo0`000dLo
10000dLo1@00LWoo000iOol2000OOol40002Jm/01000ImaWg0000VOL00D006?MHmeSg@0000=Og@04
001K_U^n0002Ekh70003Cgl20002Bgl30003Bel30003Ael2000014Lo000004Lo0P0000=7?`000000
0TLo0P0000A7?`000017?`800097?`@00097?`800003Ool00000071oo`00=goo0P0087oo00@006^k
Jk/0009[f`04001Wg6OL0003Im`01000HmeSg@000eoM00@005^nFkh000=G_P800003Dih00000009?
W`<000=;O`80009;G`<000=7G`<000A7?`<000=7?`<000A7?`<00097?`800004Acl00000Acl20000
14Lo000007oo0`00KGoo000eOol2000QOol01@00Jk][^f^k00000V_K6@000TnO0P000Tmo10000T]O
0P000T]O0`000dMO10000dLo0`000dLo10000dLo0`000dLo0`000dLo100000=oo`0000005Woo1@00
D7oo000cOol3000ROol01@00Jk][^`00Jm/010000f_K00@006OLIm`000=Wg004001OgEoM0002Fkd2
0002Ekh00`00DiiCWP030003Cgl20002Bgl30002Bel2000014MO000004MO0P000TLo10000dLo0`00
0dLo10000dLo0`000dLo0`000dLo0P000Woo0P005Woo00<007ooOol0D7oo000LOol5000?Ool3000T
Ool70002Km/01000Jm][f`000VOL00D006OLImaWg000009Og@@000=G_P03001CWU>N0080009?W`L0
00=;G`<000=7G`<000=7?`800004Acl00000Acl2000014Lo000004Lo0P0000=7?`0000000TLo0P00
00A7?`00Acm7?`800004Acl00000Acl2000014Lo000007oo0`003Woo0`000goo00<007ooOol0D7oo
000NOol00`00Oomoo`0>Ool2000UOol01000KkY_^P000fnj00<006oK00000f_K30000UoM2P000dmo
0P000T]o0`000dMO0`000dMO0`0014Lo0`000dLo0`000dLo0`000dLo0`0014Lo0`000dLo0`000Woo
0P004Woo00<007ooOol0D7oo000HOol30003Ool00`00Oomoo`0<Ool2000WOol01000KkY_^P000Vnj
00D006oKKm/006_K00@000=[f`06001Wg6OL001Sg0000eoM0P0000AG_P00001C_P80009?W`<000=;
O`80009;G`<000=7G`<000=7?`@000=7?`<000=7?`<000=7?`<000=7?`@000=7?`<000=7?`<00003
Ool00000011oo`03001oogoo051oo`007Woo00<007ooOol02Woo0P00:7oo00@006njKkX000=_^PH0
009_fP04001[ff_K0002Im`01@00HmaSg000Gmd02@000TnO0P000T]o0`000d]O0P0000A7G`000017
G`800097?`<000=7?`@000=7?`<000=7?`<000=7?`<000=7?`@000=7?`<000=7?`H000aoo`80059o
o`007Woo00<007ooOol027oo0`00:7oo00H006njKkY_^P00KkX40003KmX00`00KmX00003Jm/90002
Gmd01000FmeKg@000U>n0`000T]o0P000T]o10000dMO0`000TLo0P0000A7?`000017?`800003Acl0
00000097?`800004Acl004LoAcl2000014Lo000004Lo0P0000A7?`000017?`800003Acl000000097
?`800004Acl004LoAcl200000dLo00000002Ool2001NOol001eoo`8000Qoo`8002]oo`03001_^P00
00@0009c^P04001_fVoJ0002KmX00`00Jm/000030002Jo/01000IoaWo0000UoM00@005_MFmd0009C
_P80009?W`L000=;G`<000=7G`<000=7?`<000=7?`<000=7?`<000A7?`<000=7?`<000=7?`<000=7
?`<000A7?`80009oo`<005aoo`009Goo0P00;7oo10000g>j00<007>j00000foJ1P000VoJ00<006_k
00000VOl00<005oM00002`000T]o0P000T]o10000dMO0`000dLo0`000dLo0`000dLo0`000dLo1000
0dLo0`000dLo0`000dLo0`000dLo10000TLo0`000Woo0P00FWoo000SOol2000]Ool01@00LkUc^G>i
00000W>j00D007>jLkX006oJ00@0009cfP04001_fVoJ0002Jo/60002Ho`01@00Fmd00000Dkh00P00
0TnO0`000d]o0P000TMO0`000dLo0`000dLo0`000dLo0`000dLo0`000dLo10000TLo10000dLo0`00
0dLo0`000dLo0`000dLo0`0000=oo`000000F7oo000QOol2000_Ool01000LkUc^@000W>j00<007>j
LkX010000W>i00@007?JLmX0009_fPD0009[n`03001So6?l00L0009?W`80009;O`<000=7G`800097
G`<000=7?`<000=7?`<000=7?`<000=7?`<000=7?`<000=7?`@00097?`@00097?`@000=7?`<000=7
?`800004Ool00000001EOol001moo`80031oo`05001c^G>iLkT00002LkX40002LkT00`00LkT00002
LmX00`00KmX0000300000foj001[n`02Jo/50002Fo`00`00DmiCgP060003Bel30003Ael2000014Lo
000004Lo0P0000A7?`000017?`800004Acl00000Acl2000014Lo000004Lo0P0000A7?`000017?`80
0004Acl00000Acl2000014Lo000004Lo0P0000A7?`000017?`800003Acl000000097?`800004Acl0
04LoAcl200000dLo001oo`02Ool2001COol001aoo`<0039oo`05001c^G>i001c^P0300001G>i001c
^G>i00000W>i00<007?J00000`000W?I00@006oj001[n`@00005Ho/005_lFo`00002Dmh200000dnN
00000002Bgl30003Ael30004Acl20004Acl20004Acl30003Acl30003Acl30003Acl30003Acl30003
Acl30003Acl30003Acl30003Acl30002Ool3000EOol3000iOol000Ioo`<0019oo`8003=oo`03001c
^G>i00@000=c^@03001c^@00009c^@@0009cf@04001cf@00KoX4000016_i001Snf?k3@000dMO0`00
0dLo10000TLo10000TLo10000dLo0`000dLo0`000dLo0`000dLo0`000dLo0`000dLo0`000dLo0`00
0dLo0`000dLo0`000Woo0P004goo00<007ooOol0>Goo0006Ool00`00Oomoo`0@Ool200000goo001o
o`0bOol40002LiT01000LkUc^@000W>i00H007>i000007Nh0002LmT00`00LmUcf@020003LoP00`00
JoT00004000015_k000005?M0P0000=;WP0000000TMo0`000dMO0`000dLo0`000dLo0`000dLo1000
0TLo10000TLo10000TLo10000TLo10000TLo10000TLo10000TLo10000TLo10000TLo0`0000Aoo`00
000000aoo`<000=oo`03001oogoo03Qoo`0000Aoo`00000000=oo`03001oogoo00eoo`8003Ioo`07
001cVG>ILiT007>I00000g>i00<007>i00000`000WNh00P007?ILmT007?I001gf0000W?h00<006_i
00000P0000=Wn@00Fo/020000TMo0P000TMO0`000dLo0`000dLo0`000dLo0`000dLn0`000dLn0`00
0dLn0`000dLn0`000dLn0`000dLo0`000dLo0`000dLo0`000dLo0`000dLo0P000Woo0P0047oo00<0
07ooOol0>7oo0007Ool00`00Oomoo`0;Ool3000gOol01000LiUcV@000W>I00<007>iLkT010000WNH
00<007Nh00000W?I1@000g?h0P000Vog00@006Oi0000009Gf004001?g0000002Bih30002Ael20002
Acl30002Acl2000014Lo000004Ln0P0000A7?`000017?P800004Ach00000Ach2000014Ln000004Ln
0P0000A7?P000017?P800004Ach00000Ach2000014Ln000004Ln0P0000A7?`000017?P800004Acl0
0000Acl2000014Lo000004Lo0P0000A7?`000017?`800004Acl00000Acl20002Ool3000<Ool00`00
Ool0000iOol000Ioo`03001oo`0000Uoo`<003Uoo`07001cVG>ILiT007>I00000W>i0P0000EcV000
MiQgV000009g^008001cfG?I001g^000MmP0009cn00:001ge`00KoL006Oi001Wm@00EmP70003Agl3
0002Acl200000dLo00000002Acl30003Ach30003Ach30003Ach30003Ach30003Ach30003Ach30003
Ach20004Ach20004Acl20004Acl20004Acl20004Acl2000017oo001oogoo0P002goo00<007ooOol0
>7oo0007Ool00`00Oomoo`07Ool2000kOol01@00LiUcV@00LiT01@000W>H00L007NHMiP007Nh001c
f@03000017Nh000007?h10000Vog0P0000=Wm@00EmP00`0000=3^@0000000TNN0`000dLo0`000dLo
0`000dLn0`000dLn0`000dLn0`000d/n0`000d/n0`000d/n0`000d/n0`000TLn10000TLn10000TLn
10000TLo10000TLo10000TLo0`000goo0P00A7oo000>Ool3000lOol00`00LiUcV@0300001g>I001c
V7>H001cV000009gV003001g^00000800005MiP007Nh001gf00200002GNg001ge`00KoL007?E001W
m@0200000dMa000000050003Ael30003Acl30003Ach30003Bch30003Bch30003Bch30003Bch30002
Bch40002Bch40002Bch30003Bch30003Bch30003Bch30003Ach30003Acl30003Acl200000goo001o
o`02000=Ool5000`Ool000eoo`8003ioo`@0009cV@04001cV7>H0002LiP00`00MiQgV00200001WNH
001gV7NH001g^0<0009g]`H00003IoD005n?00@0008[4`030013Od=o00<000=7?P<000=;7P<000=;
?P<000=;?P<000=;?P<0009;?P@0009;?P<000=;?P<000=;?P<000=;?P<000=;?P<000=;?P<0009;
?P@0009;?P@00097?`@00097?`8000=oo`8000eoo`03001oogoo031oo`002goo0P00?goo00D007=i
LgUcN@00009cV@07001cV7>H001cV000MiP00`0000IgV000MiQgV000MkP30002MkL01P00MmL007^e
001ce@d000=;?P<000=;7P<0009;7P800004Bch00000Bah2000014/n000004/n0P0000I;?P00001;
?P00Bch2000014/n000004/n0P0000A;?P00001;?P800004Bch00000Bch2000014/n000004/n0P00
00A;?P00Bci;?P800004Bch004/nBch200000d/n001;?P02000014/n000004/n0P0000A;?P000017
?`800004Bch00000Acl200000dLo001oo`02Ool30005Ool30003Ool00`00Oomoo`0`Ool000Uoo`80
045oo`04001cNG=i0002LiT01@00LiQcV000LiP00`0000EgV000MiQgV000009gV005001g^000MiL0
0002MkL300000g^e0000000200000en?000000060002Bah30002Bah2000014/N000004/N0P000T/N
0`000d/N0P0014/n0P000d/n0`000d/n0`000d/n0`000d/n0P0014/n0P000d/n0`000d/n0`000d/n
0`000d/n0P0014/n0P0014/n0P000dLo0`0017oo0P002Goo00<007ooOol0<7oo0007Ool20012Ool0
1000LgUcN@000g>I00<007>HLiP00P0000McN000MiQgV000MiP00002MiP50002MkL300001G^e001c
e@00Mk800P0000=G200000000`0000=7^@00Bah00P0000=>o@0000000T/N0`000d/N0`000d/N0`00
0T/n10000T/n0`000d/n0`000d/n0`000d/n0`000T/n10000T/n0`000d/n0`000d/n0`000d/n0`00
0T/n10000T/n10000T/n0`000d/o0P000goo0P0027oo00<007ooOol0<7oo0005Ool20014Ool01000
LgUcN@000W>I00@007>H0000009cN004001gV7NH0002MiP02000MiQgV000MiL007NG0002MkL01000
NiH007^e1P0000=G200000000`000TNi00<004kmC_d00dkm0P000dlM0`000dlN0`000T/N0`000d/n
0`000d/n0`000d/n0`000d/n0`000T/n0`000d/n0`000d/n0`000d/n0`000T/n10000T/n0`000d/n
0`000d/n0`000T/n10000T/o1@001goo0P00<Woo0005Ool00`00Oomoo`12Ool00`00LgT000060000
1G=h001cN7=h00000WNH00@007NH001gV080009gU`04001gU`00MkL200000g^F0000000200000gNb
00000002E`P40002AkT01@00E[X00000C_d00P0000ABo000001?7@800004Cad00000Cah200001DlN
000004/N00000TlN0`000d/n0`000d/n0`000T/n10000T/n0`000d/n0`000d/n0`000T/n10000T/n
0`000d/n0`000d/n0`000T/n10000T/n0`000d/n0`000d/o0P00>goo001:Ool200001Fmi001cNG=i
00000W=h00@007=hLgP000=gV009001gV000001gM`00MiL007NG00@00007NiH007^e001kU000Mk80
0P0000=G200000001@0015Jj0P000e;l0`000dlM0`000dlN0P000TlN0P0000A??P00001;?P800004
Bch00000Bch200000d/n001;?P02000014/n000004/n0P0000A;?P00001;?P80009;?P<0009;?P<0
00=;?P<000=;?P<0009;?P@0009;?P<000=;?P<000=;?P<0009;?PD003aoo`00BGoo00@006miKgT0
00=cN@04001cN7=h0002LgP00`00MiQgV00400001gMg001gUgNG001gU`00009kMP03001kUP000080
0003Ni@0000000800003E`P006L800<00003L[<00000009F^P03001JnU[j00<000=G70<000=C7@<0
009?7P<000=??P<000=;?P8000=;?P<000=;?P<000=;?P8000=;?P800003Bch004/n00800004Bch0
0000Bch2000014/n001;?T/n0P0000=;?P00Bch00P000T/n0`000d/n0`000T/n10000T/n0`0017oo
0P00>goo0019Ool01000KgU_N@000W=i00@007=hLgP0009cN003001gV7NH00800005MgL007MgMgL0
0002MiL3000017]f001kUW^F0P0000EkU000Mk8007^A00<00003I`P00000009b/`0500002000E[X0
0002F_X01@00Ga/00000Ea`00P0000AG7000001C7@800004Dad000000003Cah30003Cch30002Cch3
0003Bch30003Bch30002Bch30003Bch30003Bch20003Bch30003Bch30002Bch2000014/n001;?T/n
0P0000=;?P00Bch00P000T/n0`001goo00<007ooOol0>Woo0018Ool01000KgU_N@000g=i00D007=h
LgP007=h00D0009gM`03001gM`00009gU`<0009kMP03001kUP0000800003Ni@0000000800003E`P0
000000<0009b/`04000020080002F_X00`00Ga]O6`02Ga/00`00EaaG7003Ea`00`00DaeC7@020000
15<M000004lN0P000Tln0`000Tln0`000dln0`000d/n0`000T/n0`000d/n0`000d/n0`000T/n0`00
0d/n0`000d/n0P000d/n0`000d/n0P000d/n0P002Woo00<007ooOol0>Goo0017Ool01@00KgU_NFmi
00000W=i00<007=h00000`0000McN000LgQcN000MgL00002MgL01P00MiMgU`00MgH0009kMP06001k
UP00NgD007^D1@0000Ek<`00001fl`00009b/`030000200800800003F_X005lK009O6`05001O6`00
001G7002000015LL000000000e<M0`000Tln0P0000=??P00Cch00P000Tln0`000dln0`000T/n0`00
0d/n0`000d/n0`000T/n0`000d/n0`000T/n10000T/n0`000d/n0`000T/n0`002goo0P00>goo0017
Ool01000KgU_N@000W=i0`0000E_N@00LgQcN000009cN007001gMgMg001gM`00MiL00`0000EgMP00
NgH007^F00800003NgD007^D00800005Ni400000001W20030002L[<01@0000P02000Mi000P000UlK
00<005lKGa/00UlK0P000ULL00<005LMEad00`000e<m0`000dln0P000Tln0P0000A??P00001??P80
0003Cch004/n0080009??P<0009;?P@0009;?P<000=;?P<0009;?P<000=;?P<0009;?P@0009;?P<0
00moo`03001oogoo03Uoo`00AWoo20000Vmi00D007=hLgQcN000009cN005001gMgMg001gM`020000
17MG001gMP000W]f0`0000=kM@00Ni@00`0000EkT@00Nc<006L800<0009b/`0700002008001gT000
MgL00P0015lK00<005lKGa/00P000ULM0P0000AG?@00001C?@80009C?@<0009C?P<000=??P8000=?
?P<0009??P800003Cch004/n0080009;?P<000=;?P<0009;?P<000=;?P<0009;?P<000=;?P<0019o
o`03001oogoo03Uoo`00AGoo00D006mjKgY_NP0000=_N@04001_NFmi0002LgP01000LgQcN0000WMg
10000WMG00@007Mf001kMP800007MeD007]e001kU000Ne@00`0000=k<`0000000`000W:c00<00008
00000WN@00<007MgMgL00`0000=O6`00Ga/00UlK00@005ll000000EG?@80009C?@800004Dcd00000
0003Dch30002Cch30003Cch20003Cch30002Bch2000014/n001;?T/n0P0000A;?P00000000=;?P<0
009;?P<000=;?P<001Aoo`8000Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Eoo`00
AGoo00D006mjKgY_NP00009_N@04001_NFmi0003LgP01@00LgQcN000MgL00P0000=cE`00MeL00WMG
00D007Mf001kMP00009gE@03001kM@0000800003Ne@00000009k<`800003M_<00000009b/`050000
2000Mi000002MgL01000KeU_FFmI0P000UlK00D005llGc`005ll00800003Ecd00000009G?@80009C
?@800004Dcd00000Dch2000015<n000000000dln0`000Tln0`000dln0P000d/n0`000T/n0P0000A;
?P00Bci;?P800004Bch000000002Bch4000HOol00`00Oomoo`06Ool00`00Ool00007Ool00`00Ool0
000VOol004Aoo`05001_NVmjKgX00003KgT01000KgU_N@000W=h00<007=h00000`0000AcF000LeL0
009gE`03001gMWMf00<0009gE@03001kM@0000<00004Ni4007/cNc<200001GKc000007:c00000P08
00<007N@00000WMg00@006mIKeT0009[>@<0009O?004001O?5llGc`20002Ecd2000015Lm00000000
0e<m0P000U<n0P000U<n0`000Tln0`000dln0`000Tln0`000d/n0P000d/n0`000T/n0P0000A;?P00
000001aoo`04001oogooOol30002Ool00`00Ool00009Ool00`00Oomoo`0TOol004Aoo`05001_NVmj
KgX00002KgT01000KgU_N@000W=h0`0000M_F000LeQcF000LeL00003MeL00`00MgH000020002MeD0
0`00NgD00002000017]D001kT@000W/c0P0000Efl`00L[=b/`0000802005001gT000MgL00003KeT0
1000JcU[>@000VLj0P000Ull0P000U/l0P000ULm0P000ULm0`000U<m0`000U<n0P0000=C?P00Cch0
0P000Tln0`000Tln0`000dln0`000T/n0`000d/n0P000T/n0P007Woo00<007ooOol01Woo00<007oo
00001goo0P009goo0013Ool>000016mI001_F0000g=H00<007=G00000gMG00D007Mf001gEP00009g
E@03001kM@0000800005Ne@00000001k<`0300001GKc001b/g:c00000P0800D007N@001gM`00009_
F@05001[>F/iJcT00002IcX00`00Ic/000020002Fc`2000015/l000000000ULm0P000ULm0`000U<m
0`000e<n0P000Tln0P0000A??P00000000=??P<0009??P<000=;?P<0009;?P80021oo`03001oogoo
00Ioo`03001oo`0000Moo`03001oogoo02Ioo`00@Woo00D006]JJeY[FP0000=[FP04001_FFmI0003
KeT01000KeQ_F0000W=H00@007=GLeL0009gE`@0000:MeH007MEMeD007]e001g=@00Ne@300001W/c
00000000M_<0009b/`0500002008001gT0020003KeT01000JcU[>@000VLj00@006LkIc/0009S>`<0
009K?003001K?5/l00<0009G?@800003Ecd005<m0080009C?@<0009C?P<0009??P03001??Tln00<0
009??P<000=??P<0009;?P<0025oo`<000Qoo`03001oogoo00Ioo`<002Ioo`00@Woo00D006]JJeY[
FP0000=[FP04001_FFmI0003KeT00`00KeP00003LeP00`00LeL00002MeL2000017=G001gEP000gME
0`0000=g=@00Ne@00P000W/c0`0000Yfl`00L[=b/`0000P007N@001gM`D0009[>@06001W>VLj001W
>`000f<k00<006<kHc/00P000e/l00<005/mFcd00P000eLm0`000U<m0P0000AC?P00000000=C?P80
009??P800003Cch004ln0080009??P<0009??P<002Eoo`03001oogoo03Uoo`00@Goo00D006]JJeY[
FP0000=[FP04001_FFmI0003KeT01000KeQ_F0000W=H00<007=G00000`0000IcE`00LeL007MF0002
MeD300000gLe001kE0030002Nc<20002M_<01`00L[=b/`0000P007N@00<0009oTP03001kM@0000@0
009W>`04001S>f<k0003Hc/01@00Hc`005/l00000e/m00<005/m00000P000eLm0P000U<n0P000U<n
0`000U<n0P000dln0`000Tln0P0000A??P00000002Qoo`03001oogoo03Uoo`00@Goo00D006]JJeY[
FP0000=[FP04001_FFmI0003KeT00`00KeP00002LeP300001FmH001cEg=G00000W=G00<007MF0000
0WME00T007Le001g=@00Ne@007LD00000W/c0P000WKc00X007:cL[<00008001gT000Ofh0009oTP04
001kMG]e0002MgL40002Hc/01000Hc]S>`000f<l0P000U/m00@005/mFcd0009K?@<0009G?@<0009C
?P800004Dch000000002Dch30003Cch20002Cch2000ZOol2000jOol0041oo`H0009[FP04001_FFmI
0003KeT00`00KeP00003000016mI001_F0000g=G00<007=G00000WMF00`007ME000007Le001g=@00
Ne@007LD0002Nc<200000gKc00000002L[<02@0000P007N@001oKP00Oi800002NgD01000MgMgM`00
0Vmi00<006mI00000P000V<k00@006<l0000009OG080009K?@03001K?E/m00800004Ecd000000003
Ecd20002Dch20002Dch30002Dch30002Cch2000]Ool00`00Oomoo`0JOol20004Ool20008Ool20004
Ool20006Ool003moo`05001WFfMKIe/00002Ie/<0003KeT01000KeQ_F0000W=G00D007=GLeL007MF
00@0009g=@03001g=@0000800004Ma@007/cNc<200000gKc00000002L[<00`0000P00002000017m^
001oTP000W]e00H007MgMgL006mi0002KeT00`00JeY[FP050002Ge`200000emL000000040002Ecd0
0`00EceG?@030002Ecd30002Dch2000015<n000000000Tln0`00;goo00<007ooOol06Woo00<007oo
Ool00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol017oo000nOol00`00Ie]WF`02Ie/0
1@00Ie]WFfMK00000V]J00D006]JJeY[FP00009_F@07001_FFmIKeT006mH00000g=G00H007=GLeL0
07MF0002LcH00`00McD00002McD300000gLD001k<`0300000gKc00000002L[<00`0000P000030002
Oi801P00NgEkM@00MgL0009_N@04001_FFmI0002JeX00`00Ie/00002Ie/30002Ge`01000GeaOG000
0U]L0P000ULm0P0000AG?@00000000=C?@80009C?P800004Dch00000000aOol2000EOol30004Ool0
0`00Oomoo`03Ool01000Oomoogoo0`0017oo00<007ooOol00goo00<007ooOol017oo000nOol01@00
Ie]WFfMK00000fMK00D006]JJeY[FP0000=[FP03001_F@0000=_F@04001_F6mH0003LeL00`00LeL0
00030002LcH01000McD007Le0`0000Qg5000Nc=k<`00L]<007Kc0P000W:c0`0000=k<P0000000WnB
00<007]e00000WMg00H006miKgT006mI0002JeX01000Ie]WF`000VMK00<006=KHe/00P000UmL00H0
05]LFeaKG000Fed30002Ecd00`00EceG?@030002Dcd30002Dch00`00Oomoo`0bOol00`00Oomoo`0B
Ool01000Oomoo`0017oo00<007ooOol00goo00D007ooOomoo`0000Ioo`03001oogoo00=oo`03001o
ogoo00Aoo`00?Goo0P000fMK00@006MKIe/000=[FP05001[FV]JJeX00002KeT01@00KeU_FFmI0000
0VmH00D007=GLeL007=G00800003LcL007<f009c=P04001g=@00McD3000027LD001k<g/c001bd`00
M_<20002L[<4000017m^001oTP000W]e00<007Mg00000Vmi00@006mIKeT0009[FP03001WF`00009W
F`06001SFf=KHe/006=L0`000U]L00@005]MFed0009KG@80009G?@800004Ecd000000003Dch2000e
Ool00`00Oomoo`0BOol01000Oomoo`0017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol017oo000lOol00`00HeaSG0070003JeX01`00JeY[FV]J001_
F@0000=_F@04001_F6mH0002LeL3000016lh001c=`000W<f00X007LeMcD007Le001c5@00Ma@0009k
<`04001bd`00M_<20002L[<200001W/b001oKP00Oi80009kM@03001gM`0000/0009WF`04001SFf=K
0002He`00`00HeaSG0020002Fed00`00FeeKG@0200000e]M00000002Ecd20002Ecd3000fOol2000C
Ool200000goo00000004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool003]oo`03001SG6=L009SG004001SFf=K0002Ie/C000016lh001_>000
0W<g00L007<fLcH007Le001g=@0200001G<E001g5000Nc<00P0000=bd`00M_<00P000W:c0P0000Mk
<P00Ofh007nB001kM@040002NgH01@00MgL007=h00000Vmi00<006mj000010000V=L00<006=LHe`0
0P0000=OG00000000`000U]M0P0000AKG@000000009G?@8003Uoo`03001oogoo00=oo`03001oogoo
01Aoo`03001oogoo00=oo`07001oogooOol007oo000017oo00<007ooOol00goo00<007ooOol017oo
000kOol01@00HeaSG6=L00000V=K00<006MKIe/00VMK00D006MKIe]WF`00009[FP05001[FV]JJeX0
0002JeT01@00KcQ_>6lh00000Vlh00<007<g00000g<f00<007Le00000P000W<E00@007LD001k<`80
0003L]<007Kc0080009b/`80000:Nc8007m^001oTP00NgD007]d0002NgH00`00MgL00002LgP01P00
KgU_N@00KgX0009[FP03001WF`0000D0009OG005001OG5mL001OG0030002Fed00`00EeeGG@02000k
Ool00`00Oomoo`02Ool00`00Ool0000EOol20004Ool20003Ool00`00Oomoo`02Ool20004Ool20006
Ool003Yoo`H0009SF`05001WFfMKIe/00004Ie/01000JeY[FP000f]J00@006]IJeT000=_>003001_
>000009c=`0;001c=W<fLcH007Le001c5P00LaD00002Ma@200000g;D00000002M_<20002L[<20000
0g/b001oKP0200001G]e000007]d00000W]f00D007Mg001cN000009_N@06001_NVmj001[FP000VMK
00@006MKIe/0009SF`80009OG004001OG5mL0002Fed20002Eed2000lOol00`00Oomoo`02Ool00`00
Ool0000cOol003Uoo`05001OG5mLGe`00002Ge`30003Ie/01@00Ie]WFfMK00000V]J00D006]JJeY[
FP00009[F@05001_>6lhKcP00002KcP01000LcMc=`000W<f100000Mc5P00LaD007LD001k<`020000
17;C001flgKc0P000W:c0P0000=k<P00Ofh00`0000IoLP00Ng@007]f0002MgL00`00LgP00002KgT0
0`00KgX00002JeX01P00Ie]WF`00Ie/000=SF`04001SG0000002Ge`00`00FeeKG@0200000e]M0000
000nOol00`00Oomoo`02Ool00`00Ool0000cOol003Qoo`05001OG5mLGe`00003Ge`00`00HeaSG004
0003Ie/01000JeY[FP000f]J00@006]IJeT000=_>006001_>6lh001c=`000W<f0P0000Q_5`00LaIc
5P00LaD007LD0P0000Abe000L]<0009fl`80009b/`800003Nc8007m^0080009oLP05001kM000NgH0
0002MgL200000fmi000000080002Ie/01000He]SF`000V=L00<006=L000010000U]M0P00?goo0P00
0goo00<007oo0000<goo000gOol20003Ge`01000GeaOG00016=L00<006=LHe`02`0000=[F@00KcP0
0Vlh00D006lhKcP007<g00@00006KcL006lG001c5P000W<E01<007LD000007;D001bd`00M_<006jc
001b/`0000P007/b001oKP02000017mb001kM0000W]f00@007Mg001cN0800006MgL007=h001_N@00
0Vmj00<006]j000010000V=L00@006=LHe`0009OG004001OG0000010Ool30004Ool00`00Oomoo`0b
Ool003Eoo`80009KG@L000=SG003001SG6=L009SG004001WFfMK0003Ie/00`00IeYWFP0:00001Flh
001_=flg00000VlG00<007<F00000W<E00<007LD00000W;D00@007;C001fl`80009b/`80009k<P@0
0007Og8007]d001kMP00MgL0100000MgM`00LgQcN000KgT00002KgX00`00JgX00002Jg/00`00Ig/0
00040002Ge`01000GeaOG000@goo00<007ooOol0=goo000dOol20003Fed20002Fed00`00GeeOG@04
0003He`01000Ie]WF`0016MK00@006MJIeX000=[>P04001[>F/i0002KcP01`00KcM_=flg001_5`00
009c5P03001c5G<E00<0009be004001bd`00M_<20002L[<20002Nc8400001Gmb001kM000NgH00P00
00=kM@0000000WMg00D007=h001_N@00009_NP06001[NV]j001[N`000VMk00D006MkIg/006=L00D0
04=oo`8003Uoo`00<goo00<005MNEeh010000U]M00<005mMGed00UmM00<005mLGe`010000VMK00D0
06MKIe]WF`00009WFP03001[>V/j009[>P04001[>F/i0002KcP01000KcM_=`000VlG00D007<FLaH0
07<E00800008K_D007;DL]@007;C001fl`80009b/`800003Nc8007m^00<00003Og8007]d00<00006
NgD007]f001gM`000W=h00<006mi00000Vmj00<006]j00000V]k00H006MkIg/006Mk0002He`01000
HeaSG000AGoo00<007ooOol0=goo000bOol00`00EeiGGP02Eeh00`00EeeGG@030003Ged00`00GeaO
G002Ge`00`00GeaOG0030003Ie/01000IeYWFP000f/j00@006/iJcT0009_>005001_=flgKcL00002
KaL00`00LaH00002LaD30002L]@01@00L]=bd`00M_<00P000W:c0P0000=k<P00Ofh00P000Wmb1000
0W]e00P007]f001gM`00LgP006mi3`000V=L00<006=L0000AWoo00<007ooOol0=goo000aOol20003
Eeh01@00EeeGGEMM00000U]M10000emL00D005mLGeaOG000009SG0L000=[>P04001[>F/i0002KcP0
1@00KcM_=flg00000VlG00@007<F001c5@800005K_D007;DL]@00002L]<01000M_<000000W:c0P00
00=k<P00Ofh00P000Wmb0P0000IkM000NgEkM@00NgH200000g=h0000000200001g=h001_NFmi001_
NP00009[NP03001[N`00009WN`@004Ioo`8003Uoo`00;goo0P000U=N10000eMM00D005]MFeeKG@00
009KG@@0009OG003001SG6=L009SG004001SFf=K0002He/400001F/i001_>6lh00000flg00D006lG
KaL007<F00<00004KaL006ke0002L]@01@00L]=bd`00M_<00P000W:c0P0000=k<P00Ofh00P000Wmb
0P0000MkM000NgD007]f001gM`0200000gNG00000002LgP01@00KgT006mj00000V]j00<006]k0000
0fMk00<006Mk0000B7oo00<007ooOol0=goo000^Ool20003Deh20002Eeh40002Fed00`00FeeKG@02
Fed00`00FeeKG@030003He`01000He]SF`0016=K00<006LkIc/03@0000A_6000KaL0009^m@07001b
e7;D001bd`00M_<00`000W:c0P0000=k<P0000000P0000UoLP00000007]d001kM@00NgH00`0000Ig
U`00MiP007=h0002KgT00`00KgX00002JgX00`00Jg/00002Ig/00`00Ig/00019Ool00`00Oomoo`0g
Ool002aoo`80009CGP@000=GGP80009GGP<000=KG@05001KGE]MFed00002Fed40002He/01@00He]S
Ff=K00000fLk00@006LjIcX000=[>@04001[>F/i0002KaP01P00KaM_5`00K_D000=be004001bd`00
M_<30002L[<200000g/b0000000200000gmb000000020002NgD40002MiL01000MiP007=h3`00BWoo
00<007ooOol0=goo000[Ool20003Deh20002Deh40002Eeh20002Eeh40002Fed00`00FeeKG@02Fed0
0`00GeeOG@030003He/01000Ic]W>`000fLj00D006/iJcU[>@00009[>@04001_66lH0002KaL00`00
K_D00003L]@00`00L]<00002000016jc001b/g:c0P0000Ik<P00001oDP00Og8200000g]d001kM@03
00001g^F001gU`00MiP007=h00<0009cV@05001_N@00KgX00002JgX00`00Jg/0001;Ool00`00Oomo
o`0gOol002Uoo`80009?GP@000=CGP80009CGP<000=GGP80009GGP<000=KG@05001OGEmMGed00002
Ge`40002Ic/01000IcYW>P000f/i00@006/iJcT0009_6004001_5flG0002K_D01P00L]Abe7;D001b
d`<00004K[<007:cL[<200001W/b000007mB001oLP80000;Ng@007]e001kM@00NiH007NG001gV003
00001W>H001cV@00KgT0009_NP03001[NP00009[N`03001oogoo04Uoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo02Moo`009goo0P000T]O0`000dmN10000U=N0P000U=N
10000UMN0P000UMM10000UmM00<005mLGe`00UmL00<005mLGe`00`000VLj00D006/iJcU[>@00009[
>@04001_66lH0002KaL01000K_E^m@000W;D00P007;CL]<006jd001^/`000W:c0P0000Ik<P00001o
DP00Og8200001g]d00000000NgD007^F00H00009LiP007>ILiT006mi001_NP00009[NP03001[N`00
04aoo`8000=oo`03001oo`0000Moo`03001oo`0002Qoo`009Goo0`000d]O00<004]OBel010000dmN
0`000e=N0P000U=N0`000eMM0P000UMM0`000emL00D005mLGeaOG000009S?0L00003JcT006lH009_
6006001_5flG001^m@000g;D00P007;CL]<006jd001^/`000W:c00<007/bNc800P0000=oDP000000
1@0000mkM@00NiH007NG001gU`00MiL007>H001cV@00KgT02@00CGoo00L007ooOomoo`00Ool00009
Ool00`00Oomoo`0VOol002=oo`8000=;G`@0009;G`80009;G`@0009?GP@000=CGP03001CGU=N00@0
009GG@80009KG@@0009OG005001S?6<lHc`00003Hc/00`00Hc]S>`0300001FlH001_5flG00000Vke
00@007;DL]Abe0@00004K[@006jc0002L[<00`00Nc80000300000gmb001kL`0200001G]e001kM@00
NiH00`0000=gU`00MiL00P0000=cV@0000000P0000AcV@00KiX0009_VP03001oogoo04aoo`07001o
ogooOol007oo00001goo0P00:Goo000ROol00`00Aem7G`040003Bel30003Bel2000014]N000004mN
0P000TmN10000U=N0P000U=N0`000e]M0P000U]M0`000V<l00D006<kHc]S>`0000=S>`03001W>VLj
00`00007J]H006jdK[@006jc00000W:c00<007/b00001@0000QkL`00001kM@00NgD007^F0P0000Eg
U`00MiL007>H00<00009LiT007>ILiT006nJ001_VP0004eoo`<000=oo`03001oo`0000Moo`03001o
ogoo02Qoo`0087oo0`000TMO0P000TMO10000T]O10000d]N0`000dmN0P000TmN0`000U=N0P000U=N
10000U]M0P000U]M0`000f<k00@006<kHc/000=W>P04001W6FLI0002IaP00`00J_MZm`02J_L01@00
J]H006jd00000Vjc00D007:cL[<007/b00800003Oe80000000D00003NgD0000000<00003MiL007NG
00<00008MiP007>I001cV@00KiX0009_VP03001oogoo04eoo`03001oogoo009oo`03001oogoo00Io
o`<002Qoo`007Goo0`000dMO0`000dMO0P000TMO0`000d]O0`000d]N10000TmN0P000TmN0`000e=N
0P000U=N0`000U]M0P000U]M10000V<k00@006LjIcX000=W6@04001W66LH0003J_L01P00J]IZeP00
K[@0009^/`05001b/g:c001k<P0200000gmB001kE00300001g]e001kM@00NiH007^F00H00004MiP0
07>I0002LiT5001@Ool00`00Oomoo`0fOol001]oo`8000=7G`@00097G`@00097G`800003Ael00000
009;G`03001;Gd]O00@000=?GP<000=?GP03001?GTmN00@0009CGP80009GGP8000EKG@03001K?5/l
00<0009W>P04001W6FLI0002IaP00`00J_MZm`02J_L01P00J]IZeP00K[@0009^/`05001b/g:c001k
<P02000017mB000007]c0P0000MkM@00000007^F001kUP0200001gNG001gV000MiP007>I00D00003
KiT007oo04moo`8003Qoo`006Goo0P000TMO10000dMO0`000dMO0`0014MO0`000T]O0P000T]O0`00
0dmN10000TmN0P000TmN0P0015MN00@005MM0000009KG@05001K?5/lFc`00002Gc`30002IaT01000
IaQW60000f[g00@006[FJ]H0009^]005001^/fjc001b/`02000017/b000007mB0P0000AkL`00001k
M@800003NiH007^F00<00003MiL007NH00@0009cV@04001cV@00001BOol00`00Oomoo`0fOol001Mo
o`800093G`<000=7G`@00097G`@00097G`@000=7G`<000=;G`03001;Gd]O00@000=?GP<0009?GP80
0003Ceh00000009GGP04001GGEMMEed30002Fc`01@00GcaO?5ll00000Ull0`0000=W6000J_L00f[g
00@006[FJ]H0009^]003001^/`00009b/`H00003Ne@0000000D00003NiH007^F0080000>MiL007NH
001gV000MiP007>I001cV@00KiT0059oo`03001oogoo03Ioo`005Woo0P000d=O00<004<o@cl01000
0dMO0`000dMO0`000dMO0`000dMO10000T]O0P000T]O0`000d]N0`0014mN0`000UMM0P000ULm0`00
0Ull00D005llGcaO?000009O>`8000AZm`04001ZeV[F0002K[@00`00K[<00002L[<3000017/c0000
07]D0P0000IkM@00001kUP00NiH400000gNG001gV0040002LiT01000LiT00000DWoo0P00>7oo000C
Ool30002@cl40002@cl20002@cl40002@cl40002Ael40002Ael40003Ael30003Bel01000Bel00000
0T]N00<004]NBeh010000dmN0`000ULm0P000ULm0`000Ull00H005lkGc]O>`00Ga/200000f[g001Z
eP02J]H01P00K[A^]000K[<0009b/`T00005NgD00000001kUP0300000gNG0000000200001gNH001g
V000LiT007>I008005Aoo`03001oogoo03Ioo`004Goo0P000d<o0`000d<o0`000d<o0P000T<o0`00
0d<o0`000dLo0`000dMO0`000dMO10000d]O0`000T]N0P000T/n0`000dln0`000ULm0P000ULm0P00
15lk00@005lKGa]O6`<00005J]H006jdK[@00002K[<00`00L[=b/`0;00001g^F001kUP00MiL007NG
00800003MiP007NH00800006LiT00000001cV@00E7oo00<007ooOol0=Woo000>Ool30002@cl40002
@cl40002@cl70003@cl40002@cl40002Acl40002Acl40003Acl30003Bcl30002Bch20002Bch30003
Cch30003Ecd01P00Ecd00000Gc/000AO6`03001O6elK0080009^]004001^/fjc0002L[<5000017]D
000007]e0P0000=kUP0000000P0000QgU`00001gV000MiP007NH100000=cV@00Ool0E7oo0P00=goo
000<Ool20003@cl30003@cl30003@cl30003@cl00`00@cm3?`040003@cl30003@cl30003Acl30003
Acl30003Acl30003Bcl30003Bch01000Bch000000Tln00<004lnCch010000eLm0`000UlK00H005lK
Ga]O6`00Fa/30002K[<00`00L[=b/`0200000g/c0000000300000g]e0000000300000gNG001gU`02
00000gNH001gV0020002LiT4001FOol00`00Oomoo`0eOol000Uoo`<00093?`@00093?`@00093?`@0
0093?`@00093?`800093?`<000=3?`<000=3?`<000=3?`<000=7?`<000=7?`<000=7?`@000=;?P<0
009??P80009??P<000=C?@<0009O6`03001K6e/K009K6`04001^/fjc0002L[<600000g]e00000003
00000gNG0000000300001gNH00000000MiP007>I00@005Moo`03001oogoo00D0031oo`001goo0P00
0d<o0`000d<o0`000d<o0`000d<o0`000d<o1`000T<o10000T<o10000T<o10000T<o10000TLo1000
0TLo10000dLo0`000d/o0`000Tln0P0000A;?P00001C?@80009C?P8000AK6`05001C7@00K[<00002
L[<300000g]E0000000700000gNG001gV00200000gNH001gV0020002LiT200000g>I001oo`1EOol2
0004Ool00`00Oomoo`0`Ool000Eoo`80008o?`@0008o?`@00093?`@00093?`d000=3?`<000=3?`<0
00=3?`<000=3?`<000=3?`<000=3?`<000=7?`<000=7?`<000=;?`<000=;?P<0009C?P800005Bch0
0000Fa/00003Dad900000g]e001gU`03000017NG000007NH100000=gV000MiP0100000=cV@00Ool0
Egoo00<007ooOol00Woo00<007ooOol0<7oo0002Ool30002?clI0002@cl40002@cl40002@cl40002
@cl40002@cl30003@cl30003@cl30003@cl30003@cl30003Acl30003Acl30003Bch30003Bch20005
Dad00`00IaX0000200001g]E00000000MiL007^F00D00006MiP00000MkP007NH100000Ac^@00LiT0
05Qoo`03001oogoo009oo`03001oogoo031oo`0030000Slo10000Slo10000Slo10000Slo0`000clo
0`000d<o0`000d<o0`000d<o0`000T<o10000T<o10000T<o10000T<o0`000d<o0`000d<o0`000dLo
0`000dLo0`000T<O0P0000AC7@00001W6PD00004MgL00000MiL200001GNG00000000MiP0100000=g
V00000000P0000Ac^@00LiT005Qoo`8000Aoo`03001oogoo031oo`001Woo10000Slo0`000clo0`00
0clo0`000clo0`000Slo10000Slo10000Slo0`000d<o0`000d<o0`000d<o0`000d<o0`000d<o0`00
0T<o10000T<o0`000d<o0`000T<o0P0000A7?`000013?`8000937`<0009W6P03001g5@0000@00003
MiL0000000D00004MiP00000MkP400000g>i00000002001JOol01000Oomoogoo0P00<Woo000:Ool3
0002?cl40002?cl40002?cl40002?cl30003?cl30003?cl30002?cl40002?cl40002?cl30003@cl3
0003@cl30003@cl30003@cl30002@cl40002@cl60003@cl30003@cl6000017Mg000007NG0P0000=g
U`0000000`0000=c^@0000000P0000=c^@0000000P0000=c^@00Ool0TGoo000=Ool40002?cl30003
?cl30003?cl30002?cl40002?cl30003?cl30003?cl30003?cl30002?cl40002?cl30003?cl30003
?cl30003?cl30003?cl30002?cl60003?cl700000g>I00000003000017Nh000007>i0`0000Ic^@00
001c^@00LkT2000017>i001c^@00Tgoo000AOol30002?cl40002?cl40002?cl30003?cl30002?cl4
0002?cl40002?cl30003?cl30003?cl30002?cl40002?cl30003?cl30003?cl30003?cl30002?clB
000017Nh000007>i0P0000=c^@0000000P0000=c^@0000000P0000Ac^@00000009=oo`0057oo0`00
0clo0`000clo0`000Slo10000Slo0`000clo0`000clo0`000Slo0`000clo0`000clo0`000clo0`00
0Slo0`000clo0`000clo0`000clo0`000SmO3@0000A_^P00001c^PP00003LkT0000000800004LkT0
0000002DOol001MoocL000<o?`<0008o?`@0008o?`<000<o?`<000<o?`H0009?WP@00003Im`00000
00P00003KkX007>i00800003LkX007>j00800003KkX007oo09Aoo`007Woo0`000clo0`000Slo1000
0Slo0`000clo0`000Slo10000Slo0`000clo0`000Slo80000dMo0`000Unm1`0000=_f`0000000P00
00I_^P00001_^P00LkX2000016nj001_^P00UGoo000QOol40002?cl30003?cl30002?cl40002?cl3
0003?cl30002?cl30003?cl30003?cl30002?cl30003?cl30003?cl30002?el30003@el<00000fOL
0000000400001Vnj000006nj001c^P800004KkX006nj002FOol002Eoo`<0008o?`@0008o?`<000<o
?`<0008o?`<000<o?`<0008o?`<000<o?`<000<o?`<0008o?`<000<o?`<0008oGa80009Sg@@00003
Jm`0000000800003Kk/0000000800003Kk/00000008009Moo`00:7oo?P000SmO3`0000=Sg@000000
0`0000=[f`0000000P0000=[^`0000000P0000=_^`00Ool0UWoo000^Ool30003?cl30002?cl30003
?cl30002?cl30003?cl30003?cl30002?cl30003?cl30002?el30003?el80002Cil:00000fOL0000
000200000f_L00000002000016^k00000000V7oo000aOol40002?cl30002?cl40002?cl30002?cl4
0002?cl30002?cl30003?cl30002?el?0002Agl4000015>n000005^n300000=[_00000000P00VGoo
000eOol/0002?el60002Agl<00000enm0000000300000f?M001Wg00400000f^l001oo`2IOol003]o
o`<0008o?`<000<o?`<0008o?`<0008o?`<000<o?`<0008oG`/000=3Oa400003Gkd0000000D00003
Ik`0000009]oo`00?Woo80000cmO700000=S_@0000001000W7oo0014Ool30002?cl30002?cl30003
?cl30002?el;0002@el90002Bil01@00Cih00000Dkh02@0000AS_@00000009eoo`00Agoo5@000cmO
3@000dMo20000UNn2@00WWoo001<Ool30003?cl30002?el;0002?el60002Agl>000015Nn000005^n
0P00X7oo001?Ool;0002?elS002QOol005Eoo`/0008oG`H00093Oa@00:9oo`00FWoo8P00Y7oo001P
Ool50002@el;0002Bil01P00Cil00000Dih00:Ioo`00IGoo2`000T]o1`00Ygoo001_Ool8002YOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol007Yoo`<00:=oo`00Ngoo00<007ooOol0XWoo000MOol2000017oo000007oo0`00
00=oo`0000000Woo00<007oo00000P0000Ioo`00Ool007oo0002Ool4000017oo001oo`003goo0P00
0Woo0`0000Ioo`00Ool007oo0002Ool2000<Ool30003Ool20002Ool20003Ool30003Ool200000goo
00000002Ool01000Ool0000017oo0P0047oo0`000goo0P0000=oo`0000000Woo00<007ooOol00P00
0Woo0`000goo0P000Woo0`00GGoo000MOol01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`04
001oogoo0002Ool01`00Ool007oo001oo`00009oo`800004Ool007oo000>Ool01000Oomoo`000Woo
00X007ooOol007oo001oo`00Ool000moo`05001oogooOol00006Ool01000Oomoo`000Woo00<007oo
00000Woo00<007oo00000Woo00D007ooOomoo`00009oo`03001oogoo011oo`03001oogoo009oo`06
001oogoo001oo`000Woo00<007oo00000Woo00@007ooOol000=oo`04001oogoo0002Ool00`00Oomo
o`1LOol001eoo`05001oo`00Ool00002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`07001o
o`00Ool007oo00000Woo0P0000Aoo`00Ool000ioo`03001oogoo00=oo`09001oogoo001oo`00Ool0
07oo00<000eoo`04001oogooOol30003Ool01@00Oomoogoo00000Woo00<007oo00000Woo00<007oo
00000Woo00@007ooOol000=oo`<0011oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo
00001Goo00D007ooOomoo`00009oo`04001oogoo001NOol001eoo`800004Ool00000Ool20002Ool4
0002Ool20002Ool200000goo001oo`0200000goo0000000200000goo001oo`0=Ool40002Ool20002
Ool2000017oo001oogoo0`0037oo100000Aoo`00000000=oo`800003Ool00000008000=oo`800003
Ool00000008000=oo`80009oo`<0011oo`<000=oo`800003Ool0000000800003Ool000000080009o
o`@0009oo`8000=oo`03001oogoo05aoo`007Goo0P0000=oo`000000;7oo00<007ooOol0H7oo00<0
07ooOol03Goo00<007ooOol0G7oo000MOol200000goo00000002Ool00`00Oomoo`07Ool00`00Oomo
o`0SOol00`00Oomoo`1YOol2001NOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {173.688, 0}} -> {8.31853, 0.0785682, 
  0.00429921, 0.00429921}},
  CellTags->"12.2"]
}, Open  ]],

Cell[TextData[{
  "Currently, Lyapunov equations can be solved using the direct method (via \
the built\[Hyphen]in function ",
  StyleBox["Solve", "MR"],
  ") or by eigenvalue decomposition. The method to be employed is set using \
the option ",
  StyleBox["SolveMethod", "MR"],
  ", which correspondingly accepts the values ",
  StyleBox["DirectSolve", "MR"],
  " and ",
  StyleBox["Eigendecomposition", "MR"],
  ". If this option's value is ",
  StyleBox["Automatic", "MR"],
  ", these methods are tried in turn until one succeeds or all are tried.  "
}], "Text",
  CellTags->"12.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["SolveMethod",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            StyleBox[\(method\ to\ solve\ the\ equation\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{RowLines->{True, False}},
  CellTags->"12.2"],

Cell["Option specific to Lyapunov equation solvers. ", "Caption",
  CellTags->"12.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["12.3 Rank of Matrix", "Subsection",
  CellTags->"12.3"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Rank",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["m",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["rank",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["m",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  CellTags->"12.3"],

Cell["Determining the rank of matrix. ", "Caption",
  CellTags->"12.3"],

Cell[TextData[{
  "For inexact numerical matrices ",
  StyleBox["m", "TI"],
  ", ",
  StyleBox["Rank", "MR"],
  " counts the nonzero singular values, as obtained through the \
built\[Hyphen]in function ",
  StyleBox["SingularValues", "MR"],
  ". For exact and symbolic matrices, the difference between the number of \
columns of ",
  StyleBox["m", "TI"],
  " and the length of the null space, as obtained through ",
  StyleBox["NullSpace", "MR"],
  ", is used to determine the rank. Correspondingly, ",
  StyleBox["Rank", "MR"],
  " accepts the options pertinent to ",
  StyleBox["SingularValues", "MR"],
  " or ",
  StyleBox["NullSpace", "MR"],
  " and passes them along to these functions. "
}], "Text",
  CellTags->"12.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["12.4 Part Count and Consistency Check", "Subsection",
  CellTags->"12.4"],

Cell[TextData[{
  StyleBox["CountInputs", "MR"],
  ", ",
  StyleBox["CountOutputs", "MR"],
  ", and ",
  StyleBox["CountStates", "MR"],
  " can be used to determine the number of inputs, outputs, or states of the \
system. They are useful in cases when systems change as the result of \
structural operations (say, merging or connecting with others). \
Alternatively, for a system entered manually, you may wish to check that no \
mistakes have been made and that the matrices you entered can really \
represent a system. The following functions help with these chores. "
}], "Text",
  CellTags->"12.4"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["CountInputs",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["number",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["inputs",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]},
          {
            RowBox[{
              StyleBox["CountOutputs",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["number",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["outputs",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]},
          {
            RowBox[{
              StyleBox["CountStates",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["number",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["states",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]},
          {
            RowBox[{
              StyleBox["ConsistentQ",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["determine",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["if",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["elements",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["have",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["dimensions",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["consistent",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["with",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["each",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["other",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  GridBoxOptions->{RowLines->{False, False, True, False}},
  CellTags->"12.4"],

Cell["Checking on the system parameters. ", "Caption",
  CellTags->"12.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["12.5 Displaying Graphics Array Objects Together", "Subsection",
  CellTags->"12.5"],

Cell[TextData[{
  "The function ",
  StyleBox["DisplayTogetherGraphicsArray", "MR"],
  " displays multiple ",
  StyleBox["GraphicsArray", "MR"],
  " objects as one such object and is similar to the function ",
  StyleBox["DisplayTogether", "MR"],
  " from the standard package ",
  StyleBox["Graphics`Graphics`", "MR"],
  ". Input arguments can be either ",
  StyleBox["GraphicsArray", "MR"],
  " objects or any other ",
  StyleBox["Mathematica", "TI"],
  " commands that result in such objects (",
  StyleBox["e.g.", "TI"],
  ", ",
  StyleBox["BodePlot", "MR"],
  "). The function also accepts options pertinent to ",
  StyleBox["GraphicsArray", "MR"],
  ". All input ",
  StyleBox["GraphicsArray", "MR"],
  " objects must have the same dimensions.   "
}], "Text",
  CellTags->"12.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["DisplayTogetherGraphicsArray",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox[
                  FormBox[\(array\_1\),
                    "TraditionalForm"],
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[\(array\_2\),
                    "TraditionalForm"],
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", "\[Ellipsis]", 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["opts",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"12.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              
              StyleBox[
                \(combine\ the\ graphics\ arrays\ that\ result\ from\ the\ 
                  given\ \),
                SingleLetterItalics->False], 
              StyleBox[
                FormBox[
                  SubscriptBox[
                    StyleBox["array",
                      FontSlant->"Italic"], "i"],
                  "TraditionalForm"],
                "Text"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["commands",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["GraphicsArray",
                "MR",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["object",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "BottomBox",
  CellTags->"12.5"],

Cell[TextData[{
  "Displaying ",
  StyleBox["GraphicsArray", "MR"],
  " objects together. "
}], "Caption",
  CellTags->"12.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["12.6 Systems with Random Elements", "Subsection",
  CellTags->"12.6"],

Cell[TextData[{
  "Random yet stable (at least in the sense of Lyapunov) systems can be \
generated using the function ",
  StyleBox["RandomSystem", "MR"],
  " in conjunction with the desired system type\[LongDash]",
  StyleBox["StateSpace", "MR"],
  ", ",
  StyleBox["TransferFunction", "MR"],
  ", or \n",
  StyleBox["ZeroPoleGain", "MR"],
  ". ",
  StyleBox["RandomSystem[", "MR"],
  StyleBox["args", "TI"],
  StyleBox["]", "MR"],
  " is used in place of the actual system contents and causes the parameters \
to be chosen randomly. Such a system may be used to experiment or to check \
the design concepts, for example. "
}], "Text",
  CellTags->"12.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["type",
                "MR",
                FontSlant->"Italic"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["RandomSystem",
                  "MR"], 
                StyleBox["[",
                  "MR"], 
                StyleBox["args",
                  "TI"], 
                StyleBox["]",
                  "MR"]}], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["create",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["random",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["type",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["type",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "TopBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.38, 0.55}},
  CellTags->"12.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["type",
                "MR",
                FontSlant->"Italic"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["var",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                RowBox[{
                  StyleBox["RandomSystem",
                    "MR"], 
                  StyleBox["[",
                    "MR"], 
                  StyleBox["args",
                    "TI"], 
                  StyleBox["]",
                    "MR"]}]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"12.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["use",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["variable",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["var",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["body",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["random",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["transfer",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["function",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.38, 0.55}},
  CellTags->"12.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"RandomSystem", 
                  StyleBox["[",
                    "MR"], 
                  StyleBox["]",
                    "MR"]}],
                "TraditionalForm"],
              "TI"], 
            
            StyleBox[\(random\ first - order\ single - input, \ 
              single - output\ \((SISO)\)\ system\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.38, 0.55}},
  CellTags->"12.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["RandomSystem",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["n",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[
              RowBox[{
                FormBox[\(n\^th\),
                  "TraditionalForm"], 
                StyleBox[\(\(-order\)\ SISO\ system\),
                  SingleLetterItalics->False]}],
              "Text"]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.38, 0.55}},
  CellTags->"12.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["RandomSystem",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["n",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["i",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["o",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox[
                FormBox[\(n\^th\),
                  "TraditionalForm"],
                "Text"], 
              StyleBox[\(-order\),
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["with",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["i",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["inputs",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["and",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["o",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["outputs",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.38, 0.55}},
  CellTags->"12.6"],

Cell["Generating a system with random elements. ", "Caption",
  CellTags->"12.6"],

Cell[TextData[{
  "This creates a random first\[Hyphen]order transfer function in variable ",
  StyleBox["s", "MR"],
  ". "
}], "MathCaption",
  CellTags->"12.6"],

Cell[CellGroupData[{

Cell["TransferFunction[s, RandomSystem[]]", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"12.6"],

Cell[BoxData[
    \(TransferFunction[
      s, {{0.400733494129919787`
            \/\(\(2.40162082490151362`\[InvisibleSpace]\) + s\)}}]\)], 
  "Output",
  CellLabel->"Out[22]= ",
  CellTags->"12.6"]
}, Open  ]],

Cell["\<\
This is a second\[Hyphen]order single\[Hyphen]input, \
two\[Hyphen]output state\[Hyphen]space system. \
\>", "MathCaption",
  CellTags->"12.6"],

Cell[CellGroupData[{

Cell["StateSpace[RandomSystem[2, 1, 2]]", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"12.6"],

Cell[BoxData[
    \(StateSpace[{{\(-1.93888118835320284`\), \(-0.00387746118037205622`\)}, {
          0.344929359641195754`, \(-2.5966902706548125`\)}}, {{
          1.82356835116111959`}, {\(-3.01260834939638488`\)}}, {{
          3.7692283003179785`, 0.228546792366467244`}, {
          \(-3.05821376960453017`\), 3.55685820821710052`}}, {{
          \(-3.05476171520118899`\)}, {4.87885115286424841`}}]\)], "Output",
  CellLabel->"Out[23]= ",
  CellTags->"12.6"]
}, Open  ]],

Cell[TextData[{
  StyleBox["RandomSystem", "MR"],
  " works by creating random matrices of zeros, poles, and gains (for \
transfer function systems) or by creating a block diagonal matrix with \
suitable eigenvalues and then performing linear transformation on that matrix \
to form matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " (for state\[Hyphen]space systems). Almost all of the following options \
listed below (with the exception of ",
  StyleBox["Exact", "MR"],
  ") accept either one value (to be applied to both numerators and \
denominators or to the eigenvalues) or a list of two values to create the \
numerators and denominators according to different rules.  "
}], "Text",
  CellTags->"12.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["Exact",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["False",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(whether\ to\ generate\ an\ infinite - precision\ system\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["ComplexRootProbability",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{"{", 
                  StyleBox["0.33",
                    SingleLetterItalics->False], ",", 
                  StyleBox["0.5",
                    SingleLetterItalics->False], "}"}],
                "StandardForm"],
              "Text"], 
            StyleBox[\(probability\ of\ complex\ roots\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["RealRootProbability",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{"{", 
                  StyleBox["0.33",
                    SingleLetterItalics->False], ",", 
                  StyleBox["Automatic",
                    SingleLetterItalics->False], "}"}],
                "StandardForm"],
              "Text"], 
            StyleBox[\(probability\ of\ real - valued\ roots\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["SpecialPoints",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            StyleBox[\(special\ point\ locations\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["SpecialPointProbability",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{"{", 
                  StyleBox["0.05",
                    SingleLetterItalics->False], ",", 
                  StyleBox["0.1",
                    SingleLetterItalics->False], "}"}],
                "StandardForm"],
              "Text"], 
            StyleBox[\(probability\ of\ special\ points\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["MultipleRootProbability",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{"{", 
                  StyleBox["0.1",
                    SingleLetterItalics->False], ",", 
                  StyleBox["0.2",
                    SingleLetterItalics->False], "}"}],
                "StandardForm"],
              "Text"], 
            StyleBox[\(probability\ of\ multiple\ roots\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["ImaginaryToRealRatio",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            StyleBox[\(mean\ imaginary/real\ ratio\ for\ complex\ roots\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["MappingFunction",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            StyleBox[\(function \((s)\)\ to\ map\ over\ random\ roots\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["ExactConversionFunction",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(additional\ function \((s)\)\ to\ map\ over\ roots\ to\ create
                  \ an\ infinite - precision\ system\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.39, 0.27, 0.34},
  RowLines->{True, False}},
  CellTags->"12.6"],

Cell[TextData[{
  "Options to ",
  StyleBox["RandomSystem", "MR"],
  ". "
}], "Caption",
  CellTags->"12.6"],

Cell[TextData[{
  "If ",
  StyleBox["RealRootProbability", "MR"],
  " is set to ",
  StyleBox["Automatic", "MR"],
  ", then all available root positions that remain after the creation of \
complex roots and special points will be filled with real roots. This is \
usually what one wants in the denominator of a transfer function to ensure \
that the system has the required order, but this is not necessarily the case \
for the numerators. Setting ",
  StyleBox["RealRootProbability", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["Automatic", "MR"],
  " will generate a strictly proper transfer function. \nThe option ",
  StyleBox["SpecialPoints", "MR"],
  " allows the location(s) of some special roots to be specified (to create \
an integrator, for example). The probability of such points in numerators and \
denominators is set by the option ",
  StyleBox["SpecialPointProbability", "MR"],
  ". "
}], "Text",
  CellTags->"12.6"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
ScreenStyleEnvironment->"Working",
WindowSize->{484, 284},
WindowMargins->{{3, Automatic}, {Automatic, 5}},
StyleDefinitions -> "Manual.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "12.0"->{
    Cell[1731, 51, 56, 1, 68, "Section",
      CellTags->"12.0"],
    Cell[1790, 54, 851, 26, 133, "Text",
      CellTags->"12.0"]},
  "12.1"->{
    Cell[2666, 84, 74, 1, 56, "Subsection",
      CellTags->"12.1"],
    Cell[2743, 87, 1142, 31, 190, "Text",
      CellTags->"12.1"],
    Cell[3888, 120, 391, 14, 48, "TopSpanBox",
      CellTags->"12.1"],
    Cell[4282, 136, 2712, 73, 61, "MiddleBox",
      CellTags->"12.1"],
    Cell[6997, 211, 543, 19, 32, "MiddleSpanBox",
      CellTags->"12.1"],
    Cell[7543, 232, 2101, 57, 49, "BottomBox",
      CellTags->"12.1"],
    Cell[9647, 291, 68, 1, 26, "Caption",
      CellTags->"12.1"],
    Cell[9718, 294, 65, 1, 40, "MathCaption",
      CellTags->"12.1"],
    Cell[9786, 297, 78, 2, 39, "Input",
      CellTags->"12.1"],
    Cell[9867, 301, 203, 7, 40, "MathCaption",
      CellTags->"12.1"],
    Cell[10095, 312, 91, 2, 39, "Input",
      CellTags->"12.1"],
    Cell[10189, 316, 318, 6, 68, "Output",
      CellTags->"12.1"],
    Cell[10522, 325, 171, 5, 42, "MathCaption",
      CellTags->"12.1"],
    Cell[10696, 332, 93, 2, 39, "Input",
      CellTags->"12.1"],
    Cell[10792, 336, 126, 4, 40, "MathCaption",
      CellTags->"12.1"],
    Cell[10943, 344, 75, 2, 39, "Input",
      CellTags->"12.1"],
    Cell[11021, 348, 393, 10, 79, "Output",
      CellTags->"12.1"],
    Cell[11429, 361, 218, 7, 58, "MathCaption",
      CellTags->"12.1"],
    Cell[11650, 370, 102, 2, 39, "Input",
      CellTags->"12.1"],
    Cell[11755, 374, 96, 1, 40, "MathCaption",
      CellTags->"12.1"],
    Cell[11876, 379, 82, 2, 39, "Input",
      CellTags->"12.1"],
    Cell[11961, 383, 399, 10, 79, "Output",
      CellTags->"12.1"],
    Cell[12375, 396, 77, 1, 40, "MathCaption",
      CellTags->"12.1"],
    Cell[12477, 401, 115, 2, 54, "Input",
      CellTags->"12.1"],
    Cell[12595, 405, 257, 9, 79, "Output",
      CellTags->"12.1"],
    Cell[12867, 417, 178, 5, 54, "MathCaption",
      CellTags->"12.1"],
    Cell[13048, 424, 112, 2, 54, "Input",
      CellTags->"12.1"],
    Cell[13163, 428, 119, 5, 41, "MathCaption",
      CellTags->"12.1"],
    Cell[13307, 437, 82, 2, 39, "Input",
      CellTags->"12.1"],
    Cell[13392, 441, 395, 10, 79, "Output",
      CellTags->"12.1"],
    Cell[13802, 454, 255, 6, 69, "MathCaption",
      CellTags->"12.1"],
    Cell[14060, 462, 128, 5, 54, "Input",
      CellTags->"12.1"],
    Cell[14213, 471, 83, 2, 39, "Input",
      CellTags->"12.1"],
    Cell[14299, 475, 396, 10, 79, "Output",
      CellTags->"12.1"],
    Cell[14710, 488, 432, 15, 77, "Text",
      CellTags->"12.1"],
    Cell[15145, 505, 812, 25, 84, "DefinitionBox3Col",
      CellTags->"12.1"],
    Cell[15960, 532, 135, 5, 26, "Caption",
      CellTags->"12.1"]},
  "12.2"->{
    Cell[16132, 542, 65, 1, 68, "Subsection",
      CellTags->"12.2"],
    Cell[16200, 545, 336, 13, 44, "Text",
      CellTags->"12.2"],
    Cell[16539, 560, 349, 13, 40, "DisplayFormula",
      CellTags->"12.2"],
    Cell[16891, 575, 1360, 43, 108, "Text",
      CellTags->"12.2"],
    Cell[18254, 620, 383, 14, 44, "DisplayFormula",
      CellTags->"12.2"],
    Cell[18640, 636, 535, 18, 83, "Text",
      CellTags->"12.2"],
    Cell[19178, 656, 383, 14, 44, "DisplayFormula",
      CellTags->"12.2"],
    Cell[19564, 672, 234, 9, 61, "Text",
      CellTags->"12.2"],
    Cell[19801, 683, 772, 25, 76, "TopBox",
      CellTags->"12.2"],
    Cell[20576, 710, 810, 26, 35, "MiddleBox",
      CellTags->"12.2"],
    Cell[21389, 738, 536, 19, 32, "MiddleSpanBox",
      CellTags->"12.2"],
    Cell[21928, 759, 375, 11, 49, "BottomBox",
      CellTags->"12.2"],
    Cell[22306, 772, 81, 1, 26, "Caption",
      CellTags->"12.2"],
    Cell[22390, 775, 110, 5, 41, "MathCaption",
      CellTags->"12.2"],
    Cell[22503, 782, 88, 2, 39, "Input",
      CellTags->"12.2"],
    Cell[22594, 786, 105, 5, 41, "MathCaption",
      CellTags->"12.2"],
    Cell[22702, 793, 86, 2, 39, "Input",
      CellTags->"12.2"],
    Cell[22791, 797, 123, 4, 40, "MathCaption",
      CellTags->"12.2"],
    Cell[22939, 805, 101, 2, 39, "Input",
      CellTags->"12.2"],
    Cell[23043, 809, 193, 4, 54, "Output",
      CellTags->"12.2"],
    Cell[23251, 816, 134, 4, 40, "MathCaption",
      CellTags->"12.2"],
    Cell[23410, 824, 99, 2, 39, "Input",
      CellTags->"12.2"],
    Cell[23512, 828, 84, 3, 38, "Output",
      CellTags->"12.2"],
    Cell[23611, 834, 3492, 115, 140, "Text",
      CellTags->"12.2"],
    Cell[27106, 951, 702, 23, 63, "DisplayFormula",
      CellTags->"12.2"],
    Cell[27811, 976, 457, 16, 54, "MathCaption",
      CellTags->"12.2"],
    Cell[28271, 994, 87, 2, 39, "Input",
      CellTags->"12.2"],
    Cell[28361, 998, 85, 2, 39, "Input",
      CellTags->"12.2"],
    Cell[28449, 1002, 394, 13, 54, "MathCaption",
      CellTags->"12.2"],
    Cell[28868, 1019, 103, 2, 39, "Input",
      CellTags->"12.2"],
    Cell[28974, 1023, 130, 3, 54, "Output",
      CellTags->"12.2"],
    Cell[29119, 1029, 83, 1, 40, "MathCaption",
      CellTags->"12.2"],
    Cell[29227, 1034, 140, 7, 84, "Input",
      CellTags->"12.2"],
    Cell[29370, 1043, 221, 5, 97, "Output",
      CellTags->"12.2"],
    Cell[29606, 1051, 132, 4, 42, "Text",
      CellTags->"12.2"],
    Cell[29741, 1057, 132, 4, 40, "MathCaption",
      CellTags->"12.2"],
    Cell[29898, 1065, 279, 10, 129, "Input",
      CellTags->"12.2"],
    Cell[30180, 1077, 179410, 4273, 194, 133835, 3704, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"12.2"],
    Cell[209605, 5353, 95, 1, 40, "MathCaption",
      CellTags->"12.2"],
    Cell[209725, 5358, 277, 10, 129, "Input",
      CellTags->"12.2"],
    Cell[210005, 5370, 167334, 4107, 195, 133093, 3678, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"12.2"],
    Cell[377354, 9480, 585, 15, 109, "Text",
      CellTags->"12.2"],
    Cell[377942, 9497, 666, 21, 69, "DefinitionBox3Col",
      CellTags->"12.2"],
    Cell[378611, 9520, 85, 1, 26, "Caption",
      CellTags->"12.2"]},
  "12.3"->{
    Cell[378733, 9526, 61, 1, 68, "Subsection",
      CellTags->"12.3"],
    Cell[378797, 9529, 1261, 38, 51, "DefinitionBox",
      CellTags->"12.3"],
    Cell[380061, 9569, 71, 1, 26, "Caption",
      CellTags->"12.3"],
    Cell[380135, 9572, 725, 21, 129, "Text",
      CellTags->"12.3"]},
  "12.4"->{
    Cell[380897, 9598, 79, 1, 68, "Subsection",
      CellTags->"12.4"],
    Cell[380979, 9601, 603, 13, 123, "Text",
      CellTags->"12.4"],
    Cell[381585, 9616, 6169, 177, 139, "DefinitionBox",
      CellTags->"12.4"],
    Cell[387757, 9795, 74, 1, 26, "Caption",
      CellTags->"12.4"]},
  "12.5"->{
    Cell[387868, 9801, 89, 1, 68, "Subsection",
      CellTags->"12.5"],
    Cell[387960, 9804, 785, 23, 130, "Text",
      CellTags->"12.5"],
    Cell[388748, 9829, 888, 29, 49, "TopSpanBox",
      CellTags->"12.5"],
    Cell[389639, 9860, 1350, 38, 50, "BottomBox",
      CellTags->"12.5"],
    Cell[390992, 9900, 126, 5, 26, "Caption",
      CellTags->"12.5"]},
  "12.6"->{
    Cell[391155, 9910, 75, 1, 68, "Subsection",
      CellTags->"12.6"],
    Cell[391233, 9913, 657, 18, 134, "Text",
      CellTags->"12.6"],
    Cell[391893, 9933, 1706, 51, 63, "TopBox",
      CellTags->"12.6"],
    Cell[393602, 9986, 783, 27, 32, "MiddleSpanBox",
      CellTags->"12.6"],
    Cell[394388, 10015, 2144, 58, 48, "MiddleBox",
      CellTags->"12.6"],
    Cell[396535, 10075, 623, 19, 48, "MiddleBox",
      CellTags->"12.6"],
    Cell[397161, 10096, 672, 22, 36, "MiddleBox",
      CellTags->"12.6"],
    Cell[397836, 10120, 2046, 61, 37, "BottomBox",
      CellTags->"12.6"],
    Cell[399885, 10183, 81, 1, 26, "Caption",
      CellTags->"12.6"],
    Cell[399969, 10186, 162, 5, 41, "MathCaption",
      CellTags->"12.6"],
    Cell[400156, 10195, 98, 2, 39, "Input",
      CellTags->"12.6"],
    Cell[400257, 10199, 200, 6, 54, "Output",
      CellTags->"12.6"],
    Cell[400472, 10208, 153, 4, 40, "MathCaption",
      CellTags->"12.6"],
    Cell[400650, 10216, 96, 2, 39, "Input",
      CellTags->"12.6"],
    Cell[400749, 10220, 466, 8, 83, "Output",
      CellTags->"12.6"],
    Cell[401230, 10231, 812, 18, 124, "Text",
      CellTags->"12.6"],
    Cell[402045, 10251, 4508, 135, 335, "DefinitionBox3Col",
      CellTags->"12.6"],
    Cell[406556, 10388, 108, 5, 26, "Caption",
      CellTags->"12.6"],
    Cell[406667, 10395, 945, 23, 167, "Text",
      CellTags->"12.6"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"12.0", 408492, 10444},
  {"12.1", 408637, 10449},
  {"12.2", 411226, 10524},
  {"12.3", 414467, 10615},
  {"12.4", 414772, 10624},
  {"12.5", 415079, 10633},
  {"12.6", 415456, 10644}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 56, 1, 68, "Section",
  CellTags->"12.0"],
Cell[1790, 54, 851, 26, 133, "Text",
  CellTags->"12.0"],

Cell[CellGroupData[{
Cell[2666, 84, 74, 1, 56, "Subsection",
  CellTags->"12.1"],
Cell[2743, 87, 1142, 31, 190, "Text",
  CellTags->"12.1"],
Cell[3888, 120, 391, 14, 48, "TopSpanBox",
  CellTags->"12.1"],
Cell[4282, 136, 2712, 73, 61, "MiddleBox",
  CellTags->"12.1"],
Cell[6997, 211, 543, 19, 32, "MiddleSpanBox",
  CellTags->"12.1"],
Cell[7543, 232, 2101, 57, 49, "BottomBox",
  CellTags->"12.1"],
Cell[9647, 291, 68, 1, 26, "Caption",
  CellTags->"12.1"],
Cell[9718, 294, 65, 1, 40, "MathCaption",
  CellTags->"12.1"],
Cell[9786, 297, 78, 2, 39, "Input",
  CellTags->"12.1"],
Cell[9867, 301, 203, 7, 40, "MathCaption",
  CellTags->"12.1"],

Cell[CellGroupData[{
Cell[10095, 312, 91, 2, 39, "Input",
  CellTags->"12.1"],
Cell[10189, 316, 318, 6, 68, "Output",
  CellTags->"12.1"]
}, Open  ]],
Cell[10522, 325, 171, 5, 42, "MathCaption",
  CellTags->"12.1"],
Cell[10696, 332, 93, 2, 39, "Input",
  CellTags->"12.1"],
Cell[10792, 336, 126, 4, 40, "MathCaption",
  CellTags->"12.1"],

Cell[CellGroupData[{
Cell[10943, 344, 75, 2, 39, "Input",
  CellTags->"12.1"],
Cell[11021, 348, 393, 10, 79, "Output",
  CellTags->"12.1"]
}, Open  ]],
Cell[11429, 361, 218, 7, 58, "MathCaption",
  CellTags->"12.1"],
Cell[11650, 370, 102, 2, 39, "Input",
  CellTags->"12.1"],
Cell[11755, 374, 96, 1, 40, "MathCaption",
  CellTags->"12.1"],

Cell[CellGroupData[{
Cell[11876, 379, 82, 2, 39, "Input",
  CellTags->"12.1"],
Cell[11961, 383, 399, 10, 79, "Output",
  CellTags->"12.1"]
}, Open  ]],
Cell[12375, 396, 77, 1, 40, "MathCaption",
  CellTags->"12.1"],

Cell[CellGroupData[{
Cell[12477, 401, 115, 2, 54, "Input",
  CellTags->"12.1"],
Cell[12595, 405, 257, 9, 79, "Output",
  CellTags->"12.1"]
}, Open  ]],
Cell[12867, 417, 178, 5, 54, "MathCaption",
  CellTags->"12.1"],
Cell[13048, 424, 112, 2, 54, "Input",
  CellTags->"12.1"],
Cell[13163, 428, 119, 5, 41, "MathCaption",
  CellTags->"12.1"],

Cell[CellGroupData[{
Cell[13307, 437, 82, 2, 39, "Input",
  CellTags->"12.1"],
Cell[13392, 441, 395, 10, 79, "Output",
  CellTags->"12.1"]
}, Open  ]],
Cell[13802, 454, 255, 6, 69, "MathCaption",
  CellTags->"12.1"],
Cell[14060, 462, 128, 5, 54, "Input",
  CellTags->"12.1"],

Cell[CellGroupData[{
Cell[14213, 471, 83, 2, 39, "Input",
  CellTags->"12.1"],
Cell[14299, 475, 396, 10, 79, "Output",
  CellTags->"12.1"]
}, Open  ]],
Cell[14710, 488, 432, 15, 77, "Text",
  CellTags->"12.1"],
Cell[15145, 505, 812, 25, 84, "DefinitionBox3Col",
  CellTags->"12.1"],
Cell[15960, 532, 135, 5, 26, "Caption",
  CellTags->"12.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16132, 542, 65, 1, 68, "Subsection",
  CellTags->"12.2"],
Cell[16200, 545, 336, 13, 44, "Text",
  CellTags->"12.2"],
Cell[16539, 560, 349, 13, 40, "DisplayFormula",
  CellTags->"12.2"],
Cell[16891, 575, 1360, 43, 108, "Text",
  CellTags->"12.2"],
Cell[18254, 620, 383, 14, 44, "DisplayFormula",
  CellTags->"12.2"],
Cell[18640, 636, 535, 18, 83, "Text",
  CellTags->"12.2"],
Cell[19178, 656, 383, 14, 44, "DisplayFormula",
  CellTags->"12.2"],
Cell[19564, 672, 234, 9, 61, "Text",
  CellTags->"12.2"],
Cell[19801, 683, 772, 25, 76, "TopBox",
  CellTags->"12.2"],
Cell[20576, 710, 810, 26, 35, "MiddleBox",
  CellTags->"12.2"],
Cell[21389, 738, 536, 19, 32, "MiddleSpanBox",
  CellTags->"12.2"],
Cell[21928, 759, 375, 11, 49, "BottomBox",
  CellTags->"12.2"],
Cell[22306, 772, 81, 1, 26, "Caption",
  CellTags->"12.2"],
Cell[22390, 775, 110, 5, 41, "MathCaption",
  CellTags->"12.2"],
Cell[22503, 782, 88, 2, 39, "Input",
  CellTags->"12.2"],
Cell[22594, 786, 105, 5, 41, "MathCaption",
  CellTags->"12.2"],
Cell[22702, 793, 86, 2, 39, "Input",
  CellTags->"12.2"],
Cell[22791, 797, 123, 4, 40, "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{
Cell[22939, 805, 101, 2, 39, "Input",
  CellTags->"12.2"],
Cell[23043, 809, 193, 4, 54, "Output",
  CellTags->"12.2"]
}, Open  ]],
Cell[23251, 816, 134, 4, 40, "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{
Cell[23410, 824, 99, 2, 39, "Input",
  CellTags->"12.2"],
Cell[23512, 828, 84, 3, 38, "Output",
  CellTags->"12.2"]
}, Open  ]],
Cell[23611, 834, 3492, 115, 140, "Text",
  CellTags->"12.2"],
Cell[27106, 951, 702, 23, 63, "DisplayFormula",
  CellTags->"12.2"],
Cell[27811, 976, 457, 16, 54, "MathCaption",
  CellTags->"12.2"],
Cell[28271, 994, 87, 2, 39, "Input",
  CellTags->"12.2"],
Cell[28361, 998, 85, 2, 39, "Input",
  CellTags->"12.2"],
Cell[28449, 1002, 394, 13, 54, "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{
Cell[28868, 1019, 103, 2, 39, "Input",
  CellTags->"12.2"],
Cell[28974, 1023, 130, 3, 54, "Output",
  CellTags->"12.2"]
}, Open  ]],
Cell[29119, 1029, 83, 1, 40, "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{
Cell[29227, 1034, 140, 7, 84, "Input",
  CellTags->"12.2"],
Cell[29370, 1043, 221, 5, 97, "Output",
  CellTags->"12.2"]
}, Open  ]],
Cell[29606, 1051, 132, 4, 42, "Text",
  CellTags->"12.2"],
Cell[29741, 1057, 132, 4, 40, "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{
Cell[29898, 1065, 279, 10, 129, "Input",
  CellTags->"12.2"],
Cell[30180, 1077, 179410, 4273, 194, 133835, 3704, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"12.2"]
}, Open  ]],
Cell[209605, 5353, 95, 1, 40, "MathCaption",
  CellTags->"12.2"],

Cell[CellGroupData[{
Cell[209725, 5358, 277, 10, 129, "Input",
  CellTags->"12.2"],
Cell[210005, 5370, 167334, 4107, 195, 133093, 3678, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"12.2"]
}, Open  ]],
Cell[377354, 9480, 585, 15, 109, "Text",
  CellTags->"12.2"],
Cell[377942, 9497, 666, 21, 69, "DefinitionBox3Col",
  CellTags->"12.2"],
Cell[378611, 9520, 85, 1, 26, "Caption",
  CellTags->"12.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[378733, 9526, 61, 1, 68, "Subsection",
  CellTags->"12.3"],
Cell[378797, 9529, 1261, 38, 51, "DefinitionBox",
  CellTags->"12.3"],
Cell[380061, 9569, 71, 1, 26, "Caption",
  CellTags->"12.3"],
Cell[380135, 9572, 725, 21, 129, "Text",
  CellTags->"12.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[380897, 9598, 79, 1, 68, "Subsection",
  CellTags->"12.4"],
Cell[380979, 9601, 603, 13, 123, "Text",
  CellTags->"12.4"],
Cell[381585, 9616, 6169, 177, 139, "DefinitionBox",
  CellTags->"12.4"],
Cell[387757, 9795, 74, 1, 26, "Caption",
  CellTags->"12.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[387868, 9801, 89, 1, 68, "Subsection",
  CellTags->"12.5"],
Cell[387960, 9804, 785, 23, 130, "Text",
  CellTags->"12.5"],
Cell[388748, 9829, 888, 29, 49, "TopSpanBox",
  CellTags->"12.5"],
Cell[389639, 9860, 1350, 38, 50, "BottomBox",
  CellTags->"12.5"],
Cell[390992, 9900, 126, 5, 26, "Caption",
  CellTags->"12.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[391155, 9910, 75, 1, 68, "Subsection",
  CellTags->"12.6"],
Cell[391233, 9913, 657, 18, 134, "Text",
  CellTags->"12.6"],
Cell[391893, 9933, 1706, 51, 63, "TopBox",
  CellTags->"12.6"],
Cell[393602, 9986, 783, 27, 32, "MiddleSpanBox",
  CellTags->"12.6"],
Cell[394388, 10015, 2144, 58, 48, "MiddleBox",
  CellTags->"12.6"],
Cell[396535, 10075, 623, 19, 48, "MiddleBox",
  CellTags->"12.6"],
Cell[397161, 10096, 672, 22, 36, "MiddleBox",
  CellTags->"12.6"],
Cell[397836, 10120, 2046, 61, 37, "BottomBox",
  CellTags->"12.6"],
Cell[399885, 10183, 81, 1, 26, "Caption",
  CellTags->"12.6"],
Cell[399969, 10186, 162, 5, 41, "MathCaption",
  CellTags->"12.6"],

Cell[CellGroupData[{
Cell[400156, 10195, 98, 2, 39, "Input",
  CellTags->"12.6"],
Cell[400257, 10199, 200, 6, 54, "Output",
  CellTags->"12.6"]
}, Open  ]],
Cell[400472, 10208, 153, 4, 40, "MathCaption",
  CellTags->"12.6"],

Cell[CellGroupData[{
Cell[400650, 10216, 96, 2, 39, "Input",
  CellTags->"12.6"],
Cell[400749, 10220, 466, 8, 83, "Output",
  CellTags->"12.6"]
}, Open  ]],
Cell[401230, 10231, 812, 18, 124, "Text",
  CellTags->"12.6"],
Cell[402045, 10251, 4508, 135, 335, "DefinitionBox3Col",
  CellTags->"12.6"],
Cell[406556, 10388, 108, 5, 26, "Caption",
  CellTags->"12.6"],
Cell[406667, 10395, 945, 23, 167, "Text",
  CellTags->"12.6"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

